/* Generated by Cython 0.29.23 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "pyteomics/compat.h"
        ],
        "include_dirs": [
            "./pyteomics"
        ],
        "name": "pyteomics.cparser",
        "sources": [
            "pyteomics/cparser.pyx"
        ]
    },
    "module_name": "pyteomics.cparser"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_23"
#define CYTHON_HEX_VERSION 0x001D17F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pyteomics__cparser
#define __PYX_HAVE_API__pyteomics__cparser
/* Early includes */
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "compat.h"
#include <ctype.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "pyteomics/cparser.pyx",
  "stringsource",
  "type.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_9pyteomics_7cparser_SequencePosition;
struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator;
struct __pyx_obj_9pyteomics_7cparser_ModificationRule;
struct __pyx_obj_9pyteomics_7cparser_ModificationTarget;
struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate;
struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms;
struct __pyx_obj___Pyx_EnumMeta;
struct __pyx_opt_args_9pyteomics_7cparser_parse;
struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition;
struct __pyx_opt_args_9pyteomics_7cparser_tostring;
struct __pyx_opt_args_9pyteomics_7cparser_length;
struct __pyx_opt_args_9pyteomics_7cparser__tokenize_modx_sequence;
struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring;
struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map;

/* "pyteomics/cparser.pxd":17
 * 
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=*, bint split=*,             # <<<<<<<<<<<<<<
 *                  bint allow_unknown_modifications=*, object  labels=*)
 * 
 */
struct __pyx_opt_args_9pyteomics_7cparser_parse {
  int __pyx_n;
  int show_unmodified_termini;
  int split;
  int allow_unknown_modifications;
  PyObject *labels;
};

/* "pyteomics/cparser.pxd":20
 *                  bint allow_unknown_modifications=*, object  labels=*)
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=*, bint term_aa=*,             # <<<<<<<<<<<<<<
 *                                   bint allow_unknown_modifications=*, object labels=*)
 * 
 */
struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition {
  int __pyx_n;
  int show_unmodified_termini;
  int term_aa;
  int allow_unknown_modifications;
  PyObject *labels;
};

/* "pyteomics/cparser.pxd":25
 * cpdef tuple _split_label(str label)
 * 
 * cpdef str tostring(object parsed_sequence, bint show_unmodified_termini=*)             # <<<<<<<<<<<<<<
 */
struct __pyx_opt_args_9pyteomics_7cparser_tostring {
  int __pyx_n;
  int show_unmodified_termini;
};

/* "pyteomics/cparser.pyx":677
 * 
 * 
 * cpdef enum PositionType:             # <<<<<<<<<<<<<<
 *     n_term = 1
 *     c_term = 2
 */
enum __pyx_t_9pyteomics_7cparser_PositionType {
  __pyx_e_9pyteomics_7cparser_n_term = 1,
  __pyx_e_9pyteomics_7cparser_c_term = 2,
  __pyx_e_9pyteomics_7cparser_internal = 3,
  __pyx_e_9pyteomics_7cparser_universal = 4
};

/* "pyteomics/cparser.pyx":118
 *     return bool(match_modX(label))
 * 
 * cpdef int length(object sequence,             # <<<<<<<<<<<<<<
 *                  int show_unmodified_termini=0, int split=0,
 *                  int allow_unknown_modifications=0, object labels=std_labels):
 */
struct __pyx_opt_args_9pyteomics_7cparser_length {
  int __pyx_n;
  int show_unmodified_termini;
  int split;
  int allow_unknown_modifications;
  PyObject *labels;
};

/* "pyteomics/cparser.pyx":375
 * 
 * 
 * cdef list _tokenize_modx_sequence(str sequence, bint split=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         char* csequence
 */
struct __pyx_opt_args_9pyteomics_7cparser__tokenize_modx_sequence {
  int __pyx_n;
  int split;
};

/* "pyteomics/cparser.pyx":908
 * 
 * 
 * cpdef str _sequence_tostring(list sequence, bint show_unmodified_termini=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         size_t i, n, acc, j
 */
struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring {
  int __pyx_n;
  int show_unmodified_termini;
};

/* "pyteomics/cparser.pyx":1069
 *         return sequence
 * 
 *     cpdef dict build_site_map(self, list sequence, bint include_unmodified=True):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */
struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map {
  int __pyx_n;
  int include_unmodified;
};

/* "pyteomics/cparser.pyx":700
 * @cython.final
 * @cython.freelist(5000)
 * cdef class SequencePosition(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str modification
 */
struct __pyx_obj_9pyteomics_7cparser_SequencePosition {
  PyObject_HEAD
  struct __pyx_vtabstruct_9pyteomics_7cparser_SequencePosition *__pyx_vtab;
  PyObject *modification;
  enum __pyx_t_9pyteomics_7cparser_PositionType position_type;
  PyObject *amino_acid;
  PyObject *terminal;
};


/* "pyteomics/cparser.pyx":990
 * 
 * @cython.freelist(100)
 * cdef class IsoformGenerator(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public dict variable_mods
 */
struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator {
  PyObject_HEAD
  struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *__pyx_vtab;
  PyObject *variable_mods;
  PyObject *fixed_mods;
  PyObject *labels;
  long max_mods;
  int override;
  int show_unmodified_termini;
  int persist;
  PyObject *sequence;
  PyObject *original_sequence;
  PyObject *last_indices;
};


/* "pyteomics/cparser.pyx":1212
 * 
 * @cython.freelist(100)
 * cdef class ModificationRule(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str modification
 */
struct __pyx_obj_9pyteomics_7cparser_ModificationRule {
  PyObject_HEAD
  struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule *__pyx_vtab;
  PyObject *modification;
  PyObject *targets;
};


/* "pyteomics/cparser.pyx":1243
 * 
 * @cython.freelist(1000)
 * cdef class ModificationTarget(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str target
 */
struct __pyx_obj_9pyteomics_7cparser_ModificationTarget {
  PyObject_HEAD
  struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget *__pyx_vtab;
  PyObject *target;
  enum __pyx_t_9pyteomics_7cparser_PositionType position_type;
};


/* "pyteomics/cparser.pyx":1108
 * 
 *     @cython.boundscheck(False)
 *     def generate(self, sequence_spec):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list sequence
 */
struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate {
  PyObject_HEAD
  PyObject *__pyx_v_a;
  PyObject *__pyx_v_assignment;
  PyObject *__pyx_v_assignments;
  PyObject *__pyx_v_assignments_product;
  size_t __pyx_v_i;
  PyObject *__pyx_v_indices;
  size_t __pyx_v_j;
  size_t __pyx_v_k;
  size_t __pyx_v_n;
  size_t __pyx_v_n_mods;
  long *__pyx_v_pindices;
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self;
  PyObject *__pyx_v_sequence;
  PyObject *__pyx_v_sequence_spec;
  PyObject *__pyx_v_subassignments;
  PyObject *__pyx_v_subindices;
  PyObject *__pyx_v_temp1;
  PyObject *__pyx_v_temp2;
  PyObject *__pyx_v_variable_mod_sites;
  Py_ssize_t __pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3;
  size_t __pyx_t_4;
  long __pyx_t_5;
  long __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
};


/* "pyteomics/cparser.pyx":1310
 * 
 * 
 * def isoforms(str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *     cdef:
 *         IsoformGenerator isoform_generator
 */
struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms {
  PyObject_HEAD
  PyObject *__pyx_v__format;
  PyObject *__pyx_v_fixed_mods;
  PyObject *__pyx_v_form;
  PyObject *__pyx_v_gen;
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_isoform_generator;
  PyObject *__pyx_v_kwargs;
  PyObject *__pyx_v_labels;
  PyObject *__pyx_v_max_mods;
  PyObject *__pyx_v_override;
  PyObject *__pyx_v_sequence;
  PyObject *__pyx_v_show_unmodified_termini;
  PyObject *__pyx_v_variable_mods;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "EnumBase":15
 * 
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):             # <<<<<<<<<<<<<<
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 */
struct __pyx_obj___Pyx_EnumMeta {
  PyHeapTypeObject __pyx_base;
};



/* "pyteomics/cparser.pyx":700
 * @cython.final
 * @cython.freelist(5000)
 * cdef class SequencePosition(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str modification
 */

struct __pyx_vtabstruct_9pyteomics_7cparser_SequencePosition {
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *(*_create)(PyObject *, PyObject *, PyObject *, enum __pyx_t_9pyteomics_7cparser_PositionType);
  PyObject *(*get_index)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, long, int __pyx_skip_dispatch);
  size_t (*get_size)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
  int (*is_modified)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
  PyObject *(*add_modification)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*as_tuple)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch);
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *(*copy)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
  int (*_eq)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
  int (*_eq_tuple)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *);
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_SequencePosition *__pyx_vtabptr_9pyteomics_7cparser_SequencePosition;
static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition__create(PyObject *, PyObject *, PyObject *, enum __pyx_t_9pyteomics_7cparser_PositionType);
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_get_index(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, long, int __pyx_skip_dispatch);
static size_t __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
static int __pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch);
static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *);
static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *);


/* "pyteomics/cparser.pyx":990
 * 
 * @cython.freelist(100)
 * cdef class IsoformGenerator(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public dict variable_mods
 */

struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator {
  PyObject *(*coerce_modification_dict)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*initialize_from_str)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*initialize_from_iterable)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*apply_fixed_mods)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*build_site_map)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map *__pyx_optional_args);
  void (*_reset_sequence)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *);
  PyObject *(*__pyx_fuse_0_apply_variable_assignment)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, long *, PyObject *, size_t);
  PyObject *(*__pyx_fuse_1_apply_variable_assignment)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, long *, PyObject *, size_t);
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *__pyx_vtabptr_9pyteomics_7cparser_IsoformGenerator;


/* "pyteomics/cparser.pyx":1212
 * 
 * @cython.freelist(100)
 * cdef class ModificationRule(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str modification
 */

struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule {
  int (*test)(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule *__pyx_vtabptr_9pyteomics_7cparser_ModificationRule;


/* "pyteomics/cparser.pyx":1243
 * 
 * @cython.freelist(1000)
 * cdef class ModificationTarget(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         public str target
 */

struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget {
  int (*test)(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch);
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *(*_create)(PyObject *, enum __pyx_t_9pyteomics_7cparser_PositionType);
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *(*_from_string)(PyObject *);
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget *__pyx_vtabptr_9pyteomics_7cparser_ModificationTarget;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* bytes_tailmatch.proto */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction);
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction);

/* unicode_tailmatch.proto */
static int __Pyx_PyUnicode_Tailmatch(
    PyObject* s, PyObject* substr, Py_ssize_t start, Py_ssize_t end, int direction);

/* str_tailmatch.proto */
static CYTHON_INLINE int __Pyx_PyStr_Tailmatch(PyObject* self, PyObject* arg, Py_ssize_t start,
                                               Py_ssize_t end, int direction);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* pop_index.proto */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix);
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix);
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (likely(PyList_CheckExact(L) && __Pyx_fits_Py_ssize_t(ix, type, is_signed))) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    __Pyx_fits_Py_ssize_t(ix, type, is_signed) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#else
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)\
    __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
        __Pyx__PyObject_PopIndex(L, py_ix))
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* py_dict_items.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* ClassMethod.proto */
#include "descrobject.h"
static CYTHON_UNUSED PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(enum __pyx_t_9pyteomics_7cparser_PositionType value);

/* CIntFromPy.proto */
static CYTHON_INLINE enum __pyx_t_9pyteomics_7cparser_PositionType __Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition__create(PyObject *__pyx_v_amino_acid, PyObject *__pyx_v_modification, PyObject *__pyx_v_terminal, enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_get_index(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, long __pyx_v_i, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static size_t __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto*/
static int __pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_mod, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto*/
static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_other); /* proto*/
static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_coerce_modification_dict(CYTHON_UNUSED struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_source, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_str(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_iterable(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_apply_fixed_mods(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_build_site_map(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map *__pyx_optional_args); /* proto*/
static PyObject *__pyx_fuse_0__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, long *__pyx_v_indices, PyObject *__pyx_v_assignment, size_t __pyx_v_n); /* proto*/
static PyObject *__pyx_fuse_1__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, long *__pyx_v_indices, PyObject *__pyx_v_assignment, size_t __pyx_v_n); /* proto*/
static void __pyx_f_9pyteomics_7cparser_16IsoformGenerator__reset_sequence(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto*/
static int __pyx_f_9pyteomics_7cparser_16ModificationRule_test(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_9pyteomics_7cparser_18ModificationTarget_test(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_f_9pyteomics_7cparser_18ModificationTarget__create(PyObject *__pyx_v_target, enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type); /* proto*/
static struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_f_9pyteomics_7cparser_18ModificationTarget__from_string(PyObject *__pyx_v_string); /* proto*/

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'cython' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.iterator' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.int' */

/* Module declarations from 'cpython.float' */

/* Module declarations from 'cpython.list' */

/* Module declarations from 'cpython.tuple' */

/* Module declarations from 'cpython.sequence' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'pyteomics.ccompat' */

/* Module declarations from 'pyteomics.cparser' */
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser_SequencePosition = 0;
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser_IsoformGenerator = 0;
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser_ModificationRule = 0;
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser_ModificationTarget = 0;
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser___pyx_scope_struct__generate = 0;
static PyTypeObject *__pyx_ptype_9pyteomics_7cparser___pyx_scope_struct_1_isoforms = 0;
static PyTypeObject *__pyx_ptype___Pyx_EnumMeta = 0;
static PyObject *__pyx_v_9pyteomics_7cparser_std_amino_acids = 0;
static PyObject *__pyx_v_9pyteomics_7cparser_std_labels = 0;
static PyObject *__pyx_v_9pyteomics_7cparser_std_nterm = 0;
static PyObject *__pyx_v_9pyteomics_7cparser_std_cterm = 0;
static PyObject *__pyx_v_9pyteomics_7cparser__modX_sequence = 0;
static PyObject *__pyx_v_9pyteomics_7cparser__modX_group = 0;
static PyObject *__pyx_v_9pyteomics_7cparser__modX_split = 0;
static PyObject *__pyx_v_9pyteomics_7cparser__modX_split_findall = 0;
static PyObject *__Pyx_OrderedDict = 0;
static PyObject *__Pyx_EnumBase = 0;
static PyObject *__Pyx_globals = 0;
static PyObject *__pyx_f_9pyteomics_7cparser_parse(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_parse *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_amino_acid_composition(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition *__pyx_optional_args); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser__split_label(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_tostring(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_tostring *__pyx_optional_args); /*proto*/
static int __pyx_f_9pyteomics_7cparser_is_term_mod(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser_match_modX(PyObject *); /*proto*/
static int __pyx_f_9pyteomics_7cparser_length(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_length *__pyx_optional_args); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser_interpolate_labels(PyObject *); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser__tokenize_modx_sequence(PyObject *, struct __pyx_opt_args_9pyteomics_7cparser__tokenize_modx_sequence *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser__sequence_tostring(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_copy_sequence(PyObject *, int __pyx_skip_dispatch); /*proto*/
static int __pyx_f_9pyteomics_7cparser__is_nterm_mod(PyObject *); /*proto*/
static int __pyx_f_9pyteomics_7cparser__is_cterm_mod(PyObject *); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_SequencePosition__set_state(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_IsoformGenerator__set_state(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationRule__set_state(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *, PyObject *); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationTarget__set_state(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *, PyObject *); /*proto*/
static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "pyteomics.cparser"
extern int __pyx_module_is_main_pyteomics__cparser;
int __pyx_module_is_main_pyteomics__cparser = 0;

/* Implementation of 'pyteomics.cparser' */
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_ValueError;
static const char __pyx_k_[] = "-";
static const char __pyx_k_A[] = "A";
static const char __pyx_k_C[] = "C";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_E[] = "E";
static const char __pyx_k_F[] = "F";
static const char __pyx_k_G[] = "G";
static const char __pyx_k_H[] = "H";
static const char __pyx_k_I[] = "I";
static const char __pyx_k_K[] = "K";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_N[] = "N";
static const char __pyx_k_P[] = "P";
static const char __pyx_k_Q[] = "Q";
static const char __pyx_k_R[] = "R";
static const char __pyx_k_S[] = "S";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_V[] = "V";
static const char __pyx_k_W[] = "W";
static const char __pyx_k_Y[] = "Y";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_OH[] = "-OH";
static const char __pyx_k__3[] = "";
static const char __pyx_k_it[] = "it";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_H_2[] = "H-";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_dct[] = "dct";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_gen[] = "gen";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_s_s[] = "%s.%s";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_enum[] = "enum";
static const char __pyx_k_form[] = "form";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_repr[] = "__repr__";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_test[] = "test";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_cterm[] = "cterm";
static const char __pyx_k_deque[] = "deque";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_label[] = "label";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_nterm[] = "nterm";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_s_s_d[] = "<%s.%s: %d>";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_str_2[] = "__str__";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_c_term[] = "c_term";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_groups[] = "groups";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_labels[] = "labels";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_n_term[] = "n_term";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_target[] = "target";
static const char __pyx_k_test_2[] = "__test__";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_A_Z_A_Z[] = "^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$";
static const char __pyx_k_IntEnum[] = "IntEnum";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_findall[] = "findall";
static const char __pyx_k_members[] = "__members__";
static const char __pyx_k_memoize[] = "memoize";
static const char __pyx_k_parents[] = "parents";
static const char __pyx_k_persist[] = "persist";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_product[] = "product";
static const char __pyx_k_targets[] = "targets";
static const char __pyx_k_term_aa[] = "term_aa";
static const char __pyx_k_EnumBase[] = "EnumBase";
static const char __pyx_k_EnumType[] = "EnumType";
static const char __pyx_k_format_2[] = "_format";
static const char __pyx_k_generate[] = "generate";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_internal[] = "internal";
static const char __pyx_k_isoforms[] = "isoforms";
static const char __pyx_k_max_mods[] = "max_mods";
static const char __pyx_k_override[] = "override";
static const char __pyx_k_position[] = "position";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_sequence[] = "sequence";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_terminal[] = "terminal";
static const char __pyx_k_A_Z_A_Z_2[] = "[^A-Z-]*[A-Z]";
static const char __pyx_k_A_Z_A_Z_3[] = "([^A-Z-]*)([A-Z])";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_itertools[] = "itertools";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_universal[] = "universal";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_amino_acid[] = "amino_acid";
static const char __pyx_k_fixed_mods[] = "fixed_mods";
static const char __pyx_k_from_tuple[] = "from_tuple";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_OrderedDict[] = "OrderedDict";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_from_string[] = "from_string";
static const char __pyx_k_PositionType[] = "PositionType";
static const char __pyx_k_Pyx_EnumBase[] = "__Pyx_EnumBase";
static const char __pyx_k_combinations[] = "combinations";
static const char __pyx_k_modification[] = "modification";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_staticmethod[] = "staticmethod";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_Unknown_label[] = "Unknown label: {}";
static const char __pyx_k_from_iterable[] = "from_iterable";
static const char __pyx_k_position_type[] = "position_type";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_sequence_spec[] = "sequence_spec";
static const char __pyx_k_variable_mods[] = "variable_mods";
static const char __pyx_k_PyteomicsError[] = "PyteomicsError";
static const char __pyx_k_build_site_map[] = "build_site_map";
static const char __pyx_k_parse_line_211[] = "parse (line 211)";
static const char __pyx_k_length_line_118[] = "length (line 118)";
static const char __pyx_k_parsed_sequence[] = "parsed_sequence";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_BasicComposition[] = "BasicComposition";
static const char __pyx_k_IsoformGenerator[] = "IsoformGenerator";
static const char __pyx_k_ModificationRule[] = "ModificationRule";
static const char __pyx_k_SequencePosition[] = "SequencePosition";
static const char __pyx_k_apply_fixed_mods[] = "apply_fixed_mods";
static const char __pyx_k_isoform_generator[] = "isoform_generator";
static const char __pyx_k_pyteomics_cparser[] = "pyteomics.cparser";
static const char __pyx_k_ModificationTarget[] = "ModificationTarget";
static const char __pyx_k_Pyx_EnumBase___new[] = "__Pyx_EnumBase.__new__";
static const char __pyx_k_Pyx_EnumBase___str[] = "__Pyx_EnumBase.__str__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_include_unmodified[] = "include_unmodified";
static const char __pyx_k_Pyx_EnumBase___repr[] = "__Pyx_EnumBase.__repr__";
static const char __pyx_k_initialize_from_str[] = "initialize_from_str";
static const char __pyx_k_pyteomics_auxiliary[] = "pyteomics.auxiliary";
static const char __pyx_k_Unknown_enum_value_s[] = "Unknown enum value: '%s'";
static const char __pyx_k_pyteomics_cparser_pyx[] = "pyteomics/cparser.pyx";
static const char __pyx_k_show_unmodified_termini[] = "show_unmodified_termini";
static const char __pyx_k_coerce_modification_dict[] = "coerce_modification_dict";
static const char __pyx_k_initialize_from_iterable[] = "initialize_from_iterable";
static const char __pyx_k_IsoformGenerator_generate[] = "IsoformGenerator.generate";
static const char __pyx_k_Not_a_valid_modX_sequence[] = "Not a valid modX sequence: ";
static const char __pyx_k_Unsupported_value_of_format[] = "Unsupported value of \"format\": {}";
static const char __pyx_k_allow_unknown_modifications[] = "allow_unknown_modifications";
static const char __pyx_k_pyx_unpickle___Pyx_EnumMeta[] = "__pyx_unpickle___Pyx_EnumMeta";
static const char __pyx_k_Unsupported_type_of_sequence[] = "Unsupported type of sequence.";
static const char __pyx_k_pyx_unpickle_IsoformGenerator[] = "__pyx_unpickle_IsoformGenerator";
static const char __pyx_k_pyx_unpickle_ModificationRule[] = "__pyx_unpickle_ModificationRule";
static const char __pyx_k_pyx_unpickle_SequencePosition[] = "__pyx_unpickle_SequencePosition";
static const char __pyx_k_pyx_unpickle_ModificationTarge[] = "__pyx_unpickle_ModificationTarget";
static const char __pyx_k_Cannot_split_a_non_modX_label_s[] = "Cannot split a non-modX label: %s";
static const char __pyx_k_Parse_a_sequence_string_written[] = "Parse a sequence string written in modX notation into a list of\n    labels or (if `split` argument is :py:const:`True`) into a list of\n    tuples representing amino acid residues and their modifications.\n\n    Parameters\n    ----------\n    sequence : str\n        The sequence of a polypeptide.\n    show_unmodified_termini : bool, optional\n        If :py:const:`True` then the unmodified N- and C-termini are explicitly\n        shown in the returned list. Default value is :py:const:`False`.\n    split : bool, optional\n        If :py:const:`True` then the result will be a list of tuples with 1 to 4\n        elements: terminal modification, modification, residue. Default value is\n        :py:const:`False`.\n    allow_unknown_modifications : bool, optional\n        If :py:const:`True` then do not raise an exception when an unknown\n        modification of a known amino acid residue is found in the sequence.\n        This also includes terminal groups.\n        Default value is :py:const:`False`.\n\n        .. note::\n            Since version 2.5, this parameter has effect only if `labels`\n            are provided.\n    labels : container, optional\n        A container of allowed labels for amino acids,\n        modifications and terminal modifications.\n        If not provided, no checks will be done.\n        Separate labels for modifications (such as 'p' or 'ox')\n        can be supplied, which means they are applicable to all residues.\n\n        .. warning::\n            If `show_unmodified_termini` is set to :py:const:`True`, standard\n            terminal groups need to be present in `labels`.\n\n        .. warning::\n            Avoid using sequences with only one terminal group, as they are\n            ambiguous. If you provide one, `labels` (or :py:const:`std_labels`)\n            will be used to resolve the ambiguity.\n\n    Returns\n    -------\n    out : list\n        List of tuples with labels of modifications and amino acid residues.\n\n    Examp""les\n    --------\n    >>> parse('PEPTIDE', split=True)\n    [('P',), ('E',), ('P',), ('T',), ('I',), ('D',), ('E',)]\n    >>> parse('H-PEPTIDE')\n    ['P', 'E', 'P', 'T', 'I', 'D', 'E']\n    >>> parse('PEPTIDE', show_unmodified_termini=True)\n    ['H-', 'P', 'E', 'P', 'T', 'I', 'D', 'E', '-OH']\n    >>> parse('TEpSToxM', labels=std_labels + ['pS', 'oxM'])\n    ['T', 'E', 'pS', 'T', 'oxM']\n    >>> parse('zPEPzTIDzE', True, True, labels=std_labels+['z'])\n    [('H-', 'z', 'P'), ('E',), ('P',), ('z', 'T'), ('I',), ('D',), ('z', 'E', '-OH')]\n    ";
static const char __pyx_k_amino_acid_composition_line_566[] = "amino_acid_composition (line 566)";
static const char __pyx_k_self___class_____name___self_mo[] = "{self.__class__.__name__}({self.modification!r}, {self.targets})";
static const char __pyx_k_self___class_____name___self_ta[] = "{self.__class__.__name__}({self.target!r}, {self.position_type!r})";
static const char __pyx_k_Calculate_amino_acid_composition[] = "Calculate amino acid composition of a polypeptide.\n\n    Parameters\n    ----------\n    sequence : str or list\n        The sequence of a polypeptide or a list with a parsed sequence.\n    show_unmodified_termini : bool, optional\n        If :py:const:`True` then the unmodified N- and C-terminus are explicitly\n        shown in the returned dict. Default value is :py:const:`False`.\n    term_aa : bool, optional\n        If :py:const:`True` then the terminal amino acid residues are\n        artificially modified with `nterm` or `cterm` modification.\n        Default value is :py:const:`False`.\n    allow_unknown_modifications : bool, optional\n        If :py:const:`True` then do not raise an exception when an unknown\n        modification of a known amino acid residue is found in the sequence.\n        Default value is :py:const:`False`.\n    labels : list, optional\n        A list of allowed labels for amino acids and terminal modifications.\n\n    Returns\n    -------\n    out : dict\n        A dictionary of amino acid composition.\n\n    Examples\n    --------\n    >>> amino_acid_composition('PEPTIDE') ==     {'I': 1, 'P': 2, 'E': 2, 'T': 1, 'D': 1}\n    True\n    >>> amino_acid_composition('PEPTDE', term_aa=True) ==     {'ctermE': 1, 'E': 1, 'D': 1, 'P': 1, 'T': 1, 'ntermP': 1}\n    True\n    >>> amino_acid_composition('PEPpTIDE', labels=std_labels+['pT']) ==     {'I': 1, 'P': 2, 'E': 2, 'D': 1, 'pT': 1}\n    True\n    ";
static const char __pyx_k_Calculate_the_number_of_amino_ac[] = "Calculate the number of amino acid residues in a polypeptide\n    written in modX notation.\n\n    Parameters\n    ----------\n    sequence : str or list or dict\n        A string with a polypeptide sequence, a list with a parsed sequence or\n        a dict of amino acid composition.\n    labels : list, optional\n        A list of allowed labels for amino acids and terminal modifications.\n\n    Examples\n    --------\n    >>> length('PEPTIDE')\n    7\n    >>> length('H-PEPTIDE-OH')\n    7\n    ";
static const char __pyx_k_Incompatible_checksums_s_vs_0x2f[] = "Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x5a[] = "Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x96[] = "Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))";
static const char __pyx_k_Incompatible_checksums_s_vs_0xc8[] = "Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))";
static const char __pyx_k_Incompatible_checksums_s_vs_0xd4[] = "Incompatible checksums (%s vs 0xd41d8cd = ())";
static const char __pyx_k_Position_already_has_position_ty[] = "Position already has position type %s, second type provided %s";
static const char __pyx_k_Target_must_be_a_single_Amino_Ac[] = "Target must be a single Amino Acid, got %s";
static const char __pyx_k_Terminal_Modifications_with_Targ[] = "Terminal Modifications with Target must be a single Amino Acid, got %s";
static const char __pyx_k_Unsupported_type_of_a_sequence_M[] = "Unsupported type of a sequence.Must be str or list, not %s";
static PyObject *__pyx_kp_s_;
static PyObject *__pyx_n_s_A;
static PyObject *__pyx_kp_s_A_Z_A_Z;
static PyObject *__pyx_kp_s_A_Z_A_Z_2;
static PyObject *__pyx_kp_s_A_Z_A_Z_3;
static PyObject *__pyx_n_s_BasicComposition;
static PyObject *__pyx_n_s_C;
static PyObject *__pyx_kp_u_Calculate_amino_acid_composition;
static PyObject *__pyx_kp_u_Calculate_the_number_of_amino_ac;
static PyObject *__pyx_kp_s_Cannot_split_a_non_modX_label_s;
static PyObject *__pyx_n_s_D;
static PyObject *__pyx_n_s_E;
static PyObject *__pyx_n_s_EnumBase;
static PyObject *__pyx_n_s_EnumType;
static PyObject *__pyx_n_s_F;
static PyObject *__pyx_n_s_G;
static PyObject *__pyx_n_s_H;
static PyObject *__pyx_kp_s_H_2;
static PyObject *__pyx_n_s_I;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x2f;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x5a;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x96;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xc8;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xd4;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_n_s_IntEnum;
static PyObject *__pyx_n_s_IsoformGenerator;
static PyObject *__pyx_n_s_IsoformGenerator_generate;
static PyObject *__pyx_n_s_K;
static PyObject *__pyx_n_s_L;
static PyObject *__pyx_n_s_M;
static PyObject *__pyx_n_s_ModificationRule;
static PyObject *__pyx_n_s_ModificationTarget;
static PyObject *__pyx_n_s_N;
static PyObject *__pyx_kp_s_Not_a_valid_modX_sequence;
static PyObject *__pyx_kp_s_OH;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_n_s_P;
static PyObject *__pyx_kp_u_Parse_a_sequence_string_written;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_PositionType;
static PyObject *__pyx_kp_s_Position_already_has_position_ty;
static PyObject *__pyx_n_s_PyteomicsError;
static PyObject *__pyx_n_s_Pyx_EnumBase;
static PyObject *__pyx_n_s_Pyx_EnumBase___new;
static PyObject *__pyx_n_s_Pyx_EnumBase___repr;
static PyObject *__pyx_n_s_Pyx_EnumBase___str;
static PyObject *__pyx_n_s_Q;
static PyObject *__pyx_n_s_R;
static PyObject *__pyx_n_s_S;
static PyObject *__pyx_n_s_SequencePosition;
static PyObject *__pyx_n_s_T;
static PyObject *__pyx_kp_s_Target_must_be_a_single_Amino_Ac;
static PyObject *__pyx_kp_s_Terminal_Modifications_with_Targ;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_s_Unknown_enum_value_s;
static PyObject *__pyx_kp_s_Unknown_label;
static PyObject *__pyx_kp_s_Unsupported_type_of_a_sequence_M;
static PyObject *__pyx_kp_s_Unsupported_type_of_sequence;
static PyObject *__pyx_kp_s_Unsupported_value_of_format;
static PyObject *__pyx_n_s_V;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_W;
static PyObject *__pyx_n_s_Y;
static PyObject *__pyx_kp_s__3;
static PyObject *__pyx_n_s_allow_unknown_modifications;
static PyObject *__pyx_n_s_amino_acid;
static PyObject *__pyx_kp_u_amino_acid_composition_line_566;
static PyObject *__pyx_n_s_apply_fixed_mods;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_build_site_map;
static PyObject *__pyx_n_s_c_term;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_cls;
static PyObject *__pyx_n_s_coerce_modification_dict;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_combinations;
static PyObject *__pyx_n_s_compile;
static PyObject *__pyx_n_s_cterm;
static PyObject *__pyx_n_s_dct;
static PyObject *__pyx_n_s_deque;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_enum;
static PyObject *__pyx_n_s_findall;
static PyObject *__pyx_n_s_fixed_mods;
static PyObject *__pyx_n_s_form;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_format_2;
static PyObject *__pyx_n_s_from_iterable;
static PyObject *__pyx_n_s_from_string;
static PyObject *__pyx_n_s_from_tuple;
static PyObject *__pyx_n_s_gen;
static PyObject *__pyx_n_s_generate;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_groups;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_include_unmodified;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_initialize_from_iterable;
static PyObject *__pyx_n_s_initialize_from_str;
static PyObject *__pyx_n_s_internal;
static PyObject *__pyx_n_s_isoform_generator;
static PyObject *__pyx_n_s_isoforms;
static PyObject *__pyx_n_s_it;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_itertools;
static PyObject *__pyx_n_s_kwargs;
static PyObject *__pyx_n_s_label;
static PyObject *__pyx_n_s_labels;
static PyObject *__pyx_kp_u_length_line_118;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_match;
static PyObject *__pyx_n_s_max_mods;
static PyObject *__pyx_n_s_members;
static PyObject *__pyx_n_s_memoize;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_modification;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_n_term;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_nterm;
static PyObject *__pyx_n_s_override;
static PyObject *__pyx_n_s_parents;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_kp_u_parse_line_211;
static PyObject *__pyx_n_s_parsed_sequence;
static PyObject *__pyx_n_s_persist;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_position;
static PyObject *__pyx_n_s_position_type;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_product;
static PyObject *__pyx_n_s_pyteomics_auxiliary;
static PyObject *__pyx_n_s_pyteomics_cparser;
static PyObject *__pyx_kp_s_pyteomics_cparser_pyx;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_IsoformGenerator;
static PyObject *__pyx_n_s_pyx_unpickle_ModificationRule;
static PyObject *__pyx_n_s_pyx_unpickle_ModificationTarge;
static PyObject *__pyx_n_s_pyx_unpickle_SequencePosition;
static PyObject *__pyx_n_s_pyx_unpickle___Pyx_EnumMeta;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_repr;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_kp_s_s_s;
static PyObject *__pyx_kp_s_s_s_d;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_kp_s_self___class_____name___self_mo;
static PyObject *__pyx_kp_s_self___class_____name___self_ta;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_sequence;
static PyObject *__pyx_n_s_sequence_spec;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_show_unmodified_termini;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_staticmethod;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_n_s_str_2;
static PyObject *__pyx_n_s_string;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_sum;
static PyObject *__pyx_n_s_target;
static PyObject *__pyx_n_s_targets;
static PyObject *__pyx_n_s_term_aa;
static PyObject *__pyx_n_s_terminal;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_test_2;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_universal;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_n_s_variable_mods;
static PyObject *__pyx_pf_9pyteomics_7cparser_length(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_split, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_2_split_label(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_label); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_4parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_split, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_6tostring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_parsed_sequence, int __pyx_v_show_unmodified_termini); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_8amino_acid_composition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_term_aa, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition___init__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_amino_acid, PyObject *__pyx_v_modification, PyObject *__pyx_v_terminal, PyObject *__pyx_v_position_type); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_2__getitem__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_4get_index(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, long __pyx_v_i); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_6add_modification(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_mod); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_8__repr__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_9pyteomics_7cparser_16SequencePosition_10__len__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_12as_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_14from_tuple(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_source); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_16parse(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_sequence, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_18from_iterable(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_iterable); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_20__eq__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_22__ne__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_24__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_26__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_10_sequence_tostring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_12copy_sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator___init__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_variable_mods, PyObject *__pyx_v_fixed_mods, PyObject *__pyx_v_labels, PyObject *__pyx_v_max_mods, PyObject *__pyx_v_override, PyObject *__pyx_v_show_unmodified_termini, PyObject *__pyx_v_persist); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_2coerce_modification_dict(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_source); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_4initialize_from_str(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6initialize_from_iterable(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8apply_fixed_mods(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10build_site_map(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_v_include_unmodified); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12generate(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence_spec); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_15__call__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence_spec); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_19__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16ModificationRule___init__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_label, PyObject *__pyx_v_targets); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_2test(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_4__call__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_position); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_6__repr__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_8__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_10__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget___init__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_target, PyObject *__pyx_v_position_type); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_2test(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_4__call__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_position); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_6__repr__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_8from_string(PyObject *__pyx_v_string); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self); /* proto */
static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_10__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_12__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_14isoforms(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_17__pyx_unpickle_SequencePosition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_19__pyx_unpickle_IsoformGenerator(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_21__pyx_unpickle_ModificationRule(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9pyteomics_7cparser_23__pyx_unpickle_ModificationTarget(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9pyteomics_7cparser_SequencePosition(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9pyteomics_7cparser_IsoformGenerator(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9pyteomics_7cparser_ModificationRule(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9pyteomics_7cparser_ModificationTarget(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct__generate(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct_1_isoforms(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, &__pyx_n_s_get, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items = {0, &__pyx_n_s_items, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_50086419;
static PyObject *__pyx_int_94445299;
static PyObject *__pyx_int_158260321;
static PyObject *__pyx_int_209977177;
static PyObject *__pyx_int_222419149;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_k__2;
static PyObject *__pyx_k__4;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_codeobj__5;
static PyObject *__pyx_codeobj__10;
static PyObject *__pyx_codeobj__13;
static PyObject *__pyx_codeobj__15;
static PyObject *__pyx_codeobj__17;
static PyObject *__pyx_codeobj__19;
static PyObject *__pyx_codeobj__21;
static PyObject *__pyx_codeobj__24;
static PyObject *__pyx_codeobj__26;
static PyObject *__pyx_codeobj__28;
/* Late includes */

/* "pyteomics/cparser.pyx":72
 * 
 * @cython.nonecheck(False)
 * cdef bint is_term_mod(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` corresponds to a terminal modification.
 * 
 */

static int __pyx_f_9pyteomics_7cparser_is_term_mod(PyObject *__pyx_v_label) {
  int __pyx_v_result;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_term_mod", 0);

  /* "pyteomics/cparser.pyx":85
 *     cdef:
 *         bint result
 *     result = label.startswith("-")             # <<<<<<<<<<<<<<
 *     if result:
 *         return result
 */
  if (unlikely(__pyx_v_label == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
    __PYX_ERR(0, 85, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyStr_Tailmatch(__pyx_v_label, __pyx_kp_s_, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 85, __pyx_L1_error)
  __pyx_v_result = __pyx_t_1;

  /* "pyteomics/cparser.pyx":86
 *         bint result
 *     result = label.startswith("-")
 *     if result:             # <<<<<<<<<<<<<<
 *         return result
 *     else:
 */
  __pyx_t_1 = (__pyx_v_result != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":87
 *     result = label.startswith("-")
 *     if result:
 *         return result             # <<<<<<<<<<<<<<
 *     else:
 *         result = label.endswith("-")
 */
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":86
 *         bint result
 *     result = label.startswith("-")
 *     if result:             # <<<<<<<<<<<<<<
 *         return result
 *     else:
 */
  }

  /* "pyteomics/cparser.pyx":89
 *         return result
 *     else:
 *         result = label.endswith("-")             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  /*else*/ {
    if (unlikely(__pyx_v_label == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
      __PYX_ERR(0, 89, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyStr_Tailmatch(__pyx_v_label, __pyx_kp_s_, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 89, __pyx_L1_error)
    __pyx_v_result = __pyx_t_1;

    /* "pyteomics/cparser.pyx":90
 *     else:
 *         result = label.endswith("-")
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef inline object match_modX(str label):
 */
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;
  }

  /* "pyteomics/cparser.pyx":72
 * 
 * @cython.nonecheck(False)
 * cdef bint is_term_mod(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` corresponds to a terminal modification.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("pyteomics.cparser.is_term_mod", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":92
 *         return result
 * 
 * cdef inline object match_modX(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` is a valid 'modX' label.
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser_match_modX(PyObject *__pyx_v_label) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("match_modX", 0);

  /* "pyteomics/cparser.pyx":103
 *     out : re.match or None
 *     """
 *     return PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>label, NULL)             # <<<<<<<<<<<<<<
 * 
 * cdef inline int is_modX(str label):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_9pyteomics_7cparser__modX_split;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_CallMethodObjArgs(__pyx_t_1, __pyx_n_s_match, ((PyObject *)__pyx_v_label), NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":92
 *         return result
 * 
 * cdef inline object match_modX(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` is a valid 'modX' label.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.match_modX", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":105
 *     return PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>label, NULL)
 * 
 * cdef inline int is_modX(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` is a valid 'modX' label.
 * 
 */

static CYTHON_INLINE int __pyx_f_9pyteomics_7cparser_is_modX(PyObject *__pyx_v_label) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_modX", 0);

  /* "pyteomics/cparser.pyx":116
 *     out : bool
 *     """
 *     return bool(match_modX(label))             # <<<<<<<<<<<<<<
 * 
 * cpdef int length(object sequence,
 */
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_match_modX(__pyx_v_label); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = (!(!__pyx_t_2));
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":105
 *     return PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>label, NULL)
 * 
 * cdef inline int is_modX(str label):             # <<<<<<<<<<<<<<
 *     """Check if `label` is a valid 'modX' label.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("pyteomics.cparser.is_modX", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":118
 *     return bool(match_modX(label))
 * 
 * cpdef int length(object sequence,             # <<<<<<<<<<<<<<
 *                  int show_unmodified_termini=0, int split=0,
 *                  int allow_unknown_modifications=0, object labels=std_labels):
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_1length(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_9pyteomics_7cparser_length(PyObject *__pyx_v_sequence, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_length *__pyx_optional_args) {
  int __pyx_v_show_unmodified_termini = ((int)0);
  int __pyx_v_split = ((int)0);
  int __pyx_v_allow_unknown_modifications = ((int)0);
  PyObject *__pyx_v_labels = __pyx_k__2;
  PyObject *__pyx_v_parsed_sequence = NULL;
  PyObject *__pyx_v_num_term_groups = NULL;
  PyObject *__pyx_v_aa = NULL;
  PyObject *__pyx_v_amount = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_parse __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("length", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_show_unmodified_termini = __pyx_optional_args->show_unmodified_termini;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_split = __pyx_optional_args->split;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_allow_unknown_modifications = __pyx_optional_args->allow_unknown_modifications;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_labels = __pyx_optional_args->labels;
          }
        }
      }
    }
  }

  /* "pyteomics/cparser.pyx":139
 *     7
 *     """
 *     if not sequence: return 0             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(sequence, str) or isinstance(sequence, list):
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_sequence); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 139, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "pyteomics/cparser.pyx":141
 *     if not sequence: return 0
 * 
 *     if isinstance(sequence, str) or isinstance(sequence, list):             # <<<<<<<<<<<<<<
 *         if isinstance(sequence, str):
 *             parsed_sequence = parse(sequence, show_unmodified_termini,
 */
  __pyx_t_1 = PyString_Check(__pyx_v_sequence); 
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = PyList_Check(__pyx_v_sequence); 
  __pyx_t_1 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_1;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":142
 * 
 *     if isinstance(sequence, str) or isinstance(sequence, list):
 *         if isinstance(sequence, str):             # <<<<<<<<<<<<<<
 *             parsed_sequence = parse(sequence, show_unmodified_termini,
 *                                     split, allow_unknown_modifications, labels)
 */
    __pyx_t_2 = PyString_Check(__pyx_v_sequence); 
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":143
 *     if isinstance(sequence, str) or isinstance(sequence, list):
 *         if isinstance(sequence, str):
 *             parsed_sequence = parse(sequence, show_unmodified_termini,             # <<<<<<<<<<<<<<
 *                                     split, allow_unknown_modifications, labels)
 *         else:
 */
      if (!(likely(PyString_CheckExact(__pyx_v_sequence))||((__pyx_v_sequence) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_sequence)->tp_name), 0))) __PYX_ERR(0, 143, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":144
 *         if isinstance(sequence, str):
 *             parsed_sequence = parse(sequence, show_unmodified_termini,
 *                                     split, allow_unknown_modifications, labels)             # <<<<<<<<<<<<<<
 *         else:
 *             parsed_sequence = sequence
 */
      __pyx_t_5.__pyx_n = 4;
      __pyx_t_5.show_unmodified_termini = __pyx_v_show_unmodified_termini;
      __pyx_t_5.split = __pyx_v_split;
      __pyx_t_5.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
      __pyx_t_5.labels = __pyx_v_labels;
      __pyx_t_4 = __pyx_f_9pyteomics_7cparser_parse(((PyObject*)__pyx_v_sequence), 0, &__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 143, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_parsed_sequence = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":142
 * 
 *     if isinstance(sequence, str) or isinstance(sequence, list):
 *         if isinstance(sequence, str):             # <<<<<<<<<<<<<<
 *             parsed_sequence = parse(sequence, show_unmodified_termini,
 *                                     split, allow_unknown_modifications, labels)
 */
      goto __pyx_L7;
    }

    /* "pyteomics/cparser.pyx":146
 *                                     split, allow_unknown_modifications, labels)
 *         else:
 *             parsed_sequence = sequence             # <<<<<<<<<<<<<<
 *         num_term_groups = 0
 *         if is_term_mod(parsed_sequence[0]):
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_sequence);
      __pyx_v_parsed_sequence = __pyx_v_sequence;
    }
    __pyx_L7:;

    /* "pyteomics/cparser.pyx":147
 *         else:
 *             parsed_sequence = sequence
 *         num_term_groups = 0             # <<<<<<<<<<<<<<
 *         if is_term_mod(parsed_sequence[0]):
 *             num_term_groups += 1
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_v_num_term_groups = __pyx_int_0;

    /* "pyteomics/cparser.pyx":148
 *             parsed_sequence = sequence
 *         num_term_groups = 0
 *         if is_term_mod(parsed_sequence[0]):             # <<<<<<<<<<<<<<
 *             num_term_groups += 1
 *         if is_term_mod(parsed_sequence[-1]):
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_parsed_sequence, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (!(likely(PyString_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 148, __pyx_L1_error)
    __pyx_t_1 = (__pyx_f_9pyteomics_7cparser_is_term_mod(((PyObject*)__pyx_t_4)) != 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":149
 *         num_term_groups = 0
 *         if is_term_mod(parsed_sequence[0]):
 *             num_term_groups += 1             # <<<<<<<<<<<<<<
 *         if is_term_mod(parsed_sequence[-1]):
 *             num_term_groups += 1
 */
      __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_num_term_groups, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_num_term_groups, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":148
 *             parsed_sequence = sequence
 *         num_term_groups = 0
 *         if is_term_mod(parsed_sequence[0]):             # <<<<<<<<<<<<<<
 *             num_term_groups += 1
 *         if is_term_mod(parsed_sequence[-1]):
 */
    }

    /* "pyteomics/cparser.pyx":150
 *         if is_term_mod(parsed_sequence[0]):
 *             num_term_groups += 1
 *         if is_term_mod(parsed_sequence[-1]):             # <<<<<<<<<<<<<<
 *             num_term_groups += 1
 *         return len(parsed_sequence) - num_term_groups
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_parsed_sequence, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (!(likely(PyString_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 150, __pyx_L1_error)
    __pyx_t_1 = (__pyx_f_9pyteomics_7cparser_is_term_mod(((PyObject*)__pyx_t_4)) != 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":151
 *             num_term_groups += 1
 *         if is_term_mod(parsed_sequence[-1]):
 *             num_term_groups += 1             # <<<<<<<<<<<<<<
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):
 */
      __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_num_term_groups, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_num_term_groups, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":150
 *         if is_term_mod(parsed_sequence[0]):
 *             num_term_groups += 1
 *         if is_term_mod(parsed_sequence[-1]):             # <<<<<<<<<<<<<<
 *             num_term_groups += 1
 *         return len(parsed_sequence) - num_term_groups
 */
    }

    /* "pyteomics/cparser.pyx":152
 *         if is_term_mod(parsed_sequence[-1]):
 *             num_term_groups += 1
 *         return len(parsed_sequence) - num_term_groups             # <<<<<<<<<<<<<<
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 152, __pyx_L1_error)
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyNumber_Subtract(__pyx_t_4, __pyx_v_num_term_groups); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_r = __pyx_t_8;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":141
 *     if not sequence: return 0
 * 
 *     if isinstance(sequence, str) or isinstance(sequence, list):             # <<<<<<<<<<<<<<
 *         if isinstance(sequence, str):
 *             parsed_sequence = parse(sequence, show_unmodified_termini,
 */
  }

  /* "pyteomics/cparser.pyx":153
 *             num_term_groups += 1
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):             # <<<<<<<<<<<<<<
 *         return sum([amount for aa, amount in sequence.items()
 *                     if not is_term_mod(aa)])
 */
  __pyx_t_1 = PyDict_Check(__pyx_v_sequence); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":154
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()             # <<<<<<<<<<<<<<
 *                     if not is_term_mod(aa)])
 * 
 */
    __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_n_s_items); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_9 = __pyx_t_4; __Pyx_INCREF(__pyx_t_9); __pyx_t_6 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_9 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = Py_TYPE(__pyx_t_9)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 154, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_9))) {
          if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_9)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 154, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_9, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 154, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_9)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_9, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 154, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_9, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 154, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_11(__pyx_t_9);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 154, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 154, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_14 = Py_TYPE(__pyx_t_13)->tp_iternext;
        index = 0; __pyx_t_10 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_10)) goto __pyx_L12_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        index = 1; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L12_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
        __pyx_t_14 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L13_unpacking_done;
        __pyx_L12_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 154, __pyx_L1_error)
        __pyx_L13_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_aa, __pyx_t_10);
      __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_amount, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "pyteomics/cparser.pyx":155
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()
 *                     if not is_term_mod(aa)])             # <<<<<<<<<<<<<<
 * 
 *     raise PyteomicsError('Unsupported type of sequence.')
 */
      if (!(likely(PyString_CheckExact(__pyx_v_aa))||((__pyx_v_aa) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_aa)->tp_name), 0))) __PYX_ERR(0, 155, __pyx_L1_error)
      __pyx_t_2 = ((!(__pyx_f_9pyteomics_7cparser_is_term_mod(((PyObject*)__pyx_v_aa)) != 0)) != 0);
      if (__pyx_t_2) {

        /* "pyteomics/cparser.pyx":154
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()             # <<<<<<<<<<<<<<
 *                     if not is_term_mod(aa)])
 * 
 */
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_7, (PyObject*)__pyx_v_amount))) __PYX_ERR(0, 154, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":155
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()
 *                     if not is_term_mod(aa)])             # <<<<<<<<<<<<<<
 * 
 *     raise PyteomicsError('Unsupported type of sequence.')
 */
      }

      /* "pyteomics/cparser.pyx":154
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):
 *         return sum([amount for aa, amount in sequence.items()             # <<<<<<<<<<<<<<
 *                     if not is_term_mod(aa)])
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_9); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_r = __pyx_t_8;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":153
 *             num_term_groups += 1
 *         return len(parsed_sequence) - num_term_groups
 *     elif isinstance(sequence, dict):             # <<<<<<<<<<<<<<
 *         return sum([amount for aa, amount in sequence.items()
 *                     if not is_term_mod(aa)])
 */
  }

  /* "pyteomics/cparser.pyx":157
 *                     if not is_term_mod(aa)])
 * 
 *     raise PyteomicsError('Unsupported type of sequence.')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_kp_s_Unsupported_type_of_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_s_Unsupported_type_of_sequence);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_Raise(__pyx_t_9, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __PYX_ERR(0, 157, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":118
 *     return bool(match_modX(label))
 * 
 * cpdef int length(object sequence,             # <<<<<<<<<<<<<<
 *                  int show_unmodified_termini=0, int split=0,
 *                  int allow_unknown_modifications=0, object labels=std_labels):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_WriteUnraisable("pyteomics.cparser.length", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parsed_sequence);
  __Pyx_XDECREF(__pyx_v_num_term_groups);
  __Pyx_XDECREF(__pyx_v_aa);
  __Pyx_XDECREF(__pyx_v_amount);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_1length(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_length[] = "length(sequence, int show_unmodified_termini=0, int split=0, int allow_unknown_modifications=0, labels=std_labels) -> int\nCalculate the number of amino acid residues in a polypeptide\n    written in modX notation.\n\n    Parameters\n    ----------\n    sequence : str or list or dict\n        A string with a polypeptide sequence, a list with a parsed sequence or\n        a dict of amino acid composition.\n    labels : list, optional\n        A list of allowed labels for amino acids and terminal modifications.\n\n    Examples\n    --------\n    >>> length('PEPTIDE')\n    7\n    >>> length('H-PEPTIDE-OH')\n    7\n    ";
static PyObject *__pyx_pw_9pyteomics_7cparser_1length(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_v_show_unmodified_termini;
  int __pyx_v_split;
  int __pyx_v_allow_unknown_modifications;
  PyObject *__pyx_v_labels = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("length (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_show_unmodified_termini,&__pyx_n_s_split,&__pyx_n_s_allow_unknown_modifications,&__pyx_n_s_labels,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[4] = __pyx_k__2;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_split);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_allow_unknown_modifications);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "length") < 0)) __PYX_ERR(0, 118, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
    if (values[1]) {
      __pyx_v_show_unmodified_termini = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_show_unmodified_termini == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L3_error)
    } else {
      __pyx_v_show_unmodified_termini = ((int)0);
    }
    if (values[2]) {
      __pyx_v_split = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_split == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L3_error)
    } else {
      __pyx_v_split = ((int)0);
    }
    if (values[3]) {
      __pyx_v_allow_unknown_modifications = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_allow_unknown_modifications == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 120, __pyx_L3_error)
    } else {
      __pyx_v_allow_unknown_modifications = ((int)0);
    }
    __pyx_v_labels = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("length", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 118, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_length(__pyx_self, __pyx_v_sequence, __pyx_v_show_unmodified_termini, __pyx_v_split, __pyx_v_allow_unknown_modifications, __pyx_v_labels);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_length(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_split, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_opt_args_9pyteomics_7cparser_length __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("length", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 4;
  __pyx_t_2.show_unmodified_termini = __pyx_v_show_unmodified_termini;
  __pyx_t_2.split = __pyx_v_split;
  __pyx_t_2.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
  __pyx_t_2.labels = __pyx_v_labels;
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_length(__pyx_v_sequence, 0, &__pyx_t_2); 
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":160
 * 
 * 
 * cdef inline list interpolate_labels(object labels):             # <<<<<<<<<<<<<<
 *     cdef list _labels
 *     if labels is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser_interpolate_labels(PyObject *__pyx_v_labels) {
  PyObject *__pyx_v__labels = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interpolate_labels", 0);

  /* "pyteomics/cparser.pyx":162
 * cdef inline list interpolate_labels(object labels):
 *     cdef list _labels
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         _labels = list(std_labels)
 *     else:
 */
  __pyx_t_1 = (__pyx_v_labels == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":163
 *     cdef list _labels
 *     if labels is None:
 *         _labels = list(std_labels)             # <<<<<<<<<<<<<<
 *     else:
 *         _labels = list(labels)
 */
    __pyx_t_3 = PySequence_List(__pyx_v_9pyteomics_7cparser_std_labels); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__labels = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":162
 * cdef inline list interpolate_labels(object labels):
 *     cdef list _labels
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         _labels = list(std_labels)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "pyteomics/cparser.pyx":165
 *         _labels = list(std_labels)
 *     else:
 *         _labels = list(labels)             # <<<<<<<<<<<<<<
 *     _labels.extend((std_cterm, std_nterm))
 *     return _labels
 */
  /*else*/ {
    __pyx_t_3 = PySequence_List(__pyx_v_labels); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__labels = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pyteomics/cparser.pyx":166
 *     else:
 *         _labels = list(labels)
 *     _labels.extend((std_cterm, std_nterm))             # <<<<<<<<<<<<<<
 *     return _labels
 * 
 */
  __pyx_t_4 = __Pyx_ListComp_Append(__pyx_v__labels, __pyx_v_9pyteomics_7cparser_std_cterm); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 166, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v__labels, __pyx_v_9pyteomics_7cparser_std_nterm); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 166, __pyx_L1_error)
  (void)((__pyx_t_4 | __pyx_t_5));

  /* "pyteomics/cparser.pyx":167
 *         _labels = list(labels)
 *     _labels.extend((std_cterm, std_nterm))
 *     return _labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v__labels);
  __pyx_r = __pyx_v__labels;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":160
 * 
 * 
 * cdef inline list interpolate_labels(object labels):             # <<<<<<<<<<<<<<
 *     cdef list _labels
 *     if labels is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.interpolate_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":170
 * 
 * 
 * cpdef inline tuple _split_label(str label):             # <<<<<<<<<<<<<<
 *     cdef:
 *         str mod, X
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_3_split_label(PyObject *__pyx_self, PyObject *__pyx_v_label); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser__split_label(PyObject *__pyx_v_label, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_mod = 0;
  PyObject *__pyx_v_X = 0;
  PyObject *__pyx_v_temp = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_split_label", 0);

  /* "pyteomics/cparser.pyx":176
 * 
 * 
 *     temp = <tuple>PyObject_CallMethodObjArgs(match_modX(label), "groups", NULL)             # <<<<<<<<<<<<<<
 *     if <PyObject*>temp == NULL:
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)
 */
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_match_modX(__pyx_v_label); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_CallMethodObjArgs(__pyx_t_1, __pyx_n_s_groups, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_temp = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":177
 * 
 *     temp = <tuple>PyObject_CallMethodObjArgs(match_modX(label), "groups", NULL)
 *     if <PyObject*>temp == NULL:             # <<<<<<<<<<<<<<
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 */
  __pyx_t_3 = ((((PyObject *)__pyx_v_temp) == NULL) != 0);
  if (unlikely(__pyx_t_3)) {

    /* "pyteomics/cparser.pyx":178
 *     temp = <tuple>PyObject_CallMethodObjArgs(match_modX(label), "groups", NULL)
 *     if <PyObject*>temp == NULL:
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)             # <<<<<<<<<<<<<<
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Cannot_split_a_non_modX_label_s, __pyx_v_label); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 178, __pyx_L1_error)

    /* "pyteomics/cparser.pyx":177
 * 
 *     temp = <tuple>PyObject_CallMethodObjArgs(match_modX(label), "groups", NULL)
 *     if <PyObject*>temp == NULL:             # <<<<<<<<<<<<<<
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 */
  }

  /* "pyteomics/cparser.pyx":179
 *     if <PyObject*>temp == NULL:
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)             # <<<<<<<<<<<<<<
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)
 *     if not mod:
 */
  __pyx_t_6 = PyTuple_GET_ITEM(__pyx_v_temp, 0);
  __pyx_t_1 = ((PyObject *)__pyx_t_6);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_mod = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":180
 *         raise PyteomicsError('Cannot split a non-modX label: %s' % label)
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)             # <<<<<<<<<<<<<<
 *     if not mod:
 *         return (X,)
 */
  __pyx_t_6 = PyTuple_GET_ITEM(__pyx_v_temp, 1);
  __pyx_t_1 = ((PyObject *)__pyx_t_6);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_X = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":181
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)
 *     if not mod:             # <<<<<<<<<<<<<<
 *         return (X,)
 *     else:
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_mod); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 181, __pyx_L1_error)
  __pyx_t_7 = ((!__pyx_t_3) != 0);
  if (__pyx_t_7) {

    /* "pyteomics/cparser.pyx":182
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)
 *     if not mod:
 *         return (X,)             # <<<<<<<<<<<<<<
 *     else:
 *         return temp
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_X);
    __Pyx_GIVEREF(__pyx_v_X);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_X);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":181
 *     mod = <str>PyTuple_GET_ITEM(<tuple>temp, 0)
 *     X = <str>PyTuple_GET_ITEM(<tuple>temp, 1)
 *     if not mod:             # <<<<<<<<<<<<<<
 *         return (X,)
 *     else:
 */
  }

  /* "pyteomics/cparser.pyx":184
 *         return (X,)
 *     else:
 *         return temp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_temp);
    __pyx_r = __pyx_v_temp;
    goto __pyx_L0;
  }

  /* "pyteomics/cparser.pyx":170
 * 
 * 
 * cpdef inline tuple _split_label(str label):             # <<<<<<<<<<<<<<
 *     cdef:
 *         str mod, X
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser._split_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mod);
  __Pyx_XDECREF(__pyx_v_X);
  __Pyx_XDECREF(__pyx_v_temp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_3_split_label(PyObject *__pyx_self, PyObject *__pyx_v_label); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_2_split_label[] = "_split_label(str label) -> tuple";
static PyObject *__pyx_pw_9pyteomics_7cparser_3_split_label(PyObject *__pyx_self, PyObject *__pyx_v_label) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_split_label (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_label), (&PyString_Type), 1, "label", 1))) __PYX_ERR(0, 170, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_2_split_label(__pyx_self, ((PyObject*)__pyx_v_label));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_2_split_label(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_label) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_split_label", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser__split_label(__pyx_v_label, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser._split_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":190
 * 
 * 
 * cdef list _parse_modx_sequence_split(str sequence):             # <<<<<<<<<<<<<<
 *     cdef:
 *         list parsed_sequence
 */

static PyObject *__pyx_f_9pyteomics_7cparser__parse_modx_sequence_split(PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_parsed_sequence = 0;
  PyObject *__pyx_v_parts = 0;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  PyObject *__pyx_v_g = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_modx_sequence_split", 0);

  /* "pyteomics/cparser.pyx":197
 *         object g
 * 
 *     parsed_sequence = []             # <<<<<<<<<<<<<<
 *     parts = tuple(_modX_split_findall(sequence))
 *     n = len(parts)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_parsed_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":198
 * 
 *     parsed_sequence = []
 *     parts = tuple(_modX_split_findall(sequence))             # <<<<<<<<<<<<<<
 *     n = len(parts)
 * 
 */
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser__modX_split_findall);
  __pyx_t_2 = __pyx_v_9pyteomics_7cparser__modX_split_findall; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_sequence);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_parts = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":199
 *     parsed_sequence = []
 *     parts = tuple(_modX_split_findall(sequence))
 *     n = len(parts)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v_parts); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 199, __pyx_L1_error)
  __pyx_v_n = __pyx_t_4;

  /* "pyteomics/cparser.pyx":201
 *     n = len(parts)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         g = <object>PyTuple_GET_ITEM(parts, i)
 * 
 */
  __pyx_t_4 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pyteomics/cparser.pyx":202
 * 
 *     for i in range(n):
 *         g = <object>PyTuple_GET_ITEM(parts, i)             # <<<<<<<<<<<<<<
 * 
 *         if g[0]:
 */
    __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_parts, __pyx_v_i);
    __pyx_t_2 = ((PyObject *)__pyx_t_7);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_g, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":204
 *         g = <object>PyTuple_GET_ITEM(parts, i)
 * 
 *         if g[0]:             # <<<<<<<<<<<<<<
 *             parsed_sequence.append(g)
 *         else:
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_g, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_8) {

      /* "pyteomics/cparser.pyx":205
 * 
 *         if g[0]:
 *             parsed_sequence.append(g)             # <<<<<<<<<<<<<<
 *         else:
 *             parsed_sequence.append((g[1],))
 */
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_parsed_sequence, __pyx_v_g); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 205, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":204
 *         g = <object>PyTuple_GET_ITEM(parts, i)
 * 
 *         if g[0]:             # <<<<<<<<<<<<<<
 *             parsed_sequence.append(g)
 *         else:
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":207
 *             parsed_sequence.append(g)
 *         else:
 *             parsed_sequence.append((g[1],))             # <<<<<<<<<<<<<<
 *     return parsed_sequence
 * 
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_g, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_parsed_sequence, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;
  }

  /* "pyteomics/cparser.pyx":208
 *         else:
 *             parsed_sequence.append((g[1],))
 *     return parsed_sequence             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_parsed_sequence);
  __pyx_r = __pyx_v_parsed_sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":190
 * 
 * 
 * cdef list _parse_modx_sequence_split(str sequence):             # <<<<<<<<<<<<<<
 *     cdef:
 *         list parsed_sequence
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser._parse_modx_sequence_split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parsed_sequence);
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":211
 * 
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=0, bint split=0,             # <<<<<<<<<<<<<<
 *                  bint allow_unknown_modifications=0, object labels=None):
 *     """Parse a sequence string written in modX notation into a list of
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_5parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_parse(PyObject *__pyx_v_sequence, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_parse *__pyx_optional_args) {
  int __pyx_v_show_unmodified_termini = ((int)0);
  int __pyx_v_split = ((int)0);
  int __pyx_v_allow_unknown_modifications = ((int)0);

  /* "pyteomics/cparser.pyx":212
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=0, bint split=0,
 *                  bint allow_unknown_modifications=0, object labels=None):             # <<<<<<<<<<<<<<
 *     """Parse a sequence string written in modX notation into a list of
 *     labels or (if `split` argument is :py:const:`True`) into a list of
 */
  PyObject *__pyx_v_labels = ((PyObject *)Py_None);
  PyObject *__pyx_v_match = 0;
  PyObject *__pyx_v_temp = 0;
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_body = 0;
  PyObject *__pyx_v_c = 0;
  PyObject *__pyx_v_nterm = 0;
  PyObject *__pyx_v_cterm = 0;
  PyObject *__pyx_v_mod = 0;
  PyObject *__pyx_v_X = 0;
  PyObject *__pyx_v_parsed_sequence = 0;
  PyObject *__pyx_v_tgroup = 0;
  PyObject *__pyx_v_sgroup = 0;
  PyObject *__pyx_v__labels = 0;
  Py_ssize_t __pyx_v_i;
  int __pyx_v_is_mod;
  int __pyx_v_in_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7;
  int __pyx_t_8;
  struct __pyx_opt_args_9pyteomics_7cparser__tokenize_modx_sequence __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_show_unmodified_termini = __pyx_optional_args->show_unmodified_termini;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_split = __pyx_optional_args->split;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_allow_unknown_modifications = __pyx_optional_args->allow_unknown_modifications;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_labels = __pyx_optional_args->labels;
          }
        }
      }
    }
  }

  /* "pyteomics/cparser.pyx":284
 *         int is_mod, is_residue, in_labels
 * 
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         allow_unknown_modifications = True
 *     _labels = interpolate_labels(labels)
 */
  __pyx_t_1 = (__pyx_v_labels == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":285
 * 
 *     if labels is None:
 *         allow_unknown_modifications = True             # <<<<<<<<<<<<<<
 *     _labels = interpolate_labels(labels)
 * 
 */
    __pyx_v_allow_unknown_modifications = 1;

    /* "pyteomics/cparser.pyx":284
 *         int is_mod, is_residue, in_labels
 * 
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         allow_unknown_modifications = True
 *     _labels = interpolate_labels(labels)
 */
  }

  /* "pyteomics/cparser.pyx":286
 *     if labels is None:
 *         allow_unknown_modifications = True
 *     _labels = interpolate_labels(labels)             # <<<<<<<<<<<<<<
 * 
 *     match = PyObject_CallMethodObjArgs(_modX_sequence, "match", <PyObject*>sequence, NULL)
 */
  __pyx_t_3 = __pyx_f_9pyteomics_7cparser_interpolate_labels(__pyx_v_labels); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__labels = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":288
 *     _labels = interpolate_labels(labels)
 * 
 *     match = PyObject_CallMethodObjArgs(_modX_sequence, "match", <PyObject*>sequence, NULL)             # <<<<<<<<<<<<<<
 *     if match is None:
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)
 */
  __pyx_t_3 = __pyx_v_9pyteomics_7cparser__modX_sequence;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = PyObject_CallMethodObjArgs(__pyx_t_3, __pyx_n_s_match, ((PyObject *)__pyx_v_sequence), NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_match = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":289
 * 
 *     match = PyObject_CallMethodObjArgs(_modX_sequence, "match", <PyObject*>sequence, NULL)
 *     if match is None:             # <<<<<<<<<<<<<<
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 */
  __pyx_t_2 = (__pyx_v_match == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "pyteomics/cparser.pyx":290
 *     match = PyObject_CallMethodObjArgs(_modX_sequence, "match", <PyObject*>sequence, NULL)
 *     if match is None:
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)             # <<<<<<<<<<<<<<
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *     n = <str>PyTuple_GET_ITEM(temp, 0)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_kp_s_Not_a_valid_modX_sequence, __pyx_v_sequence); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 290, __pyx_L1_error)

    /* "pyteomics/cparser.pyx":289
 * 
 *     match = PyObject_CallMethodObjArgs(_modX_sequence, "match", <PyObject*>sequence, NULL)
 *     if match is None:             # <<<<<<<<<<<<<<
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 */
  }

  /* "pyteomics/cparser.pyx":291
 *     if match is None:
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)             # <<<<<<<<<<<<<<
 *     n = <str>PyTuple_GET_ITEM(temp, 0)
 *     body = <str>PyTuple_GET_ITEM(temp, 1)
 */
  __pyx_t_4 = PyObject_CallMethodObjArgs(__pyx_v_match, __pyx_n_s_groups, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_temp = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":292
 *         raise PyteomicsError('Not a valid modX sequence: ' + sequence)
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *     n = <str>PyTuple_GET_ITEM(temp, 0)             # <<<<<<<<<<<<<<
 *     body = <str>PyTuple_GET_ITEM(temp, 1)
 *     c = <str>PyTuple_GET_ITEM(temp, 2)
 */
  __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_temp, 0);
  __pyx_t_3 = ((PyObject *)__pyx_t_7);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_n = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":293
 *     temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *     n = <str>PyTuple_GET_ITEM(temp, 0)
 *     body = <str>PyTuple_GET_ITEM(temp, 1)             # <<<<<<<<<<<<<<
 *     c = <str>PyTuple_GET_ITEM(temp, 2)
 *     # slabels = set(_labels)
 */
  __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_temp, 1);
  __pyx_t_3 = ((PyObject *)__pyx_t_7);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_body = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":294
 *     n = <str>PyTuple_GET_ITEM(temp, 0)
 *     body = <str>PyTuple_GET_ITEM(temp, 1)
 *     c = <str>PyTuple_GET_ITEM(temp, 2)             # <<<<<<<<<<<<<<
 *     # slabels = set(_labels)
 *     # labels help save the day when only one terminal group is given
 */
  __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_temp, 2);
  __pyx_t_3 = ((PyObject *)__pyx_t_7);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_c = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":297
 *     # slabels = set(_labels)
 *     # labels help save the day when only one terminal group is given
 *     if c is None and n is not None:             # <<<<<<<<<<<<<<
 *         # we can try to resolve the ambiguity
 *         if n != std_nterm and n not in _labels:
 */
  __pyx_t_2 = (__pyx_v_c == ((PyObject*)Py_None));
  __pyx_t_8 = (__pyx_t_2 != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = (__pyx_v_n != ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_8 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":299
 *     if c is None and n is not None:
 *         # we can try to resolve the ambiguity
 *         if n != std_nterm and n not in _labels:             # <<<<<<<<<<<<<<
 *             # n is the body then
 *             c = '-' + body
 */
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_n, __pyx_v_9pyteomics_7cparser_std_nterm, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 299, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_2 != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_1 = __pyx_t_8;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_n, __pyx_v__labels, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 299, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_8 != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":301
 *         if n != std_nterm and n not in _labels:
 *             # n is the body then
 *             c = '-' + body             # <<<<<<<<<<<<<<
 *             body = n[:-1]
 *             n = None
 */
      __pyx_t_3 = PyNumber_Add(__pyx_kp_s_, __pyx_v_body); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_c, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":302
 *             # n is the body then
 *             c = '-' + body
 *             body = n[:-1]             # <<<<<<<<<<<<<<
 *             n = None
 * 
 */
      if (unlikely(__pyx_v_n == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 302, __pyx_L1_error)
      }
      __pyx_t_3 = PySequence_GetSlice(__pyx_v_n, 0, -1L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_body, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":303
 *             c = '-' + body
 *             body = n[:-1]
 *             n = None             # <<<<<<<<<<<<<<
 * 
 *     # Actual parsing
 */
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_n, ((PyObject*)Py_None));

      /* "pyteomics/cparser.pyx":299
 *     if c is None and n is not None:
 *         # we can try to resolve the ambiguity
 *         if n != std_nterm and n not in _labels:             # <<<<<<<<<<<<<<
 *             # n is the body then
 *             c = '-' + body
 */
    }

    /* "pyteomics/cparser.pyx":297
 *     # slabels = set(_labels)
 *     # labels help save the day when only one terminal group is given
 *     if c is None and n is not None:             # <<<<<<<<<<<<<<
 *         # we can try to resolve the ambiguity
 *         if n != std_nterm and n not in _labels:
 */
  }

  /* "pyteomics/cparser.pyx":312
 *     # else:
 *     #     parsed_sequence = <list>PyObject_CallMethodObjArgs(_modX_group, "findall", <PyObject*>body, NULL)
 *     parsed_sequence = _tokenize_modx_sequence(body, split)             # <<<<<<<<<<<<<<
 * 
 *     nterm, cterm = (n or std_nterm), (c or std_cterm)
 */
  __pyx_t_9.__pyx_n = 1;
  __pyx_t_9.split = __pyx_v_split;
  __pyx_t_3 = __pyx_f_9pyteomics_7cparser__tokenize_modx_sequence(__pyx_v_body, &__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_parsed_sequence = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":314
 *     parsed_sequence = _tokenize_modx_sequence(body, split)
 * 
 *     nterm, cterm = (n or std_nterm), (c or std_cterm)             # <<<<<<<<<<<<<<
 * 
 *     if not allow_unknown_modifications:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_n); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
  if (!__pyx_t_1) {
  } else {
    __Pyx_INCREF(__pyx_v_n);
    __pyx_t_3 = __pyx_v_n;
    goto __pyx_L11_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_nterm);
  __pyx_t_3 = __pyx_v_9pyteomics_7cparser_std_nterm;
  __pyx_L11_bool_binop_done:;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_c); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
  if (!__pyx_t_1) {
  } else {
    __Pyx_INCREF(__pyx_v_c);
    __pyx_t_4 = __pyx_v_c;
    goto __pyx_L13_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_cterm);
  __pyx_t_4 = __pyx_v_9pyteomics_7cparser_std_cterm;
  __pyx_L13_bool_binop_done:;
  __pyx_v_nterm = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_cterm = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":316
 *     nterm, cterm = (n or std_nterm), (c or std_cterm)
 * 
 *     if not allow_unknown_modifications:             # <<<<<<<<<<<<<<
 *         if nterm is not None and nterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 */
  __pyx_t_1 = ((!(__pyx_v_allow_unknown_modifications != 0)) != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":317
 * 
 *     if not allow_unknown_modifications:
 *         if nterm is not None and nterm not in _labels:             # <<<<<<<<<<<<<<
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 *         if cterm is not None and cterm not in _labels:
 */
    __pyx_t_2 = (__pyx_v_nterm != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_2 != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_1 = __pyx_t_8;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_nterm, __pyx_v__labels, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 317, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_8 != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L17_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "pyteomics/cparser.pyx":318
 *     if not allow_unknown_modifications:
 *         if nterm is not None and nterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))             # <<<<<<<<<<<<<<
 *         if cterm is not None and cterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Unknown_label, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_v_nterm) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_nterm);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 318, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":317
 * 
 *     if not allow_unknown_modifications:
 *         if nterm is not None and nterm not in _labels:             # <<<<<<<<<<<<<<
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 *         if cterm is not None and cterm not in _labels:
 */
    }

    /* "pyteomics/cparser.pyx":319
 *         if nterm is not None and nterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 *         if cterm is not None and cterm not in _labels:             # <<<<<<<<<<<<<<
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))
 * 
 */
    __pyx_t_2 = (__pyx_v_cterm != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_2 != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_1 = __pyx_t_8;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_cterm, __pyx_v__labels, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_8 != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L20_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "pyteomics/cparser.pyx":320
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 *         if cterm is not None and cterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))             # <<<<<<<<<<<<<<
 * 
 *     if split:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Unknown_label, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_v_cterm) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_cterm);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 320, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":319
 *         if nterm is not None and nterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 *         if cterm is not None and cterm not in _labels:             # <<<<<<<<<<<<<<
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))
 * 
 */
    }

    /* "pyteomics/cparser.pyx":316
 *     nterm, cterm = (n or std_nterm), (c or std_cterm)
 * 
 *     if not allow_unknown_modifications:             # <<<<<<<<<<<<<<
 *         if nterm is not None and nterm not in _labels:
 *             raise PyteomicsError('Unknown label: {}'.format(nterm))
 */
  }

  /* "pyteomics/cparser.pyx":322
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))
 * 
 *     if split:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):
 */
  __pyx_t_1 = (__pyx_v_split != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":323
 * 
 *     if split:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(PyList_Size(parsed_sequence)):
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 */
    __pyx_v_i = 0;

    /* "pyteomics/cparser.pyx":324
 *     if split:
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):             # <<<<<<<<<<<<<<
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *             if len(tgroup) == 2:
 */
    __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 324, __pyx_L1_error)
    __pyx_t_12 = __pyx_t_11;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_i = __pyx_t_13;

      /* "pyteomics/cparser.pyx":325
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)             # <<<<<<<<<<<<<<
 *             if len(tgroup) == 2:
 *                 mod = <str>PyTuple_GET_ITEM(tgroup, 0)
 */
      __pyx_t_7 = PyList_GET_ITEM(__pyx_v_parsed_sequence, __pyx_v_i);
      __pyx_t_4 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_tgroup, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":326
 *         for i in range(PyList_Size(parsed_sequence)):
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *             if len(tgroup) == 2:             # <<<<<<<<<<<<<<
 *                 mod = <str>PyTuple_GET_ITEM(tgroup, 0)
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 1)
 */
      if (unlikely(__pyx_v_tgroup == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 326, __pyx_L1_error)
      }
      __pyx_t_14 = PyTuple_GET_SIZE(__pyx_v_tgroup); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 326, __pyx_L1_error)
      __pyx_t_1 = ((__pyx_t_14 == 2) != 0);
      if (__pyx_t_1) {

        /* "pyteomics/cparser.pyx":327
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *             if len(tgroup) == 2:
 *                 mod = <str>PyTuple_GET_ITEM(tgroup, 0)             # <<<<<<<<<<<<<<
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 1)
 *             else:
 */
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_tgroup, 0);
        __pyx_t_4 = ((PyObject *)__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_mod, ((PyObject*)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "pyteomics/cparser.pyx":328
 *             if len(tgroup) == 2:
 *                 mod = <str>PyTuple_GET_ITEM(tgroup, 0)
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 1)             # <<<<<<<<<<<<<<
 *             else:
 *                 mod = ''
 */
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_tgroup, 1);
        __pyx_t_4 = ((PyObject *)__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_X, ((PyObject*)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "pyteomics/cparser.pyx":326
 *         for i in range(PyList_Size(parsed_sequence)):
 *             tgroup = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *             if len(tgroup) == 2:             # <<<<<<<<<<<<<<
 *                 mod = <str>PyTuple_GET_ITEM(tgroup, 0)
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 1)
 */
        goto __pyx_L25;
      }

      /* "pyteomics/cparser.pyx":330
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 1)
 *             else:
 *                 mod = ''             # <<<<<<<<<<<<<<
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_kp_s__3);
        __Pyx_XDECREF_SET(__pyx_v_mod, __pyx_kp_s__3);

        /* "pyteomics/cparser.pyx":331
 *             else:
 *                 mod = ''
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)             # <<<<<<<<<<<<<<
 *             if ((not mod) and X not in _labels) or\
 *                 not ((mod+X in _labels) or\
 */
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_tgroup, 0);
        __pyx_t_4 = ((PyObject *)__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_X, ((PyObject*)__pyx_t_4));
        __pyx_t_4 = 0;
      }
      __pyx_L25:;

      /* "pyteomics/cparser.pyx":332
 *                 mod = ''
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_mod); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 332, __pyx_L1_error)
      __pyx_t_8 = ((!__pyx_t_2) != 0);
      if (!__pyx_t_8) {
        goto __pyx_L28_next_or;
      } else {
      }
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_X, __pyx_v__labels, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 332, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_8 != 0);
      if (!__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L27_bool_binop_done;
      }
      __pyx_L28_next_or:;

      /* "pyteomics/cparser.pyx":333
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\
 *                 not ((mod+X in _labels) or\             # <<<<<<<<<<<<<<
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(tgroup))
 */
      __pyx_t_4 = PyNumber_Add(__pyx_v_mod, __pyx_v_X); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 333, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_15 = (__pyx_t_8 != 0);
      if (!__pyx_t_15) {
      } else {
        __pyx_t_2 = __pyx_t_15;
        goto __pyx_L30_bool_binop_done;
      }

      /* "pyteomics/cparser.pyx":334
 *             if ((not mod) and X not in _labels) or\
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):             # <<<<<<<<<<<<<<
 *                 raise PyteomicsError('Unknown label: {}'.format(tgroup))
 * 
 */
      __pyx_t_15 = (__Pyx_PySequence_ContainsTF(__pyx_v_X, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 334, __pyx_L1_error)
      __pyx_t_8 = (__pyx_t_15 != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_mod, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 334, __pyx_L1_error)
      __pyx_t_15 = (__pyx_t_8 != 0);
      if (!__pyx_t_15) {
      } else {
        __pyx_t_2 = __pyx_t_15;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_15 = (__pyx_v_allow_unknown_modifications != 0);
      __pyx_t_2 = __pyx_t_15;
      __pyx_L30_bool_binop_done:;

      /* "pyteomics/cparser.pyx":333
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\
 *                 not ((mod+X in _labels) or\             # <<<<<<<<<<<<<<
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(tgroup))
 */
      __pyx_t_15 = ((!__pyx_t_2) != 0);
      __pyx_t_1 = __pyx_t_15;
      __pyx_L27_bool_binop_done:;

      /* "pyteomics/cparser.pyx":332
 *                 mod = ''
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      if (unlikely(__pyx_t_1)) {

        /* "pyteomics/cparser.pyx":335
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(tgroup))             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Unknown_label, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_v_tgroup) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_tgroup);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 335, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":332
 *                 mod = ''
 *                 X = <str>PyTuple_GET_ITEM(tgroup, 0)
 *             if ((not mod) and X not in _labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      }
    }

    /* "pyteomics/cparser.pyx":322
 *             raise PyteomicsError('Unknown label: {}'.format(cterm))
 * 
 *     if split:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):
 */
    goto __pyx_L22;
  }

  /* "pyteomics/cparser.pyx":338
 * 
 *     else:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(PyList_Size(parsed_sequence)):
 *             sgroup = <str>PyList_GET_ITEM(parsed_sequence, i)
 */
  /*else*/ {
    __pyx_v_i = 0;

    /* "pyteomics/cparser.pyx":339
 *     else:
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):             # <<<<<<<<<<<<<<
 *             sgroup = <str>PyList_GET_ITEM(parsed_sequence, i)
 * 
 */
    __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 339, __pyx_L1_error)
    __pyx_t_12 = __pyx_t_11;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_i = __pyx_t_13;

      /* "pyteomics/cparser.pyx":340
 *         i = 0
 *         for i in range(PyList_Size(parsed_sequence)):
 *             sgroup = <str>PyList_GET_ITEM(parsed_sequence, i)             # <<<<<<<<<<<<<<
 * 
 *             match = PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>sgroup, NULL)
 */
      __pyx_t_7 = PyList_GET_ITEM(__pyx_v_parsed_sequence, __pyx_v_i);
      __pyx_t_4 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_sgroup, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":342
 *             sgroup = <str>PyList_GET_ITEM(parsed_sequence, i)
 * 
 *             match = PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>sgroup, NULL)             # <<<<<<<<<<<<<<
 *             temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *             mod = <str>PyTuple_GET_ITEM(temp, 0)
 */
      __pyx_t_4 = __pyx_v_9pyteomics_7cparser__modX_split;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = PyObject_CallMethodObjArgs(__pyx_t_4, __pyx_n_s_match, ((PyObject *)__pyx_v_sgroup), NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 342, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_match, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":343
 * 
 *             match = PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>sgroup, NULL)
 *             temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)             # <<<<<<<<<<<<<<
 *             mod = <str>PyTuple_GET_ITEM(temp, 0)
 *             X = <str>PyTuple_GET_ITEM(temp, 1)
 */
      __pyx_t_3 = PyObject_CallMethodObjArgs(__pyx_v_match, __pyx_n_s_groups, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __pyx_t_3;
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":344
 *             match = PyObject_CallMethodObjArgs(_modX_split, "match", <PyObject*>sgroup, NULL)
 *             temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *             mod = <str>PyTuple_GET_ITEM(temp, 0)             # <<<<<<<<<<<<<<
 *             X = <str>PyTuple_GET_ITEM(temp, 1)
 *             is_mod = PyObject_IsTrue(mod)
 */
      __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_temp, 0);
      __pyx_t_4 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_mod, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":345
 *             temp = <tuple>PyObject_CallMethodObjArgs(match, "groups", NULL)
 *             mod = <str>PyTuple_GET_ITEM(temp, 0)
 *             X = <str>PyTuple_GET_ITEM(temp, 1)             # <<<<<<<<<<<<<<
 *             is_mod = PyObject_IsTrue(mod)
 *             in_labels = X not in _labels
 */
      __pyx_t_7 = PyTuple_GET_ITEM(__pyx_v_temp, 1);
      __pyx_t_4 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_X, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":346
 *             mod = <str>PyTuple_GET_ITEM(temp, 0)
 *             X = <str>PyTuple_GET_ITEM(temp, 1)
 *             is_mod = PyObject_IsTrue(mod)             # <<<<<<<<<<<<<<
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\
 */
      __pyx_t_1 = PyObject_IsTrue(__pyx_v_mod); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 346, __pyx_L1_error)
      __pyx_v_is_mod = __pyx_t_1;

      /* "pyteomics/cparser.pyx":347
 *             X = <str>PyTuple_GET_ITEM(temp, 1)
 *             is_mod = PyObject_IsTrue(mod)
 *             in_labels = X not in _labels             # <<<<<<<<<<<<<<
 *             if ((not is_mod) and in_labels) or\
 *                 not ((mod+X in _labels) or\
 */
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_X, __pyx_v__labels, Py_NE)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 347, __pyx_L1_error)
      __pyx_v_in_labels = __pyx_t_1;

      /* "pyteomics/cparser.pyx":348
 *             is_mod = PyObject_IsTrue(mod)
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      __pyx_t_15 = ((!(__pyx_v_is_mod != 0)) != 0);
      if (!__pyx_t_15) {
        goto __pyx_L38_next_or;
      } else {
      }
      __pyx_t_15 = (__pyx_v_in_labels != 0);
      if (!__pyx_t_15) {
      } else {
        __pyx_t_1 = __pyx_t_15;
        goto __pyx_L37_bool_binop_done;
      }
      __pyx_L38_next_or:;

      /* "pyteomics/cparser.pyx":349
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\
 *                 not ((mod+X in _labels) or\             # <<<<<<<<<<<<<<
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(sgroup))
 */
      __pyx_t_4 = PyNumber_Add(__pyx_v_mod, __pyx_v_X); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (__pyx_t_2 != 0);
      if (!__pyx_t_8) {
      } else {
        __pyx_t_15 = __pyx_t_8;
        goto __pyx_L40_bool_binop_done;
      }

      /* "pyteomics/cparser.pyx":350
 *             if ((not is_mod) and in_labels) or\
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):             # <<<<<<<<<<<<<<
 *                 raise PyteomicsError('Unknown label: {}'.format(sgroup))
 * 
 */
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_X, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 350, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_8 != 0);
      if (__pyx_t_2) {
      } else {
        __pyx_t_15 = __pyx_t_2;
        goto __pyx_L40_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_mod, __pyx_v__labels, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 350, __pyx_L1_error)
      __pyx_t_8 = (__pyx_t_2 != 0);
      if (!__pyx_t_8) {
      } else {
        __pyx_t_15 = __pyx_t_8;
        goto __pyx_L40_bool_binop_done;
      }
      __pyx_t_8 = (__pyx_v_allow_unknown_modifications != 0);
      __pyx_t_15 = __pyx_t_8;
      __pyx_L40_bool_binop_done:;

      /* "pyteomics/cparser.pyx":349
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\
 *                 not ((mod+X in _labels) or\             # <<<<<<<<<<<<<<
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(sgroup))
 */
      __pyx_t_8 = ((!__pyx_t_15) != 0);
      __pyx_t_1 = __pyx_t_8;
      __pyx_L37_bool_binop_done:;

      /* "pyteomics/cparser.pyx":348
 *             is_mod = PyObject_IsTrue(mod)
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      if (unlikely(__pyx_t_1)) {

        /* "pyteomics/cparser.pyx":351
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 *                 raise PyteomicsError('Unknown label: {}'.format(sgroup))             # <<<<<<<<<<<<<<
 * 
 *     # Append terminal labels
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Unknown_label, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_v_sgroup) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_sgroup);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 351, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":348
 *             is_mod = PyObject_IsTrue(mod)
 *             in_labels = X not in _labels
 *             if ((not is_mod) and in_labels) or\             # <<<<<<<<<<<<<<
 *                 not ((mod+X in _labels) or\
 *                 (X in _labels and (mod in _labels or allow_unknown_modifications))):
 */
      }
    }
  }
  __pyx_L22:;

  /* "pyteomics/cparser.pyx":354
 * 
 *     # Append terminal labels
 *     if show_unmodified_termini or nterm != std_nterm:             # <<<<<<<<<<<<<<
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 */
  __pyx_t_8 = (__pyx_v_show_unmodified_termini != 0);
  if (!__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L45_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_nterm, __pyx_v_9pyteomics_7cparser_std_nterm, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 354, __pyx_L1_error)
  __pyx_t_15 = (__pyx_t_8 != 0);
  __pyx_t_1 = __pyx_t_15;
  __pyx_L45_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":355
 *     # Append terminal labels
 *     if show_unmodified_termini or nterm != std_nterm:
 *         if split:             # <<<<<<<<<<<<<<
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 *             temp = (<str>nterm, ) + temp
 */
    __pyx_t_1 = (__pyx_v_split != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":356
 *     if show_unmodified_termini or nterm != std_nterm:
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)             # <<<<<<<<<<<<<<
 *             temp = (<str>nterm, ) + temp
 *             Py_INCREF(temp)
 */
      __pyx_t_7 = PyList_GET_ITEM(__pyx_v_parsed_sequence, 0);
      __pyx_t_4 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":357
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 *             temp = (<str>nterm, ) + temp             # <<<<<<<<<<<<<<
 *             Py_INCREF(temp)
 *             PyList_SET_ITEM(<list>parsed_sequence, 0, tuple(temp))
 */
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject*)__pyx_v_nterm));
      __Pyx_GIVEREF(__pyx_v_nterm);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_nterm);
      __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_v_temp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":358
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 *             temp = (<str>nterm, ) + temp
 *             Py_INCREF(temp)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(<list>parsed_sequence, 0, tuple(temp))
 *         else:
 */
      Py_INCREF(__pyx_v_temp);

      /* "pyteomics/cparser.pyx":359
 *             temp = (<str>nterm, ) + temp
 *             Py_INCREF(temp)
 *             PyList_SET_ITEM(<list>parsed_sequence, 0, tuple(temp))             # <<<<<<<<<<<<<<
 *         else:
 *             PyList_Insert(parsed_sequence, 0, nterm)
 */
      PyList_SET_ITEM(__pyx_v_parsed_sequence, 0, __pyx_v_temp);

      /* "pyteomics/cparser.pyx":355
 *     # Append terminal labels
 *     if show_unmodified_termini or nterm != std_nterm:
 *         if split:             # <<<<<<<<<<<<<<
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 *             temp = (<str>nterm, ) + temp
 */
      goto __pyx_L47;
    }

    /* "pyteomics/cparser.pyx":361
 *             PyList_SET_ITEM(<list>parsed_sequence, 0, tuple(temp))
 *         else:
 *             PyList_Insert(parsed_sequence, 0, nterm)             # <<<<<<<<<<<<<<
 *     if show_unmodified_termini or cterm != std_cterm:
 *         if split:
 */
    /*else*/ {
      __pyx_t_16 = PyList_Insert(__pyx_v_parsed_sequence, 0, __pyx_v_nterm); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 361, __pyx_L1_error)
    }
    __pyx_L47:;

    /* "pyteomics/cparser.pyx":354
 * 
 *     # Append terminal labels
 *     if show_unmodified_termini or nterm != std_nterm:             # <<<<<<<<<<<<<<
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, 0)
 */
  }

  /* "pyteomics/cparser.pyx":362
 *         else:
 *             PyList_Insert(parsed_sequence, 0, nterm)
 *     if show_unmodified_termini or cterm != std_cterm:             # <<<<<<<<<<<<<<
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 */
  __pyx_t_15 = (__pyx_v_show_unmodified_termini != 0);
  if (!__pyx_t_15) {
  } else {
    __pyx_t_1 = __pyx_t_15;
    goto __pyx_L49_bool_binop_done;
  }
  __pyx_t_15 = (__Pyx_PyString_Equals(__pyx_v_cterm, __pyx_v_9pyteomics_7cparser_std_cterm, Py_NE)); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 362, __pyx_L1_error)
  __pyx_t_8 = (__pyx_t_15 != 0);
  __pyx_t_1 = __pyx_t_8;
  __pyx_L49_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":363
 *             PyList_Insert(parsed_sequence, 0, nterm)
 *     if show_unmodified_termini or cterm != std_cterm:
 *         if split:             # <<<<<<<<<<<<<<
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 *             temp = temp + (cterm,)
 */
    __pyx_t_1 = (__pyx_v_split != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":364
 *     if show_unmodified_termini or cterm != std_cterm:
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)             # <<<<<<<<<<<<<<
 *             temp = temp + (cterm,)
 *             Py_INCREF(temp)
 */
      if (unlikely(__pyx_v_parsed_sequence == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 364, __pyx_L1_error)
      }
      __pyx_t_11 = PyList_GET_SIZE(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 364, __pyx_L1_error)
      __pyx_t_7 = PyList_GET_ITEM(__pyx_v_parsed_sequence, (__pyx_t_11 - 1));
      __pyx_t_3 = ((PyObject *)__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":365
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 *             temp = temp + (cterm,)             # <<<<<<<<<<<<<<
 *             Py_INCREF(temp)
 *             PyList_SET_ITEM(parsed_sequence, len(parsed_sequence) - 1, temp)
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_cterm);
      __Pyx_GIVEREF(__pyx_v_cterm);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_cterm);
      __pyx_t_4 = PyNumber_Add(__pyx_v_temp, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":366
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 *             temp = temp + (cterm,)
 *             Py_INCREF(temp)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(parsed_sequence, len(parsed_sequence) - 1, temp)
 *         else:
 */
      Py_INCREF(__pyx_v_temp);

      /* "pyteomics/cparser.pyx":367
 *             temp = temp + (cterm,)
 *             Py_INCREF(temp)
 *             PyList_SET_ITEM(parsed_sequence, len(parsed_sequence) - 1, temp)             # <<<<<<<<<<<<<<
 *         else:
 *             PyList_Append(parsed_sequence, cterm)
 */
      if (unlikely(__pyx_v_parsed_sequence == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 367, __pyx_L1_error)
      }
      __pyx_t_11 = PyList_GET_SIZE(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 367, __pyx_L1_error)
      PyList_SET_ITEM(__pyx_v_parsed_sequence, (__pyx_t_11 - 1), __pyx_v_temp);

      /* "pyteomics/cparser.pyx":363
 *             PyList_Insert(parsed_sequence, 0, nterm)
 *     if show_unmodified_termini or cterm != std_cterm:
 *         if split:             # <<<<<<<<<<<<<<
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 *             temp = temp + (cterm,)
 */
      goto __pyx_L51;
    }

    /* "pyteomics/cparser.pyx":369
 *             PyList_SET_ITEM(parsed_sequence, len(parsed_sequence) - 1, temp)
 *         else:
 *             PyList_Append(parsed_sequence, cterm)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_16 = PyList_Append(__pyx_v_parsed_sequence, __pyx_v_cterm); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 369, __pyx_L1_error)
    }
    __pyx_L51:;

    /* "pyteomics/cparser.pyx":362
 *         else:
 *             PyList_Insert(parsed_sequence, 0, nterm)
 *     if show_unmodified_termini or cterm != std_cterm:             # <<<<<<<<<<<<<<
 *         if split:
 *             temp = <tuple>PyList_GET_ITEM(parsed_sequence, len(parsed_sequence) - 1)
 */
  }

  /* "pyteomics/cparser.pyx":372
 * 
 * 
 *     return parsed_sequence             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_parsed_sequence);
  __pyx_r = __pyx_v_parsed_sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":211
 * 
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=0, bint split=0,             # <<<<<<<<<<<<<<
 *                  bint allow_unknown_modifications=0, object labels=None):
 *     """Parse a sequence string written in modX notation into a list of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyteomics.cparser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_match);
  __Pyx_XDECREF(__pyx_v_temp);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XDECREF(__pyx_v_nterm);
  __Pyx_XDECREF(__pyx_v_cterm);
  __Pyx_XDECREF(__pyx_v_mod);
  __Pyx_XDECREF(__pyx_v_X);
  __Pyx_XDECREF(__pyx_v_parsed_sequence);
  __Pyx_XDECREF(__pyx_v_tgroup);
  __Pyx_XDECREF(__pyx_v_sgroup);
  __Pyx_XDECREF(__pyx_v__labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_5parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_4parse[] = "parse(str sequence, bool show_unmodified_termini=0, bool split=0, bool allow_unknown_modifications=0, labels=None) -> list\nParse a sequence string written in modX notation into a list of\n    labels or (if `split` argument is :py:const:`True`) into a list of\n    tuples representing amino acid residues and their modifications.\n\n    Parameters\n    ----------\n    sequence : str\n        The sequence of a polypeptide.\n    show_unmodified_termini : bool, optional\n        If :py:const:`True` then the unmodified N- and C-termini are explicitly\n        shown in the returned list. Default value is :py:const:`False`.\n    split : bool, optional\n        If :py:const:`True` then the result will be a list of tuples with 1 to 4\n        elements: terminal modification, modification, residue. Default value is\n        :py:const:`False`.\n    allow_unknown_modifications : bool, optional\n        If :py:const:`True` then do not raise an exception when an unknown\n        modification of a known amino acid residue is found in the sequence.\n        This also includes terminal groups.\n        Default value is :py:const:`False`.\n\n        .. note::\n            Since version 2.5, this parameter has effect only if `labels`\n            are provided.\n    labels : container, optional\n        A container of allowed labels for amino acids,\n        modifications and terminal modifications.\n        If not provided, no checks will be done.\n        Separate labels for modifications (such as 'p' or 'ox')\n        can be supplied, which means they are applicable to all residues.\n\n        .. warning::\n            If `show_unmodified_termini` is set to :py:const:`True`, standard\n            terminal groups need to be present in `labels`.\n\n        .. warning::\n            Avoid using sequences with only one terminal group, as they are\n            ambiguous. If you provide one, `labels` (or :py:const:`std_labels`)\n            will be used to resolve the ambiguity.\n\n    Ret""urns\n    -------\n    out : list\n        List of tuples with labels of modifications and amino acid residues.\n\n    Examples\n    --------\n    >>> parse('PEPTIDE', split=True)\n    [('P',), ('E',), ('P',), ('T',), ('I',), ('D',), ('E',)]\n    >>> parse('H-PEPTIDE')\n    ['P', 'E', 'P', 'T', 'I', 'D', 'E']\n    >>> parse('PEPTIDE', show_unmodified_termini=True)\n    ['H-', 'P', 'E', 'P', 'T', 'I', 'D', 'E', '-OH']\n    >>> parse('TEpSToxM', labels=std_labels + ['pS', 'oxM'])\n    ['T', 'E', 'pS', 'T', 'oxM']\n    >>> parse('zPEPzTIDzE', True, True, labels=std_labels+['z'])\n    [('H-', 'z', 'P'), ('E',), ('P',), ('z', 'T'), ('I',), ('D',), ('z', 'E', '-OH')]\n    ";
static PyObject *__pyx_pw_9pyteomics_7cparser_5parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_v_show_unmodified_termini;
  int __pyx_v_split;
  int __pyx_v_allow_unknown_modifications;
  PyObject *__pyx_v_labels = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_show_unmodified_termini,&__pyx_n_s_split,&__pyx_n_s_allow_unknown_modifications,&__pyx_n_s_labels,0};
    PyObject* values[5] = {0,0,0,0,0};

    /* "pyteomics/cparser.pyx":212
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=0, bint split=0,
 *                  bint allow_unknown_modifications=0, object labels=None):             # <<<<<<<<<<<<<<
 *     """Parse a sequence string written in modX notation into a list of
 *     labels or (if `split` argument is :py:const:`True`) into a list of
 */
    values[4] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_split);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_allow_unknown_modifications);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse") < 0)) __PYX_ERR(0, 211, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_show_unmodified_termini = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_show_unmodified_termini == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 211, __pyx_L3_error)
    } else {
      __pyx_v_show_unmodified_termini = ((int)0);
    }
    if (values[2]) {
      __pyx_v_split = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_split == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 211, __pyx_L3_error)
    } else {
      __pyx_v_split = ((int)0);
    }
    if (values[3]) {
      __pyx_v_allow_unknown_modifications = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_allow_unknown_modifications == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 212, __pyx_L3_error)
    } else {
      __pyx_v_allow_unknown_modifications = ((int)0);
    }
    __pyx_v_labels = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 211, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyString_Type), 1, "sequence", 1))) __PYX_ERR(0, 211, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_4parse(__pyx_self, __pyx_v_sequence, __pyx_v_show_unmodified_termini, __pyx_v_split, __pyx_v_allow_unknown_modifications, __pyx_v_labels);

  /* "pyteomics/cparser.pyx":211
 * 
 * 
 * cpdef list parse(str sequence, bint show_unmodified_termini=0, bint split=0,             # <<<<<<<<<<<<<<
 *                  bint allow_unknown_modifications=0, object labels=None):
 *     """Parse a sequence string written in modX notation into a list of
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_4parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_split, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_parse __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 4;
  __pyx_t_2.show_unmodified_termini = __pyx_v_show_unmodified_termini;
  __pyx_t_2.split = __pyx_v_split;
  __pyx_t_2.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
  __pyx_t_2.labels = __pyx_v_labels;
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_parse(__pyx_v_sequence, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":375
 * 
 * 
 * cdef list _tokenize_modx_sequence(str sequence, bint split=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         char* csequence
 */

static PyObject *__pyx_f_9pyteomics_7cparser__tokenize_modx_sequence(PyObject *__pyx_v_sequence, struct __pyx_opt_args_9pyteomics_7cparser__tokenize_modx_sequence *__pyx_optional_args) {
  int __pyx_v_split = ((int)1);
  char *__pyx_v_csequence;
  char __pyx_v_c;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_parsed_n;
  Py_ssize_t __pyx_v_start;
  Py_ssize_t __pyx_v_end;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_v_nterm = 0;
  PyObject *__pyx_v_cterm = 0;
  PyObject *__pyx_v_mod = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_tokenize_modx_sequence", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_split = __pyx_optional_args->split;
    }
  }

  /* "pyteomics/cparser.pyx":383
 *         str nterm, cterm
 * 
 *     start = 0             # <<<<<<<<<<<<<<
 *     end = 0
 *     tokens = []
 */
  __pyx_v_start = 0;

  /* "pyteomics/cparser.pyx":384
 * 
 *     start = 0
 *     end = 0             # <<<<<<<<<<<<<<
 *     tokens = []
 *     i = 0
 */
  __pyx_v_end = 0;

  /* "pyteomics/cparser.pyx":385
 *     start = 0
 *     end = 0
 *     tokens = []             # <<<<<<<<<<<<<<
 *     i = 0
 *     parsed_n = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tokens = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":386
 *     end = 0
 *     tokens = []
 *     i = 0             # <<<<<<<<<<<<<<
 *     parsed_n = 0
 *     csequence = PyStr_AsUTF8AndSize(sequence, &n)
 */
  __pyx_v_i = 0;

  /* "pyteomics/cparser.pyx":387
 *     tokens = []
 *     i = 0
 *     parsed_n = 0             # <<<<<<<<<<<<<<
 *     csequence = PyStr_AsUTF8AndSize(sequence, &n)
 *     nterm = None
 */
  __pyx_v_parsed_n = 0;

  /* "pyteomics/cparser.pyx":388
 *     i = 0
 *     parsed_n = 0
 *     csequence = PyStr_AsUTF8AndSize(sequence, &n)             # <<<<<<<<<<<<<<
 *     nterm = None
 *     cterm = None
 */
  __pyx_v_csequence = PyStr_AsUTF8AndSize(__pyx_v_sequence, (&__pyx_v_n));

  /* "pyteomics/cparser.pyx":389
 *     parsed_n = 0
 *     csequence = PyStr_AsUTF8AndSize(sequence, &n)
 *     nterm = None             # <<<<<<<<<<<<<<
 *     cterm = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_nterm = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":390
 *     csequence = PyStr_AsUTF8AndSize(sequence, &n)
 *     nterm = None
 *     cterm = None             # <<<<<<<<<<<<<<
 * 
 *     while i < n:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_cterm = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":392
 *     cterm = None
 * 
 *     while i < n:             # <<<<<<<<<<<<<<
 *         c = csequence[i]
 *         # We've reached an amino acid. Process the current modX block
 */
  while (1) {
    __pyx_t_2 = ((__pyx_v_i < __pyx_v_n) != 0);
    if (!__pyx_t_2) break;

    /* "pyteomics/cparser.pyx":393
 * 
 *     while i < n:
 *         c = csequence[i]             # <<<<<<<<<<<<<<
 *         # We've reached an amino acid. Process the current modX block
 *         if isupper(c):
 */
    __pyx_v_c = (__pyx_v_csequence[__pyx_v_i]);

    /* "pyteomics/cparser.pyx":395
 *         c = csequence[i]
 *         # We've reached an amino acid. Process the current modX block
 *         if isupper(c):             # <<<<<<<<<<<<<<
 *             end = i + 1
 *             if not split:
 */
    __pyx_t_2 = (isupper(__pyx_v_c) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":396
 *         # We've reached an amino acid. Process the current modX block
 *         if isupper(c):
 *             end = i + 1             # <<<<<<<<<<<<<<
 *             if not split:
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))
 */
      __pyx_v_end = (__pyx_v_i + 1);

      /* "pyteomics/cparser.pyx":397
 *         if isupper(c):
 *             end = i + 1
 *             if not split:             # <<<<<<<<<<<<<<
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))
 *             else:
 */
      __pyx_t_2 = ((!(__pyx_v_split != 0)) != 0);
      if (__pyx_t_2) {

        /* "pyteomics/cparser.pyx":398
 *             end = i + 1
 *             if not split:
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))             # <<<<<<<<<<<<<<
 *             else:
 *                 if end - start > 1:
 */
        __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[__pyx_v_start])), (__pyx_v_end - __pyx_v_start)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_tokens, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":397
 *         if isupper(c):
 *             end = i + 1
 *             if not split:             # <<<<<<<<<<<<<<
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))
 *             else:
 */
        goto __pyx_L6;
      }

      /* "pyteomics/cparser.pyx":400
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))
 *             else:
 *                 if end - start > 1:             # <<<<<<<<<<<<<<
 *                     mod = PyStr_FromStringAndSize(&csequence[start], (end - start) - 1)
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 */
      /*else*/ {
        __pyx_t_2 = (((__pyx_v_end - __pyx_v_start) > 1) != 0);
        if (__pyx_t_2) {

          /* "pyteomics/cparser.pyx":401
 *             else:
 *                 if end - start > 1:
 *                     mod = PyStr_FromStringAndSize(&csequence[start], (end - start) - 1)             # <<<<<<<<<<<<<<
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 *                     tokens.append((mod, x))
 */
          __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[__pyx_v_start])), ((__pyx_v_end - __pyx_v_start) - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 401, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_mod, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":402
 *                 if end - start > 1:
 *                     mod = PyStr_FromStringAndSize(&csequence[start], (end - start) - 1)
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)             # <<<<<<<<<<<<<<
 *                     tokens.append((mod, x))
 *                 else:
 */
          __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[(__pyx_v_end - 1)])), 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":403
 *                     mod = PyStr_FromStringAndSize(&csequence[start], (end - start) - 1)
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 *                     tokens.append((mod, x))             # <<<<<<<<<<<<<<
 *                 else:
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 */
          __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_v_mod);
          __Pyx_GIVEREF(__pyx_v_mod);
          PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mod);
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_x);
          __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_tokens, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 403, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":400
 *                 tokens.append(PyStr_FromStringAndSize(&csequence[start], end - start))
 *             else:
 *                 if end - start > 1:             # <<<<<<<<<<<<<<
 *                     mod = PyStr_FromStringAndSize(&csequence[start], (end - start) - 1)
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 */
          goto __pyx_L7;
        }

        /* "pyteomics/cparser.pyx":405
 *                     tokens.append((mod, x))
 *                 else:
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)             # <<<<<<<<<<<<<<
 *                     tokens.append((x, ))
 *             parsed_n += 1
 */
        /*else*/ {
          __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[(__pyx_v_end - 1)])), 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":406
 *                 else:
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 *                     tokens.append((x, ))             # <<<<<<<<<<<<<<
 *             parsed_n += 1
 *             start = i + 1
 */
          __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 406, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
          __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_tokens, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 406, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L7:;
      }
      __pyx_L6:;

      /* "pyteomics/cparser.pyx":407
 *                     x = PyStr_FromStringAndSize(&csequence[end - 1], 1)
 *                     tokens.append((x, ))
 *             parsed_n += 1             # <<<<<<<<<<<<<<
 *             start = i + 1
 *         # We've reached a terminal modification boundary
 */
      __pyx_v_parsed_n = (__pyx_v_parsed_n + 1);

      /* "pyteomics/cparser.pyx":408
 *                     tokens.append((x, ))
 *             parsed_n += 1
 *             start = i + 1             # <<<<<<<<<<<<<<
 *         # We've reached a terminal modification boundary
 *         elif c == '-':
 */
      __pyx_v_start = (__pyx_v_i + 1);

      /* "pyteomics/cparser.pyx":395
 *         c = csequence[i]
 *         # We've reached an amino acid. Process the current modX block
 *         if isupper(c):             # <<<<<<<<<<<<<<
 *             end = i + 1
 *             if not split:
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":410
 *             start = i + 1
 *         # We've reached a terminal modification boundary
 *         elif c == '-':             # <<<<<<<<<<<<<<
 *             # If we haven't parsed any other tokens
 *             if parsed_n == 0:
 */
    __pyx_t_2 = ((__pyx_v_c == '-') != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":412
 *         elif c == '-':
 *             # If we haven't parsed any other tokens
 *             if parsed_n == 0:             # <<<<<<<<<<<<<<
 *                 end = i + 1
 *                 if split:
 */
      __pyx_t_2 = ((__pyx_v_parsed_n == 0) != 0);
      if (__pyx_t_2) {

        /* "pyteomics/cparser.pyx":413
 *             # If we haven't parsed any other tokens
 *             if parsed_n == 0:
 *                 end = i + 1             # <<<<<<<<<<<<<<
 *                 if split:
 *                     nterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 */
        __pyx_v_end = (__pyx_v_i + 1);

        /* "pyteomics/cparser.pyx":414
 *             if parsed_n == 0:
 *                 end = i + 1
 *                 if split:             # <<<<<<<<<<<<<<
 *                     nterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *                 else:
 */
        __pyx_t_2 = (__pyx_v_split != 0);
        if (__pyx_t_2) {

          /* "pyteomics/cparser.pyx":415
 *                 end = i + 1
 *                 if split:
 *                     nterm = PyStr_FromStringAndSize(&csequence[start], end - start)             # <<<<<<<<<<<<<<
 *                 else:
 *                     tokens.append(nterm)
 */
          __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[__pyx_v_start])), (__pyx_v_end - __pyx_v_start)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_nterm, ((PyObject*)__pyx_t_1));
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":414
 *             if parsed_n == 0:
 *                 end = i + 1
 *                 if split:             # <<<<<<<<<<<<<<
 *                     nterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *                 else:
 */
          goto __pyx_L9;
        }

        /* "pyteomics/cparser.pyx":417
 *                     nterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *                 else:
 *                     tokens.append(nterm)             # <<<<<<<<<<<<<<
 *                 start = i + 1
 * 
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_tokens, __pyx_v_nterm); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 417, __pyx_L1_error)
        }
        __pyx_L9:;

        /* "pyteomics/cparser.pyx":418
 *                 else:
 *                     tokens.append(nterm)
 *                 start = i + 1             # <<<<<<<<<<<<<<
 * 
 *         i += 1
 */
        __pyx_v_start = (__pyx_v_i + 1);

        /* "pyteomics/cparser.pyx":412
 *         elif c == '-':
 *             # If we haven't parsed any other tokens
 *             if parsed_n == 0:             # <<<<<<<<<<<<<<
 *                 end = i + 1
 *                 if split:
 */
      }

      /* "pyteomics/cparser.pyx":410
 *             start = i + 1
 *         # We've reached a terminal modification boundary
 *         elif c == '-':             # <<<<<<<<<<<<<<
 *             # If we haven't parsed any other tokens
 *             if parsed_n == 0:
 */
    }
    __pyx_L5:;

    /* "pyteomics/cparser.pyx":420
 *                 start = i + 1
 * 
 *         i += 1             # <<<<<<<<<<<<<<
 *     end = n
 *     # The end of the last position was different from the end of the string so we must have
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }

  /* "pyteomics/cparser.pyx":421
 * 
 *         i += 1
 *     end = n             # <<<<<<<<<<<<<<
 *     # The end of the last position was different from the end of the string so we must have
 *     # a C-terminal
 */
  __pyx_v_end = __pyx_v_n;

  /* "pyteomics/cparser.pyx":424
 *     # The end of the last position was different from the end of the string so we must have
 *     # a C-terminal
 *     if start != end:             # <<<<<<<<<<<<<<
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *         if not split:
 */
  __pyx_t_2 = ((__pyx_v_start != __pyx_v_end) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":425
 *     # a C-terminal
 *     if start != end:
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)             # <<<<<<<<<<<<<<
 *         if not split:
 *             tokens.append(cterm)
 */
    __pyx_t_1 = PyStr_FromStringAndSize((&(__pyx_v_csequence[__pyx_v_start])), (__pyx_v_end - __pyx_v_start)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_cterm, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":426
 *     if start != end:
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *         if not split:             # <<<<<<<<<<<<<<
 *             tokens.append(cterm)
 *         else:
 */
    __pyx_t_2 = ((!(__pyx_v_split != 0)) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":427
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *         if not split:
 *             tokens.append(cterm)             # <<<<<<<<<<<<<<
 *         else:
 *             tokens[-1] = tokens[-1] + (cterm, )
 */
      __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_tokens, __pyx_v_cterm); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 427, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":426
 *     if start != end:
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *         if not split:             # <<<<<<<<<<<<<<
 *             tokens.append(cterm)
 *         else:
 */
      goto __pyx_L11;
    }

    /* "pyteomics/cparser.pyx":429
 *             tokens.append(cterm)
 *         else:
 *             tokens[-1] = tokens[-1] + (cterm, )             # <<<<<<<<<<<<<<
 *     if split and nterm:
 *         tokens[0] = (nterm, ) + tokens[0]
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_tokens, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_cterm);
      __Pyx_GIVEREF(__pyx_v_cterm);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_cterm);
      __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(__Pyx_SetItemInt(__pyx_v_tokens, -1L, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 1, 1, 1) < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L11:;

    /* "pyteomics/cparser.pyx":424
 *     # The end of the last position was different from the end of the string so we must have
 *     # a C-terminal
 *     if start != end:             # <<<<<<<<<<<<<<
 *         cterm = PyStr_FromStringAndSize(&csequence[start], end - start)
 *         if not split:
 */
  }

  /* "pyteomics/cparser.pyx":430
 *         else:
 *             tokens[-1] = tokens[-1] + (cterm, )
 *     if split and nterm:             # <<<<<<<<<<<<<<
 *         tokens[0] = (nterm, ) + tokens[0]
 *     return tokens
 */
  __pyx_t_6 = (__pyx_v_split != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_nterm); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 430, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_6;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":431
 *             tokens[-1] = tokens[-1] + (cterm, )
 *     if split and nterm:
 *         tokens[0] = (nterm, ) + tokens[0]             # <<<<<<<<<<<<<<
 *     return tokens
 * 
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_nterm);
    __Pyx_GIVEREF(__pyx_v_nterm);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_nterm);
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__Pyx_SetItemInt(__pyx_v_tokens, 0, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 431, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":430
 *         else:
 *             tokens[-1] = tokens[-1] + (cterm, )
 *     if split and nterm:             # <<<<<<<<<<<<<<
 *         tokens[0] = (nterm, ) + tokens[0]
 *     return tokens
 */
  }

  /* "pyteomics/cparser.pyx":432
 *     if split and nterm:
 *         tokens[0] = (nterm, ) + tokens[0]
 *     return tokens             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tokens);
  __pyx_r = __pyx_v_tokens;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":375
 * 
 * 
 * cdef list _tokenize_modx_sequence(str sequence, bint split=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         char* csequence
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser._tokenize_modx_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_nterm);
  __Pyx_XDECREF(__pyx_v_cterm);
  __Pyx_XDECREF(__pyx_v_mod);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":435
 * 
 * 
 * cpdef str tostring(object parsed_sequence, bint show_unmodified_termini=True):             # <<<<<<<<<<<<<<
 *     """Create a string from a parsed sequence.
 * 
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_7tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_tostring(PyObject *__pyx_v_parsed_sequence, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_tostring *__pyx_optional_args) {
  int __pyx_v_show_unmodified_termini = ((int)1);
  PyObject *__pyx_v_group = 0;
  PyObject *__pyx_v_group_j = 0;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_acc;
  Py_ssize_t __pyx_v_sz;
  Py_ssize_t __pyx_v_j;
  Py_ssize_t __pyx_v_m;
  Py_ssize_t __pyx_v_k;
  PyObject *__pyx_v_sequence_fast = 0;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_pos = 0;
  PyObject *__pyx_v_result = 0;
  char *__pyx_v_cstr;
  char __pyx_v_prealloc_buffer[0x96];
  char *__pyx_v_string_buffer;
  int __pyx_v_needs_free;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tostring", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_show_unmodified_termini = __pyx_optional_args->show_unmodified_termini;
    }
  }

  /* "pyteomics/cparser.pyx":468
 *         char* string_buffer
 *         bint needs_free
 *     needs_free = False             # <<<<<<<<<<<<<<
 *     sz = 0
 *     acc = 0
 */
  __pyx_v_needs_free = 0;

  /* "pyteomics/cparser.pyx":469
 *         bint needs_free
 *     needs_free = False
 *     sz = 0             # <<<<<<<<<<<<<<
 *     acc = 0
 *     sequence_fast = PySequence_Fast(parsed_sequence, "tostring requires an iterable sequence!")
 */
  __pyx_v_sz = 0;

  /* "pyteomics/cparser.pyx":470
 *     needs_free = False
 *     sz = 0
 *     acc = 0             # <<<<<<<<<<<<<<
 *     sequence_fast = PySequence_Fast(parsed_sequence, "tostring requires an iterable sequence!")
 *     n = PySequence_Fast_GET_SIZE(sequence_fast)
 */
  __pyx_v_acc = 0;

  /* "pyteomics/cparser.pyx":471
 *     sz = 0
 *     acc = 0
 *     sequence_fast = PySequence_Fast(parsed_sequence, "tostring requires an iterable sequence!")             # <<<<<<<<<<<<<<
 *     n = PySequence_Fast_GET_SIZE(sequence_fast)
 *     for i in range(n):
 */
  __pyx_t_1 = PySequence_Fast(__pyx_v_parsed_sequence, ((char *)"tostring requires an iterable sequence!")); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":472
 *     acc = 0
 *     sequence_fast = PySequence_Fast(parsed_sequence, "tostring requires an iterable sequence!")
 *     n = PySequence_Fast_GET_SIZE(sequence_fast)             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 */
  __pyx_v_n = PySequence_Fast_GET_SIZE(__pyx_v_sequence_fast);

  /* "pyteomics/cparser.pyx":473
 *     sequence_fast = PySequence_Fast(parsed_sequence, "tostring requires an iterable sequence!")
 *     n = PySequence_Fast_GET_SIZE(sequence_fast)
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "pyteomics/cparser.pyx":474
 *     n = PySequence_Fast_GET_SIZE(sequence_fast)
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)             # <<<<<<<<<<<<<<
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)
 */
    __pyx_t_5 = PySequence_Fast_GET_ITEM(__pyx_v_sequence_fast, __pyx_v_i);
    __pyx_t_1 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_group, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":475
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):             # <<<<<<<<<<<<<<
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 */
    __pyx_t_6 = PyTuple_Check(__pyx_v_group); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":476
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)             # <<<<<<<<<<<<<<
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)
 */
      __pyx_t_8 = PyTuple_Size(__pyx_v_group); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 476, __pyx_L1_error)
      __pyx_v_m = __pyx_t_8;

      /* "pyteomics/cparser.pyx":477
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)
 *             for j in range(m):             # <<<<<<<<<<<<<<
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 PyStr_AsUTF8AndSize(group_j, &sz)
 */
      __pyx_t_8 = __pyx_v_m;
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_j = __pyx_t_10;

        /* "pyteomics/cparser.pyx":478
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)             # <<<<<<<<<<<<<<
 *                 PyStr_AsUTF8AndSize(group_j, &sz)
 *                 acc += sz
 */
        __pyx_t_5 = PyTuple_GetItem(__pyx_v_group, __pyx_v_j); if (unlikely(__pyx_t_5 == ((PyObject *)NULL))) __PYX_ERR(0, 478, __pyx_L1_error)
        __pyx_t_1 = ((PyObject *)__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_group_j, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":479
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 PyStr_AsUTF8AndSize(group_j, &sz)             # <<<<<<<<<<<<<<
 *                 acc += sz
 *         elif isinstance(group, str):
 */
        (void)(PyStr_AsUTF8AndSize(__pyx_v_group_j, (&__pyx_v_sz)));

        /* "pyteomics/cparser.pyx":480
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 PyStr_AsUTF8AndSize(group_j, &sz)
 *                 acc += sz             # <<<<<<<<<<<<<<
 *         elif isinstance(group, str):
 *             PyStr_AsUTF8AndSize(group, &sz)
 */
        __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);
      }

      /* "pyteomics/cparser.pyx":475
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):             # <<<<<<<<<<<<<<
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":481
 *                 PyStr_AsUTF8AndSize(group_j, &sz)
 *                 acc += sz
 *         elif isinstance(group, str):             # <<<<<<<<<<<<<<
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             acc += sz
 */
    __pyx_t_7 = PyString_Check(__pyx_v_group); 
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (__pyx_t_6) {

      /* "pyteomics/cparser.pyx":482
 *                 acc += sz
 *         elif isinstance(group, str):
 *             PyStr_AsUTF8AndSize(group, &sz)             # <<<<<<<<<<<<<<
 *             acc += sz
 *         elif isinstance(group, SequencePosition):
 */
      if (!(likely(PyString_CheckExact(__pyx_v_group))||((__pyx_v_group) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_group)->tp_name), 0))) __PYX_ERR(0, 482, __pyx_L1_error)
      (void)(PyStr_AsUTF8AndSize(((PyObject*)__pyx_v_group), (&__pyx_v_sz)));

      /* "pyteomics/cparser.pyx":483
 *         elif isinstance(group, str):
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             acc += sz             # <<<<<<<<<<<<<<
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group
 */
      __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

      /* "pyteomics/cparser.pyx":481
 *                 PyStr_AsUTF8AndSize(group_j, &sz)
 *                 acc += sz
 *         elif isinstance(group, str):             # <<<<<<<<<<<<<<
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             acc += sz
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":484
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             acc += sz
 *         elif isinstance(group, SequencePosition):             # <<<<<<<<<<<<<<
 *             pos = <SequencePosition>group
 *             if pos.terminal is not None:
 */
    __pyx_t_6 = __Pyx_TypeCheck(__pyx_v_group, __pyx_ptype_9pyteomics_7cparser_SequencePosition); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (likely(__pyx_t_7)) {

      /* "pyteomics/cparser.pyx":485
 *             acc += sz
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group             # <<<<<<<<<<<<<<
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
      __pyx_t_1 = __pyx_v_group;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pos, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":486
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 acc += sz
 */
      __pyx_t_7 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
      __pyx_t_6 = (__pyx_t_7 != 0);
      if (__pyx_t_6) {

        /* "pyteomics/cparser.pyx":487
 *             pos = <SequencePosition>group
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *                 acc += sz
 *             if pos.modification is not None:
 */
        __pyx_t_1 = __pyx_v_pos->terminal;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":488
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 acc += sz             # <<<<<<<<<<<<<<
 *             if pos.modification is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 */
        __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

        /* "pyteomics/cparser.pyx":486
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 acc += sz
 */
      }

      /* "pyteomics/cparser.pyx":489
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 acc += sz
 *             if pos.modification is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 acc += sz
 */
      __pyx_t_6 = (__pyx_v_pos->modification != ((PyObject*)Py_None));
      __pyx_t_7 = (__pyx_t_6 != 0);
      if (__pyx_t_7) {

        /* "pyteomics/cparser.pyx":490
 *                 acc += sz
 *             if pos.modification is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)             # <<<<<<<<<<<<<<
 *                 acc += sz
 *             if pos.amino_acid is not None:
 */
        __pyx_t_1 = __pyx_v_pos->modification;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":491
 *             if pos.modification is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 acc += sz             # <<<<<<<<<<<<<<
 *             if pos.amino_acid is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 */
        __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

        /* "pyteomics/cparser.pyx":489
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 acc += sz
 *             if pos.modification is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 acc += sz
 */
      }

      /* "pyteomics/cparser.pyx":492
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 acc += sz
 *             if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 acc += sz
 */
      __pyx_t_7 = (__pyx_v_pos->amino_acid != ((PyObject*)Py_None));
      __pyx_t_6 = (__pyx_t_7 != 0);
      if (__pyx_t_6) {

        /* "pyteomics/cparser.pyx":493
 *                 acc += sz
 *             if pos.amino_acid is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)             # <<<<<<<<<<<<<<
 *                 acc += sz
 *         else:
 */
        __pyx_t_1 = __pyx_v_pos->amino_acid;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":494
 *             if pos.amino_acid is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 acc += sz             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(type(group))
 */
        __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

        /* "pyteomics/cparser.pyx":492
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 acc += sz
 *             if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 acc += sz
 */
      }

      /* "pyteomics/cparser.pyx":484
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             acc += sz
 *         elif isinstance(group, SequencePosition):             # <<<<<<<<<<<<<<
 *             pos = <SequencePosition>group
 *             if pos.terminal is not None:
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":496
 *                 acc += sz
 *         else:
 *             raise TypeError(type(group))             # <<<<<<<<<<<<<<
 * 
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, ((PyObject *)Py_TYPE(__pyx_v_group))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 496, __pyx_L1_error)
    }
    __pyx_L5:;
  }

  /* "pyteomics/cparser.pyx":498
 *             raise TypeError(type(group))
 * 
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:             # <<<<<<<<<<<<<<
 *         string_buffer = prealloc_buffer
 *     else:
 */
  __pyx_t_6 = ((__pyx_v_acc < 0x96) != 0);
  if (__pyx_t_6) {

    /* "pyteomics/cparser.pyx":499
 * 
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:
 *         string_buffer = prealloc_buffer             # <<<<<<<<<<<<<<
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 */
    __pyx_v_string_buffer = __pyx_v_prealloc_buffer;

    /* "pyteomics/cparser.pyx":498
 *             raise TypeError(type(group))
 * 
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:             # <<<<<<<<<<<<<<
 *         string_buffer = prealloc_buffer
 *     else:
 */
    goto __pyx_L11;
  }

  /* "pyteomics/cparser.pyx":501
 *         string_buffer = prealloc_buffer
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)             # <<<<<<<<<<<<<<
 *         needs_free = True
 *     acc = 0
 */
  /*else*/ {
    __pyx_v_string_buffer = ((char *)malloc(((sizeof(char *)) * __pyx_v_acc)));

    /* "pyteomics/cparser.pyx":502
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 *         needs_free = True             # <<<<<<<<<<<<<<
 *     acc = 0
 *     for i in range(n):
 */
    __pyx_v_needs_free = 1;
  }
  __pyx_L11:;

  /* "pyteomics/cparser.pyx":503
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 *         needs_free = True
 *     acc = 0             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 */
  __pyx_v_acc = 0;

  /* "pyteomics/cparser.pyx":504
 *         needs_free = True
 *     acc = 0
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "pyteomics/cparser.pyx":505
 *     acc = 0
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)             # <<<<<<<<<<<<<<
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)
 */
    __pyx_t_5 = PySequence_Fast_GET_ITEM(__pyx_v_sequence_fast, __pyx_v_i);
    __pyx_t_1 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_group, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":506
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):             # <<<<<<<<<<<<<<
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 */
    __pyx_t_6 = PyTuple_Check(__pyx_v_group); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":507
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)             # <<<<<<<<<<<<<<
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)
 */
      __pyx_t_8 = PyTuple_Size(__pyx_v_group); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 507, __pyx_L1_error)
      __pyx_v_m = __pyx_t_8;

      /* "pyteomics/cparser.pyx":508
 *         if isinstance(group, tuple):
 *             m = PyTuple_Size(group)
 *             for j in range(m):             # <<<<<<<<<<<<<<
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 */
      __pyx_t_8 = __pyx_v_m;
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_j = __pyx_t_10;

        /* "pyteomics/cparser.pyx":509
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)             # <<<<<<<<<<<<<<
 *                 if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 *                     continue
 */
        __pyx_t_5 = PyTuple_GetItem(__pyx_v_group, __pyx_v_j); if (unlikely(__pyx_t_5 == ((PyObject *)NULL))) __PYX_ERR(0, 509, __pyx_L1_error)
        __pyx_t_1 = ((PyObject *)__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_group_j, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":510
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:             # <<<<<<<<<<<<<<
 *                     continue
 * 
 */
        __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_v_group_j, __pyx_v_9pyteomics_7cparser_std_cterm, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 510, __pyx_L1_error)
        __pyx_t_11 = (__pyx_t_6 != 0);
        if (!__pyx_t_11) {
        } else {
          goto __pyx_L19_next_and;
        }
        __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_group_j, __pyx_v_9pyteomics_7cparser_std_nterm, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 510, __pyx_L1_error)
        __pyx_t_6 = (__pyx_t_11 != 0);
        if (__pyx_t_6) {
        } else {
          __pyx_t_7 = __pyx_t_6;
          goto __pyx_L18_bool_binop_done;
        }
        __pyx_L19_next_and:;
        __pyx_t_6 = ((!(__pyx_v_show_unmodified_termini != 0)) != 0);
        __pyx_t_7 = __pyx_t_6;
        __pyx_L18_bool_binop_done:;
        if (__pyx_t_7) {

          /* "pyteomics/cparser.pyx":511
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 cstr = PyStr_AsUTF8AndSize(group_j, &sz)
 */
          goto __pyx_L15_continue;

          /* "pyteomics/cparser.pyx":510
 *             for j in range(m):
 *                 group_j = <str>PyTuple_GetItem(group, j)
 *                 if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:             # <<<<<<<<<<<<<<
 *                     continue
 * 
 */
        }

        /* "pyteomics/cparser.pyx":513
 *                     continue
 * 
 *                 cstr = PyStr_AsUTF8AndSize(group_j, &sz)             # <<<<<<<<<<<<<<
 *                 for k in range(sz):
 *                     string_buffer[acc] = cstr[k]
 */
        __pyx_v_cstr = PyStr_AsUTF8AndSize(__pyx_v_group_j, (&__pyx_v_sz));

        /* "pyteomics/cparser.pyx":514
 * 
 *                 cstr = PyStr_AsUTF8AndSize(group_j, &sz)
 *                 for k in range(sz):             # <<<<<<<<<<<<<<
 *                     string_buffer[acc] = cstr[k]
 *                     acc += 1
 */
        __pyx_t_12 = __pyx_v_sz;
        __pyx_t_13 = __pyx_t_12;
        for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
          __pyx_v_k = __pyx_t_14;

          /* "pyteomics/cparser.pyx":515
 *                 cstr = PyStr_AsUTF8AndSize(group_j, &sz)
 *                 for k in range(sz):
 *                     string_buffer[acc] = cstr[k]             # <<<<<<<<<<<<<<
 *                     acc += 1
 * 
 */
          (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_k]);

          /* "pyteomics/cparser.pyx":516
 *                 for k in range(sz):
 *                     string_buffer[acc] = cstr[k]
 *                     acc += 1             # <<<<<<<<<<<<<<
 * 
 *         elif isinstance(group, str):
 */
          __pyx_v_acc = (__pyx_v_acc + 1);
        }
        __pyx_L15_continue:;
      }

      /* "pyteomics/cparser.pyx":506
 *     for i in range(n):
 *         group = <object>PySequence_Fast_GET_ITEM(sequence_fast, i)
 *         if isinstance(group, tuple):             # <<<<<<<<<<<<<<
 *             m = PyTuple_Size(group)
 *             for j in range(m):
 */
      goto __pyx_L14;
    }

    /* "pyteomics/cparser.pyx":518
 *                     acc += 1
 * 
 *         elif isinstance(group, str):             # <<<<<<<<<<<<<<
 *             group_j = <str>group
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 */
    __pyx_t_7 = PyString_Check(__pyx_v_group); 
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (__pyx_t_6) {

      /* "pyteomics/cparser.pyx":519
 * 
 *         elif isinstance(group, str):
 *             group_j = <str>group             # <<<<<<<<<<<<<<
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 *                 continue
 */
      __pyx_t_1 = __pyx_v_group;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_group_j, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":520
 *         elif isinstance(group, str):
 *             group_j = <str>group
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_v_group_j, __pyx_v_9pyteomics_7cparser_std_cterm, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 520, __pyx_L1_error)
      __pyx_t_11 = (__pyx_t_7 != 0);
      if (!__pyx_t_11) {
      } else {
        goto __pyx_L25_next_and;
      }
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_group_j, __pyx_v_9pyteomics_7cparser_std_nterm, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 520, __pyx_L1_error)
      __pyx_t_7 = (__pyx_t_11 != 0);
      if (__pyx_t_7) {
      } else {
        __pyx_t_6 = __pyx_t_7;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_L25_next_and:;
      __pyx_t_7 = ((!(__pyx_v_show_unmodified_termini != 0)) != 0);
      __pyx_t_6 = __pyx_t_7;
      __pyx_L24_bool_binop_done:;
      if (__pyx_t_6) {

        /* "pyteomics/cparser.pyx":521
 *             group_j = <str>group
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             PyStr_AsUTF8AndSize(group, &sz)
 */
        goto __pyx_L12_continue;

        /* "pyteomics/cparser.pyx":520
 *         elif isinstance(group, str):
 *             group_j = <str>group
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      }

      /* "pyteomics/cparser.pyx":523
 *                 continue
 * 
 *             PyStr_AsUTF8AndSize(group, &sz)             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(group, &sz)
 *             for k in range(sz):
 */
      if (!(likely(PyString_CheckExact(__pyx_v_group))||((__pyx_v_group) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_group)->tp_name), 0))) __PYX_ERR(0, 523, __pyx_L1_error)
      (void)(PyStr_AsUTF8AndSize(((PyObject*)__pyx_v_group), (&__pyx_v_sz)));

      /* "pyteomics/cparser.pyx":524
 * 
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             cstr = PyStr_AsUTF8AndSize(group, &sz)             # <<<<<<<<<<<<<<
 *             for k in range(sz):
 *                 string_buffer[acc] = cstr[k]
 */
      if (!(likely(PyString_CheckExact(__pyx_v_group))||((__pyx_v_group) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_group)->tp_name), 0))) __PYX_ERR(0, 524, __pyx_L1_error)
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_v_group), (&__pyx_v_sz));

      /* "pyteomics/cparser.pyx":525
 *             PyStr_AsUTF8AndSize(group, &sz)
 *             cstr = PyStr_AsUTF8AndSize(group, &sz)
 *             for k in range(sz):             # <<<<<<<<<<<<<<
 *                 string_buffer[acc] = cstr[k]
 *                 acc += 1
 */
      __pyx_t_8 = __pyx_v_sz;
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_k = __pyx_t_10;

        /* "pyteomics/cparser.pyx":526
 *             cstr = PyStr_AsUTF8AndSize(group, &sz)
 *             for k in range(sz):
 *                 string_buffer[acc] = cstr[k]             # <<<<<<<<<<<<<<
 *                 acc += 1
 * 
 */
        (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_k]);

        /* "pyteomics/cparser.pyx":527
 *             for k in range(sz):
 *                 string_buffer[acc] = cstr[k]
 *                 acc += 1             # <<<<<<<<<<<<<<
 * 
 *         elif isinstance(group, SequencePosition):
 */
        __pyx_v_acc = (__pyx_v_acc + 1);
      }

      /* "pyteomics/cparser.pyx":518
 *                     acc += 1
 * 
 *         elif isinstance(group, str):             # <<<<<<<<<<<<<<
 *             group_j = <str>group
 *             if (group_j == std_cterm or group_j == std_nterm) and not show_unmodified_termini:
 */
      goto __pyx_L14;
    }

    /* "pyteomics/cparser.pyx":529
 *                 acc += 1
 * 
 *         elif isinstance(group, SequencePosition):             # <<<<<<<<<<<<<<
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:
 */
    __pyx_t_6 = __Pyx_TypeCheck(__pyx_v_group, __pyx_ptype_9pyteomics_7cparser_SequencePosition); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":530
 * 
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group             # <<<<<<<<<<<<<<
 *             if pos.position_type == PositionType.n_term:
 *                 if pos.terminal is not None:
 */
      __pyx_t_1 = __pyx_v_group;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pos, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":531
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 */
      __pyx_t_7 = ((__pyx_v_pos->position_type == __pyx_e_9pyteomics_7cparser_n_term) != 0);
      if (__pyx_t_7) {

        /* "pyteomics/cparser.pyx":532
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:
 *                 if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
        __pyx_t_7 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
        __pyx_t_6 = (__pyx_t_7 != 0);
        if (__pyx_t_6) {

          /* "pyteomics/cparser.pyx":533
 *             if pos.position_type == PositionType.n_term:
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_nterm:             # <<<<<<<<<<<<<<
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 */
          __pyx_t_7 = (__pyx_v_show_unmodified_termini != 0);
          if (!__pyx_t_7) {
          } else {
            __pyx_t_6 = __pyx_t_7;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_v_pos->terminal, __pyx_v_9pyteomics_7cparser_std_nterm, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 533, __pyx_L1_error)
          __pyx_t_11 = (__pyx_t_7 != 0);
          __pyx_t_6 = __pyx_t_11;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_6) {

            /* "pyteomics/cparser.pyx":534
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]
 */
            __pyx_t_1 = __pyx_v_pos->terminal;
            __Pyx_INCREF(__pyx_t_1);
            __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "pyteomics/cparser.pyx":535
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):             # <<<<<<<<<<<<<<
 *                             string_buffer[acc] = cstr[j]
 *                             acc += 1
 */
            __pyx_t_8 = __pyx_v_sz;
            __pyx_t_9 = __pyx_t_8;
            for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
              __pyx_v_j = __pyx_t_10;

              /* "pyteomics/cparser.pyx":536
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                             acc += 1
 * 
 */
              (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

              /* "pyteomics/cparser.pyx":537
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]
 *                             acc += 1             # <<<<<<<<<<<<<<
 * 
 *             if pos.modification is not None:
 */
              __pyx_v_acc = (__pyx_v_acc + 1);
            }

            /* "pyteomics/cparser.pyx":533
 *             if pos.position_type == PositionType.n_term:
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_nterm:             # <<<<<<<<<<<<<<
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 */
          }

          /* "pyteomics/cparser.pyx":532
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:
 *                 if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
        }

        /* "pyteomics/cparser.pyx":531
 *         elif isinstance(group, SequencePosition):
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_nterm:
 */
      }

      /* "pyteomics/cparser.pyx":539
 *                             acc += 1
 * 
 *             if pos.modification is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 for j in range(sz):
 */
      __pyx_t_6 = (__pyx_v_pos->modification != ((PyObject*)Py_None));
      __pyx_t_11 = (__pyx_t_6 != 0);
      if (__pyx_t_11) {

        /* "pyteomics/cparser.pyx":540
 * 
 *             if pos.modification is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)             # <<<<<<<<<<<<<<
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 */
        __pyx_t_1 = __pyx_v_pos->modification;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":541
 *             if pos.modification is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 for j in range(sz):             # <<<<<<<<<<<<<<
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1
 */
        __pyx_t_8 = __pyx_v_sz;
        __pyx_t_9 = __pyx_t_8;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_j = __pyx_t_10;

          /* "pyteomics/cparser.pyx":542
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                     acc += 1
 * 
 */
          (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

          /* "pyteomics/cparser.pyx":543
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1             # <<<<<<<<<<<<<<
 * 
 *             if pos.amino_acid is not None:
 */
          __pyx_v_acc = (__pyx_v_acc + 1);
        }

        /* "pyteomics/cparser.pyx":539
 *                             acc += 1
 * 
 *             if pos.modification is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *                 for j in range(sz):
 */
      }

      /* "pyteomics/cparser.pyx":545
 *                     acc += 1
 * 
 *             if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 for j in range(sz):
 */
      __pyx_t_11 = (__pyx_v_pos->amino_acid != ((PyObject*)Py_None));
      __pyx_t_6 = (__pyx_t_11 != 0);
      if (__pyx_t_6) {

        /* "pyteomics/cparser.pyx":546
 * 
 *             if pos.amino_acid is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)             # <<<<<<<<<<<<<<
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 */
        __pyx_t_1 = __pyx_v_pos->amino_acid;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyteomics/cparser.pyx":547
 *             if pos.amino_acid is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 for j in range(sz):             # <<<<<<<<<<<<<<
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1
 */
        __pyx_t_8 = __pyx_v_sz;
        __pyx_t_9 = __pyx_t_8;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_j = __pyx_t_10;

          /* "pyteomics/cparser.pyx":548
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                     acc += 1
 * 
 */
          (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

          /* "pyteomics/cparser.pyx":549
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1             # <<<<<<<<<<<<<<
 * 
 *             if pos.position_type == PositionType.c_term:
 */
          __pyx_v_acc = (__pyx_v_acc + 1);
        }

        /* "pyteomics/cparser.pyx":545
 *                     acc += 1
 * 
 *             if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *                 for j in range(sz):
 */
      }

      /* "pyteomics/cparser.pyx":551
 *                     acc += 1
 * 
 *             if pos.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 */
      __pyx_t_6 = ((__pyx_v_pos->position_type == __pyx_e_9pyteomics_7cparser_c_term) != 0);
      if (__pyx_t_6) {

        /* "pyteomics/cparser.pyx":552
 * 
 *             if pos.position_type == PositionType.c_term:
 *                 if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
        __pyx_t_6 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
        __pyx_t_11 = (__pyx_t_6 != 0);
        if (__pyx_t_11) {

          /* "pyteomics/cparser.pyx":553
 *             if pos.position_type == PositionType.c_term:
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_cterm:             # <<<<<<<<<<<<<<
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 */
          __pyx_t_6 = (__pyx_v_show_unmodified_termini != 0);
          if (!__pyx_t_6) {
          } else {
            __pyx_t_11 = __pyx_t_6;
            goto __pyx_L45_bool_binop_done;
          }
          __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_v_pos->terminal, __pyx_v_9pyteomics_7cparser_std_cterm, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 553, __pyx_L1_error)
          __pyx_t_7 = (__pyx_t_6 != 0);
          __pyx_t_11 = __pyx_t_7;
          __pyx_L45_bool_binop_done:;
          if (__pyx_t_11) {

            /* "pyteomics/cparser.pyx":554
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]
 */
            __pyx_t_1 = __pyx_v_pos->terminal;
            __Pyx_INCREF(__pyx_t_1);
            __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_1), (&__pyx_v_sz));
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "pyteomics/cparser.pyx":555
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):             # <<<<<<<<<<<<<<
 *                             string_buffer[acc] = cstr[j]
 *                             acc += 1
 */
            __pyx_t_8 = __pyx_v_sz;
            __pyx_t_9 = __pyx_t_8;
            for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
              __pyx_v_j = __pyx_t_10;

              /* "pyteomics/cparser.pyx":556
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                             acc += 1
 * 
 */
              (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

              /* "pyteomics/cparser.pyx":557
 *                         for j in range(sz):
 *                             string_buffer[acc] = cstr[j]
 *                             acc += 1             # <<<<<<<<<<<<<<
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 */
              __pyx_v_acc = (__pyx_v_acc + 1);
            }

            /* "pyteomics/cparser.pyx":553
 *             if pos.position_type == PositionType.c_term:
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_cterm:             # <<<<<<<<<<<<<<
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                         for j in range(sz):
 */
          }

          /* "pyteomics/cparser.pyx":552
 * 
 *             if pos.position_type == PositionType.c_term:
 *                 if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 *                         cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
        }

        /* "pyteomics/cparser.pyx":551
 *                     acc += 1
 * 
 *             if pos.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *                 if pos.terminal is not None:
 *                     if show_unmodified_termini or pos.terminal != std_cterm:
 */
      }

      /* "pyteomics/cparser.pyx":529
 *                 acc += 1
 * 
 *         elif isinstance(group, SequencePosition):             # <<<<<<<<<<<<<<
 *             pos = <SequencePosition>group
 *             if pos.position_type == PositionType.n_term:
 */
    }
    __pyx_L14:;
    __pyx_L12_continue:;
  }

  /* "pyteomics/cparser.pyx":559
 *                             acc += 1
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)             # <<<<<<<<<<<<<<
 *     if needs_free:
 *         free(string_buffer)
 */
  __pyx_t_1 = PyStr_FromStringAndSize(__pyx_v_string_buffer, __pyx_v_acc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":560
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:             # <<<<<<<<<<<<<<
 *         free(string_buffer)
 *     return result
 */
  __pyx_t_11 = (__pyx_v_needs_free != 0);
  if (__pyx_t_11) {

    /* "pyteomics/cparser.pyx":561
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:
 *         free(string_buffer)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    free(__pyx_v_string_buffer);

    /* "pyteomics/cparser.pyx":560
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:             # <<<<<<<<<<<<<<
 *         free(string_buffer)
 *     return result
 */
  }

  /* "pyteomics/cparser.pyx":562
 *     if needs_free:
 *         free(string_buffer)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":435
 * 
 * 
 * cpdef str tostring(object parsed_sequence, bint show_unmodified_termini=True):             # <<<<<<<<<<<<<<
 *     """Create a string from a parsed sequence.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_group);
  __Pyx_XDECREF(__pyx_v_group_j);
  __Pyx_XDECREF(__pyx_v_sequence_fast);
  __Pyx_XDECREF((PyObject *)__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_7tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_6tostring[] = "tostring(parsed_sequence, bool show_unmodified_termini=True) -> str\nCreate a string from a parsed sequence.\n\n    Parameters\n    ----------\n    parsed_sequence : iterable\n        Expected to be in one of the formats returned by\n        :py:func:`parse`, i.e. list of labels or list of tuples.\n    show_unmodified_termini : bool, optional\n        Defines the behavior towards standard terminal groups in the input.\n        :py:const:`True` means that they will be preserved if present (default).\n        :py:const:`False` means that they will be removed. Standard terminal\n        groups will not be added if not shown in `parsed_sequence`,\n        regardless of this setting.\n\n    Returns\n    -------\n    sequence : str\n    ";
static PyObject *__pyx_pw_9pyteomics_7cparser_7tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parsed_sequence = 0;
  int __pyx_v_show_unmodified_termini;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tostring (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parsed_sequence,&__pyx_n_s_show_unmodified_termini,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parsed_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "tostring") < 0)) __PYX_ERR(0, 435, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_parsed_sequence = values[0];
    if (values[1]) {
      __pyx_v_show_unmodified_termini = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_show_unmodified_termini == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 435, __pyx_L3_error)
    } else {
      __pyx_v_show_unmodified_termini = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tostring", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 435, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_6tostring(__pyx_self, __pyx_v_parsed_sequence, __pyx_v_show_unmodified_termini);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_6tostring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_parsed_sequence, int __pyx_v_show_unmodified_termini) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_tostring __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tostring", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.show_unmodified_termini = __pyx_v_show_unmodified_termini;
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_tostring(__pyx_v_parsed_sequence, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":566
 * 
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=0, bint term_aa=0,             # <<<<<<<<<<<<<<
 *                                   bint allow_unknown_modifications=0, object labels=None):
 *     """Calculate amino acid composition of a polypeptide.
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_9amino_acid_composition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_amino_acid_composition(PyObject *__pyx_v_sequence, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition *__pyx_optional_args) {
  int __pyx_v_show_unmodified_termini = ((int)0);
  int __pyx_v_term_aa = ((int)0);
  int __pyx_v_allow_unknown_modifications = ((int)0);

  /* "pyteomics/cparser.pyx":567
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=0, bint term_aa=0,
 *                                   bint allow_unknown_modifications=0, object labels=None):             # <<<<<<<<<<<<<<
 *     """Calculate amino acid composition of a polypeptide.
 * 
 */
  PyObject *__pyx_v_labels = ((PyObject *)Py_None);
  PyObject *__pyx_v_parsed_sequence = 0;
  int __pyx_v_nterm_aa_position;
  int __pyx_v_cterm_aa_position;
  int __pyx_v_aa_count;
  PyObject *__pyx_v_aa_dict = 0;
  PyObject *__pyx_v_aa = 0;
  PyObject *__pyx_v__labels = 0;
  PyObject *__pyx_v_temp = 0;
  PyObject *__pyx_v_pvalue;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_parse __pyx_t_4;
  PyObject *__pyx_t_5;
  int __pyx_t_6;
  struct __pyx_opt_args_9pyteomics_7cparser_tostring __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  long __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("amino_acid_composition", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_show_unmodified_termini = __pyx_optional_args->show_unmodified_termini;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_term_aa = __pyx_optional_args->term_aa;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_allow_unknown_modifications = __pyx_optional_args->allow_unknown_modifications;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_labels = __pyx_optional_args->labels;
          }
        }
      }
    }
  }

  /* "pyteomics/cparser.pyx":615
 *         Py_ssize_t i
 * 
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         allow_unknown_modifications = True
 * 
 */
  __pyx_t_1 = (__pyx_v_labels == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":616
 * 
 *     if labels is None:
 *         allow_unknown_modifications = True             # <<<<<<<<<<<<<<
 * 
 *     _labels = interpolate_labels(labels)
 */
    __pyx_v_allow_unknown_modifications = 1;

    /* "pyteomics/cparser.pyx":615
 *         Py_ssize_t i
 * 
 *     if labels is None:             # <<<<<<<<<<<<<<
 *         allow_unknown_modifications = True
 * 
 */
  }

  /* "pyteomics/cparser.pyx":618
 *         allow_unknown_modifications = True
 * 
 *     _labels = interpolate_labels(labels)             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(sequence, str):
 */
  __pyx_t_3 = __pyx_f_9pyteomics_7cparser_interpolate_labels(__pyx_v_labels); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__labels = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":620
 *     _labels = interpolate_labels(labels)
 * 
 *     if isinstance(sequence, str):             # <<<<<<<<<<<<<<
 *         parsed_sequence = parse(<str>sequence, show_unmodified_termini, split=False,
 *                                 allow_unknown_modifications=allow_unknown_modifications,
 */
  __pyx_t_2 = PyString_Check(__pyx_v_sequence); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":621
 * 
 *     if isinstance(sequence, str):
 *         parsed_sequence = parse(<str>sequence, show_unmodified_termini, split=False,             # <<<<<<<<<<<<<<
 *                                 allow_unknown_modifications=allow_unknown_modifications,
 *                                 labels=_labels)
 */
    __pyx_t_4.__pyx_n = 4;
    __pyx_t_4.show_unmodified_termini = __pyx_v_show_unmodified_termini;
    __pyx_t_4.split = 0;
    __pyx_t_4.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
    __pyx_t_4.labels = __pyx_v__labels;
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser_parse(((PyObject*)__pyx_v_sequence), 0, &__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_parsed_sequence = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":620
 *     _labels = interpolate_labels(labels)
 * 
 *     if isinstance(sequence, str):             # <<<<<<<<<<<<<<
 *         parsed_sequence = parse(<str>sequence, show_unmodified_termini, split=False,
 *                                 allow_unknown_modifications=allow_unknown_modifications,
 */
    goto __pyx_L4;
  }

  /* "pyteomics/cparser.pyx":624
 *                                 allow_unknown_modifications=allow_unknown_modifications,
 *                                 labels=_labels)
 *     elif isinstance(sequence, list):             # <<<<<<<<<<<<<<
 *         if sequence and isinstance(<object>PyList_GetItem(sequence, 0), tuple):
 *             parsed_sequence = parse(tostring(sequence, True),
 */
  __pyx_t_1 = PyList_Check(__pyx_v_sequence); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (likely(__pyx_t_2)) {

    /* "pyteomics/cparser.pyx":625
 *                                 labels=_labels)
 *     elif isinstance(sequence, list):
 *         if sequence and isinstance(<object>PyList_GetItem(sequence, 0), tuple):             # <<<<<<<<<<<<<<
 *             parsed_sequence = parse(tostring(sequence, True),
 *                 show_unmodified_termini,
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_sequence); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 625, __pyx_L1_error)
    if (__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = PyList_GetItem(__pyx_v_sequence, 0); if (unlikely(__pyx_t_5 == ((PyObject *)NULL))) __PYX_ERR(0, 625, __pyx_L1_error)
    __pyx_t_1 = PyTuple_Check(((PyObject *)__pyx_t_5)); 
    __pyx_t_6 = (__pyx_t_1 != 0);
    __pyx_t_2 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":626
 *     elif isinstance(sequence, list):
 *         if sequence and isinstance(<object>PyList_GetItem(sequence, 0), tuple):
 *             parsed_sequence = parse(tostring(sequence, True),             # <<<<<<<<<<<<<<
 *                 show_unmodified_termini,
 *                 split=False,
 */
      __pyx_t_7.__pyx_n = 1;
      __pyx_t_7.show_unmodified_termini = 1;
      __pyx_t_3 = __pyx_f_9pyteomics_7cparser_tostring(__pyx_v_sequence, 0, &__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "pyteomics/cparser.pyx":630
 *                 split=False,
 *                 allow_unknown_modifications=allow_unknown_modifications,
 *                 labels=_labels)             # <<<<<<<<<<<<<<
 *         else:
 *             parsed_sequence = sequence
 */
      __pyx_t_4.__pyx_n = 4;
      __pyx_t_4.show_unmodified_termini = __pyx_v_show_unmodified_termini;
      __pyx_t_4.split = 0;
      __pyx_t_4.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
      __pyx_t_4.labels = __pyx_v__labels;
      __pyx_t_8 = __pyx_f_9pyteomics_7cparser_parse(((PyObject*)__pyx_t_3), 0, &__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_parsed_sequence = ((PyObject*)__pyx_t_8);
      __pyx_t_8 = 0;

      /* "pyteomics/cparser.pyx":625
 *                                 labels=_labels)
 *     elif isinstance(sequence, list):
 *         if sequence and isinstance(<object>PyList_GetItem(sequence, 0), tuple):             # <<<<<<<<<<<<<<
 *             parsed_sequence = parse(tostring(sequence, True),
 *                 show_unmodified_termini,
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":632
 *                 labels=_labels)
 *         else:
 *             parsed_sequence = sequence             # <<<<<<<<<<<<<<
 *     else:
 *         raise PyteomicsError('Unsupported type of a sequence.'
 */
    /*else*/ {
      if (!(likely(PyList_CheckExact(__pyx_v_sequence))||((__pyx_v_sequence) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_sequence)->tp_name), 0))) __PYX_ERR(0, 632, __pyx_L1_error)
      __pyx_t_8 = __pyx_v_sequence;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_parsed_sequence = ((PyObject*)__pyx_t_8);
      __pyx_t_8 = 0;
    }
    __pyx_L5:;

    /* "pyteomics/cparser.pyx":624
 *                                 allow_unknown_modifications=allow_unknown_modifications,
 *                                 labels=_labels)
 *     elif isinstance(sequence, list):             # <<<<<<<<<<<<<<
 *         if sequence and isinstance(<object>PyList_GetItem(sequence, 0), tuple):
 *             parsed_sequence = parse(tostring(sequence, True),
 */
    goto __pyx_L4;
  }

  /* "pyteomics/cparser.pyx":634
 *             parsed_sequence = sequence
 *     else:
 *         raise PyteomicsError('Unsupported type of a sequence.'             # <<<<<<<<<<<<<<
 *                 'Must be str or list, not %s' % type(sequence))
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "pyteomics/cparser.pyx":635
 *     else:
 *         raise PyteomicsError('Unsupported type of a sequence.'
 *                 'Must be str or list, not %s' % type(sequence))             # <<<<<<<<<<<<<<
 * 
 *     aa_dict = {}
 */
    __pyx_t_9 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Unsupported_type_of_a_sequence_M, ((PyObject *)Py_TYPE(__pyx_v_sequence))); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_8 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_10, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 634, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "pyteomics/cparser.pyx":637
 *                 'Must be str or list, not %s' % type(sequence))
 * 
 *     aa_dict = {}             # <<<<<<<<<<<<<<
 *     # Process terminal amino acids.
 *     if term_aa:
 */
  __pyx_t_8 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_v_aa_dict = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "pyteomics/cparser.pyx":639
 *     aa_dict = {}
 *     # Process terminal amino acids.
 *     if term_aa:             # <<<<<<<<<<<<<<
 *         if is_term_mod(<object>PyList_GetItem(parsed_sequence, 0)):
 *             nterm_aa_position = 1
 */
  __pyx_t_2 = (__pyx_v_term_aa != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":640
 *     # Process terminal amino acids.
 *     if term_aa:
 *         if is_term_mod(<object>PyList_GetItem(parsed_sequence, 0)):             # <<<<<<<<<<<<<<
 *             nterm_aa_position = 1
 *         else:
 */
    __pyx_t_5 = PyList_GetItem(__pyx_v_parsed_sequence, 0); if (unlikely(__pyx_t_5 == ((PyObject *)NULL))) __PYX_ERR(0, 640, __pyx_L1_error)
    if (!(likely(PyString_CheckExact(((PyObject *)__pyx_t_5)))||((((PyObject *)__pyx_t_5)) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(((PyObject *)__pyx_t_5))->tp_name), 0))) __PYX_ERR(0, 640, __pyx_L1_error)
    __pyx_t_2 = (__pyx_f_9pyteomics_7cparser_is_term_mod(((PyObject*)((PyObject *)__pyx_t_5))) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":641
 *     if term_aa:
 *         if is_term_mod(<object>PyList_GetItem(parsed_sequence, 0)):
 *             nterm_aa_position = 1             # <<<<<<<<<<<<<<
 *         else:
 *             nterm_aa_position = 0
 */
      __pyx_v_nterm_aa_position = 1;

      /* "pyteomics/cparser.pyx":640
 *     # Process terminal amino acids.
 *     if term_aa:
 *         if is_term_mod(<object>PyList_GetItem(parsed_sequence, 0)):             # <<<<<<<<<<<<<<
 *             nterm_aa_position = 1
 *         else:
 */
      goto __pyx_L9;
    }

    /* "pyteomics/cparser.pyx":643
 *             nterm_aa_position = 1
 *         else:
 *             nterm_aa_position = 0             # <<<<<<<<<<<<<<
 *         if is_term_mod(parsed_sequence[-1]):
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 2
 */
    /*else*/ {
      __pyx_v_nterm_aa_position = 0;
    }
    __pyx_L9:;

    /* "pyteomics/cparser.pyx":644
 *         else:
 *             nterm_aa_position = 0
 *         if is_term_mod(parsed_sequence[-1]):             # <<<<<<<<<<<<<<
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 2
 *         else:
 */
    if (unlikely(__pyx_v_parsed_sequence == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 644, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_GetItemInt_List(__pyx_v_parsed_sequence, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (!(likely(PyString_CheckExact(__pyx_t_8))||((__pyx_t_8) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_8)->tp_name), 0))) __PYX_ERR(0, 644, __pyx_L1_error)
    __pyx_t_2 = (__pyx_f_9pyteomics_7cparser_is_term_mod(((PyObject*)__pyx_t_8)) != 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":645
 *             nterm_aa_position = 0
 *         if is_term_mod(parsed_sequence[-1]):
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 2             # <<<<<<<<<<<<<<
 *         else:
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 1
 */
      __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 645, __pyx_L1_error)
      __pyx_v_cterm_aa_position = (__pyx_t_11 - 2);

      /* "pyteomics/cparser.pyx":644
 *         else:
 *             nterm_aa_position = 0
 *         if is_term_mod(parsed_sequence[-1]):             # <<<<<<<<<<<<<<
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 2
 *         else:
 */
      goto __pyx_L10;
    }

    /* "pyteomics/cparser.pyx":647
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 2
 *         else:
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 1             # <<<<<<<<<<<<<<
 *         if PyList_Size(parsed_sequence) > 1:
 *             # temp = PyInt_FromLong(cterm_aa_position)
 */
    /*else*/ {
      __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 647, __pyx_L1_error)
      __pyx_v_cterm_aa_position = (__pyx_t_11 - 1);
    }
    __pyx_L10:;

    /* "pyteomics/cparser.pyx":648
 *         else:
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 1
 *         if PyList_Size(parsed_sequence) > 1:             # <<<<<<<<<<<<<<
 *             # temp = PyInt_FromLong(cterm_aa_position)
 *             # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 */
    __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 648, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_11 > 1) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":651
 *             # temp = PyInt_FromLong(cterm_aa_position)
 *             # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 *             temp = parsed_sequence.pop(cterm_aa_position)             # <<<<<<<<<<<<<<
 *             PyDict_SetItem(aa_dict, 'cterm' + temp, 1)
 *         # temp = PyInt_FromLong(nterm_aa_position)
 */
      if (unlikely(__pyx_v_parsed_sequence == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 651, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyList_PopIndex(__pyx_v_parsed_sequence, Py_None, __pyx_v_cterm_aa_position, 1, int, __Pyx_PyInt_From_int); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_v_temp = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "pyteomics/cparser.pyx":652
 *             # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 *             temp = parsed_sequence.pop(cterm_aa_position)
 *             PyDict_SetItem(aa_dict, 'cterm' + temp, 1)             # <<<<<<<<<<<<<<
 *         # temp = PyInt_FromLong(nterm_aa_position)
 *         # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 */
      __pyx_t_8 = PyNumber_Add(__pyx_n_s_cterm, __pyx_v_temp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 652, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_12 = PyDict_SetItem(__pyx_v_aa_dict, __pyx_t_8, __pyx_int_1); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 652, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "pyteomics/cparser.pyx":648
 *         else:
 *             cterm_aa_position = PyList_Size(parsed_sequence) - 1
 *         if PyList_Size(parsed_sequence) > 1:             # <<<<<<<<<<<<<<
 *             # temp = PyInt_FromLong(cterm_aa_position)
 *             # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 */
    }

    /* "pyteomics/cparser.pyx":655
 *         # temp = PyInt_FromLong(nterm_aa_position)
 *         # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 *         temp = parsed_sequence.pop(nterm_aa_position)             # <<<<<<<<<<<<<<
 *         PyDict_SetItem(aa_dict, 'nterm' + temp, 1)
 *     # Process core amino acids.
 */
    if (unlikely(__pyx_v_parsed_sequence == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 655, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyList_PopIndex(__pyx_v_parsed_sequence, Py_None, __pyx_v_nterm_aa_position, 1, int, __Pyx_PyInt_From_int); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_temp, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "pyteomics/cparser.pyx":656
 *         # temp = PyObject_CallMethodObjArgs(parsed_sequence, "pop", <PyObject*>temp, NULL)
 *         temp = parsed_sequence.pop(nterm_aa_position)
 *         PyDict_SetItem(aa_dict, 'nterm' + temp, 1)             # <<<<<<<<<<<<<<
 *     # Process core amino acids.
 *     i = 0
 */
    __pyx_t_8 = PyNumber_Add(__pyx_n_s_nterm, __pyx_v_temp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_12 = PyDict_SetItem(__pyx_v_aa_dict, __pyx_t_8, __pyx_int_1); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pyteomics/cparser.pyx":639
 *     aa_dict = {}
 *     # Process terminal amino acids.
 *     if term_aa:             # <<<<<<<<<<<<<<
 *         if is_term_mod(<object>PyList_GetItem(parsed_sequence, 0)):
 *             nterm_aa_position = 1
 */
  }

  /* "pyteomics/cparser.pyx":658
 *         PyDict_SetItem(aa_dict, 'nterm' + temp, 1)
 *     # Process core amino acids.
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(PyList_Size(parsed_sequence)):
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 */
  __pyx_v_i = 0;

  /* "pyteomics/cparser.pyx":659
 *     # Process core amino acids.
 *     i = 0
 *     for i in range(PyList_Size(parsed_sequence)):             # <<<<<<<<<<<<<<
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *         pvalue = PyDict_GetItem(aa_dict, aa)
 */
  __pyx_t_11 = PyList_Size(__pyx_v_parsed_sequence); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 659, __pyx_L1_error)
  __pyx_t_13 = __pyx_t_11;
  for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
    __pyx_v_i = __pyx_t_14;

    /* "pyteomics/cparser.pyx":660
 *     i = 0
 *     for i in range(PyList_Size(parsed_sequence)):
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)             # <<<<<<<<<<<<<<
 *         pvalue = PyDict_GetItem(aa_dict, aa)
 *         if pvalue == NULL:
 */
    __pyx_t_5 = PyList_GET_ITEM(__pyx_v_parsed_sequence, __pyx_v_i);
    __pyx_t_8 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_aa, ((PyObject*)__pyx_t_8));
    __pyx_t_8 = 0;

    /* "pyteomics/cparser.pyx":661
 *     for i in range(PyList_Size(parsed_sequence)):
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *         pvalue = PyDict_GetItem(aa_dict, aa)             # <<<<<<<<<<<<<<
 *         if pvalue == NULL:
 *             aa_count = 0
 */
    __pyx_v_pvalue = PyDict_GetItem(__pyx_v_aa_dict, __pyx_v_aa);

    /* "pyteomics/cparser.pyx":662
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *         pvalue = PyDict_GetItem(aa_dict, aa)
 *         if pvalue == NULL:             # <<<<<<<<<<<<<<
 *             aa_count = 0
 *         else:
 */
    __pyx_t_2 = ((__pyx_v_pvalue == NULL) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":663
 *         pvalue = PyDict_GetItem(aa_dict, aa)
 *         if pvalue == NULL:
 *             aa_count = 0             # <<<<<<<<<<<<<<
 *         else:
 *             aa_count = PyInt_AsLong(<object>pvalue)
 */
      __pyx_v_aa_count = 0;

      /* "pyteomics/cparser.pyx":662
 *         aa = <tuple>PyList_GET_ITEM(parsed_sequence, i)
 *         pvalue = PyDict_GetItem(aa_dict, aa)
 *         if pvalue == NULL:             # <<<<<<<<<<<<<<
 *             aa_count = 0
 *         else:
 */
      goto __pyx_L14;
    }

    /* "pyteomics/cparser.pyx":665
 *             aa_count = 0
 *         else:
 *             aa_count = PyInt_AsLong(<object>pvalue)             # <<<<<<<<<<<<<<
 *         aa_count += 1
 *         PyDict_SetItem(aa_dict, aa, aa_count)
 */
    /*else*/ {
      __pyx_t_15 = PyInt_AsLong(((PyObject *)__pyx_v_pvalue)); if (unlikely(__pyx_t_15 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 665, __pyx_L1_error)
      __pyx_v_aa_count = __pyx_t_15;
    }
    __pyx_L14:;

    /* "pyteomics/cparser.pyx":666
 *         else:
 *             aa_count = PyInt_AsLong(<object>pvalue)
 *         aa_count += 1             # <<<<<<<<<<<<<<
 *         PyDict_SetItem(aa_dict, aa, aa_count)
 * 
 */
    __pyx_v_aa_count = (__pyx_v_aa_count + 1);

    /* "pyteomics/cparser.pyx":667
 *             aa_count = PyInt_AsLong(<object>pvalue)
 *         aa_count += 1
 *         PyDict_SetItem(aa_dict, aa, aa_count)             # <<<<<<<<<<<<<<
 * 
 *     return aa_dict
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_aa_count); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_12 = PyDict_SetItem(__pyx_v_aa_dict, __pyx_v_aa, __pyx_t_8); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "pyteomics/cparser.pyx":669
 *         PyDict_SetItem(aa_dict, aa, aa_count)
 * 
 *     return aa_dict             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_aa_dict);
  __pyx_r = __pyx_v_aa_dict;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":566
 * 
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=0, bint term_aa=0,             # <<<<<<<<<<<<<<
 *                                   bint allow_unknown_modifications=0, object labels=None):
 *     """Calculate amino acid composition of a polypeptide.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyteomics.cparser.amino_acid_composition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parsed_sequence);
  __Pyx_XDECREF(__pyx_v_aa_dict);
  __Pyx_XDECREF(__pyx_v_aa);
  __Pyx_XDECREF(__pyx_v__labels);
  __Pyx_XDECREF(__pyx_v_temp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_9amino_acid_composition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_8amino_acid_composition[] = "amino_acid_composition(sequence, bool show_unmodified_termini=0, bool term_aa=0, bool allow_unknown_modifications=0, labels=None) -> dict\nCalculate amino acid composition of a polypeptide.\n\n    Parameters\n    ----------\n    sequence : str or list\n        The sequence of a polypeptide or a list with a parsed sequence.\n    show_unmodified_termini : bool, optional\n        If :py:const:`True` then the unmodified N- and C-terminus are explicitly\n        shown in the returned dict. Default value is :py:const:`False`.\n    term_aa : bool, optional\n        If :py:const:`True` then the terminal amino acid residues are\n        artificially modified with `nterm` or `cterm` modification.\n        Default value is :py:const:`False`.\n    allow_unknown_modifications : bool, optional\n        If :py:const:`True` then do not raise an exception when an unknown\n        modification of a known amino acid residue is found in the sequence.\n        Default value is :py:const:`False`.\n    labels : list, optional\n        A list of allowed labels for amino acids and terminal modifications.\n\n    Returns\n    -------\n    out : dict\n        A dictionary of amino acid composition.\n\n    Examples\n    --------\n    >>> amino_acid_composition('PEPTIDE') ==     {'I': 1, 'P': 2, 'E': 2, 'T': 1, 'D': 1}\n    True\n    >>> amino_acid_composition('PEPTDE', term_aa=True) ==     {'ctermE': 1, 'E': 1, 'D': 1, 'P': 1, 'T': 1, 'ntermP': 1}\n    True\n    >>> amino_acid_composition('PEPpTIDE', labels=std_labels+['pT']) ==     {'I': 1, 'P': 2, 'E': 2, 'D': 1, 'pT': 1}\n    True\n    ";
static PyObject *__pyx_pw_9pyteomics_7cparser_9amino_acid_composition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_v_show_unmodified_termini;
  int __pyx_v_term_aa;
  int __pyx_v_allow_unknown_modifications;
  PyObject *__pyx_v_labels = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("amino_acid_composition (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_show_unmodified_termini,&__pyx_n_s_term_aa,&__pyx_n_s_allow_unknown_modifications,&__pyx_n_s_labels,0};
    PyObject* values[5] = {0,0,0,0,0};

    /* "pyteomics/cparser.pyx":567
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=0, bint term_aa=0,
 *                                   bint allow_unknown_modifications=0, object labels=None):             # <<<<<<<<<<<<<<
 *     """Calculate amino acid composition of a polypeptide.
 * 
 */
    values[4] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_term_aa);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_allow_unknown_modifications);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "amino_acid_composition") < 0)) __PYX_ERR(0, 566, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
    if (values[1]) {
      __pyx_v_show_unmodified_termini = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_show_unmodified_termini == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L3_error)
    } else {
      __pyx_v_show_unmodified_termini = ((int)0);
    }
    if (values[2]) {
      __pyx_v_term_aa = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_term_aa == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L3_error)
    } else {
      __pyx_v_term_aa = ((int)0);
    }
    if (values[3]) {
      __pyx_v_allow_unknown_modifications = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_allow_unknown_modifications == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 567, __pyx_L3_error)
    } else {
      __pyx_v_allow_unknown_modifications = ((int)0);
    }
    __pyx_v_labels = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("amino_acid_composition", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 566, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.amino_acid_composition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_8amino_acid_composition(__pyx_self, __pyx_v_sequence, __pyx_v_show_unmodified_termini, __pyx_v_term_aa, __pyx_v_allow_unknown_modifications, __pyx_v_labels);

  /* "pyteomics/cparser.pyx":566
 * 
 * 
 * cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=0, bint term_aa=0,             # <<<<<<<<<<<<<<
 *                                   bint allow_unknown_modifications=0, object labels=None):
 *     """Calculate amino acid composition of a polypeptide.
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_8amino_acid_composition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini, int __pyx_v_term_aa, int __pyx_v_allow_unknown_modifications, PyObject *__pyx_v_labels) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("amino_acid_composition", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 4;
  __pyx_t_2.show_unmodified_termini = __pyx_v_show_unmodified_termini;
  __pyx_t_2.term_aa = __pyx_v_term_aa;
  __pyx_t_2.allow_unknown_modifications = __pyx_v_allow_unknown_modifications;
  __pyx_t_2.labels = __pyx_v_labels;
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_amino_acid_composition(__pyx_v_sequence, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.amino_acid_composition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":684
 * 
 * 
 * cdef inline list copy_list(list source):             # <<<<<<<<<<<<<<
 *     cdef:
 *         size_t i, n
 */

static CYTHON_INLINE PyObject *__pyx_f_9pyteomics_7cparser_copy_list(PyObject *__pyx_v_source) {
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_list", 0);

  /* "pyteomics/cparser.pyx":689
 *         list result
 *         object val
 *     n = PyList_Size(source)             # <<<<<<<<<<<<<<
 *     result = PyList_New(n)
 *     for i in range(n):
 */
  __pyx_t_1 = PyList_Size(__pyx_v_source); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 689, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pyteomics/cparser.pyx":690
 *         object val
 *     n = PyList_Size(source)
 *     result = PyList_New(n)             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         val = <object>PyList_GET_ITEM(source, i)
 */
  __pyx_t_2 = PyList_New(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":691
 *     n = PyList_Size(source)
 *     result = PyList_New(n)
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = <object>PyList_GET_ITEM(source, i)
 *         Py_INCREF(val)
 */
  __pyx_t_3 = __pyx_v_n;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "pyteomics/cparser.pyx":692
 *     result = PyList_New(n)
 *     for i in range(n):
 *         val = <object>PyList_GET_ITEM(source, i)             # <<<<<<<<<<<<<<
 *         Py_INCREF(val)
 *         PyList_SET_ITEM(result, i, val)
 */
    __pyx_t_6 = PyList_GET_ITEM(__pyx_v_source, __pyx_v_i);
    __pyx_t_2 = ((PyObject *)__pyx_t_6);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":693
 *     for i in range(n):
 *         val = <object>PyList_GET_ITEM(source, i)
 *         Py_INCREF(val)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(result, i, val)
 *     return result
 */
    Py_INCREF(__pyx_v_val);

    /* "pyteomics/cparser.pyx":694
 *         val = <object>PyList_GET_ITEM(source, i)
 *         Py_INCREF(val)
 *         PyList_SET_ITEM(result, i, val)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    PyList_SET_ITEM(__pyx_v_result, __pyx_v_i, __pyx_v_val);
  }

  /* "pyteomics/cparser.pyx":695
 *         Py_INCREF(val)
 *         PyList_SET_ITEM(result, i, val)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":684
 * 
 * 
 * cdef inline list copy_list(list source):             # <<<<<<<<<<<<<<
 *     cdef:
 *         size_t i, n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.copy_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":707
 *         public str terminal
 * 
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):             # <<<<<<<<<<<<<<
 *         if position_type is None:
 *             position_type = PositionType.internal
 */

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_amino_acid = 0;
  PyObject *__pyx_v_modification = 0;
  PyObject *__pyx_v_terminal = 0;
  PyObject *__pyx_v_position_type = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_amino_acid,&__pyx_n_s_modification,&__pyx_n_s_terminal,&__pyx_n_s_position_type,0};
    PyObject* values[4] = {0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_amino_acid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_modification);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_terminal);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_position_type);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 707, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_amino_acid = values[0];
    __pyx_v_modification = values[1];
    __pyx_v_terminal = values[2];
    __pyx_v_position_type = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 707, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition___init__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), __pyx_v_amino_acid, __pyx_v_modification, __pyx_v_terminal, __pyx_v_position_type);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition___init__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_amino_acid, PyObject *__pyx_v_modification, PyObject *__pyx_v_terminal, PyObject *__pyx_v_position_type) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_position_type);

  /* "pyteomics/cparser.pyx":708
 * 
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):
 *         if position_type is None:             # <<<<<<<<<<<<<<
 *             position_type = PositionType.internal
 *         self.amino_acid = amino_acid
 */
  __pyx_t_1 = (__pyx_v_position_type == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":709
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):
 *         if position_type is None:
 *             position_type = PositionType.internal             # <<<<<<<<<<<<<<
 *         self.amino_acid = amino_acid
 *         self.modification = modification
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_internal); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_position_type, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":708
 * 
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):
 *         if position_type is None:             # <<<<<<<<<<<<<<
 *             position_type = PositionType.internal
 *         self.amino_acid = amino_acid
 */
  }

  /* "pyteomics/cparser.pyx":710
 *         if position_type is None:
 *             position_type = PositionType.internal
 *         self.amino_acid = amino_acid             # <<<<<<<<<<<<<<
 *         self.modification = modification
 *         self.terminal = terminal
 */
  if (!(likely(PyString_CheckExact(__pyx_v_amino_acid))||((__pyx_v_amino_acid) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_amino_acid)->tp_name), 0))) __PYX_ERR(0, 710, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_amino_acid;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->amino_acid);
  __Pyx_DECREF(__pyx_v_self->amino_acid);
  __pyx_v_self->amino_acid = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":711
 *             position_type = PositionType.internal
 *         self.amino_acid = amino_acid
 *         self.modification = modification             # <<<<<<<<<<<<<<
 *         self.terminal = terminal
 *         self.position_type = position_type
 */
  if (!(likely(PyString_CheckExact(__pyx_v_modification))||((__pyx_v_modification) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_modification)->tp_name), 0))) __PYX_ERR(0, 711, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_modification;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":712
 *         self.amino_acid = amino_acid
 *         self.modification = modification
 *         self.terminal = terminal             # <<<<<<<<<<<<<<
 *         self.position_type = position_type
 * 
 */
  if (!(likely(PyString_CheckExact(__pyx_v_terminal))||((__pyx_v_terminal) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_terminal)->tp_name), 0))) __PYX_ERR(0, 712, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_terminal;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->terminal);
  __Pyx_DECREF(__pyx_v_self->terminal);
  __pyx_v_self->terminal = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":713
 *         self.modification = modification
 *         self.terminal = terminal
 *         self.position_type = position_type             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_4 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_position_type)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 713, __pyx_L1_error)
  __pyx_v_self->position_type = __pyx_t_4;

  /* "pyteomics/cparser.pyx":707
 *         public str terminal
 * 
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):             # <<<<<<<<<<<<<<
 *         if position_type is None:
 *             position_type = PositionType.internal
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_position_type);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":716
 * 
 *     @staticmethod
 *     cdef SequencePosition _create(str amino_acid, str modification, str terminal, PositionType position_type):             # <<<<<<<<<<<<<<
 *         cdef SequencePosition self = SequencePosition.__new__(SequencePosition)
 *         self.amino_acid = amino_acid
 */

static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition__create(PyObject *__pyx_v_amino_acid, PyObject *__pyx_v_modification, PyObject *__pyx_v_terminal, enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type) {
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self = 0;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create", 0);

  /* "pyteomics/cparser.pyx":717
 *     @staticmethod
 *     cdef SequencePosition _create(str amino_acid, str modification, str terminal, PositionType position_type):
 *         cdef SequencePosition self = SequencePosition.__new__(SequencePosition)             # <<<<<<<<<<<<<<
 *         self.amino_acid = amino_acid
 *         self.modification = modification
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_9pyteomics_7cparser_SequencePosition(((PyTypeObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_self = ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":718
 *     cdef SequencePosition _create(str amino_acid, str modification, str terminal, PositionType position_type):
 *         cdef SequencePosition self = SequencePosition.__new__(SequencePosition)
 *         self.amino_acid = amino_acid             # <<<<<<<<<<<<<<
 *         self.modification = modification
 *         self.terminal = terminal
 */
  __Pyx_INCREF(__pyx_v_amino_acid);
  __Pyx_GIVEREF(__pyx_v_amino_acid);
  __Pyx_GOTREF(__pyx_v_self->amino_acid);
  __Pyx_DECREF(__pyx_v_self->amino_acid);
  __pyx_v_self->amino_acid = __pyx_v_amino_acid;

  /* "pyteomics/cparser.pyx":719
 *         cdef SequencePosition self = SequencePosition.__new__(SequencePosition)
 *         self.amino_acid = amino_acid
 *         self.modification = modification             # <<<<<<<<<<<<<<
 *         self.terminal = terminal
 *         self.position_type = position_type
 */
  __Pyx_INCREF(__pyx_v_modification);
  __Pyx_GIVEREF(__pyx_v_modification);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = __pyx_v_modification;

  /* "pyteomics/cparser.pyx":720
 *         self.amino_acid = amino_acid
 *         self.modification = modification
 *         self.terminal = terminal             # <<<<<<<<<<<<<<
 *         self.position_type = position_type
 *         return self
 */
  __Pyx_INCREF(__pyx_v_terminal);
  __Pyx_GIVEREF(__pyx_v_terminal);
  __Pyx_GOTREF(__pyx_v_self->terminal);
  __Pyx_DECREF(__pyx_v_self->terminal);
  __pyx_v_self->terminal = __pyx_v_terminal;

  /* "pyteomics/cparser.pyx":721
 *         self.modification = modification
 *         self.terminal = terminal
 *         self.position_type = position_type             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_v_self->position_type = __pyx_v_position_type;

  /* "pyteomics/cparser.pyx":722
 *         self.terminal = terminal
 *         self.position_type = position_type
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, i):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":716
 * 
 *     @staticmethod
 *     cdef SequencePosition _create(str amino_acid, str modification, str terminal, PositionType position_type):             # <<<<<<<<<<<<<<
 *         cdef SequencePosition self = SequencePosition.__new__(SequencePosition)
 *         self.amino_acid = amino_acid
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition._create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":724
 *         return self
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, slice):
 *             return self.as_tuple()[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_i); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_2__getitem__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_i));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_2__getitem__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  long __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "pyteomics/cparser.pyx":725
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, slice):             # <<<<<<<<<<<<<<
 *             return self.as_tuple()[i]
 *         return self.get_index(i)
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_i); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":726
 *     def __getitem__(self, i):
 *         if isinstance(i, slice):
 *             return self.as_tuple()[i]             # <<<<<<<<<<<<<<
 *         return self.get_index(i)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(__pyx_v_self, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__pyx_t_3 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 726, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":725
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, slice):             # <<<<<<<<<<<<<<
 *             return self.as_tuple()[i]
 *         return self.get_index(i)
 */
  }

  /* "pyteomics/cparser.pyx":727
 *         if isinstance(i, slice):
 *             return self.as_tuple()[i]
 *         return self.get_index(i)             # <<<<<<<<<<<<<<
 * 
 *     cpdef str get_index(self, long i):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyInt_As_long(__pyx_v_i); if (unlikely((__pyx_t_5 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 727, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_9pyteomics_7cparser_16SequencePosition_get_index(__pyx_v_self, __pyx_t_5, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":724
 *         return self
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, slice):
 *             return self.as_tuple()[i]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":729
 *         return self.get_index(i)
 * 
 *     cpdef str get_index(self, long i):             # <<<<<<<<<<<<<<
 *         cdef:
 *             long size, n_mods
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_5get_index(PyObject *__pyx_v_self, PyObject *__pyx_arg_i); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_get_index(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, long __pyx_v_i, CYTHON_UNUSED int __pyx_skip_dispatch) {
  long __pyx_v_size;
  long __pyx_v_n_mods;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_index", 0);

  /* "pyteomics/cparser.pyx":732
 *         cdef:
 *             long size, n_mods
 *         size = self.get_size()             # <<<<<<<<<<<<<<
 *         n_mods = self.modification is not None
 *         if i >= size:
 */
  __pyx_v_size = __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(__pyx_v_self);

  /* "pyteomics/cparser.pyx":733
 *             long size, n_mods
 *         size = self.get_size()
 *         n_mods = self.modification is not None             # <<<<<<<<<<<<<<
 *         if i >= size:
 *             raise IndexError(i)
 */
  __pyx_t_1 = (__pyx_v_self->modification != ((PyObject*)Py_None));
  __pyx_v_n_mods = __pyx_t_1;

  /* "pyteomics/cparser.pyx":734
 *         size = self.get_size()
 *         n_mods = self.modification is not None
 *         if i >= size:             # <<<<<<<<<<<<<<
 *             raise IndexError(i)
 *         elif i < 0:
 */
  __pyx_t_1 = ((__pyx_v_i >= __pyx_v_size) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "pyteomics/cparser.pyx":735
 *         n_mods = self.modification is not None
 *         if i >= size:
 *             raise IndexError(i)             # <<<<<<<<<<<<<<
 *         elif i < 0:
 *             if size + i < 0:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_IndexError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 735, __pyx_L1_error)

    /* "pyteomics/cparser.pyx":734
 *         size = self.get_size()
 *         n_mods = self.modification is not None
 *         if i >= size:             # <<<<<<<<<<<<<<
 *             raise IndexError(i)
 *         elif i < 0:
 */
  }

  /* "pyteomics/cparser.pyx":736
 *         if i >= size:
 *             raise IndexError(i)
 *         elif i < 0:             # <<<<<<<<<<<<<<
 *             if size + i < 0:
 *                 raise IndexError(i)
 */
  __pyx_t_1 = ((__pyx_v_i < 0) != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":737
 *             raise IndexError(i)
 *         elif i < 0:
 *             if size + i < 0:             # <<<<<<<<<<<<<<
 *                 raise IndexError(i)
 *             i = size + i
 */
    __pyx_t_1 = (((__pyx_v_size + __pyx_v_i) < 0) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "pyteomics/cparser.pyx":738
 *         elif i < 0:
 *             if size + i < 0:
 *                 raise IndexError(i)             # <<<<<<<<<<<<<<
 *             i = size + i
 *         if self.position_type == PositionType.n_term:
 */
      __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_IndexError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 738, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":737
 *             raise IndexError(i)
 *         elif i < 0:
 *             if size + i < 0:             # <<<<<<<<<<<<<<
 *                 raise IndexError(i)
 *             i = size + i
 */
    }

    /* "pyteomics/cparser.pyx":739
 *             if size + i < 0:
 *                 raise IndexError(i)
 *             i = size + i             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.n_term:
 *             if i == 0:
 */
    __pyx_v_i = (__pyx_v_size + __pyx_v_i);

    /* "pyteomics/cparser.pyx":736
 *         if i >= size:
 *             raise IndexError(i)
 *         elif i < 0:             # <<<<<<<<<<<<<<
 *             if size + i < 0:
 *                 raise IndexError(i)
 */
  }

  /* "pyteomics/cparser.pyx":740
 *                 raise IndexError(i)
 *             i = size + i
 *         if self.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             if i == 0:
 *                 return self.terminal
 */
  switch (__pyx_v_self->position_type) {
    case __pyx_e_9pyteomics_7cparser_n_term:

    /* "pyteomics/cparser.pyx":741
 *             i = size + i
 *         if self.position_type == PositionType.n_term:
 *             if i == 0:             # <<<<<<<<<<<<<<
 *                 return self.terminal
 *             elif (i - 1) == n_mods:
 */
    __pyx_t_1 = ((__pyx_v_i == 0) != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":742
 *         if self.position_type == PositionType.n_term:
 *             if i == 0:
 *                 return self.terminal             # <<<<<<<<<<<<<<
 *             elif (i - 1) == n_mods:
 *                 return self.amino_acid
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->terminal);
      __pyx_r = __pyx_v_self->terminal;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":741
 *             i = size + i
 *         if self.position_type == PositionType.n_term:
 *             if i == 0:             # <<<<<<<<<<<<<<
 *                 return self.terminal
 *             elif (i - 1) == n_mods:
 */
    }

    /* "pyteomics/cparser.pyx":743
 *             if i == 0:
 *                 return self.terminal
 *             elif (i - 1) == n_mods:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             else:
 */
    __pyx_t_1 = (((__pyx_v_i - 1) == __pyx_v_n_mods) != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":744
 *                 return self.terminal
 *             elif (i - 1) == n_mods:
 *                 return self.amino_acid             # <<<<<<<<<<<<<<
 *             else:
 *                 return self.modification
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->amino_acid);
      __pyx_r = __pyx_v_self->amino_acid;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":743
 *             if i == 0:
 *                 return self.terminal
 *             elif (i - 1) == n_mods:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             else:
 */
    }

    /* "pyteomics/cparser.pyx":746
 *                 return self.amino_acid
 *             else:
 *                 return self.modification             # <<<<<<<<<<<<<<
 *         elif self.position_type == PositionType.internal:
 *             if i == n_mods:
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->modification);
      __pyx_r = __pyx_v_self->modification;
      goto __pyx_L0;
    }

    /* "pyteomics/cparser.pyx":740
 *                 raise IndexError(i)
 *             i = size + i
 *         if self.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             if i == 0:
 *                 return self.terminal
 */
    break;
    case __pyx_e_9pyteomics_7cparser_internal:

    /* "pyteomics/cparser.pyx":748
 *                 return self.modification
 *         elif self.position_type == PositionType.internal:
 *             if i == n_mods:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             else:
 */
    __pyx_t_1 = ((__pyx_v_i == __pyx_v_n_mods) != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":749
 *         elif self.position_type == PositionType.internal:
 *             if i == n_mods:
 *                 return self.amino_acid             # <<<<<<<<<<<<<<
 *             else:
 *                 return self.modification
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->amino_acid);
      __pyx_r = __pyx_v_self->amino_acid;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":748
 *                 return self.modification
 *         elif self.position_type == PositionType.internal:
 *             if i == n_mods:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             else:
 */
    }

    /* "pyteomics/cparser.pyx":751
 *                 return self.amino_acid
 *             else:
 *                 return self.modification             # <<<<<<<<<<<<<<
 *         else:
 *             if i - n_mods == 0:
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->modification);
      __pyx_r = __pyx_v_self->modification;
      goto __pyx_L0;
    }

    /* "pyteomics/cparser.pyx":747
 *             else:
 *                 return self.modification
 *         elif self.position_type == PositionType.internal:             # <<<<<<<<<<<<<<
 *             if i == n_mods:
 *                 return self.amino_acid
 */
    break;
    default:

    /* "pyteomics/cparser.pyx":753
 *                 return self.modification
 *         else:
 *             if i - n_mods == 0:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             elif i - n_mods == 1:
 */
    __pyx_t_1 = (((__pyx_v_i - __pyx_v_n_mods) == 0) != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":754
 *         else:
 *             if i - n_mods == 0:
 *                 return self.amino_acid             # <<<<<<<<<<<<<<
 *             elif i - n_mods == 1:
 *                 return self.terminal
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->amino_acid);
      __pyx_r = __pyx_v_self->amino_acid;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":753
 *                 return self.modification
 *         else:
 *             if i - n_mods == 0:             # <<<<<<<<<<<<<<
 *                 return self.amino_acid
 *             elif i - n_mods == 1:
 */
    }

    /* "pyteomics/cparser.pyx":755
 *             if i - n_mods == 0:
 *                 return self.amino_acid
 *             elif i - n_mods == 1:             # <<<<<<<<<<<<<<
 *                 return self.terminal
 *             else:
 */
    __pyx_t_1 = (((__pyx_v_i - __pyx_v_n_mods) == 1) != 0);
    if (__pyx_t_1) {

      /* "pyteomics/cparser.pyx":756
 *                 return self.amino_acid
 *             elif i - n_mods == 1:
 *                 return self.terminal             # <<<<<<<<<<<<<<
 *             else:
 *                 return self.modification
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->terminal);
      __pyx_r = __pyx_v_self->terminal;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":755
 *             if i - n_mods == 0:
 *                 return self.amino_acid
 *             elif i - n_mods == 1:             # <<<<<<<<<<<<<<
 *                 return self.terminal
 *             else:
 */
    }

    /* "pyteomics/cparser.pyx":758
 *                 return self.terminal
 *             else:
 *                 return self.modification             # <<<<<<<<<<<<<<
 * 
 *     cdef size_t get_size(self):
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->modification);
      __pyx_r = __pyx_v_self->modification;
      goto __pyx_L0;
    }
    break;
  }

  /* "pyteomics/cparser.pyx":729
 *         return self.get_index(i)
 * 
 *     cpdef str get_index(self, long i):             # <<<<<<<<<<<<<<
 *         cdef:
 *             long size, n_mods
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.get_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_5get_index(PyObject *__pyx_v_self, PyObject *__pyx_arg_i); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_4get_index[] = "SequencePosition.get_index(self, long i) -> str";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_5get_index(PyObject *__pyx_v_self, PyObject *__pyx_arg_i) {
  long __pyx_v_i;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_index (wrapper)", 0);
  assert(__pyx_arg_i); {
    __pyx_v_i = __Pyx_PyInt_As_long(__pyx_arg_i); if (unlikely((__pyx_v_i == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 729, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.get_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_4get_index(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((long)__pyx_v_i));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_4get_index(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, long __pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_index", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16SequencePosition_get_index(__pyx_v_self, __pyx_v_i, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.get_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":760
 *                 return self.modification
 * 
 *     cdef size_t get_size(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t n_mods
 */

static size_t __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  size_t __pyx_v_n_mods;
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_size", 0);

  /* "pyteomics/cparser.pyx":764
 *             size_t n_mods
 * 
 *         n_mods = self.modification is not None             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.internal:
 *             return n_mods + 1
 */
  __pyx_t_1 = (__pyx_v_self->modification != ((PyObject*)Py_None));
  __pyx_v_n_mods = __pyx_t_1;

  /* "pyteomics/cparser.pyx":765
 * 
 *         n_mods = self.modification is not None
 *         if self.position_type == PositionType.internal:             # <<<<<<<<<<<<<<
 *             return n_mods + 1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_self->position_type == __pyx_e_9pyteomics_7cparser_internal) != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":766
 *         n_mods = self.modification is not None
 *         if self.position_type == PositionType.internal:
 *             return n_mods + 1             # <<<<<<<<<<<<<<
 *         else:
 *             return n_mods + 2
 */
    __pyx_r = (__pyx_v_n_mods + 1);
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":765
 * 
 *         n_mods = self.modification is not None
 *         if self.position_type == PositionType.internal:             # <<<<<<<<<<<<<<
 *             return n_mods + 1
 *         else:
 */
  }

  /* "pyteomics/cparser.pyx":768
 *             return n_mods + 1
 *         else:
 *             return n_mods + 2             # <<<<<<<<<<<<<<
 * 
 *     cdef bint is_modified(self):
 */
  /*else*/ {
    __pyx_r = (__pyx_v_n_mods + 2);
    goto __pyx_L0;
  }

  /* "pyteomics/cparser.pyx":760
 *                 return self.modification
 * 
 *     cdef size_t get_size(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t n_mods
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":770
 *             return n_mods + 2
 * 
 *     cdef bint is_modified(self):             # <<<<<<<<<<<<<<
 *         return self.modification is not None
 * 
 */

static int __pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("is_modified", 0);

  /* "pyteomics/cparser.pyx":771
 * 
 *     cdef bint is_modified(self):
 *         return self.modification is not None             # <<<<<<<<<<<<<<
 * 
 *     cpdef add_modification(self, str mod):
 */
  __pyx_t_1 = (__pyx_v_self->modification != ((PyObject*)Py_None));
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":770
 *             return n_mods + 2
 * 
 *     cdef bint is_modified(self):             # <<<<<<<<<<<<<<
 *         return self.modification is not None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":773
 *         return self.modification is not None
 * 
 *     cpdef add_modification(self, str mod):             # <<<<<<<<<<<<<<
 *         self.modification = mod
 * 
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_7add_modification(PyObject *__pyx_v_self, PyObject *__pyx_v_mod); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_mod, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_modification", 0);

  /* "pyteomics/cparser.pyx":774
 * 
 *     cpdef add_modification(self, str mod):
 *         self.modification = mod             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_INCREF(__pyx_v_mod);
  __Pyx_GIVEREF(__pyx_v_mod);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = __pyx_v_mod;

  /* "pyteomics/cparser.pyx":773
 *         return self.modification is not None
 * 
 *     cpdef add_modification(self, str mod):             # <<<<<<<<<<<<<<
 *         self.modification = mod
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_7add_modification(PyObject *__pyx_v_self, PyObject *__pyx_v_mod); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_6add_modification[] = "SequencePosition.add_modification(self, str mod)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_7add_modification(PyObject *__pyx_v_self, PyObject *__pyx_v_mod) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_modification (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_mod), (&PyString_Type), 1, "mod", 1))) __PYX_ERR(0, 773, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_6add_modification(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject*)__pyx_v_mod));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_6add_modification(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_mod) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_modification", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification(__pyx_v_self, __pyx_v_mod, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.add_modification", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":776
 *         self.modification = mod
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return str(self.as_tuple())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_9__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_9__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_8__repr__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_8__repr__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyteomics/cparser.pyx":777
 * 
 *     def __repr__(self):
 *         return str(self.as_tuple())             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyString_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":776
 *         self.modification = mod
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return str(self.as_tuple())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":779
 *         return str(self.as_tuple())
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.get_size()
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_9pyteomics_7cparser_16SequencePosition_11__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_9pyteomics_7cparser_16SequencePosition_11__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_10__len__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_9pyteomics_7cparser_16SequencePosition_10__len__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "pyteomics/cparser.pyx":780
 * 
 *     def __len__(self):
 *         return self.get_size()             # <<<<<<<<<<<<<<
 * 
 *     cpdef tuple as_tuple(self):
 */
  __pyx_r = __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(__pyx_v_self);
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":779
 *         return str(self.as_tuple())
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.get_size()
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":782
 *         return self.get_size()
 * 
 *     cpdef tuple as_tuple(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size, i, n_mods, j
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_13as_tuple(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  size_t __pyx_v_size;
  size_t __pyx_v_i;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_mod = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_tuple", 0);

  /* "pyteomics/cparser.pyx":787
 *             tuple result
 *             str mod
 *         size = self.get_size()             # <<<<<<<<<<<<<<
 *         result = PyTuple_New(size)
 *         i = 0
 */
  __pyx_v_size = __pyx_f_9pyteomics_7cparser_16SequencePosition_get_size(__pyx_v_self);

  /* "pyteomics/cparser.pyx":788
 *             str mod
 *         size = self.get_size()
 *         result = PyTuple_New(size)             # <<<<<<<<<<<<<<
 *         i = 0
 *         if self.position_type == PositionType.n_term:
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":789
 *         size = self.get_size()
 *         result = PyTuple_New(size)
 *         i = 0             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.n_term:
 *             Py_INCREF(self.terminal)
 */
  __pyx_v_i = 0;

  /* "pyteomics/cparser.pyx":790
 *         result = PyTuple_New(size)
 *         i = 0
 *         if self.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 */
  __pyx_t_2 = ((__pyx_v_self->position_type == __pyx_e_9pyteomics_7cparser_n_term) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":791
 *         i = 0
 *         if self.position_type == PositionType.n_term:
 *             Py_INCREF(self.terminal)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1
 */
    __pyx_t_1 = __pyx_v_self->terminal;
    __Pyx_INCREF(__pyx_t_1);
    Py_INCREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":792
 *         if self.position_type == PositionType.n_term:
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)             # <<<<<<<<<<<<<<
 *             i += 1
 *         if self.is_modified():
 */
    __pyx_t_1 = __pyx_v_self->terminal;
    __Pyx_INCREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_v_result, __pyx_v_i, __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":793
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1             # <<<<<<<<<<<<<<
 *         if self.is_modified():
 *             mod = self.modification
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "pyteomics/cparser.pyx":790
 *         result = PyTuple_New(size)
 *         i = 0
 *         if self.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 */
  }

  /* "pyteomics/cparser.pyx":794
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1
 *         if self.is_modified():             # <<<<<<<<<<<<<<
 *             mod = self.modification
 *             Py_INCREF(mod)
 */
  __pyx_t_2 = (__pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(__pyx_v_self) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":795
 *             i += 1
 *         if self.is_modified():
 *             mod = self.modification             # <<<<<<<<<<<<<<
 *             Py_INCREF(mod)
 *             PyTuple_SET_ITEM(result, i, mod)
 */
    __pyx_t_1 = __pyx_v_self->modification;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_mod = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":796
 *         if self.is_modified():
 *             mod = self.modification
 *             Py_INCREF(mod)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(result, i, mod)
 *             i += 1
 */
    Py_INCREF(__pyx_v_mod);

    /* "pyteomics/cparser.pyx":797
 *             mod = self.modification
 *             Py_INCREF(mod)
 *             PyTuple_SET_ITEM(result, i, mod)             # <<<<<<<<<<<<<<
 *             i += 1
 *         Py_INCREF(self.amino_acid)
 */
    PyTuple_SET_ITEM(__pyx_v_result, __pyx_v_i, __pyx_v_mod);

    /* "pyteomics/cparser.pyx":798
 *             Py_INCREF(mod)
 *             PyTuple_SET_ITEM(result, i, mod)
 *             i += 1             # <<<<<<<<<<<<<<
 *         Py_INCREF(self.amino_acid)
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "pyteomics/cparser.pyx":794
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1
 *         if self.is_modified():             # <<<<<<<<<<<<<<
 *             mod = self.modification
 *             Py_INCREF(mod)
 */
  }

  /* "pyteomics/cparser.pyx":799
 *             PyTuple_SET_ITEM(result, i, mod)
 *             i += 1
 *         Py_INCREF(self.amino_acid)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)
 *         i += 1
 */
  __pyx_t_1 = __pyx_v_self->amino_acid;
  __Pyx_INCREF(__pyx_t_1);
  Py_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":800
 *             i += 1
 *         Py_INCREF(self.amino_acid)
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)             # <<<<<<<<<<<<<<
 *         i += 1
 *         if self.position_type == PositionType.c_term:
 */
  __pyx_t_1 = __pyx_v_self->amino_acid;
  __Pyx_INCREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_v_result, __pyx_v_i, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":801
 *         Py_INCREF(self.amino_acid)
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)
 *         i += 1             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.c_term:
 *             Py_INCREF(self.terminal)
 */
  __pyx_v_i = (__pyx_v_i + 1);

  /* "pyteomics/cparser.pyx":802
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)
 *         i += 1
 *         if self.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 */
  __pyx_t_2 = ((__pyx_v_self->position_type == __pyx_e_9pyteomics_7cparser_c_term) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":803
 *         i += 1
 *         if self.position_type == PositionType.c_term:
 *             Py_INCREF(self.terminal)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1
 */
    __pyx_t_1 = __pyx_v_self->terminal;
    __Pyx_INCREF(__pyx_t_1);
    Py_INCREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":804
 *         if self.position_type == PositionType.c_term:
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)             # <<<<<<<<<<<<<<
 *             i += 1
 *         return result
 */
    __pyx_t_1 = __pyx_v_self->terminal;
    __Pyx_INCREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_v_result, __pyx_v_i, __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":805
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "pyteomics/cparser.pyx":802
 *         PyTuple_SET_ITEM(result, i, self.amino_acid)
 *         i += 1
 *         if self.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *             Py_INCREF(self.terminal)
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 */
  }

  /* "pyteomics/cparser.pyx":806
 *             PyTuple_SET_ITEM(result, i, self.terminal)
 *             i += 1
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cdef SequencePosition copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":782
 *         return self.get_size()
 * 
 *     cpdef tuple as_tuple(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size, i, n_mods, j
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_mod);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_13as_tuple(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_12as_tuple[] = "SequencePosition.as_tuple(self) -> tuple";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_13as_tuple(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_tuple (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_12as_tuple(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_12as_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_tuple", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":808
 *         return result
 * 
 *     cdef SequencePosition copy(self):             # <<<<<<<<<<<<<<
 *         return SequencePosition._create(
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)
 */

static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "pyteomics/cparser.pyx":809
 * 
 *     cdef SequencePosition copy(self):
 *         return SequencePosition._create(             # <<<<<<<<<<<<<<
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));

  /* "pyteomics/cparser.pyx":810
 *     cdef SequencePosition copy(self):
 *         return SequencePosition._create(
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_1 = __pyx_v_self->amino_acid;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->modification;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->terminal;
  __Pyx_INCREF(__pyx_t_3);

  /* "pyteomics/cparser.pyx":809
 * 
 *     cdef SequencePosition copy(self):
 *         return SequencePosition._create(             # <<<<<<<<<<<<<<
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)
 * 
 */
  __pyx_t_4 = ((PyObject *)__pyx_f_9pyteomics_7cparser_16SequencePosition__create(((PyObject*)__pyx_t_1), ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3), __pyx_v_self->position_type)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":808
 *         return result
 * 
 *     cdef SequencePosition copy(self):             # <<<<<<<<<<<<<<
 *         return SequencePosition._create(
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":813
 * 
 *     @classmethod
 *     def from_tuple(cls, tuple source):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size, i
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_15from_tuple(PyObject *__pyx_v_cls, PyObject *__pyx_v_source); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_14from_tuple[] = "SequencePosition.from_tuple(type cls, tuple source)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_15from_tuple(PyObject *__pyx_v_cls, PyObject *__pyx_v_source) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_tuple (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_source), (&PyTuple_Type), 1, "source", 1))) __PYX_ERR(0, 813, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_14from_tuple(((PyTypeObject*)__pyx_v_cls), ((PyObject*)__pyx_v_source));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_14from_tuple(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_source) {
  size_t __pyx_v_size;
  size_t __pyx_v_i;
  PyObject *__pyx_v_entry = 0;
  PyObject *__pyx_v_last_entry = 0;
  PyObject *__pyx_v_terminal = 0;
  PyObject *__pyx_v_amino_acid = 0;
  PyObject *__pyx_v_modification = 0;
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_tuple", 0);

  /* "pyteomics/cparser.pyx":823
 *             PositionType position_type
 * 
 *         position_type = PositionType.internal             # <<<<<<<<<<<<<<
 *         modification = None
 *         size = PyTuple_Size(source)
 */
  __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_internal;

  /* "pyteomics/cparser.pyx":824
 * 
 *         position_type = PositionType.internal
 *         modification = None             # <<<<<<<<<<<<<<
 *         size = PyTuple_Size(source)
 *         last_entry = None
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_modification = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":825
 *         position_type = PositionType.internal
 *         modification = None
 *         size = PyTuple_Size(source)             # <<<<<<<<<<<<<<
 *         last_entry = None
 *         terminal = None
 */
  __pyx_t_1 = PyTuple_Size(__pyx_v_source); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 825, __pyx_L1_error)
  __pyx_v_size = __pyx_t_1;

  /* "pyteomics/cparser.pyx":826
 *         modification = None
 *         size = PyTuple_Size(source)
 *         last_entry = None             # <<<<<<<<<<<<<<
 *         terminal = None
 *         for i in range(size):
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_last_entry = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":827
 *         size = PyTuple_Size(source)
 *         last_entry = None
 *         terminal = None             # <<<<<<<<<<<<<<
 *         for i in range(size):
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_terminal = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":828
 *         last_entry = None
 *         terminal = None
 *         for i in range(size):             # <<<<<<<<<<<<<<
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 *             if entry.endswith("-"):
 */
  __pyx_t_2 = __pyx_v_size;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "pyteomics/cparser.pyx":829
 *         terminal = None
 *         for i in range(size):
 *             entry = <str>PyTuple_GET_ITEM(source, i)             # <<<<<<<<<<<<<<
 *             if entry.endswith("-"):
 *                 if position_type != PositionType.internal:
 */
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_v_source, __pyx_v_i);
    __pyx_t_6 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_entry, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "pyteomics/cparser.pyx":830
 *         for i in range(size):
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 *             if entry.endswith("-"):             # <<<<<<<<<<<<<<
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 */
    if (unlikely(__pyx_v_entry == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
      __PYX_ERR(0, 830, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyStr_Tailmatch(__pyx_v_entry, __pyx_kp_s_, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 830, __pyx_L1_error)
    if ((__pyx_t_7 != 0)) {

      /* "pyteomics/cparser.pyx":831
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 *             if entry.endswith("-"):
 *                 if position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 */
      __pyx_t_7 = ((__pyx_v_position_type != __pyx_e_9pyteomics_7cparser_internal) != 0);
      if (unlikely(__pyx_t_7)) {

        /* "pyteomics/cparser.pyx":834
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.n_term))             # <<<<<<<<<<<<<<
 *                 position_type = PositionType.n_term
 *                 terminal = entry
 */
        __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_position_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 834, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_n_term); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 834, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 834, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_8);
        __pyx_t_6 = 0;
        __pyx_t_8 = 0;

        /* "pyteomics/cparser.pyx":833
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (             # <<<<<<<<<<<<<<
 *                             position_type, PositionType.n_term))
 *                 position_type = PositionType.n_term
 */
        __pyx_t_8 = __Pyx_PyString_Format(__pyx_kp_s_Position_already_has_position_ty, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 833, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "pyteomics/cparser.pyx":832
 *             if entry.endswith("-"):
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(             # <<<<<<<<<<<<<<
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.n_term))
 */
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 832, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_Raise(__pyx_t_9, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __PYX_ERR(0, 832, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":831
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 *             if entry.endswith("-"):
 *                 if position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 */
      }

      /* "pyteomics/cparser.pyx":835
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.n_term))
 *                 position_type = PositionType.n_term             # <<<<<<<<<<<<<<
 *                 terminal = entry
 *             elif entry.startswith("-"):
 */
      __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_n_term;

      /* "pyteomics/cparser.pyx":836
 *                             position_type, PositionType.n_term))
 *                 position_type = PositionType.n_term
 *                 terminal = entry             # <<<<<<<<<<<<<<
 *             elif entry.startswith("-"):
 *                 if position_type != PositionType.internal:
 */
      __Pyx_INCREF(__pyx_v_entry);
      __Pyx_DECREF_SET(__pyx_v_terminal, __pyx_v_entry);

      /* "pyteomics/cparser.pyx":830
 *         for i in range(size):
 *             entry = <str>PyTuple_GET_ITEM(source, i)
 *             if entry.endswith("-"):             # <<<<<<<<<<<<<<
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":837
 *                 position_type = PositionType.n_term
 *                 terminal = entry
 *             elif entry.startswith("-"):             # <<<<<<<<<<<<<<
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 */
    if (unlikely(__pyx_v_entry == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
      __PYX_ERR(0, 837, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyStr_Tailmatch(__pyx_v_entry, __pyx_kp_s_, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 837, __pyx_L1_error)
    if ((__pyx_t_7 != 0)) {

      /* "pyteomics/cparser.pyx":838
 *                 terminal = entry
 *             elif entry.startswith("-"):
 *                 if position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 */
      __pyx_t_7 = ((__pyx_v_position_type != __pyx_e_9pyteomics_7cparser_internal) != 0);
      if (unlikely(__pyx_t_7)) {

        /* "pyteomics/cparser.pyx":841
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.c_term))             # <<<<<<<<<<<<<<
 *                 position_type = PositionType.c_term
 *                 terminal = entry
 */
        __pyx_t_9 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_position_type); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 841, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_c_term); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 841, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 841, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_8);
        __pyx_t_9 = 0;
        __pyx_t_8 = 0;

        /* "pyteomics/cparser.pyx":840
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (             # <<<<<<<<<<<<<<
 *                             position_type, PositionType.c_term))
 *                 position_type = PositionType.c_term
 */
        __pyx_t_8 = __Pyx_PyString_Format(__pyx_kp_s_Position_already_has_position_ty, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 840, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":839
 *             elif entry.startswith("-"):
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(             # <<<<<<<<<<<<<<
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.c_term))
 */
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 839, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":838
 *                 terminal = entry
 *             elif entry.startswith("-"):
 *                 if position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         "Position already has position type %s, second type provided %s" % (
 */
      }

      /* "pyteomics/cparser.pyx":842
 *                         "Position already has position type %s, second type provided %s" % (
 *                             position_type, PositionType.c_term))
 *                 position_type = PositionType.c_term             # <<<<<<<<<<<<<<
 *                 terminal = entry
 *             else:
 */
      __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_c_term;

      /* "pyteomics/cparser.pyx":843
 *                             position_type, PositionType.c_term))
 *                 position_type = PositionType.c_term
 *                 terminal = entry             # <<<<<<<<<<<<<<
 *             else:
 *                 if last_entry is not None:
 */
      __Pyx_INCREF(__pyx_v_entry);
      __Pyx_DECREF_SET(__pyx_v_terminal, __pyx_v_entry);

      /* "pyteomics/cparser.pyx":837
 *                 position_type = PositionType.n_term
 *                 terminal = entry
 *             elif entry.startswith("-"):             # <<<<<<<<<<<<<<
 *                 if position_type != PositionType.internal:
 *                     raise ValueError(
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":845
 *                 terminal = entry
 *             else:
 *                 if last_entry is not None:             # <<<<<<<<<<<<<<
 *                     modification = last_entry
 *                 last_entry = entry
 */
    /*else*/ {
      __pyx_t_7 = (__pyx_v_last_entry != ((PyObject*)Py_None));
      __pyx_t_10 = (__pyx_t_7 != 0);
      if (__pyx_t_10) {

        /* "pyteomics/cparser.pyx":846
 *             else:
 *                 if last_entry is not None:
 *                     modification = last_entry             # <<<<<<<<<<<<<<
 *                 last_entry = entry
 *         amino_acid = last_entry
 */
        __Pyx_INCREF(__pyx_v_last_entry);
        __Pyx_DECREF_SET(__pyx_v_modification, __pyx_v_last_entry);

        /* "pyteomics/cparser.pyx":845
 *                 terminal = entry
 *             else:
 *                 if last_entry is not None:             # <<<<<<<<<<<<<<
 *                     modification = last_entry
 *                 last_entry = entry
 */
      }

      /* "pyteomics/cparser.pyx":847
 *                 if last_entry is not None:
 *                     modification = last_entry
 *                 last_entry = entry             # <<<<<<<<<<<<<<
 *         amino_acid = last_entry
 *         return cls(amino_acid, modification, terminal, position_type)
 */
      __Pyx_INCREF(__pyx_v_entry);
      __Pyx_DECREF_SET(__pyx_v_last_entry, __pyx_v_entry);
    }
    __pyx_L5:;
  }

  /* "pyteomics/cparser.pyx":848
 *                     modification = last_entry
 *                 last_entry = entry
 *         amino_acid = last_entry             # <<<<<<<<<<<<<<
 *         return cls(amino_acid, modification, terminal, position_type)
 * 
 */
  __Pyx_INCREF(__pyx_v_last_entry);
  __pyx_v_amino_acid = __pyx_v_last_entry;

  /* "pyteomics/cparser.pyx":849
 *                 last_entry = entry
 *         amino_acid = last_entry
 *         return cls(amino_acid, modification, terminal, position_type)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_position_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyTuple_New(4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_amino_acid);
  __Pyx_GIVEREF(__pyx_v_amino_acid);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_amino_acid);
  __Pyx_INCREF(__pyx_v_modification);
  __Pyx_GIVEREF(__pyx_v_modification);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_modification);
  __Pyx_INCREF(__pyx_v_terminal);
  __Pyx_GIVEREF(__pyx_v_terminal);
  PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_v_terminal);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_8, 3, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":813
 * 
 *     @classmethod
 *     def from_tuple(cls, tuple source):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size, i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.from_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_last_entry);
  __Pyx_XDECREF(__pyx_v_terminal);
  __Pyx_XDECREF(__pyx_v_amino_acid);
  __Pyx_XDECREF(__pyx_v_modification);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":852
 * 
 *     @classmethod
 *     def parse(cls, str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t n, i
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_17parse(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_16parse[] = "SequencePosition.parse(type cls, str sequence, **kwargs)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_17parse(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_kwargs = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, pos_args, "parse") < 0)) __PYX_ERR(0, 852, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_sequence = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 852, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyString_Type), 1, "sequence", 1))) __PYX_ERR(0, 852, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_16parse(((PyTypeObject*)__pyx_v_cls), __pyx_v_sequence, __pyx_v_kwargs);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_16parse(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_sequence, PyObject *__pyx_v_kwargs) {
  size_t __pyx_v_n;
  size_t __pyx_v_i;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_converter = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  size_t __pyx_t_6;
  size_t __pyx_t_7;
  size_t __pyx_t_8;
  PyObject *__pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "pyteomics/cparser.pyx":857
 *             list tokens, result
 *             object converter
 *         converter = cls.from_tuple             # <<<<<<<<<<<<<<
 *         tokens = parse(sequence, show_unmodified_termini=True, split=True, **kwargs)
 *         n = PyList_Size(tokens)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_from_tuple); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_converter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":858
 *             object converter
 *         converter = cls.from_tuple
 *         tokens = parse(sequence, show_unmodified_termini=True, split=True, **kwargs)             # <<<<<<<<<<<<<<
 *         n = PyList_Size(tokens)
 *         result = []
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_sequence);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_show_unmodified_termini, Py_True) < 0) __PYX_ERR(0, 858, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_split, Py_True) < 0) __PYX_ERR(0, 858, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_t_4 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 858, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 858, __pyx_L1_error)
  __pyx_v_tokens = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":859
 *         converter = cls.from_tuple
 *         tokens = parse(sequence, show_unmodified_termini=True, split=True, **kwargs)
 *         n = PyList_Size(tokens)             # <<<<<<<<<<<<<<
 *         result = []
 *         for i in range(n):
 */
  __pyx_t_5 = PyList_Size(__pyx_v_tokens); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 859, __pyx_L1_error)
  __pyx_v_n = __pyx_t_5;

  /* "pyteomics/cparser.pyx":860
 *         tokens = parse(sequence, show_unmodified_termini=True, split=True, **kwargs)
 *         n = PyList_Size(tokens)
 *         result = []             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             result.append(converter(<tuple>PyList_GET_ITEM(tokens, i)))
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":861
 *         n = PyList_Size(tokens)
 *         result = []
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             result.append(converter(<tuple>PyList_GET_ITEM(tokens, i)))
 *         return result
 */
  __pyx_t_6 = __pyx_v_n;
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "pyteomics/cparser.pyx":862
 *         result = []
 *         for i in range(n):
 *             result.append(converter(<tuple>PyList_GET_ITEM(tokens, i)))             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_t_9 = PyList_GET_ITEM(__pyx_v_tokens, __pyx_v_i);
    __Pyx_INCREF(__pyx_v_converter);
    __pyx_t_3 = __pyx_v_converter; __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, ((PyObject *)__pyx_t_9)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_t_9));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 862, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_4); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 862, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "pyteomics/cparser.pyx":863
 *         for i in range(n):
 *             result.append(converter(<tuple>PyList_GET_ITEM(tokens, i)))
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":852
 * 
 *     @classmethod
 *     def parse(cls, str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t n, i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_converter);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":866
 * 
 *     @classmethod
 *     def from_iterable(cls, object iterable):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_19from_iterable(PyObject *__pyx_v_cls, PyObject *__pyx_v_iterable); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_18from_iterable[] = "SequencePosition.from_iterable(type cls, iterable)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_19from_iterable(PyObject *__pyx_v_cls, PyObject *__pyx_v_iterable) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_iterable (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_18from_iterable(((PyTypeObject*)__pyx_v_cls), ((PyObject *)__pyx_v_iterable));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_18from_iterable(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_iterable) {
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_converter = 0;
  PyObject *__pyx_v_obj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_iterable", 0);

  /* "pyteomics/cparser.pyx":872
 *             object converter
 * 
 *         converter = cls.from_tuple             # <<<<<<<<<<<<<<
 *         result = []
 *         for obj in iterable:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_from_tuple); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_converter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":873
 * 
 *         converter = cls.from_tuple
 *         result = []             # <<<<<<<<<<<<<<
 *         for obj in iterable:
 *             if isinstance(obj, SequencePosition):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":874
 *         converter = cls.from_tuple
 *         result = []
 *         for obj in iterable:             # <<<<<<<<<<<<<<
 *             if isinstance(obj, SequencePosition):
 *                 result.append((<SequencePosition>obj).copy())
 */
  if (likely(PyList_CheckExact(__pyx_v_iterable)) || PyTuple_CheckExact(__pyx_v_iterable)) {
    __pyx_t_1 = __pyx_v_iterable; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_iterable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 874, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 874, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 874, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 874, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 874, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 874, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_obj, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyteomics/cparser.pyx":875
 *         result = []
 *         for obj in iterable:
 *             if isinstance(obj, SequencePosition):             # <<<<<<<<<<<<<<
 *                 result.append((<SequencePosition>obj).copy())
 *             else:
 */
    __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_ptype_9pyteomics_7cparser_SequencePosition); 
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "pyteomics/cparser.pyx":876
 *         for obj in iterable:
 *             if isinstance(obj, SequencePosition):
 *                 result.append((<SequencePosition>obj).copy())             # <<<<<<<<<<<<<<
 *             else:
 *                 result.append(
 */
      __pyx_t_4 = ((PyObject *)__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_obj))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 876, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 876, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "pyteomics/cparser.pyx":875
 *         result = []
 *         for obj in iterable:
 *             if isinstance(obj, SequencePosition):             # <<<<<<<<<<<<<<
 *                 result.append((<SequencePosition>obj).copy())
 *             else:
 */
      goto __pyx_L5;
    }

    /* "pyteomics/cparser.pyx":878
 *                 result.append((<SequencePosition>obj).copy())
 *             else:
 *                 result.append(             # <<<<<<<<<<<<<<
 *                     converter(<tuple?>obj))
 *         return result
 */
    /*else*/ {

      /* "pyteomics/cparser.pyx":879
 *             else:
 *                 result.append(
 *                     converter(<tuple?>obj))             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
      if (!(likely(PyTuple_CheckExact(__pyx_v_obj))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v_obj)->tp_name), 0))) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_INCREF(__pyx_v_converter);
      __pyx_t_8 = __pyx_v_converter; __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_v_obj) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_obj);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "pyteomics/cparser.pyx":878
 *                 result.append((<SequencePosition>obj).copy())
 *             else:
 *                 result.append(             # <<<<<<<<<<<<<<
 *                     converter(<tuple?>obj))
 *         return result
 */
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 878, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;

    /* "pyteomics/cparser.pyx":874
 *         converter = cls.from_tuple
 *         result = []
 *         for obj in iterable:             # <<<<<<<<<<<<<<
 *             if isinstance(obj, SequencePosition):
 *                 result.append((<SequencePosition>obj).copy())
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":880
 *                 result.append(
 *                     converter(<tuple?>obj))
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _eq(self, SequencePosition other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":866
 * 
 *     @classmethod
 *     def from_iterable(cls, object iterable):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.from_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_converter);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":882
 *         return result
 * 
 *     cdef bint _eq(self, SequencePosition other):             # <<<<<<<<<<<<<<
 *         if self.amino_acid != other.amino_acid:
 *             return False
 */

static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_other) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_eq", 0);

  /* "pyteomics/cparser.pyx":883
 * 
 *     cdef bint _eq(self, SequencePosition other):
 *         if self.amino_acid != other.amino_acid:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.modification != other.modification:
 */
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_self->amino_acid, __pyx_v_other->amino_acid, Py_NE)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 883, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":884
 *     cdef bint _eq(self, SequencePosition other):
 *         if self.amino_acid != other.amino_acid:
 *             return False             # <<<<<<<<<<<<<<
 *         elif self.modification != other.modification:
 *             return False
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":883
 * 
 *     cdef bint _eq(self, SequencePosition other):
 *         if self.amino_acid != other.amino_acid:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.modification != other.modification:
 */
  }

  /* "pyteomics/cparser.pyx":885
 *         if self.amino_acid != other.amino_acid:
 *             return False
 *         elif self.modification != other.modification:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.terminal != other.terminal:
 */
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_self->modification, __pyx_v_other->modification, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 885, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":886
 *             return False
 *         elif self.modification != other.modification:
 *             return False             # <<<<<<<<<<<<<<
 *         elif self.terminal != other.terminal:
 *             return False
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":885
 *         if self.amino_acid != other.amino_acid:
 *             return False
 *         elif self.modification != other.modification:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.terminal != other.terminal:
 */
  }

  /* "pyteomics/cparser.pyx":887
 *         elif self.modification != other.modification:
 *             return False
 *         elif self.terminal != other.terminal:             # <<<<<<<<<<<<<<
 *             return False
 *         return True
 */
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_self->terminal, __pyx_v_other->terminal, Py_NE)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 887, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":888
 *             return False
 *         elif self.terminal != other.terminal:
 *             return False             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":887
 *         elif self.modification != other.modification:
 *             return False
 *         elif self.terminal != other.terminal:             # <<<<<<<<<<<<<<
 *             return False
 *         return True
 */
  }

  /* "pyteomics/cparser.pyx":889
 *         elif self.terminal != other.terminal:
 *             return False
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _eq_tuple(self, tuple other):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":882
 *         return result
 * 
 *     cdef bint _eq(self, SequencePosition other):             # <<<<<<<<<<<<<<
 *         if self.amino_acid != other.amino_acid:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("pyteomics.cparser.SequencePosition._eq", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":891
 *         return True
 * 
 *     cdef bint _eq_tuple(self, tuple other):             # <<<<<<<<<<<<<<
 *         return self.as_tuple() == other
 * 
 */

static int __pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_eq_tuple", 0);

  /* "pyteomics/cparser.pyx":892
 * 
 *     cdef bint _eq_tuple(self, tuple other):
 *         return self.as_tuple() == other             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":891
 *         return True
 * 
 *     cdef bint _eq_tuple(self, tuple other):             # <<<<<<<<<<<<<<
 *         return self.as_tuple() == other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("pyteomics.cparser.SequencePosition._eq_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":894
 *         return self.as_tuple() == other
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if other is None:
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_21__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_21__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_20__eq__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_20__eq__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "pyteomics/cparser.pyx":895
 * 
 *     def __eq__(self, other):
 *         if other is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if isinstance(other, SequencePosition):
 */
  __pyx_t_1 = (__pyx_v_other == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":896
 *     def __eq__(self, other):
 *         if other is None:
 *             return False             # <<<<<<<<<<<<<<
 *         if isinstance(other, SequencePosition):
 *             return self._eq(<SequencePosition>other)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":895
 * 
 *     def __eq__(self, other):
 *         if other is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if isinstance(other, SequencePosition):
 */
  }

  /* "pyteomics/cparser.pyx":897
 *         if other is None:
 *             return False
 *         if isinstance(other, SequencePosition):             # <<<<<<<<<<<<<<
 *             return self._eq(<SequencePosition>other)
 *         elif isinstance(other, tuple):
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_9pyteomics_7cparser_SequencePosition); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":898
 *             return False
 *         if isinstance(other, SequencePosition):
 *             return self._eq(<SequencePosition>other)             # <<<<<<<<<<<<<<
 *         elif isinstance(other, tuple):
 *             return self._eq_tuple(<tuple>other)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_f_9pyteomics_7cparser_16SequencePosition__eq(__pyx_v_self, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_other))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":897
 *         if other is None:
 *             return False
 *         if isinstance(other, SequencePosition):             # <<<<<<<<<<<<<<
 *             return self._eq(<SequencePosition>other)
 *         elif isinstance(other, tuple):
 */
  }

  /* "pyteomics/cparser.pyx":899
 *         if isinstance(other, SequencePosition):
 *             return self._eq(<SequencePosition>other)
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             return self._eq_tuple(<tuple>other)
 *         else:
 */
  __pyx_t_1 = PyTuple_Check(__pyx_v_other); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":900
 *             return self._eq(<SequencePosition>other)
 *         elif isinstance(other, tuple):
 *             return self._eq_tuple(<tuple>other)             # <<<<<<<<<<<<<<
 *         else:
 *             return self._eq_tuple(tuple(other))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple(__pyx_v_self, ((PyObject*)__pyx_v_other))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":899
 *         if isinstance(other, SequencePosition):
 *             return self._eq(<SequencePosition>other)
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             return self._eq_tuple(<tuple>other)
 *         else:
 */
  }

  /* "pyteomics/cparser.pyx":902
 *             return self._eq_tuple(<tuple>other)
 *         else:
 *             return self._eq_tuple(tuple(other))             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_v_other); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple(__pyx_v_self, ((PyObject*)__pyx_t_3))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "pyteomics/cparser.pyx":894
 *         return self.as_tuple() == other
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if other is None:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":904
 *             return self._eq_tuple(tuple(other))
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_23__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_23__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_22__ne__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_22__ne__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ne__", 0);

  /* "pyteomics/cparser.pyx":905
 * 
 *     def __ne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self), __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":904
 *             return self._eq_tuple(tuple(other))
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":702
 * cdef class SequencePosition(object):
 *     cdef:
 *         public str modification             # <<<<<<<<<<<<<<
 *         public PositionType position_type
 *         public str amino_acid
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification___get__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->modification);
  __pyx_r = __pyx_v_self->modification;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_2__set__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 702, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.modification.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_4__del__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_12modification_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":703
 *     cdef:
 *         public str modification
 *         public PositionType position_type             # <<<<<<<<<<<<<<
 *         public str amino_acid
 *         public str terminal
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type___get__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_self->position_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.position_type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type_2__set__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_13position_type_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_value)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 703, __pyx_L1_error)
  __pyx_v_self->position_type = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.position_type.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":704
 *         public str modification
 *         public PositionType position_type
 *         public str amino_acid             # <<<<<<<<<<<<<<
 *         public str terminal
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid___get__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->amino_acid);
  __pyx_r = __pyx_v_self->amino_acid;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_2__set__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 704, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->amino_acid);
  __Pyx_DECREF(__pyx_v_self->amino_acid);
  __pyx_v_self->amino_acid = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.amino_acid.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_4__del__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_10amino_acid_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->amino_acid);
  __Pyx_DECREF(__pyx_v_self->amino_acid);
  __pyx_v_self->amino_acid = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":705
 *         public PositionType position_type
 *         public str amino_acid
 *         public str terminal             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, amino_acid, modification=None, terminal=None, position_type=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal___get__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal___get__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->terminal);
  __pyx_r = __pyx_v_self->terminal;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_2__set__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_2__set__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 705, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->terminal);
  __Pyx_DECREF(__pyx_v_self->terminal);
  __pyx_v_self->terminal = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.terminal.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_4__del__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16SequencePosition_8terminal_4__del__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->terminal);
  __Pyx_DECREF(__pyx_v_self->terminal);
  __pyx_v_self->terminal = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_24__reduce_cython__[] = "SequencePosition.__reduce_cython__(self)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_24__reduce_cython__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_24__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.amino_acid, self.modification, self.position_type, self.terminal)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_self->position_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->amino_acid);
  __Pyx_GIVEREF(__pyx_v_self->amino_acid);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->amino_acid);
  __Pyx_INCREF(__pyx_v_self->modification);
  __Pyx_GIVEREF(__pyx_v_self->modification);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->modification);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->terminal);
  __Pyx_GIVEREF(__pyx_v_self->terminal);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_self->terminal);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.amino_acid, self.modification, self.position_type, self.terminal)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":7
 *     state = (self.amino_acid, self.modification, self.position_type, self.terminal)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.amino_acid is not None or self.modification is not None or self.terminal is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.amino_acid, self.modification, self.position_type, self.terminal)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.amino_acid is not None or self.modification is not None or self.terminal is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, None), state
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->amino_acid != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_3 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->modification != ((PyObject*)Py_None));
    __pyx_t_3 = (__pyx_t_5 != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->terminal != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_3 != 0);
    __pyx_t_4 = __pyx_t_5;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.amino_acid is not None or self.modification is not None or self.terminal is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, None), state
 *     else:
 */
  __pyx_t_4 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":13
 *         use_setstate = self.amino_acid is not None or self.modification is not None or self.terminal is not None
 *     if use_setstate:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_SequencePosition); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_158260321);
    __Pyx_GIVEREF(__pyx_int_158260321);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_158260321);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.amino_acid is not None or self.modification is not None or self.terminal is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, None), state
 *     else:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_SequencePosition__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_SequencePosition); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_158260321);
    __Pyx_GIVEREF(__pyx_int_158260321);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_158260321);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SequencePosition__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16SequencePosition_26__setstate_cython__[] = "SequencePosition.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16SequencePosition_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16SequencePosition_26__setstate_cython__(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16SequencePosition_26__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_SequencePosition__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_SequencePosition__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SequencePosition, (type(self), 0x96edc61, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SequencePosition__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.SequencePosition.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":908
 * 
 * 
 * cpdef str _sequence_tostring(list sequence, bint show_unmodified_termini=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         size_t i, n, acc, j
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_11_sequence_tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser__sequence_tostring(PyObject *__pyx_v_sequence, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring *__pyx_optional_args) {
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  size_t __pyx_v_acc;
  size_t __pyx_v_j;
  Py_ssize_t __pyx_v_sz;
  char *__pyx_v_cstr;
  char __pyx_v_prealloc_buffer[0x96];
  char *__pyx_v_string_buffer;
  int __pyx_v_needs_free;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_pos = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_sequence_tostring", 0);
  if (__pyx_optional_args) {
  }

  /* "pyteomics/cparser.pyx":919
 *         str result
 * 
 *     needs_free = False             # <<<<<<<<<<<<<<
 *     sz = 0
 *     n = PyList_Size(sequence)
 */
  __pyx_v_needs_free = 0;

  /* "pyteomics/cparser.pyx":920
 * 
 *     needs_free = False
 *     sz = 0             # <<<<<<<<<<<<<<
 *     n = PyList_Size(sequence)
 *     acc = 0
 */
  __pyx_v_sz = 0;

  /* "pyteomics/cparser.pyx":921
 *     needs_free = False
 *     sz = 0
 *     n = PyList_Size(sequence)             # <<<<<<<<<<<<<<
 *     acc = 0
 *     for i in range(n):
 */
  __pyx_t_1 = PyList_Size(__pyx_v_sequence); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 921, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pyteomics/cparser.pyx":922
 *     sz = 0
 *     n = PyList_Size(sequence)
 *     acc = 0             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 */
  __pyx_v_acc = 0;

  /* "pyteomics/cparser.pyx":923
 *     n = PyList_Size(sequence)
 *     acc = 0
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.terminal is not None:
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "pyteomics/cparser.pyx":924
 *     acc = 0
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)             # <<<<<<<<<<<<<<
 *         if pos.terminal is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
    __pyx_t_5 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_v_i);
    __pyx_t_6 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_pos, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "pyteomics/cparser.pyx":925
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *             acc += sz
 */
    __pyx_t_7 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_7 != 0);
    if (__pyx_t_8) {

      /* "pyteomics/cparser.pyx":926
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.terminal is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *             acc += sz
 *         if pos.modification is not None:
 */
      __pyx_t_6 = __pyx_v_pos->terminal;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pyteomics/cparser.pyx":927
 *         if pos.terminal is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *             acc += sz             # <<<<<<<<<<<<<<
 *         if pos.modification is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 */
      __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

      /* "pyteomics/cparser.pyx":925
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *             acc += sz
 */
    }

    /* "pyteomics/cparser.pyx":928
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *             acc += sz
 *         if pos.modification is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             acc += sz
 */
    __pyx_t_8 = (__pyx_v_pos->modification != ((PyObject*)Py_None));
    __pyx_t_7 = (__pyx_t_8 != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":929
 *             acc += sz
 *         if pos.modification is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)             # <<<<<<<<<<<<<<
 *             acc += sz
 *         if pos.amino_acid is not None:
 */
      __pyx_t_6 = __pyx_v_pos->modification;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pyteomics/cparser.pyx":930
 *         if pos.modification is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             acc += sz             # <<<<<<<<<<<<<<
 *         if pos.amino_acid is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 */
      __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

      /* "pyteomics/cparser.pyx":928
 *             cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *             acc += sz
 *         if pos.modification is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             acc += sz
 */
    }

    /* "pyteomics/cparser.pyx":931
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             acc += sz
 *         if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             acc += sz
 */
    __pyx_t_7 = (__pyx_v_pos->amino_acid != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_7 != 0);
    if (__pyx_t_8) {

      /* "pyteomics/cparser.pyx":932
 *             acc += sz
 *         if pos.amino_acid is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)             # <<<<<<<<<<<<<<
 *             acc += sz
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:
 */
      __pyx_t_6 = __pyx_v_pos->amino_acid;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pyteomics/cparser.pyx":933
 *         if pos.amino_acid is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             acc += sz             # <<<<<<<<<<<<<<
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:
 *         string_buffer = prealloc_buffer
 */
      __pyx_v_acc = (__pyx_v_acc + __pyx_v_sz);

      /* "pyteomics/cparser.pyx":931
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             acc += sz
 *         if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             acc += sz
 */
    }
  }

  /* "pyteomics/cparser.pyx":934
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             acc += sz
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:             # <<<<<<<<<<<<<<
 *         string_buffer = prealloc_buffer
 *     else:
 */
  __pyx_t_8 = ((__pyx_v_acc < 0x96) != 0);
  if (__pyx_t_8) {

    /* "pyteomics/cparser.pyx":935
 *             acc += sz
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:
 *         string_buffer = prealloc_buffer             # <<<<<<<<<<<<<<
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 */
    __pyx_v_string_buffer = __pyx_v_prealloc_buffer;

    /* "pyteomics/cparser.pyx":934
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             acc += sz
 *     if acc < TOSTRING_STACK_BUFFER_SIZE:             # <<<<<<<<<<<<<<
 *         string_buffer = prealloc_buffer
 *     else:
 */
    goto __pyx_L8;
  }

  /* "pyteomics/cparser.pyx":937
 *         string_buffer = prealloc_buffer
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)             # <<<<<<<<<<<<<<
 *         needs_free = True
 *     acc = 0
 */
  /*else*/ {
    __pyx_v_string_buffer = ((char *)malloc(((sizeof(char *)) * __pyx_v_acc)));

    /* "pyteomics/cparser.pyx":938
 *     else:
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 *         needs_free = True             # <<<<<<<<<<<<<<
 *     acc = 0
 *     for i in range(n):
 */
    __pyx_v_needs_free = 1;
  }
  __pyx_L8:;

  /* "pyteomics/cparser.pyx":939
 *         string_buffer = <char*>malloc(sizeof(char*) * acc)
 *         needs_free = True
 *     acc = 0             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 */
  __pyx_v_acc = 0;

  /* "pyteomics/cparser.pyx":940
 *         needs_free = True
 *     acc = 0
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.position_type == PositionType.n_term:
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "pyteomics/cparser.pyx":941
 *     acc = 0
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)             # <<<<<<<<<<<<<<
 *         if pos.position_type == PositionType.n_term:
 *             if pos.terminal is not None:
 */
    __pyx_t_5 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_v_i);
    __pyx_t_6 = ((PyObject *)__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_pos, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "pyteomics/cparser.pyx":942
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
    __pyx_t_8 = ((__pyx_v_pos->position_type == __pyx_e_9pyteomics_7cparser_n_term) != 0);
    if (__pyx_t_8) {

      /* "pyteomics/cparser.pyx":943
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.position_type == PositionType.n_term:
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 */
      __pyx_t_8 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
      __pyx_t_7 = (__pyx_t_8 != 0);
      if (__pyx_t_7) {

        /* "pyteomics/cparser.pyx":944
 *         if pos.position_type == PositionType.n_term:
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 */
        __pyx_t_6 = __pyx_v_pos->terminal;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":945
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):             # <<<<<<<<<<<<<<
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1
 */
        __pyx_t_1 = __pyx_v_sz;
        __pyx_t_9 = __pyx_t_1;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_j = __pyx_t_10;

          /* "pyteomics/cparser.pyx":946
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                     acc += 1
 * 
 */
          (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

          /* "pyteomics/cparser.pyx":947
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1             # <<<<<<<<<<<<<<
 * 
 *         if pos.modification is not None:
 */
          __pyx_v_acc = (__pyx_v_acc + 1);
        }

        /* "pyteomics/cparser.pyx":943
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.position_type == PositionType.n_term:
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 */
      }

      /* "pyteomics/cparser.pyx":942
 *     for i in range(n):
 *         pos = <SequencePosition?>PyList_GET_ITEM(sequence, i)
 *         if pos.position_type == PositionType.n_term:             # <<<<<<<<<<<<<<
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
    }

    /* "pyteomics/cparser.pyx":949
 *                     acc += 1
 * 
 *         if pos.modification is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             for j in range(sz):
 */
    __pyx_t_7 = (__pyx_v_pos->modification != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_7 != 0);
    if (__pyx_t_8) {

      /* "pyteomics/cparser.pyx":950
 * 
 *         if pos.modification is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)             # <<<<<<<<<<<<<<
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]
 */
      __pyx_t_6 = __pyx_v_pos->modification;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pyteomics/cparser.pyx":951
 *         if pos.modification is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             for j in range(sz):             # <<<<<<<<<<<<<<
 *                 string_buffer[acc] = cstr[j]
 *                 acc += 1
 */
      __pyx_t_1 = __pyx_v_sz;
      __pyx_t_9 = __pyx_t_1;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_j = __pyx_t_10;

        /* "pyteomics/cparser.pyx":952
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                 acc += 1
 * 
 */
        (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

        /* "pyteomics/cparser.pyx":953
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]
 *                 acc += 1             # <<<<<<<<<<<<<<
 * 
 *         if pos.amino_acid is not None:
 */
        __pyx_v_acc = (__pyx_v_acc + 1);
      }

      /* "pyteomics/cparser.pyx":949
 *                     acc += 1
 * 
 *         if pos.modification is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.modification, &sz)
 *             for j in range(sz):
 */
    }

    /* "pyteomics/cparser.pyx":955
 *                 acc += 1
 * 
 *         if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             for j in range(sz):
 */
    __pyx_t_8 = (__pyx_v_pos->amino_acid != ((PyObject*)Py_None));
    __pyx_t_7 = (__pyx_t_8 != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":956
 * 
 *         if pos.amino_acid is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)             # <<<<<<<<<<<<<<
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]
 */
      __pyx_t_6 = __pyx_v_pos->amino_acid;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pyteomics/cparser.pyx":957
 *         if pos.amino_acid is not None:
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             for j in range(sz):             # <<<<<<<<<<<<<<
 *                 string_buffer[acc] = cstr[j]
 *                 acc += 1
 */
      __pyx_t_1 = __pyx_v_sz;
      __pyx_t_9 = __pyx_t_1;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_j = __pyx_t_10;

        /* "pyteomics/cparser.pyx":958
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                 acc += 1
 * 
 */
        (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

        /* "pyteomics/cparser.pyx":959
 *             for j in range(sz):
 *                 string_buffer[acc] = cstr[j]
 *                 acc += 1             # <<<<<<<<<<<<<<
 * 
 *         if pos.position_type == PositionType.c_term:
 */
        __pyx_v_acc = (__pyx_v_acc + 1);
      }

      /* "pyteomics/cparser.pyx":955
 *                 acc += 1
 * 
 *         if pos.amino_acid is not None:             # <<<<<<<<<<<<<<
 *             cstr = PyStr_AsUTF8AndSize(pos.amino_acid, &sz)
 *             for j in range(sz):
 */
    }

    /* "pyteomics/cparser.pyx":961
 *                 acc += 1
 * 
 *         if pos.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
    __pyx_t_7 = ((__pyx_v_pos->position_type == __pyx_e_9pyteomics_7cparser_c_term) != 0);
    if (__pyx_t_7) {

      /* "pyteomics/cparser.pyx":962
 * 
 *         if pos.position_type == PositionType.c_term:
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 */
      __pyx_t_7 = (__pyx_v_pos->terminal != ((PyObject*)Py_None));
      __pyx_t_8 = (__pyx_t_7 != 0);
      if (__pyx_t_8) {

        /* "pyteomics/cparser.pyx":963
 *         if pos.position_type == PositionType.c_term:
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)             # <<<<<<<<<<<<<<
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 */
        __pyx_t_6 = __pyx_v_pos->terminal;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_cstr = PyStr_AsUTF8AndSize(((PyObject*)__pyx_t_6), (&__pyx_v_sz));
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":964
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):             # <<<<<<<<<<<<<<
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1
 */
        __pyx_t_1 = __pyx_v_sz;
        __pyx_t_9 = __pyx_t_1;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_j = __pyx_t_10;

          /* "pyteomics/cparser.pyx":965
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]             # <<<<<<<<<<<<<<
 *                     acc += 1
 * 
 */
          (__pyx_v_string_buffer[__pyx_v_acc]) = (__pyx_v_cstr[__pyx_v_j]);

          /* "pyteomics/cparser.pyx":966
 *                 for j in range(sz):
 *                     string_buffer[acc] = cstr[j]
 *                     acc += 1             # <<<<<<<<<<<<<<
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 */
          __pyx_v_acc = (__pyx_v_acc + 1);
        }

        /* "pyteomics/cparser.pyx":962
 * 
 *         if pos.position_type == PositionType.c_term:
 *             if pos.terminal is not None:             # <<<<<<<<<<<<<<
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 *                 for j in range(sz):
 */
      }

      /* "pyteomics/cparser.pyx":961
 *                 acc += 1
 * 
 *         if pos.position_type == PositionType.c_term:             # <<<<<<<<<<<<<<
 *             if pos.terminal is not None:
 *                 cstr = PyStr_AsUTF8AndSize(pos.terminal, &sz)
 */
    }
  }

  /* "pyteomics/cparser.pyx":968
 *                     acc += 1
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)             # <<<<<<<<<<<<<<
 *     if needs_free:
 *         free(string_buffer)
 */
  __pyx_t_6 = PyStr_FromStringAndSize(__pyx_v_string_buffer, __pyx_v_acc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pyteomics/cparser.pyx":969
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:             # <<<<<<<<<<<<<<
 *         free(string_buffer)
 *     return result
 */
  __pyx_t_8 = (__pyx_v_needs_free != 0);
  if (__pyx_t_8) {

    /* "pyteomics/cparser.pyx":970
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:
 *         free(string_buffer)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    free(__pyx_v_string_buffer);

    /* "pyteomics/cparser.pyx":969
 * 
 *     result = PyStr_FromStringAndSize(string_buffer, acc)
 *     if needs_free:             # <<<<<<<<<<<<<<
 *         free(string_buffer)
 *     return result
 */
  }

  /* "pyteomics/cparser.pyx":971
 *     if needs_free:
 *         free(string_buffer)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":908
 * 
 * 
 * cpdef str _sequence_tostring(list sequence, bint show_unmodified_termini=True):             # <<<<<<<<<<<<<<
 *     cdef:
 *         size_t i, n, acc, j
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyteomics.cparser._sequence_tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_11_sequence_tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_10_sequence_tostring[] = "_sequence_tostring(list sequence, bool show_unmodified_termini=True) -> str";
static PyObject *__pyx_pw_9pyteomics_7cparser_11_sequence_tostring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_v_show_unmodified_termini;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_sequence_tostring (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_show_unmodified_termini,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_sequence_tostring") < 0)) __PYX_ERR(0, 908, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_show_unmodified_termini = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_show_unmodified_termini == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 908, __pyx_L3_error)
    } else {
      __pyx_v_show_unmodified_termini = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_sequence_tostring", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 908, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser._sequence_tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyList_Type), 1, "sequence", 1))) __PYX_ERR(0, 908, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_10_sequence_tostring(__pyx_self, __pyx_v_sequence, __pyx_v_show_unmodified_termini);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_10_sequence_tostring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, int __pyx_v_show_unmodified_termini) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_sequence_tostring", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.show_unmodified_termini = __pyx_v_show_unmodified_termini;
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser__sequence_tostring(__pyx_v_sequence, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser._sequence_tostring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":974
 * 
 * 
 * cpdef list copy_sequence(list sequence):             # <<<<<<<<<<<<<<
 *     cdef:
 *         list result
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_13copy_sequence(PyObject *__pyx_self, PyObject *__pyx_v_sequence); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_copy_sequence(PyObject *__pyx_v_sequence, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_sequence", 0);

  /* "pyteomics/cparser.pyx":979
 *         size_t i, n
 *         SequencePosition position
 *     n = PyList_Size(sequence)             # <<<<<<<<<<<<<<
 *     result = PyList_New(n)
 *     for i in range(n):
 */
  __pyx_t_1 = PyList_Size(__pyx_v_sequence); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 979, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pyteomics/cparser.pyx":980
 *         SequencePosition position
 *     n = PyList_Size(sequence)
 *     result = PyList_New(n)             # <<<<<<<<<<<<<<
 *     for i in range(n):
 *         position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 */
  __pyx_t_2 = PyList_New(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":981
 *     n = PyList_Size(sequence)
 *     result = PyList_New(n)
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *         position = position.copy()
 */
  __pyx_t_3 = __pyx_v_n;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "pyteomics/cparser.pyx":982
 *     result = PyList_New(n)
 *     for i in range(n):
 *         position = <SequencePosition>PyList_GET_ITEM(sequence, i)             # <<<<<<<<<<<<<<
 *         position = position.copy()
 *         Py_INCREF(position)
 */
    __pyx_t_6 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_v_i);
    __pyx_t_2 = ((PyObject *)__pyx_t_6);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":983
 *     for i in range(n):
 *         position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *         position = position.copy()             # <<<<<<<<<<<<<<
 *         Py_INCREF(position)
 *         PyList_SET_ITEM(result, i, position)
 */
    __pyx_t_2 = ((PyObject *)__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(__pyx_v_position)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":984
 *         position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *         position = position.copy()
 *         Py_INCREF(position)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(result, i, position)
 *     return result
 */
    Py_INCREF(((PyObject *)__pyx_v_position));

    /* "pyteomics/cparser.pyx":985
 *         position = position.copy()
 *         Py_INCREF(position)
 *         PyList_SET_ITEM(result, i, position)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    PyList_SET_ITEM(__pyx_v_result, __pyx_v_i, ((PyObject *)__pyx_v_position));
  }

  /* "pyteomics/cparser.pyx":986
 *         Py_INCREF(position)
 *         PyList_SET_ITEM(result, i, position)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":974
 * 
 * 
 * cpdef list copy_sequence(list sequence):             # <<<<<<<<<<<<<<
 *     cdef:
 *         list result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.copy_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_13copy_sequence(PyObject *__pyx_self, PyObject *__pyx_v_sequence); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_12copy_sequence[] = "copy_sequence(list sequence) -> list";
static PyObject *__pyx_pw_9pyteomics_7cparser_13copy_sequence(PyObject *__pyx_self, PyObject *__pyx_v_sequence) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_sequence (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyList_Type), 1, "sequence", 1))) __PYX_ERR(0, 974, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_12copy_sequence(__pyx_self, ((PyObject*)__pyx_v_sequence));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_12copy_sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_sequence", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_copy_sequence(__pyx_v_sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.copy_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1006
 *         public list last_indices
 * 
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,             # <<<<<<<<<<<<<<
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:
 */

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_variable_mods = 0;
  PyObject *__pyx_v_fixed_mods = 0;
  PyObject *__pyx_v_labels = 0;
  PyObject *__pyx_v_max_mods = 0;
  PyObject *__pyx_v_override = 0;
  PyObject *__pyx_v_show_unmodified_termini = 0;
  PyObject *__pyx_v_persist = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_variable_mods,&__pyx_n_s_fixed_mods,&__pyx_n_s_labels,&__pyx_n_s_max_mods,&__pyx_n_s_override,&__pyx_n_s_show_unmodified_termini,&__pyx_n_s_persist,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_False);

    /* "pyteomics/cparser.pyx":1007
 * 
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,
 *                  show_unmodified_termini=False, persist=True):             # <<<<<<<<<<<<<<
 *         if variable_mods is None:
 *             variable_mods = {}
 */
    values[5] = ((PyObject *)Py_False);
    values[6] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_variable_mods);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fixed_mods);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_mods);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_override);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_show_unmodified_termini);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_persist);
          if (value) { values[6] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1006, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_variable_mods = values[0];
    __pyx_v_fixed_mods = values[1];
    __pyx_v_labels = values[2];
    __pyx_v_max_mods = values[3];
    __pyx_v_override = values[4];
    __pyx_v_show_unmodified_termini = values[5];
    __pyx_v_persist = values[6];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 7, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1006, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator___init__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), __pyx_v_variable_mods, __pyx_v_fixed_mods, __pyx_v_labels, __pyx_v_max_mods, __pyx_v_override, __pyx_v_show_unmodified_termini, __pyx_v_persist);

  /* "pyteomics/cparser.pyx":1006
 *         public list last_indices
 * 
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,             # <<<<<<<<<<<<<<
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator___init__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_variable_mods, PyObject *__pyx_v_fixed_mods, PyObject *__pyx_v_labels, PyObject *__pyx_v_max_mods, PyObject *__pyx_v_override, PyObject *__pyx_v_show_unmodified_termini, PyObject *__pyx_v_persist) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_variable_mods);
  __Pyx_INCREF(__pyx_v_fixed_mods);
  __Pyx_INCREF(__pyx_v_labels);
  __Pyx_INCREF(__pyx_v_max_mods);

  /* "pyteomics/cparser.pyx":1008
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:             # <<<<<<<<<<<<<<
 *             variable_mods = {}
 *         if fixed_mods is None:
 */
  __pyx_t_1 = (__pyx_v_variable_mods == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1009
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:
 *             variable_mods = {}             # <<<<<<<<<<<<<<
 *         if fixed_mods is None:
 *             fixed_mods = {}
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_variable_mods, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":1008
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:             # <<<<<<<<<<<<<<
 *             variable_mods = {}
 *         if fixed_mods is None:
 */
  }

  /* "pyteomics/cparser.pyx":1010
 *         if variable_mods is None:
 *             variable_mods = {}
 *         if fixed_mods is None:             # <<<<<<<<<<<<<<
 *             fixed_mods = {}
 *         if labels is None:
 */
  __pyx_t_2 = (__pyx_v_fixed_mods == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":1011
 *             variable_mods = {}
 *         if fixed_mods is None:
 *             fixed_mods = {}             # <<<<<<<<<<<<<<
 *         if labels is None:
 *             labels = list(std_labels)
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_fixed_mods, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":1010
 *         if variable_mods is None:
 *             variable_mods = {}
 *         if fixed_mods is None:             # <<<<<<<<<<<<<<
 *             fixed_mods = {}
 *         if labels is None:
 */
  }

  /* "pyteomics/cparser.pyx":1012
 *         if fixed_mods is None:
 *             fixed_mods = {}
 *         if labels is None:             # <<<<<<<<<<<<<<
 *             labels = list(std_labels)
 *         if max_mods is None:
 */
  __pyx_t_1 = (__pyx_v_labels == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1013
 *             fixed_mods = {}
 *         if labels is None:
 *             labels = list(std_labels)             # <<<<<<<<<<<<<<
 *         if max_mods is None:
 *             max_mods = -1
 */
    __pyx_t_3 = PySequence_List(__pyx_v_9pyteomics_7cparser_std_labels); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1013, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_labels, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":1012
 *         if fixed_mods is None:
 *             fixed_mods = {}
 *         if labels is None:             # <<<<<<<<<<<<<<
 *             labels = list(std_labels)
 *         if max_mods is None:
 */
  }

  /* "pyteomics/cparser.pyx":1014
 *         if labels is None:
 *             labels = list(std_labels)
 *         if max_mods is None:             # <<<<<<<<<<<<<<
 *             max_mods = -1
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)
 */
  __pyx_t_2 = (__pyx_v_max_mods == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":1015
 *             labels = list(std_labels)
 *         if max_mods is None:
 *             max_mods = -1             # <<<<<<<<<<<<<<
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)
 *         self.fixed_mods = self.coerce_modification_dict(fixed_mods)
 */
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_DECREF_SET(__pyx_v_max_mods, __pyx_int_neg_1);

    /* "pyteomics/cparser.pyx":1014
 *         if labels is None:
 *             labels = list(std_labels)
 *         if max_mods is None:             # <<<<<<<<<<<<<<
 *             max_mods = -1
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)
 */
  }

  /* "pyteomics/cparser.pyx":1016
 *         if max_mods is None:
 *             max_mods = -1
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)             # <<<<<<<<<<<<<<
 *         self.fixed_mods = self.coerce_modification_dict(fixed_mods)
 *         self.labels = labels
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_variable_mods))||((__pyx_v_variable_mods) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_variable_mods)->tp_name), 0))) __PYX_ERR(0, 1016, __pyx_L1_error)
  __pyx_t_3 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self->__pyx_vtab)->coerce_modification_dict(__pyx_v_self, ((PyObject*)__pyx_v_variable_mods), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->variable_mods);
  __Pyx_DECREF(__pyx_v_self->variable_mods);
  __pyx_v_self->variable_mods = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1017
 *             max_mods = -1
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)
 *         self.fixed_mods = self.coerce_modification_dict(fixed_mods)             # <<<<<<<<<<<<<<
 *         self.labels = labels
 *         self.max_mods = PyInt_AsLong(max_mods)
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_fixed_mods))||((__pyx_v_fixed_mods) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_fixed_mods)->tp_name), 0))) __PYX_ERR(0, 1017, __pyx_L1_error)
  __pyx_t_3 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self->__pyx_vtab)->coerce_modification_dict(__pyx_v_self, ((PyObject*)__pyx_v_fixed_mods), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->fixed_mods);
  __Pyx_DECREF(__pyx_v_self->fixed_mods);
  __pyx_v_self->fixed_mods = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1018
 *         self.variable_mods = self.coerce_modification_dict(variable_mods)
 *         self.fixed_mods = self.coerce_modification_dict(fixed_mods)
 *         self.labels = labels             # <<<<<<<<<<<<<<
 *         self.max_mods = PyInt_AsLong(max_mods)
 *         self.override = override
 */
  if (!(likely(PyList_CheckExact(__pyx_v_labels))||((__pyx_v_labels) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_labels)->tp_name), 0))) __PYX_ERR(0, 1018, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_labels;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->labels);
  __Pyx_DECREF(__pyx_v_self->labels);
  __pyx_v_self->labels = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1019
 *         self.fixed_mods = self.coerce_modification_dict(fixed_mods)
 *         self.labels = labels
 *         self.max_mods = PyInt_AsLong(max_mods)             # <<<<<<<<<<<<<<
 *         self.override = override
 *         self.show_unmodified_termini = show_unmodified_termini
 */
  __pyx_t_4 = PyInt_AsLong(__pyx_v_max_mods); if (unlikely(__pyx_t_4 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 1019, __pyx_L1_error)
  __pyx_v_self->max_mods = __pyx_t_4;

  /* "pyteomics/cparser.pyx":1020
 *         self.labels = labels
 *         self.max_mods = PyInt_AsLong(max_mods)
 *         self.override = override             # <<<<<<<<<<<<<<
 *         self.show_unmodified_termini = show_unmodified_termini
 *         self.persist = persist
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_override); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1020, __pyx_L1_error)
  __pyx_v_self->override = __pyx_t_1;

  /* "pyteomics/cparser.pyx":1021
 *         self.max_mods = PyInt_AsLong(max_mods)
 *         self.override = override
 *         self.show_unmodified_termini = show_unmodified_termini             # <<<<<<<<<<<<<<
 *         self.persist = persist
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_show_unmodified_termini); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1021, __pyx_L1_error)
  __pyx_v_self->show_unmodified_termini = __pyx_t_1;

  /* "pyteomics/cparser.pyx":1022
 *         self.override = override
 *         self.show_unmodified_termini = show_unmodified_termini
 *         self.persist = persist             # <<<<<<<<<<<<<<
 * 
 *         self.sequence = None
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_persist); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1022, __pyx_L1_error)
  __pyx_v_self->persist = __pyx_t_1;

  /* "pyteomics/cparser.pyx":1024
 *         self.persist = persist
 * 
 *         self.sequence = None             # <<<<<<<<<<<<<<
 *         self.original_sequence = None
 *         self.last_indices = []
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":1025
 * 
 *         self.sequence = None
 *         self.original_sequence = None             # <<<<<<<<<<<<<<
 *         self.last_indices = []
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->original_sequence);
  __Pyx_DECREF(__pyx_v_self->original_sequence);
  __pyx_v_self->original_sequence = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":1026
 *         self.sequence = None
 *         self.original_sequence = None
 *         self.last_indices = []             # <<<<<<<<<<<<<<
 * 
 *     cpdef dict coerce_modification_dict(self, dict source):
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->last_indices);
  __Pyx_DECREF(__pyx_v_self->last_indices);
  __pyx_v_self->last_indices = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1006
 *         public list last_indices
 * 
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,             # <<<<<<<<<<<<<<
 *                  show_unmodified_termini=False, persist=True):
 *         if variable_mods is None:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_variable_mods);
  __Pyx_XDECREF(__pyx_v_fixed_mods);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XDECREF(__pyx_v_max_mods);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1028
 *         self.last_indices = []
 * 
 *     cpdef dict coerce_modification_dict(self, dict source):             # <<<<<<<<<<<<<<
 *         cdef:
 *             str label
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_3coerce_modification_dict(PyObject *__pyx_v_self, PyObject *__pyx_v_source); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_coerce_modification_dict(CYTHON_UNUSED struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_source, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_label = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_rule = 0;
  PyObject *__pyx_v_targets = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coerce_modification_dict", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_coerce_modification_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1028, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_3coerce_modification_dict)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_source) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_source);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1028, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1028, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1034
 *             object targets
 *             dict result
 *         result = {}             # <<<<<<<<<<<<<<
 *         for label, targets in source.items():
 *             rule = ModificationRule(label, list(targets))
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1035
 *             dict result
 *         result = {}
 *         for label, targets in source.items():             # <<<<<<<<<<<<<<
 *             rule = ModificationRule(label, list(targets))
 *             PyDict_SetItem(result, label, rule)
 */
  if (unlikely(__pyx_v_source == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1035, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Items(__pyx_v_source); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1035, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1035, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1035, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1035, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_6(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1035, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1035, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1035, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1035, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    if (!(likely(PyString_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 1035, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_label, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_targets, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyteomics/cparser.pyx":1036
 *         result = {}
 *         for label, targets in source.items():
 *             rule = ModificationRule(label, list(targets))             # <<<<<<<<<<<<<<
 *             PyDict_SetItem(result, label, rule)
 *         return result
 */
    __pyx_t_1 = PySequence_List(__pyx_v_targets); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_label);
    __Pyx_GIVEREF(__pyx_v_label);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_label);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationRule), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_rule, ((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":1037
 *         for label, targets in source.items():
 *             rule = ModificationRule(label, list(targets))
 *             PyDict_SetItem(result, label, rule)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_t_9 = PyDict_SetItem(__pyx_v_result, __pyx_v_label, ((PyObject *)__pyx_v_rule)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1037, __pyx_L1_error)

    /* "pyteomics/cparser.pyx":1035
 *             dict result
 *         result = {}
 *         for label, targets in source.items():             # <<<<<<<<<<<<<<
 *             rule = ModificationRule(label, list(targets))
 *             PyDict_SetItem(result, label, rule)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1038
 *             rule = ModificationRule(label, list(targets))
 *             PyDict_SetItem(result, label, rule)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef list initialize_from_str(self, str sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1028
 *         self.last_indices = []
 * 
 *     cpdef dict coerce_modification_dict(self, dict source):             # <<<<<<<<<<<<<<
 *         cdef:
 *             str label
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.coerce_modification_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_XDECREF((PyObject *)__pyx_v_rule);
  __Pyx_XDECREF(__pyx_v_targets);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_3coerce_modification_dict(PyObject *__pyx_v_self, PyObject *__pyx_v_source); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_2coerce_modification_dict[] = "IsoformGenerator.coerce_modification_dict(self, dict source) -> dict";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_3coerce_modification_dict(PyObject *__pyx_v_self, PyObject *__pyx_v_source) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coerce_modification_dict (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_source), (&PyDict_Type), 1, "source", 1))) __PYX_ERR(0, 1028, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_2coerce_modification_dict(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject*)__pyx_v_source));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_2coerce_modification_dict(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_source) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coerce_modification_dict", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16IsoformGenerator_coerce_modification_dict(__pyx_v_self, __pyx_v_source, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.coerce_modification_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1040
 *         return result
 * 
 *     cpdef list initialize_from_str(self, str sequence):             # <<<<<<<<<<<<<<
 *         labels = self.labels + list(self.fixed_mods)
 *         self.sequence = SequencePosition.parse(sequence, labels=labels)
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_5initialize_from_str(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_str(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize_from_str", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_initialize_from_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_5initialize_from_str)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sequence);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1040, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1041
 * 
 *     cpdef list initialize_from_str(self, str sequence):
 *         labels = self.labels + list(self.fixed_mods)             # <<<<<<<<<<<<<<
 *         self.sequence = SequencePosition.parse(sequence, labels=labels)
 *         return self.sequence
 */
  __pyx_t_1 = PySequence_List(__pyx_v_self->fixed_mods); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_v_self->labels, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_labels = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1042
 *     cpdef list initialize_from_str(self, str sequence):
 *         labels = self.labels + list(self.fixed_mods)
 *         self.sequence = SequencePosition.parse(sequence, labels=labels)             # <<<<<<<<<<<<<<
 *         return self.sequence
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition), __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sequence);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_labels, __pyx_v_labels) < 0) __PYX_ERR(0, 1042, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":1043
 *         labels = self.labels + list(self.fixed_mods)
 *         self.sequence = SequencePosition.parse(sequence, labels=labels)
 *         return self.sequence             # <<<<<<<<<<<<<<
 * 
 *     cpdef list initialize_from_iterable(self, object sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1040
 *         return result
 * 
 *     cpdef list initialize_from_str(self, str sequence):             # <<<<<<<<<<<<<<
 *         labels = self.labels + list(self.fixed_mods)
 *         self.sequence = SequencePosition.parse(sequence, labels=labels)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.initialize_from_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_5initialize_from_str(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_4initialize_from_str[] = "IsoformGenerator.initialize_from_str(self, str sequence) -> list";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_5initialize_from_str(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("initialize_from_str (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyString_Type), 1, "sequence", 1))) __PYX_ERR(0, 1040, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_4initialize_from_str(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject*)__pyx_v_sequence));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_4initialize_from_str(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize_from_str", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_str(__pyx_v_self, __pyx_v_sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.initialize_from_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1045
 *         return self.sequence
 * 
 *     cpdef list initialize_from_iterable(self, object sequence):             # <<<<<<<<<<<<<<
 *         self.sequence = SequencePosition.from_iterable(sequence)
 *         return self.sequence
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7initialize_from_iterable(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_iterable(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize_from_iterable", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_initialize_from_iterable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7initialize_from_iterable)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sequence);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1045, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1045, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1046
 * 
 *     cpdef list initialize_from_iterable(self, object sequence):
 *         self.sequence = SequencePosition.from_iterable(sequence)             # <<<<<<<<<<<<<<
 *         return self.sequence
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition), __pyx_n_s_from_iterable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_sequence);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1047
 *     cpdef list initialize_from_iterable(self, object sequence):
 *         self.sequence = SequencePosition.from_iterable(sequence)
 *         return self.sequence             # <<<<<<<<<<<<<<
 * 
 *     cpdef list apply_fixed_mods(self, list sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1045
 *         return self.sequence
 * 
 *     cpdef list initialize_from_iterable(self, object sequence):             # <<<<<<<<<<<<<<
 *         self.sequence = SequencePosition.from_iterable(sequence)
 *         return self.sequence
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.initialize_from_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7initialize_from_iterable(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_6initialize_from_iterable[] = "IsoformGenerator.initialize_from_iterable(self, sequence) -> list";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7initialize_from_iterable(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("initialize_from_iterable (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6initialize_from_iterable(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_sequence));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6initialize_from_iterable(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize_from_iterable", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_iterable(__pyx_v_self, __pyx_v_sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.initialize_from_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1049
 *         return self.sequence
 * 
 *     cpdef list apply_fixed_mods(self, list sequence):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_9apply_fixed_mods(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_apply_fixed_mods(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch) {
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  Py_ssize_t __pyx_v_j;
  PyObject *__pyx_v_pkey;
  PyObject *__pyx_v_pvalue;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_rule = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  size_t __pyx_t_6;
  size_t __pyx_t_7;
  size_t __pyx_t_8;
  PyObject *__pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_fixed_mods", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_apply_fixed_mods); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_9apply_fixed_mods)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sequence);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1049, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1049, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1058
 *             ModificationRule rule
 * 
 *         n = PyList_Size(sequence)             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 */
  __pyx_t_5 = PyList_Size(__pyx_v_sequence); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1058, __pyx_L1_error)
  __pyx_v_n = __pyx_t_5;

  /* "pyteomics/cparser.pyx":1059
 * 
 *         n = PyList_Size(sequence)
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0
 */
  __pyx_t_6 = __pyx_v_n;
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "pyteomics/cparser.pyx":1060
 *         n = PyList_Size(sequence)
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)             # <<<<<<<<<<<<<<
 *             j = 0
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):
 */
    __pyx_t_9 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_v_i);
    __pyx_t_1 = ((PyObject *)__pyx_t_9);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":1061
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0             # <<<<<<<<<<<<<<
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 */
    __pyx_v_j = 0;

    /* "pyteomics/cparser.pyx":1062
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):             # <<<<<<<<<<<<<<
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 */
    while (1) {
      __pyx_t_1 = __pyx_v_self->fixed_mods;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_10 = (PyDict_Next(__pyx_t_1, (&__pyx_v_j), (&__pyx_v_pkey), (&__pyx_v_pvalue)) != 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!__pyx_t_10) break;

      /* "pyteomics/cparser.pyx":1063
 *             j = 0
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue             # <<<<<<<<<<<<<<
 *                 if rule.test(position):
 *                     if not position.is_modified():
 */
      __pyx_t_1 = ((PyObject *)__pyx_v_pvalue);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_rule, ((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1064
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):             # <<<<<<<<<<<<<<
 *                     if not position.is_modified():
 *                         position.add_modification(rule.modification)
 */
      __pyx_t_10 = (((struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule *)__pyx_v_rule->__pyx_vtab)->test(__pyx_v_rule, __pyx_v_position, 0) != 0);
      if (__pyx_t_10) {

        /* "pyteomics/cparser.pyx":1065
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 *                     if not position.is_modified():             # <<<<<<<<<<<<<<
 *                         position.add_modification(rule.modification)
 *         return sequence
 */
        __pyx_t_10 = ((!(__pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(__pyx_v_position) != 0)) != 0);
        if (__pyx_t_10) {

          /* "pyteomics/cparser.pyx":1066
 *                 if rule.test(position):
 *                     if not position.is_modified():
 *                         position.add_modification(rule.modification)             # <<<<<<<<<<<<<<
 *         return sequence
 * 
 */
          __pyx_t_1 = __pyx_v_rule->modification;
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_2 = __pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification(__pyx_v_position, ((PyObject*)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1066, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "pyteomics/cparser.pyx":1065
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 *                     if not position.is_modified():             # <<<<<<<<<<<<<<
 *                         position.add_modification(rule.modification)
 *         return sequence
 */
        }

        /* "pyteomics/cparser.pyx":1064
 *             while PyDict_Next(self.fixed_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):             # <<<<<<<<<<<<<<
 *                     if not position.is_modified():
 *                         position.add_modification(rule.modification)
 */
      }
    }
  }

  /* "pyteomics/cparser.pyx":1067
 *                     if not position.is_modified():
 *                         position.add_modification(rule.modification)
 *         return sequence             # <<<<<<<<<<<<<<
 * 
 *     cpdef dict build_site_map(self, list sequence, bint include_unmodified=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sequence);
  __pyx_r = __pyx_v_sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1049
 *         return self.sequence
 * 
 *     cpdef list apply_fixed_mods(self, list sequence):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.apply_fixed_mods", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_XDECREF((PyObject *)__pyx_v_rule);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_9apply_fixed_mods(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_8apply_fixed_mods[] = "IsoformGenerator.apply_fixed_mods(self, list sequence) -> list";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_9apply_fixed_mods(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply_fixed_mods (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyList_Type), 1, "sequence", 1))) __PYX_ERR(0, 1049, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8apply_fixed_mods(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject*)__pyx_v_sequence));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8apply_fixed_mods(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_fixed_mods", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser_16IsoformGenerator_apply_fixed_mods(__pyx_v_self, __pyx_v_sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.apply_fixed_mods", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1069
 *         return sequence
 * 
 *     cpdef dict build_site_map(self, list sequence, bint include_unmodified=True):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_11build_site_map(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_9pyteomics_7cparser_16IsoformGenerator_build_site_map(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map *__pyx_optional_args) {
  int __pyx_v_include_unmodified = ((int)1);
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  Py_ssize_t __pyx_v_j;
  PyObject *__pyx_v_pkey;
  PyObject *__pyx_v_pvalue;
  PyObject *__pyx_v_psites;
  PyObject *__pyx_v_sites = 0;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_rule = 0;
  PyObject *__pyx_v_site_map = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  size_t __pyx_t_9;
  size_t __pyx_t_10;
  size_t __pyx_t_11;
  PyObject *__pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  long __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build_site_map", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_include_unmodified = __pyx_optional_args->include_unmodified;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_build_site_map); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1069, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_11build_site_map)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_include_unmodified); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1069, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sequence, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sequence, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_sequence);
          __Pyx_GIVEREF(__pyx_v_sequence);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_sequence);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1069, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1081
 *             dict site_map
 * 
 *         site_map = dict()             # <<<<<<<<<<<<<<
 *         n = PyList_Size(sequence)
 *         for i in range(n):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_site_map = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1082
 * 
 *         site_map = dict()
 *         n = PyList_Size(sequence)             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 */
  __pyx_t_8 = PyList_Size(__pyx_v_sequence); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1082, __pyx_L1_error)
  __pyx_v_n = __pyx_t_8;

  /* "pyteomics/cparser.pyx":1083
 *         site_map = dict()
 *         n = PyList_Size(sequence)
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0
 */
  __pyx_t_9 = __pyx_v_n;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "pyteomics/cparser.pyx":1084
 *         n = PyList_Size(sequence)
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)             # <<<<<<<<<<<<<<
 *             j = 0
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):
 */
    __pyx_t_12 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_v_i);
    __pyx_t_1 = ((PyObject *)__pyx_t_12);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":1085
 *         for i in range(n):
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0             # <<<<<<<<<<<<<<
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 */
    __pyx_v_j = 0;

    /* "pyteomics/cparser.pyx":1086
 *             position = <SequencePosition>PyList_GET_ITEM(sequence, i)
 *             j = 0
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):             # <<<<<<<<<<<<<<
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 */
    while (1) {
      __pyx_t_1 = __pyx_v_self->variable_mods;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_13 = (PyDict_Next(__pyx_t_1, (&__pyx_v_j), (&__pyx_v_pkey), (&__pyx_v_pvalue)) != 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!__pyx_t_13) break;

      /* "pyteomics/cparser.pyx":1087
 *             j = 0
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue             # <<<<<<<<<<<<<<
 *                 if rule.test(position):
 *                     if not position.is_modified():
 */
      __pyx_t_1 = ((PyObject *)__pyx_v_pvalue);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_rule, ((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1088
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):             # <<<<<<<<<<<<<<
 *                     if not position.is_modified():
 *                         psites = PyDict_GetItem(site_map, i)
 */
      __pyx_t_13 = (((struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule *)__pyx_v_rule->__pyx_vtab)->test(__pyx_v_rule, __pyx_v_position, 0) != 0);
      if (__pyx_t_13) {

        /* "pyteomics/cparser.pyx":1089
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 *                     if not position.is_modified():             # <<<<<<<<<<<<<<
 *                         psites = PyDict_GetItem(site_map, i)
 *                         if psites == NULL:
 */
        __pyx_t_13 = ((!(__pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified(__pyx_v_position) != 0)) != 0);
        if (__pyx_t_13) {

          /* "pyteomics/cparser.pyx":1090
 *                 if rule.test(position):
 *                     if not position.is_modified():
 *                         psites = PyDict_GetItem(site_map, i)             # <<<<<<<<<<<<<<
 *                         if psites == NULL:
 *                             sites = []
 */
          __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1090, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_v_psites = PyDict_GetItem(__pyx_v_site_map, __pyx_t_1);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":1091
 *                     if not position.is_modified():
 *                         psites = PyDict_GetItem(site_map, i)
 *                         if psites == NULL:             # <<<<<<<<<<<<<<
 *                             sites = []
 *                             PyDict_SetItem(site_map, i, sites)
 */
          __pyx_t_13 = ((__pyx_v_psites == NULL) != 0);
          if (__pyx_t_13) {

            /* "pyteomics/cparser.pyx":1092
 *                         psites = PyDict_GetItem(site_map, i)
 *                         if psites == NULL:
 *                             sites = []             # <<<<<<<<<<<<<<
 *                             PyDict_SetItem(site_map, i, sites)
 *                         else:
 */
            __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1092, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_XDECREF_SET(__pyx_v_sites, ((PyObject*)__pyx_t_1));
            __pyx_t_1 = 0;

            /* "pyteomics/cparser.pyx":1093
 *                         if psites == NULL:
 *                             sites = []
 *                             PyDict_SetItem(site_map, i, sites)             # <<<<<<<<<<<<<<
 *                         else:
 *                             sites = <list>psites
 */
            __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = PyDict_SetItem(__pyx_v_site_map, __pyx_t_1, __pyx_v_sites); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1093, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "pyteomics/cparser.pyx":1091
 *                     if not position.is_modified():
 *                         psites = PyDict_GetItem(site_map, i)
 *                         if psites == NULL:             # <<<<<<<<<<<<<<
 *                             sites = []
 *                             PyDict_SetItem(site_map, i, sites)
 */
            goto __pyx_L9;
          }

          /* "pyteomics/cparser.pyx":1095
 *                             PyDict_SetItem(site_map, i, sites)
 *                         else:
 *                             sites = <list>psites             # <<<<<<<<<<<<<<
 *                         position = position.copy()
 *                         position.modification = rule.modification
 */
          /*else*/ {
            __pyx_t_1 = ((PyObject *)__pyx_v_psites);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_XDECREF_SET(__pyx_v_sites, ((PyObject*)__pyx_t_1));
            __pyx_t_1 = 0;
          }
          __pyx_L9:;

          /* "pyteomics/cparser.pyx":1096
 *                         else:
 *                             sites = <list>psites
 *                         position = position.copy()             # <<<<<<<<<<<<<<
 *                         position.modification = rule.modification
 *                         sites.append(position)
 */
          __pyx_t_1 = ((PyObject *)__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(__pyx_v_position)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1096, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":1097
 *                             sites = <list>psites
 *                         position = position.copy()
 *                         position.modification = rule.modification             # <<<<<<<<<<<<<<
 *                         sites.append(position)
 *         if include_unmodified:
 */
          __pyx_t_1 = __pyx_v_rule->modification;
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_v_position->modification);
          __Pyx_DECREF(__pyx_v_position->modification);
          __pyx_v_position->modification = ((PyObject*)__pyx_t_1);
          __pyx_t_1 = 0;

          /* "pyteomics/cparser.pyx":1098
 *                         position = position.copy()
 *                         position.modification = rule.modification
 *                         sites.append(position)             # <<<<<<<<<<<<<<
 *         if include_unmodified:
 *             j = 0
 */
          if (unlikely(__pyx_v_sites == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 1098, __pyx_L1_error)
          }
          __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_sites, ((PyObject *)__pyx_v_position)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 1098, __pyx_L1_error)

          /* "pyteomics/cparser.pyx":1089
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):
 *                     if not position.is_modified():             # <<<<<<<<<<<<<<
 *                         psites = PyDict_GetItem(site_map, i)
 *                         if psites == NULL:
 */
        }

        /* "pyteomics/cparser.pyx":1088
 *             while PyDict_Next(self.variable_mods, &j, &pkey, &pvalue):
 *                 rule = <ModificationRule>pvalue
 *                 if rule.test(position):             # <<<<<<<<<<<<<<
 *                     if not position.is_modified():
 *                         psites = PyDict_GetItem(site_map, i)
 */
      }
    }
  }

  /* "pyteomics/cparser.pyx":1099
 *                         position.modification = rule.modification
 *                         sites.append(position)
 *         if include_unmodified:             # <<<<<<<<<<<<<<
 *             j = 0
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):
 */
  __pyx_t_13 = (__pyx_v_include_unmodified != 0);
  if (__pyx_t_13) {

    /* "pyteomics/cparser.pyx":1100
 *                         sites.append(position)
 *         if include_unmodified:
 *             j = 0             # <<<<<<<<<<<<<<
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):
 *                 position = <SequencePosition>PyList_GET_ITEM(sequence, PyInt_AsLong(<object>pkey))
 */
    __pyx_v_j = 0;

    /* "pyteomics/cparser.pyx":1101
 *         if include_unmodified:
 *             j = 0
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):             # <<<<<<<<<<<<<<
 *                 position = <SequencePosition>PyList_GET_ITEM(sequence, PyInt_AsLong(<object>pkey))
 *                 position = position.copy()
 */
    while (1) {
      __pyx_t_13 = (PyDict_Next(__pyx_v_site_map, (&__pyx_v_j), (&__pyx_v_pkey), (&__pyx_v_pvalue)) != 0);
      if (!__pyx_t_13) break;

      /* "pyteomics/cparser.pyx":1102
 *             j = 0
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):
 *                 position = <SequencePosition>PyList_GET_ITEM(sequence, PyInt_AsLong(<object>pkey))             # <<<<<<<<<<<<<<
 *                 position = position.copy()
 *                 (<list>pvalue).append(position)
 */
      __pyx_t_15 = PyInt_AsLong(((PyObject *)__pyx_v_pkey)); if (unlikely(__pyx_t_15 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 1102, __pyx_L1_error)
      __pyx_t_12 = PyList_GET_ITEM(__pyx_v_sequence, __pyx_t_15);
      __pyx_t_1 = ((PyObject *)__pyx_t_12);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1103
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):
 *                 position = <SequencePosition>PyList_GET_ITEM(sequence, PyInt_AsLong(<object>pkey))
 *                 position = position.copy()             # <<<<<<<<<<<<<<
 *                 (<list>pvalue).append(position)
 *         return site_map
 */
      __pyx_t_1 = ((PyObject *)__pyx_f_9pyteomics_7cparser_16SequencePosition_copy(__pyx_v_position)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1103, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1104
 *                 position = <SequencePosition>PyList_GET_ITEM(sequence, PyInt_AsLong(<object>pkey))
 *                 position = position.copy()
 *                 (<list>pvalue).append(position)             # <<<<<<<<<<<<<<
 *         return site_map
 * 
 */
      if (unlikely(((PyObject *)__pyx_v_pvalue) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 1104, __pyx_L1_error)
      }
      __pyx_t_14 = __Pyx_PyList_Append(((PyObject*)__pyx_v_pvalue), ((PyObject *)__pyx_v_position)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 1104, __pyx_L1_error)
    }

    /* "pyteomics/cparser.pyx":1099
 *                         position.modification = rule.modification
 *                         sites.append(position)
 *         if include_unmodified:             # <<<<<<<<<<<<<<
 *             j = 0
 *             while PyDict_Next(site_map, &j, &pkey, &pvalue):
 */
  }

  /* "pyteomics/cparser.pyx":1105
 *                 position = position.copy()
 *                 (<list>pvalue).append(position)
 *         return site_map             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_site_map);
  __pyx_r = __pyx_v_site_map;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1069
 *         return sequence
 * 
 *     cpdef dict build_site_map(self, list sequence, bint include_unmodified=True):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.build_site_map", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sites);
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_XDECREF((PyObject *)__pyx_v_rule);
  __Pyx_XDECREF(__pyx_v_site_map);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_11build_site_map(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_10build_site_map[] = "IsoformGenerator.build_site_map(self, list sequence, bool include_unmodified=True) -> dict";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_11build_site_map(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_v_include_unmodified;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("build_site_map (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_include_unmodified,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_include_unmodified);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "build_site_map") < 0)) __PYX_ERR(0, 1069, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_include_unmodified = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_include_unmodified == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1069, __pyx_L3_error)
    } else {
      __pyx_v_include_unmodified = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("build_site_map", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1069, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.build_site_map", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyList_Type), 1, "sequence", 1))) __PYX_ERR(0, 1069, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10build_site_map(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), __pyx_v_sequence, __pyx_v_include_unmodified);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10build_site_map(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, int __pyx_v_include_unmodified) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build_site_map", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.include_unmodified = __pyx_v_include_unmodified;
  __pyx_t_1 = __pyx_vtabptr_9pyteomics_7cparser_IsoformGenerator->build_site_map(__pyx_v_self, __pyx_v_sequence, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.build_site_map", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9pyteomics_7cparser_16IsoformGenerator_14generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pyteomics/cparser.pyx":1108
 * 
 *     @cython.boundscheck(False)
 *     def generate(self, sequence_spec):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list sequence
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13generate(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence_spec); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_12generate[] = "IsoformGenerator.generate(self, sequence_spec)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13generate(PyObject *__pyx_v_self, PyObject *__pyx_v_sequence_spec) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("generate (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12generate(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_sequence_spec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12generate(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence_spec) {
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("generate", 0);
  __pyx_cur_scope = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct__generate(__pyx_ptype_9pyteomics_7cparser___pyx_scope_struct__generate, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1108, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sequence_spec = __pyx_v_sequence_spec;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sequence_spec);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sequence_spec);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9pyteomics_7cparser_16IsoformGenerator_14generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_generate, __pyx_n_s_IsoformGenerator_generate, __pyx_n_s_pyteomics_cparser); if (unlikely(!gen)) __PYX_ERR(0, 1108, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.generate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9pyteomics_7cparser_16IsoformGenerator_14generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *__pyx_cur_scope = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  size_t __pyx_t_8;
  size_t __pyx_t_9;
  PyObject *__pyx_t_10;
  long __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  long __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  Py_ssize_t __pyx_t_17;
  size_t __pyx_t_18;
  long __pyx_t_19;
  PyObject *(*__pyx_t_20)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("generate", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L13_resume_from_yield;
    case 2: goto __pyx_L22_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1108, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1120
 *             long* pindices
 * 
 *         if isinstance(sequence_spec, str):             # <<<<<<<<<<<<<<
 *             self.initialize_from_str(sequence_spec)
 *         else:
 */
  __pyx_t_1 = PyString_Check(__pyx_cur_scope->__pyx_v_sequence_spec); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1121
 * 
 *         if isinstance(sequence_spec, str):
 *             self.initialize_from_str(sequence_spec)             # <<<<<<<<<<<<<<
 *         else:
 *             self.initialize_from_iterable(sequence_spec)
 */
    if (!(likely(PyString_CheckExact(__pyx_cur_scope->__pyx_v_sequence_spec))||((__pyx_cur_scope->__pyx_v_sequence_spec) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_cur_scope->__pyx_v_sequence_spec)->tp_name), 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
    __pyx_t_3 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->initialize_from_str(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_cur_scope->__pyx_v_sequence_spec), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":1120
 *             long* pindices
 * 
 *         if isinstance(sequence_spec, str):             # <<<<<<<<<<<<<<
 *             self.initialize_from_str(sequence_spec)
 *         else:
 */
    goto __pyx_L4;
  }

  /* "pyteomics/cparser.pyx":1123
 *             self.initialize_from_str(sequence_spec)
 *         else:
 *             self.initialize_from_iterable(sequence_spec)             # <<<<<<<<<<<<<<
 * 
 *         self.apply_fixed_mods(self.sequence)
 */
  /*else*/ {
    __pyx_t_3 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->initialize_from_iterable(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sequence_spec, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "pyteomics/cparser.pyx":1125
 *             self.initialize_from_iterable(sequence_spec)
 * 
 *         self.apply_fixed_mods(self.sequence)             # <<<<<<<<<<<<<<
 *         variable_mod_sites = self.build_site_map(self.sequence)
 *         indices = PyDict_Keys(variable_mod_sites)
 */
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_self->sequence;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->apply_fixed_mods(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_3), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyteomics/cparser.pyx":1126
 * 
 *         self.apply_fixed_mods(self.sequence)
 *         variable_mod_sites = self.build_site_map(self.sequence)             # <<<<<<<<<<<<<<
 *         indices = PyDict_Keys(variable_mod_sites)
 *         assignments = PyDict_Values(variable_mod_sites)
 */
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_self->sequence;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->build_site_map(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_4), 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_variable_mod_sites = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1127
 *         self.apply_fixed_mods(self.sequence)
 *         variable_mod_sites = self.build_site_map(self.sequence)
 *         indices = PyDict_Keys(variable_mod_sites)             # <<<<<<<<<<<<<<
 *         assignments = PyDict_Values(variable_mod_sites)
 *         k = PyList_Size(indices)
 */
  __pyx_t_3 = PyDict_Keys(__pyx_cur_scope->__pyx_v_variable_mod_sites); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_indices = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1128
 *         variable_mod_sites = self.build_site_map(self.sequence)
 *         indices = PyDict_Keys(variable_mod_sites)
 *         assignments = PyDict_Values(variable_mod_sites)             # <<<<<<<<<<<<<<
 *         k = PyList_Size(indices)
 * 
 */
  __pyx_t_3 = PyDict_Values(__pyx_cur_scope->__pyx_v_variable_mod_sites); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_assignments = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1129
 *         indices = PyDict_Keys(variable_mod_sites)
 *         assignments = PyDict_Values(variable_mod_sites)
 *         k = PyList_Size(indices)             # <<<<<<<<<<<<<<
 * 
 *         if self.persist:
 */
  __pyx_t_5 = PyList_Size(__pyx_cur_scope->__pyx_v_indices); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1129, __pyx_L1_error)
  __pyx_cur_scope->__pyx_v_k = __pyx_t_5;

  /* "pyteomics/cparser.pyx":1131
 *         k = PyList_Size(indices)
 * 
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             self.original_sequence = list(self.sequence)
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->persist != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1132
 * 
 *         if self.persist:
 *             self.original_sequence = list(self.sequence)             # <<<<<<<<<<<<<<
 * 
 *         if self.max_mods < 0 or self.max_mods > k:
 */
    __pyx_t_3 = PySequence_List(__pyx_cur_scope->__pyx_v_self->sequence); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->original_sequence);
    __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->original_sequence);
    __pyx_cur_scope->__pyx_v_self->original_sequence = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyteomics/cparser.pyx":1131
 *         k = PyList_Size(indices)
 * 
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             self.original_sequence = list(self.sequence)
 * 
 */
  }

  /* "pyteomics/cparser.pyx":1134
 *             self.original_sequence = list(self.sequence)
 * 
 *         if self.max_mods < 0 or self.max_mods > k:             # <<<<<<<<<<<<<<
 *             self.last_indices = indices
 *             assignments_product = it.product(*assignments)
 */
  __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_self->max_mods < 0) != 0);
  if (!__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_self->max_mods > __pyx_cur_scope->__pyx_v_k) != 0);
  __pyx_t_2 = __pyx_t_1;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1135
 * 
 *         if self.max_mods < 0 or self.max_mods > k:
 *             self.last_indices = indices             # <<<<<<<<<<<<<<
 *             assignments_product = it.product(*assignments)
 *             pindices = <long*>malloc(sizeof(long) * k)
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_indices);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_indices);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->last_indices);
    __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->last_indices);
    __pyx_cur_scope->__pyx_v_self->last_indices = __pyx_cur_scope->__pyx_v_indices;

    /* "pyteomics/cparser.pyx":1136
 *         if self.max_mods < 0 or self.max_mods > k:
 *             self.last_indices = indices
 *             assignments_product = it.product(*assignments)             # <<<<<<<<<<<<<<
 *             pindices = <long*>malloc(sizeof(long) * k)
 *             for i in range(k):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_it); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_product); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySequence_Tuple(__pyx_cur_scope->__pyx_v_assignments); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_assignments_product = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "pyteomics/cparser.pyx":1137
 *             self.last_indices = indices
 *             assignments_product = it.product(*assignments)
 *             pindices = <long*>malloc(sizeof(long) * k)             # <<<<<<<<<<<<<<
 *             for i in range(k):
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))
 */
    __pyx_cur_scope->__pyx_v_pindices = ((long *)malloc(((sizeof(long)) * __pyx_cur_scope->__pyx_v_k)));

    /* "pyteomics/cparser.pyx":1138
 *             assignments_product = it.product(*assignments)
 *             pindices = <long*>malloc(sizeof(long) * k)
 *             for i in range(k):             # <<<<<<<<<<<<<<
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))
 *             for a in assignments_product:
 */
    __pyx_t_7 = __pyx_cur_scope->__pyx_v_k;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_cur_scope->__pyx_v_i = __pyx_t_9;

      /* "pyteomics/cparser.pyx":1139
 *             pindices = <long*>malloc(sizeof(long) * k)
 *             for i in range(k):
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))             # <<<<<<<<<<<<<<
 *             for a in assignments_product:
 *                 assignment = <tuple>a
 */
      __pyx_t_10 = PyList_GET_ITEM(__pyx_cur_scope->__pyx_v_indices, __pyx_cur_scope->__pyx_v_i);
      __pyx_t_11 = PyInt_AsLong(((PyObject *)__pyx_t_10)); if (unlikely(__pyx_t_11 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 1139, __pyx_L1_error)
      (__pyx_cur_scope->__pyx_v_pindices[__pyx_cur_scope->__pyx_v_i]) = __pyx_t_11;
    }

    /* "pyteomics/cparser.pyx":1140
 *             for i in range(k):
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))
 *             for a in assignments_product:             # <<<<<<<<<<<<<<
 *                 assignment = <tuple>a
 *                 yield self._apply_variable_assignment(self.sequence, pindices, assignment, k)
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_assignments_product)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_assignments_product)) {
      __pyx_t_6 = __pyx_cur_scope->__pyx_v_assignments_product; __Pyx_INCREF(__pyx_t_6); __pyx_t_5 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_assignments_product); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_12 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1140, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_6))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_6)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1140, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1140, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1140, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1140, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_12(__pyx_t_6);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1140, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_a);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_a, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":1141
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))
 *             for a in assignments_product:
 *                 assignment = <tuple>a             # <<<<<<<<<<<<<<
 *                 yield self._apply_variable_assignment(self.sequence, pindices, assignment, k)
 *             free(pindices)
 */
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_a;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_assignment);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_assignment, ((PyObject*)__pyx_t_3));
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":1142
 *             for a in assignments_product:
 *                 assignment = <tuple>a
 *                 yield self._apply_variable_assignment(self.sequence, pindices, assignment, k)             # <<<<<<<<<<<<<<
 *             free(pindices)
 *         else:
 */
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_self->sequence;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->__pyx_fuse_0_apply_variable_assignment(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_3), __pyx_cur_scope->__pyx_v_pindices, __pyx_cur_scope->__pyx_v_assignment, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
      __Pyx_XGIVEREF(__pyx_t_6);
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_6;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_12;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L13_resume_from_yield:;
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
      __pyx_t_6 = __pyx_cur_scope->__pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = 0;
      __Pyx_XGOTREF(__pyx_t_6);
      __pyx_t_12 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1142, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":1140
 *             for i in range(k):
 *                 pindices[i] = PyInt_AsLong(<object>PyList_GET_ITEM(indices, i))
 *             for a in assignments_product:             # <<<<<<<<<<<<<<
 *                 assignment = <tuple>a
 *                 yield self._apply_variable_assignment(self.sequence, pindices, assignment, k)
 */
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "pyteomics/cparser.pyx":1143
 *                 assignment = <tuple>a
 *                 yield self._apply_variable_assignment(self.sequence, pindices, assignment, k)
 *             free(pindices)             # <<<<<<<<<<<<<<
 *         else:
 *             self._reset_sequence()
 */
    free(__pyx_cur_scope->__pyx_v_pindices);

    /* "pyteomics/cparser.pyx":1134
 *             self.original_sequence = list(self.sequence)
 * 
 *         if self.max_mods < 0 or self.max_mods > k:             # <<<<<<<<<<<<<<
 *             self.last_indices = indices
 *             assignments_product = it.product(*assignments)
 */
    goto __pyx_L6;
  }

  /* "pyteomics/cparser.pyx":1145
 *             free(pindices)
 *         else:
 *             self._reset_sequence()             # <<<<<<<<<<<<<<
 *             for n_mods in range(0, self.max_mods):
 *                 for subindices in it.combinations(indices, n_mods):
 */
  /*else*/ {
    ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_reset_sequence(__pyx_cur_scope->__pyx_v_self);

    /* "pyteomics/cparser.pyx":1146
 *         else:
 *             self._reset_sequence()
 *             for n_mods in range(0, self.max_mods):             # <<<<<<<<<<<<<<
 *                 for subindices in it.combinations(indices, n_mods):
 *                     self._reset_sequence()
 */
    __pyx_t_11 = __pyx_cur_scope->__pyx_v_self->max_mods;
    __pyx_t_13 = __pyx_t_11;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_13; __pyx_t_7+=1) {
      __pyx_cur_scope->__pyx_v_n_mods = __pyx_t_7;

      /* "pyteomics/cparser.pyx":1147
 *             self._reset_sequence()
 *             for n_mods in range(0, self.max_mods):
 *                 for subindices in it.combinations(indices, n_mods):             # <<<<<<<<<<<<<<
 *                     self._reset_sequence()
 *                     self.last_indices = list(subindices)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_it); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_combinations); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_cur_scope->__pyx_v_n_mods); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = NULL;
      __pyx_t_15 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_15 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_cur_scope->__pyx_v_indices, __pyx_t_4};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_cur_scope->__pyx_v_indices, __pyx_t_4};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_16 = PyTuple_New(2+__pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        if (__pyx_t_14) {
          __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_14); __pyx_t_14 = NULL;
        }
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_indices);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_indices);
        PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_15, __pyx_cur_scope->__pyx_v_indices);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_15, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
        __pyx_t_3 = __pyx_t_6; __Pyx_INCREF(__pyx_t_3); __pyx_t_5 = 0;
        __pyx_t_12 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_12 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1147, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      for (;;) {
        if (likely(!__pyx_t_12)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_6); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1147, __pyx_L1_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1147, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_6); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1147, __pyx_L1_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1147, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_12(__pyx_t_3);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1147, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        if (!(likely(PyTuple_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_t_6)->tp_name), 0))) __PYX_ERR(0, 1147, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_subindices);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_subindices, ((PyObject*)__pyx_t_6));
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":1148
 *             for n_mods in range(0, self.max_mods):
 *                 for subindices in it.combinations(indices, n_mods):
 *                     self._reset_sequence()             # <<<<<<<<<<<<<<
 *                     self.last_indices = list(subindices)
 *                     k = PyTuple_Size(subindices)
 */
        ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_reset_sequence(__pyx_cur_scope->__pyx_v_self);

        /* "pyteomics/cparser.pyx":1149
 *                 for subindices in it.combinations(indices, n_mods):
 *                     self._reset_sequence()
 *                     self.last_indices = list(subindices)             # <<<<<<<<<<<<<<
 *                     k = PyTuple_Size(subindices)
 *                     pindices = <long*>malloc(sizeof(long) * k)
 */
        __pyx_t_6 = PySequence_List(__pyx_cur_scope->__pyx_v_subindices); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1149, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->last_indices);
        __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->last_indices);
        __pyx_cur_scope->__pyx_v_self->last_indices = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":1150
 *                     self._reset_sequence()
 *                     self.last_indices = list(subindices)
 *                     k = PyTuple_Size(subindices)             # <<<<<<<<<<<<<<
 *                     pindices = <long*>malloc(sizeof(long) * k)
 *                     subassignments = PyTuple_New(k)
 */
        __pyx_t_17 = PyTuple_Size(__pyx_cur_scope->__pyx_v_subindices); if (unlikely(__pyx_t_17 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1150, __pyx_L1_error)
        __pyx_cur_scope->__pyx_v_k = __pyx_t_17;

        /* "pyteomics/cparser.pyx":1151
 *                     self.last_indices = list(subindices)
 *                     k = PyTuple_Size(subindices)
 *                     pindices = <long*>malloc(sizeof(long) * k)             # <<<<<<<<<<<<<<
 *                     subassignments = PyTuple_New(k)
 *                     for i in range(k):
 */
        __pyx_cur_scope->__pyx_v_pindices = ((long *)malloc(((sizeof(long)) * __pyx_cur_scope->__pyx_v_k)));

        /* "pyteomics/cparser.pyx":1152
 *                     k = PyTuple_Size(subindices)
 *                     pindices = <long*>malloc(sizeof(long) * k)
 *                     subassignments = PyTuple_New(k)             # <<<<<<<<<<<<<<
 *                     for i in range(k):
 *                         temp1 = <object>PyTuple_GET_ITEM(subindices, i)
 */
        __pyx_t_6 = PyTuple_New(__pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1152, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_subassignments);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_subassignments, ((PyObject*)__pyx_t_6));
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":1153
 *                     pindices = <long*>malloc(sizeof(long) * k)
 *                     subassignments = PyTuple_New(k)
 *                     for i in range(k):             # <<<<<<<<<<<<<<
 *                         temp1 = <object>PyTuple_GET_ITEM(subindices, i)
 *                         pindices[i] = PyInt_AsLong(temp1)
 */
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_k;
        __pyx_t_9 = __pyx_t_8;
        for (__pyx_t_18 = 0; __pyx_t_18 < __pyx_t_9; __pyx_t_18+=1) {
          __pyx_cur_scope->__pyx_v_i = __pyx_t_18;

          /* "pyteomics/cparser.pyx":1154
 *                     subassignments = PyTuple_New(k)
 *                     for i in range(k):
 *                         temp1 = <object>PyTuple_GET_ITEM(subindices, i)             # <<<<<<<<<<<<<<
 *                         pindices[i] = PyInt_AsLong(temp1)
 *                         temp2 = <object>PyDict_GetItem(variable_mod_sites, temp1)
 */
          __pyx_t_10 = PyTuple_GET_ITEM(__pyx_cur_scope->__pyx_v_subindices, __pyx_cur_scope->__pyx_v_i);
          __pyx_t_6 = ((PyObject *)__pyx_t_10);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_temp1);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_temp1, __pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          __pyx_t_6 = 0;

          /* "pyteomics/cparser.pyx":1155
 *                     for i in range(k):
 *                         temp1 = <object>PyTuple_GET_ITEM(subindices, i)
 *                         pindices[i] = PyInt_AsLong(temp1)             # <<<<<<<<<<<<<<
 *                         temp2 = <object>PyDict_GetItem(variable_mod_sites, temp1)
 *                         Py_INCREF(temp2)
 */
          __pyx_t_19 = PyInt_AsLong(__pyx_cur_scope->__pyx_v_temp1); if (unlikely(__pyx_t_19 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 1155, __pyx_L1_error)
          (__pyx_cur_scope->__pyx_v_pindices[__pyx_cur_scope->__pyx_v_i]) = __pyx_t_19;

          /* "pyteomics/cparser.pyx":1156
 *                         temp1 = <object>PyTuple_GET_ITEM(subindices, i)
 *                         pindices[i] = PyInt_AsLong(temp1)
 *                         temp2 = <object>PyDict_GetItem(variable_mod_sites, temp1)             # <<<<<<<<<<<<<<
 *                         Py_INCREF(temp2)
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)
 */
          __pyx_t_10 = PyDict_GetItem(__pyx_cur_scope->__pyx_v_variable_mod_sites, __pyx_cur_scope->__pyx_v_temp1);
          __pyx_t_6 = ((PyObject *)__pyx_t_10);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_temp2);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_temp2, __pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          __pyx_t_6 = 0;

          /* "pyteomics/cparser.pyx":1157
 *                         pindices[i] = PyInt_AsLong(temp1)
 *                         temp2 = <object>PyDict_GetItem(variable_mod_sites, temp1)
 *                         Py_INCREF(temp2)             # <<<<<<<<<<<<<<
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)
 *                     assignments_product = it.product(*subassignments)
 */
          Py_INCREF(__pyx_cur_scope->__pyx_v_temp2);

          /* "pyteomics/cparser.pyx":1158
 *                         temp2 = <object>PyDict_GetItem(variable_mod_sites, temp1)
 *                         Py_INCREF(temp2)
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)             # <<<<<<<<<<<<<<
 *                     assignments_product = it.product(*subassignments)
 *                     for a in assignments_product:
 */
          PyTuple_SET_ITEM(__pyx_cur_scope->__pyx_v_subassignments, __pyx_cur_scope->__pyx_v_i, __pyx_cur_scope->__pyx_v_temp2);
        }

        /* "pyteomics/cparser.pyx":1159
 *                         Py_INCREF(temp2)
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)
 *                     assignments_product = it.product(*subassignments)             # <<<<<<<<<<<<<<
 *                     for a in assignments_product:
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_it); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_product); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(__pyx_cur_scope->__pyx_v_subassignments == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 1159, __pyx_L1_error)
        }
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_cur_scope->__pyx_v_subassignments, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_assignments_product);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_assignments_product, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":1160
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)
 *                     assignments_product = it.product(*subassignments)
 *                     for a in assignments_product:             # <<<<<<<<<<<<<<
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)
 *                     free(pindices)
 */
        if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_assignments_product)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_assignments_product)) {
          __pyx_t_6 = __pyx_cur_scope->__pyx_v_assignments_product; __Pyx_INCREF(__pyx_t_6); __pyx_t_17 = 0;
          __pyx_t_20 = NULL;
        } else {
          __pyx_t_17 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_assignments_product); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1160, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_20 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1160, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_20)) {
            if (likely(PyList_CheckExact(__pyx_t_6))) {
              if (__pyx_t_17 >= PyList_GET_SIZE(__pyx_t_6)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_16 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_17); __Pyx_INCREF(__pyx_t_16); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 1160, __pyx_L1_error)
              #else
              __pyx_t_16 = PySequence_ITEM(__pyx_t_6, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1160, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_16);
              #endif
            } else {
              if (__pyx_t_17 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_16 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_17); __Pyx_INCREF(__pyx_t_16); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 1160, __pyx_L1_error)
              #else
              __pyx_t_16 = PySequence_ITEM(__pyx_t_6, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1160, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_16);
              #endif
            }
          } else {
            __pyx_t_16 = __pyx_t_20(__pyx_t_6);
            if (unlikely(!__pyx_t_16)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1160, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_16);
          }
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_a);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_a, __pyx_t_16);
          __Pyx_GIVEREF(__pyx_t_16);
          __pyx_t_16 = 0;

          /* "pyteomics/cparser.pyx":1161
 *                     assignments_product = it.product(*subassignments)
 *                     for a in assignments_product:
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)             # <<<<<<<<<<<<<<
 *                     free(pindices)
 *         self.sequence = None
 */
          __pyx_t_16 = __pyx_cur_scope->__pyx_v_self->sequence;
          __Pyx_INCREF(__pyx_t_16);
          __pyx_t_4 = ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->__pyx_fuse_0_apply_variable_assignment(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_16), __pyx_cur_scope->__pyx_v_pindices, ((PyObject*)__pyx_cur_scope->__pyx_v_a), __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1161, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          __Pyx_XGIVEREF(__pyx_t_3);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
          __Pyx_XGIVEREF(__pyx_t_6);
          __pyx_cur_scope->__pyx_t_3 = __pyx_t_6;
          __pyx_cur_scope->__pyx_t_4 = __pyx_t_7;
          __pyx_cur_scope->__pyx_t_5 = __pyx_t_11;
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_12;
          __pyx_cur_scope->__pyx_t_6 = __pyx_t_13;
          __pyx_cur_scope->__pyx_t_7 = __pyx_t_17;
          __pyx_cur_scope->__pyx_t_8 = __pyx_t_20;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, yielding value */
          __pyx_generator->resume_label = 2;
          return __pyx_r;
          __pyx_L22_resume_from_yield:;
          __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
          __pyx_t_6 = __pyx_cur_scope->__pyx_t_3;
          __pyx_cur_scope->__pyx_t_3 = 0;
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_4;
          __pyx_t_11 = __pyx_cur_scope->__pyx_t_5;
          __pyx_t_12 = __pyx_cur_scope->__pyx_t_2;
          __pyx_t_13 = __pyx_cur_scope->__pyx_t_6;
          __pyx_t_17 = __pyx_cur_scope->__pyx_t_7;
          __pyx_t_20 = __pyx_cur_scope->__pyx_t_8;
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1161, __pyx_L1_error)

          /* "pyteomics/cparser.pyx":1160
 *                         PyTuple_SET_ITEM(subassignments, i, temp2)
 *                     assignments_product = it.product(*subassignments)
 *                     for a in assignments_product:             # <<<<<<<<<<<<<<
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)
 *                     free(pindices)
 */
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pyteomics/cparser.pyx":1162
 *                     for a in assignments_product:
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)
 *                     free(pindices)             # <<<<<<<<<<<<<<
 *         self.sequence = None
 * 
 */
        free(__pyx_cur_scope->__pyx_v_pindices);

        /* "pyteomics/cparser.pyx":1147
 *             self._reset_sequence()
 *             for n_mods in range(0, self.max_mods):
 *                 for subindices in it.combinations(indices, n_mods):             # <<<<<<<<<<<<<<
 *                     self._reset_sequence()
 *                     self.last_indices = list(subindices)
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __pyx_L6:;

  /* "pyteomics/cparser.pyx":1163
 *                         yield self._apply_variable_assignment(self.sequence, pindices, <tuple>a, k)
 *                     free(pindices)
 *         self.sequence = None             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->sequence);
  __pyx_cur_scope->__pyx_v_self->sequence = ((PyObject*)Py_None);
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "pyteomics/cparser.pyx":1108
 * 
 *     @cython.boundscheck(False)
 *     def generate(self, sequence_spec):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list sequence
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("generate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1166
 * 
 *     @cython.boundscheck(False)
 *     cdef list _apply_variable_assignment(self, list sequence, long* indices, tuple_or_list assignment, size_t n):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i
 */

static PyObject *__pyx_fuse_0__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, long *__pyx_v_indices, PyObject *__pyx_v_assignment, size_t __pyx_v_n) {
  size_t __pyx_v_i;
  long __pyx_v_ix;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0_apply_variable_assignment", 0);
  __Pyx_INCREF(__pyx_v_sequence);

  /* "pyteomics/cparser.pyx":1172
 *             SequencePosition position
 *             str mod
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             sequence = list(sequence)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->persist != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":1173
 *             str mod
 *         if self.persist:
 *             sequence = list(sequence)             # <<<<<<<<<<<<<<
 *         else:
 *             self._reset_sequence()
 */
    __pyx_t_2 = PySequence_List(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_sequence, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1172
 *             SequencePosition position
 *             str mod
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             sequence = list(sequence)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pyteomics/cparser.pyx":1175
 *             sequence = list(sequence)
 *         else:
 *             self._reset_sequence()             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if tuple_or_list is tuple:
 */
  /*else*/ {
    ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self->__pyx_vtab)->_reset_sequence(__pyx_v_self);
  }
  __pyx_L3:;

  /* "pyteomics/cparser.pyx":1176
 *         else:
 *             self._reset_sequence()
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if tuple_or_list is tuple:
 *                 position = <SequencePosition>PyTuple_GET_ITEM(assignment, i)
 */
  __pyx_t_3 = __pyx_v_n;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "pyteomics/cparser.pyx":1178
 *         for i in range(n):
 *             if tuple_or_list is tuple:
 *                 position = <SequencePosition>PyTuple_GET_ITEM(assignment, i)             # <<<<<<<<<<<<<<
 *             else:
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)
 */
    __pyx_t_6 = PyTuple_GET_ITEM(__pyx_v_assignment, __pyx_v_i);
    __pyx_t_2 = ((PyObject *)__pyx_t_6);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1181
 *             else:
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)
 *             ix = indices[i]             # <<<<<<<<<<<<<<
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)
 */
    __pyx_v_ix = (__pyx_v_indices[__pyx_v_i]);

    /* "pyteomics/cparser.pyx":1182
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)
 *             ix = indices[i]
 *             Py_INCREF(position)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(sequence, ix, position)
 *         return sequence
 */
    Py_INCREF(((PyObject *)__pyx_v_position));

    /* "pyteomics/cparser.pyx":1183
 *             ix = indices[i]
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)             # <<<<<<<<<<<<<<
 *         return sequence
 * 
 */
    PyList_SET_ITEM(__pyx_v_sequence, __pyx_v_ix, ((PyObject *)__pyx_v_position));
  }

  /* "pyteomics/cparser.pyx":1184
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)
 *         return sequence             # <<<<<<<<<<<<<<
 * 
 *     cdef void _reset_sequence(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sequence);
  __pyx_r = __pyx_v_sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1166
 * 
 *     @cython.boundscheck(False)
 *     cdef list _apply_variable_assignment(self, list sequence, long* indices, tuple_or_list assignment, size_t n):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator._apply_variable_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_fuse_1__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence, long *__pyx_v_indices, PyObject *__pyx_v_assignment, size_t __pyx_v_n) {
  size_t __pyx_v_i;
  long __pyx_v_ix;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1_apply_variable_assignment", 0);
  __Pyx_INCREF(__pyx_v_sequence);

  /* "pyteomics/cparser.pyx":1172
 *             SequencePosition position
 *             str mod
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             sequence = list(sequence)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->persist != 0);
  if (__pyx_t_1) {

    /* "pyteomics/cparser.pyx":1173
 *             str mod
 *         if self.persist:
 *             sequence = list(sequence)             # <<<<<<<<<<<<<<
 *         else:
 *             self._reset_sequence()
 */
    __pyx_t_2 = PySequence_List(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_sequence, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1172
 *             SequencePosition position
 *             str mod
 *         if self.persist:             # <<<<<<<<<<<<<<
 *             sequence = list(sequence)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pyteomics/cparser.pyx":1175
 *             sequence = list(sequence)
 *         else:
 *             self._reset_sequence()             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if tuple_or_list is tuple:
 */
  /*else*/ {
    ((struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self->__pyx_vtab)->_reset_sequence(__pyx_v_self);
  }
  __pyx_L3:;

  /* "pyteomics/cparser.pyx":1176
 *         else:
 *             self._reset_sequence()
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if tuple_or_list is tuple:
 *                 position = <SequencePosition>PyTuple_GET_ITEM(assignment, i)
 */
  __pyx_t_3 = __pyx_v_n;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "pyteomics/cparser.pyx":1180
 *                 position = <SequencePosition>PyTuple_GET_ITEM(assignment, i)
 *             else:
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)             # <<<<<<<<<<<<<<
 *             ix = indices[i]
 *             Py_INCREF(position)
 */
    __pyx_t_6 = PyList_GET_ITEM(__pyx_v_assignment, __pyx_v_i);
    __pyx_t_2 = ((PyObject *)__pyx_t_6);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1181
 *             else:
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)
 *             ix = indices[i]             # <<<<<<<<<<<<<<
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)
 */
    __pyx_v_ix = (__pyx_v_indices[__pyx_v_i]);

    /* "pyteomics/cparser.pyx":1182
 *                 position = <SequencePosition>PyList_GET_ITEM(assignment, i)
 *             ix = indices[i]
 *             Py_INCREF(position)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(sequence, ix, position)
 *         return sequence
 */
    Py_INCREF(((PyObject *)__pyx_v_position));

    /* "pyteomics/cparser.pyx":1183
 *             ix = indices[i]
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)             # <<<<<<<<<<<<<<
 *         return sequence
 * 
 */
    PyList_SET_ITEM(__pyx_v_sequence, __pyx_v_ix, ((PyObject *)__pyx_v_position));
  }

  /* "pyteomics/cparser.pyx":1184
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(sequence, ix, position)
 *         return sequence             # <<<<<<<<<<<<<<
 * 
 *     cdef void _reset_sequence(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sequence);
  __pyx_r = __pyx_v_sequence;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1166
 * 
 *     @cython.boundscheck(False)
 *     cdef list _apply_variable_assignment(self, list sequence, long* indices, tuple_or_list assignment, size_t n):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator._apply_variable_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1186
 *         return sequence
 * 
 *     cdef void _reset_sequence(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

static void __pyx_f_9pyteomics_7cparser_16IsoformGenerator__reset_sequence(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  long __pyx_v_ix;
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  long __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_reset_sequence", 0);

  /* "pyteomics/cparser.pyx":1192
 *             SequencePosition position
 * 
 *         n = PyList_Size(self.last_indices)             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             ix = PyInt_AsLong(<object>PyList_GET_ITEM(self.last_indices, i))
 */
  __pyx_t_1 = __pyx_v_self->last_indices;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyList_Size(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_n = __pyx_t_2;

  /* "pyteomics/cparser.pyx":1193
 * 
 *         n = PyList_Size(self.last_indices)
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             ix = PyInt_AsLong(<object>PyList_GET_ITEM(self.last_indices, i))
 *             position = <SequencePosition>PyList_GET_ITEM(self.original_sequence, ix)
 */
  __pyx_t_3 = __pyx_v_n;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "pyteomics/cparser.pyx":1194
 *         n = PyList_Size(self.last_indices)
 *         for i in range(n):
 *             ix = PyInt_AsLong(<object>PyList_GET_ITEM(self.last_indices, i))             # <<<<<<<<<<<<<<
 *             position = <SequencePosition>PyList_GET_ITEM(self.original_sequence, ix)
 *             Py_INCREF(position)
 */
    __pyx_t_1 = __pyx_v_self->last_indices;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_v_i);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = PyInt_AsLong(((PyObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((long)-1L) && PyErr_Occurred())) __PYX_ERR(0, 1194, __pyx_L1_error)
    __pyx_v_ix = __pyx_t_7;

    /* "pyteomics/cparser.pyx":1195
 *         for i in range(n):
 *             ix = PyInt_AsLong(<object>PyList_GET_ITEM(self.last_indices, i))
 *             position = <SequencePosition>PyList_GET_ITEM(self.original_sequence, ix)             # <<<<<<<<<<<<<<
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(self.sequence, ix, position)
 */
    __pyx_t_1 = __pyx_v_self->original_sequence;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_v_ix);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((PyObject *)__pyx_t_6);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_position, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":1196
 *             ix = PyInt_AsLong(<object>PyList_GET_ITEM(self.last_indices, i))
 *             position = <SequencePosition>PyList_GET_ITEM(self.original_sequence, ix)
 *             Py_INCREF(position)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(self.sequence, ix, position)
 * 
 */
    Py_INCREF(((PyObject *)__pyx_v_position));

    /* "pyteomics/cparser.pyx":1197
 *             position = <SequencePosition>PyList_GET_ITEM(self.original_sequence, ix)
 *             Py_INCREF(position)
 *             PyList_SET_ITEM(self.sequence, ix, position)             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, sequence_spec):
 */
    __pyx_t_1 = __pyx_v_self->sequence;
    __Pyx_INCREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_1, __pyx_v_ix, ((PyObject *)__pyx_v_position));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "pyteomics/cparser.pyx":1186
 *         return sequence
 * 
 *     cdef void _reset_sequence(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("pyteomics.cparser.IsoformGenerator._reset_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_position);
  __Pyx_RefNannyFinishContext();
}

/* "pyteomics/cparser.pyx":1199
 *             PyList_SET_ITEM(self.sequence, ix, position)
 * 
 *     def __call__(self, sequence_spec):             # <<<<<<<<<<<<<<
 *         return self.generate(sequence_spec)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_16__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_16__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence_spec = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence_spec,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence_spec)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 1199, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_sequence_spec = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1199, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_15__call__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), __pyx_v_sequence_spec);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_15__call__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_sequence_spec) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "pyteomics/cparser.pyx":1200
 * 
 *     def __call__(self, sequence_spec):
 *         return self.generate(sequence_spec)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_generate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_sequence_spec) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_sequence_spec);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1199
 *             PyList_SET_ITEM(self.sequence, ix, position)
 * 
 *     def __call__(self, sequence_spec):             # <<<<<<<<<<<<<<
 *         return self.generate(sequence_spec)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":992
 * cdef class IsoformGenerator(object):
 *     cdef:
 *         public dict variable_mods             # <<<<<<<<<<<<<<
 *         public dict fixed_mods
 *         public list labels
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->variable_mods);
  __pyx_r = __pyx_v_self->variable_mods;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 992, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->variable_mods);
  __Pyx_DECREF(__pyx_v_self->variable_mods);
  __pyx_v_self->variable_mods = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.variable_mods.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->variable_mods);
  __Pyx_DECREF(__pyx_v_self->variable_mods);
  __pyx_v_self->variable_mods = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":993
 *     cdef:
 *         public dict variable_mods
 *         public dict fixed_mods             # <<<<<<<<<<<<<<
 *         public list labels
 *         public long max_mods
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->fixed_mods);
  __pyx_r = __pyx_v_self->fixed_mods;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 993, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->fixed_mods);
  __Pyx_DECREF(__pyx_v_self->fixed_mods);
  __pyx_v_self->fixed_mods = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.fixed_mods.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->fixed_mods);
  __Pyx_DECREF(__pyx_v_self->fixed_mods);
  __pyx_v_self->fixed_mods = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":994
 *         public dict variable_mods
 *         public dict fixed_mods
 *         public list labels             # <<<<<<<<<<<<<<
 *         public long max_mods
 *         public bint override
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->labels);
  __pyx_r = __pyx_v_self->labels;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 994, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->labels);
  __Pyx_DECREF(__pyx_v_self->labels);
  __pyx_v_self->labels = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.labels.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_6labels_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->labels);
  __Pyx_DECREF(__pyx_v_self->labels);
  __pyx_v_self->labels = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":995
 *         public dict fixed_mods
 *         public list labels
 *         public long max_mods             # <<<<<<<<<<<<<<
 *         public bint override
 *         public bint show_unmodified_termini
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v_self->max_mods); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.max_mods.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8max_mods_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_long(__pyx_v_value); if (unlikely((__pyx_t_1 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 995, __pyx_L1_error)
  __pyx_v_self->max_mods = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.max_mods.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":996
 *         public list labels
 *         public long max_mods
 *         public bint override             # <<<<<<<<<<<<<<
 *         public bint show_unmodified_termini
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->override); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.override.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8override_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 996, __pyx_L1_error)
  __pyx_v_self->override = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.override.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":997
 *         public long max_mods
 *         public bint override
 *         public bint show_unmodified_termini             # <<<<<<<<<<<<<<
 * 
 *         public bint persist
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->show_unmodified_termini); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.show_unmodified_termini.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 997, __pyx_L1_error)
  __pyx_v_self->show_unmodified_termini = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.show_unmodified_termini.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":999
 *         public bint show_unmodified_termini
 * 
 *         public bint persist             # <<<<<<<<<<<<<<
 * 
 *         # Temporary State
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->persist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.persist.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_7persist_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 999, __pyx_L1_error)
  __pyx_v_self->persist = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.persist.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1002
 * 
 *         # Temporary State
 *         public list sequence             # <<<<<<<<<<<<<<
 *         public list original_sequence
 *         public list last_indices
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1002, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_8sequence_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1003
 *         # Temporary State
 *         public list sequence
 *         public list original_sequence             # <<<<<<<<<<<<<<
 *         public list last_indices
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->original_sequence);
  __pyx_r = __pyx_v_self->original_sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->original_sequence);
  __Pyx_DECREF(__pyx_v_self->original_sequence);
  __pyx_v_self->original_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.original_sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->original_sequence);
  __Pyx_DECREF(__pyx_v_self->original_sequence);
  __pyx_v_self->original_sequence = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1004
 *         public list sequence
 *         public list original_sequence
 *         public list last_indices             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices___get__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices___get__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->last_indices);
  __pyx_r = __pyx_v_self->last_indices;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_2__set__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_2__set__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1004, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->last_indices);
  __Pyx_DECREF(__pyx_v_self->last_indices);
  __pyx_v_self->last_indices = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.last_indices.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_4__del__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_12last_indices_4__del__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->last_indices);
  __Pyx_DECREF(__pyx_v_self->last_indices);
  __pyx_v_self->last_indices = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_18__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_17__reduce_cython__[] = "IsoformGenerator.__reduce_cython__(self)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_18__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17__reduce_cython__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_17__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.fixed_mods, self.labels, self.last_indices, self.max_mods, self.original_sequence, self.override, self.persist, self.sequence, self.show_unmodified_termini, self.variable_mods)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v_self->max_mods); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->override); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->persist); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_self->show_unmodified_termini); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(10); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->fixed_mods);
  __Pyx_GIVEREF(__pyx_v_self->fixed_mods);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_self->fixed_mods);
  __Pyx_INCREF(__pyx_v_self->labels);
  __Pyx_GIVEREF(__pyx_v_self->labels);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self->labels);
  __Pyx_INCREF(__pyx_v_self->last_indices);
  __Pyx_GIVEREF(__pyx_v_self->last_indices);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_self->last_indices);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->original_sequence);
  __Pyx_GIVEREF(__pyx_v_self->original_sequence);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_v_self->original_sequence);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 5, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 6, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __Pyx_GIVEREF(__pyx_v_self->sequence);
  PyTuple_SET_ITEM(__pyx_t_5, 7, __pyx_v_self->sequence);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 8, __pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->variable_mods);
  __Pyx_GIVEREF(__pyx_v_self->variable_mods);
  PyTuple_SET_ITEM(__pyx_t_5, 9, __pyx_v_self->variable_mods);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.fixed_mods, self.labels, self.last_indices, self.max_mods, self.original_sequence, self.override, self.persist, self.sequence, self.show_unmodified_termini, self.variable_mods)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_5 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v__dict = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "(tree fragment)":7
 *     state = (self.fixed_mods, self.labels, self.last_indices, self.max_mods, self.original_sequence, self.override, self.persist, self.sequence, self.show_unmodified_termini, self.variable_mods)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_6 = (__pyx_v__dict != Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.fixed_mods is not None or self.labels is not None or self.last_indices is not None or self.original_sequence is not None or self.sequence is not None or self.variable_mods is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.fixed_mods, self.labels, self.last_indices, self.max_mods, self.original_sequence, self.override, self.persist, self.sequence, self.show_unmodified_termini, self.variable_mods)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.fixed_mods is not None or self.labels is not None or self.last_indices is not None or self.original_sequence is not None or self.sequence is not None or self.variable_mods is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, None), state
 */
  /*else*/ {
    __pyx_t_6 = (__pyx_v_self->fixed_mods != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->labels != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_8 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_7 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->last_indices != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->original_sequence != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_8 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_7 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->sequence != ((PyObject*)Py_None));
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->variable_mods != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_8 != 0);
    __pyx_t_7 = __pyx_t_6;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_7;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.fixed_mods is not None or self.labels is not None or self.last_indices is not None or self.original_sequence is not None or self.sequence is not None or self.variable_mods is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, None), state
 *     else:
 */
  __pyx_t_7 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":13
 *         use_setstate = self.fixed_mods is not None or self.labels is not None or self.last_indices is not None or self.original_sequence is not None or self.sequence is not None or self.variable_mods is not None
 *     if use_setstate:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_IsoformGenerator); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_50086419);
    __Pyx_GIVEREF(__pyx_int_50086419);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_50086419);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_5, 2, Py_None);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.fixed_mods is not None or self.labels is not None or self.last_indices is not None or self.original_sequence is not None or self.sequence is not None or self.variable_mods is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, None), state
 *     else:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_IsoformGenerator__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_IsoformGenerator); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_50086419);
    __Pyx_GIVEREF(__pyx_int_50086419);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_50086419);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_IsoformGenerator__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_20__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_19__setstate_cython__[] = "IsoformGenerator.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_20__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16IsoformGenerator_19__setstate_cython__(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16IsoformGenerator_19__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_IsoformGenerator__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_IsoformGenerator__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_IsoformGenerator, (type(self), 0x2fc4213, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_IsoformGenerator__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.IsoformGenerator.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1203
 * 
 * 
 * cdef bint _is_nterm_mod(str target):             # <<<<<<<<<<<<<<
 *     return target.startswith("nterm")
 * 
 */

static int __pyx_f_9pyteomics_7cparser__is_nterm_mod(PyObject *__pyx_v_target) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_nterm_mod", 0);

  /* "pyteomics/cparser.pyx":1204
 * 
 * cdef bint _is_nterm_mod(str target):
 *     return target.startswith("nterm")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_target == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
    __PYX_ERR(0, 1204, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyStr_Tailmatch(__pyx_v_target, __pyx_n_s_nterm, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1204, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1203
 * 
 * 
 * cdef bint _is_nterm_mod(str target):             # <<<<<<<<<<<<<<
 *     return target.startswith("nterm")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("pyteomics.cparser._is_nterm_mod", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1207
 * 
 * 
 * cdef bint _is_cterm_mod(str target):             # <<<<<<<<<<<<<<
 *     return target.startswith("cterm")
 * 
 */

static int __pyx_f_9pyteomics_7cparser__is_cterm_mod(PyObject *__pyx_v_target) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_cterm_mod", 0);

  /* "pyteomics/cparser.pyx":1208
 * 
 * cdef bint _is_cterm_mod(str target):
 *     return target.startswith("cterm")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_target == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
    __PYX_ERR(0, 1208, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyStr_Tailmatch(__pyx_v_target, __pyx_n_s_cterm, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1208, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1207
 * 
 * 
 * cdef bint _is_cterm_mod(str target):             # <<<<<<<<<<<<<<
 *     return target.startswith("cterm")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("pyteomics.cparser._is_cterm_mod", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1217
 *         public list targets
 * 
 *     def __init__(self, str label, targets):             # <<<<<<<<<<<<<<
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 */

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_label = 0;
  PyObject *__pyx_v_targets = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_label,&__pyx_n_s_targets,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_label)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_targets)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1217, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1217, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_label = ((PyObject*)values[0]);
    __pyx_v_targets = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1217, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_label), (&PyString_Type), 1, "label", 1))) __PYX_ERR(0, 1217, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule___init__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), __pyx_v_label, __pyx_v_targets);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16ModificationRule___init__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_label, PyObject *__pyx_v_targets) {
  PyObject *__pyx_v_x = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyteomics/cparser.pyx":1218
 * 
 *     def __init__(self, str label, targets):
 *         self.modification = label             # <<<<<<<<<<<<<<
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 *                         else ModificationTarget._create(None, PositionType.universal)
 */
  __Pyx_INCREF(__pyx_v_label);
  __Pyx_GIVEREF(__pyx_v_label);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = __pyx_v_label;

  /* "pyteomics/cparser.pyx":1219
 *     def __init__(self, str label, targets):
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)             # <<<<<<<<<<<<<<
 *                         else ModificationTarget._create(None, PositionType.universal)
 *                         for x in targets]
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pyteomics/cparser.pyx":1221
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 *                         else ModificationTarget._create(None, PositionType.universal)
 *                         for x in targets]             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint test(self, SequencePosition position):
 */
  if (likely(PyList_CheckExact(__pyx_v_targets)) || PyTuple_CheckExact(__pyx_v_targets)) {
    __pyx_t_2 = __pyx_v_targets; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_targets); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1221, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1221, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1221, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1221, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pyteomics/cparser.pyx":1219
 *     def __init__(self, str label, targets):
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)             # <<<<<<<<<<<<<<
 *                         else ModificationTarget._create(None, PositionType.universal)
 *                         for x in targets]
 */
    __pyx_t_6 = PyString_Check(__pyx_v_x); 
    if ((__pyx_t_6 != 0)) {
      if (!(likely(PyString_CheckExact(__pyx_v_x))||((__pyx_v_x) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_x)->tp_name), 0))) __PYX_ERR(0, 1219, __pyx_L1_error)
      __pyx_t_7 = ((PyObject *)__pyx_f_9pyteomics_7cparser_18ModificationTarget__from_string(((PyObject*)__pyx_v_x))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __pyx_t_7;
      __pyx_t_7 = 0;
    } else {

      /* "pyteomics/cparser.pyx":1220
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 *                         else ModificationTarget._create(None, PositionType.universal)             # <<<<<<<<<<<<<<
 *                         for x in targets]
 * 
 */
      __pyx_t_7 = ((PyObject *)__pyx_f_9pyteomics_7cparser_18ModificationTarget__create(((PyObject*)Py_None), __pyx_e_9pyteomics_7cparser_universal)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __pyx_t_7;
      __pyx_t_7 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyteomics/cparser.pyx":1221
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 *                         else ModificationTarget._create(None, PositionType.universal)
 *                         for x in targets]             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint test(self, SequencePosition position):
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1219
 *     def __init__(self, str label, targets):
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)             # <<<<<<<<<<<<<<
 *                         else ModificationTarget._create(None, PositionType.universal)
 *                         for x in targets]
 */
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->targets);
  __Pyx_DECREF(__pyx_v_self->targets);
  __pyx_v_self->targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1217
 *         public list targets
 * 
 *     def __init__(self, str label, targets):             # <<<<<<<<<<<<<<
 *         self.modification = label
 *         self.targets = [ModificationTarget._from_string(x) if isinstance(x, str)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1223
 *                         for x in targets]
 * 
 *     cpdef bint test(self, SequencePosition position):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position); /*proto*/
static int __pyx_f_9pyteomics_7cparser_16ModificationRule_test(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position, int __pyx_skip_dispatch) {
  size_t __pyx_v_i;
  size_t __pyx_v_n;
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_t = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  size_t __pyx_t_7;
  size_t __pyx_t_8;
  size_t __pyx_t_9;
  PyObject *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_test); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_16ModificationRule_3test)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_position)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_position));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1223, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1227
 *             size_t i, n
 *             ModificationTarget t
 *         n = PyList_Size(self.targets)             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)
 */
  __pyx_t_1 = __pyx_v_self->targets;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_6 = PyList_Size(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1L))) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_n = __pyx_t_6;

  /* "pyteomics/cparser.pyx":1228
 *             ModificationTarget t
 *         n = PyList_Size(self.targets)
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)
 *             if t.test(position):
 */
  __pyx_t_7 = __pyx_v_n;
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "pyteomics/cparser.pyx":1229
 *         n = PyList_Size(self.targets)
 *         for i in range(n):
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)             # <<<<<<<<<<<<<<
 *             if t.test(position):
 *                 return True
 */
    __pyx_t_1 = __pyx_v_self->targets;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_10 = PyList_GET_ITEM(__pyx_t_1, __pyx_v_i);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((PyObject *)__pyx_t_10);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_t, ((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pyteomics/cparser.pyx":1230
 *         for i in range(n):
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)
 *             if t.test(position):             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_5 = (((struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget *)__pyx_v_t->__pyx_vtab)->test(__pyx_v_t, __pyx_v_position, 0) != 0);
    if (__pyx_t_5) {

      /* "pyteomics/cparser.pyx":1231
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)
 *             if t.test(position):
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __pyx_r = 1;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":1230
 *         for i in range(n):
 *             t = <ModificationTarget>PyList_GET_ITEM(self.targets, i)
 *             if t.test(position):             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }
  }

  /* "pyteomics/cparser.pyx":1232
 *             if t.test(position):
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, position):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1223
 *                         for x in targets]
 * 
 *     cpdef bint test(self, SequencePosition position):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("pyteomics.cparser.ModificationRule.test", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16ModificationRule_2test[] = "ModificationRule.test(self, SequencePosition position) -> bool";
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_position), __pyx_ptype_9pyteomics_7cparser_SequencePosition, 1, "position", 0))) __PYX_ERR(0, 1223, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_2test(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_position));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_2test(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_9pyteomics_7cparser_16ModificationRule_test(__pyx_v_self, __pyx_v_position, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1234
 *         return False
 * 
 *     def __call__(self, position):             # <<<<<<<<<<<<<<
 *         return self.test(position)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_5__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_5__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_position = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_position,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_position)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 1234, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_position = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1234, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_4__call__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), __pyx_v_position);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_4__call__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_position) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "pyteomics/cparser.pyx":1235
 * 
 *     def __call__(self, position):
 *         return self.test(position)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(((__pyx_v_position) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_position, __pyx_ptype_9pyteomics_7cparser_SequencePosition))))) __PYX_ERR(0, 1235, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyBool_FromLong(((struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule *)__pyx_v_self->__pyx_vtab)->test(__pyx_v_self, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_position), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1234
 *         return False
 * 
 *     def __call__(self, position):             # <<<<<<<<<<<<<<
 *         return self.test(position)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1237
 *         return self.test(position)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         t = "{self.__class__.__name__}({self.modification!r}, {self.targets})"
 *         return t.format(self=self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_7__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_7__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_6__repr__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_6__repr__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyteomics/cparser.pyx":1238
 * 
 *     def __repr__(self):
 *         t = "{self.__class__.__name__}({self.modification!r}, {self.targets})"             # <<<<<<<<<<<<<<
 *         return t.format(self=self)
 * 
 */
  __Pyx_INCREF(__pyx_kp_s_self___class_____name___self_mo);
  __pyx_v_t = __pyx_kp_s_self___class_____name___self_mo;

  /* "pyteomics/cparser.pyx":1239
 *     def __repr__(self):
 *         t = "{self.__class__.__name__}({self.modification!r}, {self.targets})"
 *         return t.format(self=self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_self, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(0, 1239, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1237
 *         return self.test(position)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         t = "{self.__class__.__name__}({self.modification!r}, {self.targets})"
 *         return t.format(self=self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1214
 * cdef class ModificationRule(object):
 *     cdef:
 *         public str modification             # <<<<<<<<<<<<<<
 *         public list targets
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification___get__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->modification);
  __pyx_r = __pyx_v_self->modification;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_2__set__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1214, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.modification.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_4__del__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_12modification_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->modification);
  __Pyx_DECREF(__pyx_v_self->modification);
  __pyx_v_self->modification = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1215
 *     cdef:
 *         public str modification
 *         public list targets             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, str label, targets):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets___get__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->targets);
  __pyx_r = __pyx_v_self->targets;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_2__set__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1215, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->targets);
  __Pyx_DECREF(__pyx_v_self->targets);
  __pyx_v_self->targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.targets.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_4__del__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_16ModificationRule_7targets_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->targets);
  __Pyx_DECREF(__pyx_v_self->targets);
  __pyx_v_self->targets = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16ModificationRule_8__reduce_cython__[] = "ModificationRule.__reduce_cython__(self)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_8__reduce_cython__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_8__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.modification, self.targets)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->modification);
  __Pyx_GIVEREF(__pyx_v_self->modification);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->modification);
  __Pyx_INCREF(__pyx_v_self->targets);
  __Pyx_GIVEREF(__pyx_v_self->targets);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->targets);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.modification, self.targets)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.modification, self.targets)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.modification is not None or self.targets is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.modification, self.targets)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.modification is not None or self.targets is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->modification != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->targets != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.modification is not None or self.targets is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.modification is not None or self.targets is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ModificationRule); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_209977177);
    __Pyx_GIVEREF(__pyx_int_209977177);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_209977177);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.modification is not None or self.targets is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, None), state
 *     else:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ModificationRule__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_ModificationRule); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_209977177);
    __Pyx_GIVEREF(__pyx_int_209977177);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_209977177);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ModificationRule__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_16ModificationRule_10__setstate_cython__[] = "ModificationRule.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_9pyteomics_7cparser_16ModificationRule_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_16ModificationRule_10__setstate_cython__(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_16ModificationRule_10__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ModificationRule__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationRule__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ModificationRule, (type(self), 0xc83ff59, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ModificationRule__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationRule.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1248
 *         public PositionType position_type
 * 
 *     def __init__(self, target, position_type=PositionType.internal):             # <<<<<<<<<<<<<<
 *         self.target = target
 *         self.position_type = position_type
 */

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_target = 0;
  PyObject *__pyx_v_position_type = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_target,&__pyx_n_s_position_type,0};
    PyObject* values[2] = {0,0};
    values[1] = __pyx_k__4;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_position_type);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1248, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_target = values[0];
    __pyx_v_position_type = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1248, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget___init__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), __pyx_v_target, __pyx_v_position_type);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget___init__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_target, PyObject *__pyx_v_position_type) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyteomics/cparser.pyx":1249
 * 
 *     def __init__(self, target, position_type=PositionType.internal):
 *         self.target = target             # <<<<<<<<<<<<<<
 *         self.position_type = position_type
 * 
 */
  if (!(likely(PyString_CheckExact(__pyx_v_target))||((__pyx_v_target) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_target)->tp_name), 0))) __PYX_ERR(0, 1249, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_target;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->target);
  __Pyx_DECREF(__pyx_v_self->target);
  __pyx_v_self->target = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1250
 *     def __init__(self, target, position_type=PositionType.internal):
 *         self.target = target
 *         self.position_type = position_type             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint test(self, SequencePosition position):
 */
  __pyx_t_2 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_position_type)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1250, __pyx_L1_error)
  __pyx_v_self->position_type = __pyx_t_2;

  /* "pyteomics/cparser.pyx":1248
 *         public PositionType position_type
 * 
 *     def __init__(self, target, position_type=PositionType.internal):             # <<<<<<<<<<<<<<
 *         self.target = target
 *         self.position_type = position_type
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1252
 *         self.position_type = position_type
 * 
 *     cpdef bint test(self, SequencePosition position):             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.universal:
 *             return True
 */

static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position); /*proto*/
static int __pyx_f_9pyteomics_7cparser_18ModificationTarget_test(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_test); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1252, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_3test)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_position)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_position));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1252, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1252, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyteomics/cparser.pyx":1253
 * 
 *     cpdef bint test(self, SequencePosition position):
 *         if self.position_type == PositionType.universal:             # <<<<<<<<<<<<<<
 *             return True
 *         if self.position_type != PositionType.internal:
 */
  __pyx_t_5 = ((__pyx_v_self->position_type == __pyx_e_9pyteomics_7cparser_universal) != 0);
  if (__pyx_t_5) {

    /* "pyteomics/cparser.pyx":1254
 *     cpdef bint test(self, SequencePosition position):
 *         if self.position_type == PositionType.universal:
 *             return True             # <<<<<<<<<<<<<<
 *         if self.position_type != PositionType.internal:
 *             if position.position_type != self.position_type:
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "pyteomics/cparser.pyx":1253
 * 
 *     cpdef bint test(self, SequencePosition position):
 *         if self.position_type == PositionType.universal:             # <<<<<<<<<<<<<<
 *             return True
 *         if self.position_type != PositionType.internal:
 */
  }

  /* "pyteomics/cparser.pyx":1255
 *         if self.position_type == PositionType.universal:
 *             return True
 *         if self.position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *             if position.position_type != self.position_type:
 *                 return False
 */
  __pyx_t_5 = ((__pyx_v_self->position_type != __pyx_e_9pyteomics_7cparser_internal) != 0);
  if (__pyx_t_5) {

    /* "pyteomics/cparser.pyx":1256
 *             return True
 *         if self.position_type != PositionType.internal:
 *             if position.position_type != self.position_type:             # <<<<<<<<<<<<<<
 *                 return False
 *         if self.target is not None:
 */
    __pyx_t_5 = ((__pyx_v_position->position_type != __pyx_v_self->position_type) != 0);
    if (__pyx_t_5) {

      /* "pyteomics/cparser.pyx":1257
 *         if self.position_type != PositionType.internal:
 *             if position.position_type != self.position_type:
 *                 return False             # <<<<<<<<<<<<<<
 *         if self.target is not None:
 *             if self.target != position.amino_acid:
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":1256
 *             return True
 *         if self.position_type != PositionType.internal:
 *             if position.position_type != self.position_type:             # <<<<<<<<<<<<<<
 *                 return False
 *         if self.target is not None:
 */
    }

    /* "pyteomics/cparser.pyx":1255
 *         if self.position_type == PositionType.universal:
 *             return True
 *         if self.position_type != PositionType.internal:             # <<<<<<<<<<<<<<
 *             if position.position_type != self.position_type:
 *                 return False
 */
  }

  /* "pyteomics/cparser.pyx":1258
 *             if position.position_type != self.position_type:
 *                 return False
 *         if self.target is not None:             # <<<<<<<<<<<<<<
 *             if self.target != position.amino_acid:
 *                 return False
 */
  __pyx_t_5 = (__pyx_v_self->target != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "pyteomics/cparser.pyx":1259
 *                 return False
 *         if self.target is not None:
 *             if self.target != position.amino_acid:             # <<<<<<<<<<<<<<
 *                 return False
 *         return True
 */
    __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_v_self->target, __pyx_v_position->amino_acid, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1259, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "pyteomics/cparser.pyx":1260
 *         if self.target is not None:
 *             if self.target != position.amino_acid:
 *                 return False             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "pyteomics/cparser.pyx":1259
 *                 return False
 *         if self.target is not None:
 *             if self.target != position.amino_acid:             # <<<<<<<<<<<<<<
 *                 return False
 *         return True
 */
    }

    /* "pyteomics/cparser.pyx":1258
 *             if position.position_type != self.position_type:
 *                 return False
 *         if self.target is not None:             # <<<<<<<<<<<<<<
 *             if self.target != position.amino_acid:
 *                 return False
 */
  }

  /* "pyteomics/cparser.pyx":1261
 *             if self.target != position.amino_acid:
 *                 return False
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, position):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1252
 *         self.position_type = position_type
 * 
 *     cpdef bint test(self, SequencePosition position):             # <<<<<<<<<<<<<<
 *         if self.position_type == PositionType.universal:
 *             return True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("pyteomics.cparser.ModificationTarget.test", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_18ModificationTarget_2test[] = "ModificationTarget.test(self, SequencePosition position) -> bool";
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_3test(PyObject *__pyx_v_self, PyObject *__pyx_v_position) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_position), __pyx_ptype_9pyteomics_7cparser_SequencePosition, 1, "position", 0))) __PYX_ERR(0, 1252, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_2test(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_position));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_2test(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v_position) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_9pyteomics_7cparser_18ModificationTarget_test(__pyx_v_self, __pyx_v_position, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1263
 *         return True
 * 
 *     def __call__(self, position):             # <<<<<<<<<<<<<<
 *         return self.test(position)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_5__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_5__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_position = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_position,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_position)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 1263, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_position = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1263, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_4__call__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), __pyx_v_position);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_4__call__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_position) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "pyteomics/cparser.pyx":1264
 * 
 *     def __call__(self, position):
 *         return self.test(position)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(((__pyx_v_position) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_position, __pyx_ptype_9pyteomics_7cparser_SequencePosition))))) __PYX_ERR(0, 1264, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyBool_FromLong(((struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self->__pyx_vtab)->test(__pyx_v_self, ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v_position), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1263
 *         return True
 * 
 *     def __call__(self, position):             # <<<<<<<<<<<<<<
 *         return self.test(position)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1266
 *         return self.test(position)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "{self.__class__.__name__}({self.target!r}, {self.position_type!r})".format(self=self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_7__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_7__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6__repr__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_6__repr__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyteomics/cparser.pyx":1267
 * 
 *     def __repr__(self):
 *         return "{self.__class__.__name__}({self.target!r}, {self.position_type!r})".format(self=self)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_self___class_____name___self_ta, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_self, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(0, 1267, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1266
 *         return self.test(position)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "{self.__class__.__name__}({self.target!r}, {self.position_type!r})".format(self=self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1270
 * 
 *     @staticmethod
 *     cdef ModificationTarget _create(str target, PositionType position_type):             # <<<<<<<<<<<<<<
 *         cdef ModificationTarget inst = ModificationTarget.__new__(ModificationTarget)
 *         inst.target = target
 */

static struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_f_9pyteomics_7cparser_18ModificationTarget__create(PyObject *__pyx_v_target, enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type) {
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_inst = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create", 0);

  /* "pyteomics/cparser.pyx":1271
 *     @staticmethod
 *     cdef ModificationTarget _create(str target, PositionType position_type):
 *         cdef ModificationTarget inst = ModificationTarget.__new__(ModificationTarget)             # <<<<<<<<<<<<<<
 *         inst.target = target
 *         inst.position_type = position_type
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_9pyteomics_7cparser_ModificationTarget(((PyTypeObject *)__pyx_ptype_9pyteomics_7cparser_ModificationTarget), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_inst = ((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1272
 *     cdef ModificationTarget _create(str target, PositionType position_type):
 *         cdef ModificationTarget inst = ModificationTarget.__new__(ModificationTarget)
 *         inst.target = target             # <<<<<<<<<<<<<<
 *         inst.position_type = position_type
 *         return inst
 */
  __Pyx_INCREF(__pyx_v_target);
  __Pyx_GIVEREF(__pyx_v_target);
  __Pyx_GOTREF(__pyx_v_inst->target);
  __Pyx_DECREF(__pyx_v_inst->target);
  __pyx_v_inst->target = __pyx_v_target;

  /* "pyteomics/cparser.pyx":1273
 *         cdef ModificationTarget inst = ModificationTarget.__new__(ModificationTarget)
 *         inst.target = target
 *         inst.position_type = position_type             # <<<<<<<<<<<<<<
 *         return inst
 * 
 */
  __pyx_v_inst->position_type = __pyx_v_position_type;

  /* "pyteomics/cparser.pyx":1274
 *         inst.target = target
 *         inst.position_type = position_type
 *         return inst             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_inst));
  __pyx_r = __pyx_v_inst;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1270
 * 
 *     @staticmethod
 *     cdef ModificationTarget _create(str target, PositionType position_type):             # <<<<<<<<<<<<<<
 *         cdef ModificationTarget inst = ModificationTarget.__new__(ModificationTarget)
 *         inst.target = target
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget._create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_inst);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1277
 * 
 *     @staticmethod
 *     def from_string(str string):             # <<<<<<<<<<<<<<
 *         return ModificationTarget._from_string(string)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_9from_string(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_18ModificationTarget_8from_string[] = "ModificationTarget.from_string(str string)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_18ModificationTarget_9from_string = {"from_string", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_9from_string, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_18ModificationTarget_8from_string};
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_9from_string(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_string = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_string,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_string)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "from_string") < 0)) __PYX_ERR(0, 1277, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_string = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1277, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_string), (&PyString_Type), 1, "string", 1))) __PYX_ERR(0, 1277, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_8from_string(__pyx_v_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_8from_string(PyObject *__pyx_v_string) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyteomics/cparser.pyx":1278
 *     @staticmethod
 *     def from_string(str string):
 *         return ModificationTarget._from_string(string)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_9pyteomics_7cparser_18ModificationTarget__from_string(__pyx_v_string)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1277
 * 
 *     @staticmethod
 *     def from_string(str string):             # <<<<<<<<<<<<<<
 *         return ModificationTarget._from_string(string)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1281
 * 
 *     @staticmethod
 *     cdef ModificationTarget _from_string(str string):             # <<<<<<<<<<<<<<
 *         cdef:
 *             PositionType position_type
 */

static struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_f_9pyteomics_7cparser_18ModificationTarget__from_string(PyObject *__pyx_v_string) {
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_v_position_type;
  size_t __pyx_v_n;
  PyObject *__pyx_v_target = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_inst = 0;
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_string", 0);

  /* "pyteomics/cparser.pyx":1287
 *             str target
 *             ModificationTarget inst
 *         n = len(string)             # <<<<<<<<<<<<<<
 *         target = None
 *         position_type = PositionType.internal
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_string); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1287, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pyteomics/cparser.pyx":1288
 *             ModificationTarget inst
 *         n = len(string)
 *         target = None             # <<<<<<<<<<<<<<
 *         position_type = PositionType.internal
 *         if _is_cterm_mod(string):
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_target = ((PyObject*)Py_None);

  /* "pyteomics/cparser.pyx":1289
 *         n = len(string)
 *         target = None
 *         position_type = PositionType.internal             # <<<<<<<<<<<<<<
 *         if _is_cterm_mod(string):
 *             position_type = PositionType.c_term
 */
  __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_internal;

  /* "pyteomics/cparser.pyx":1290
 *         target = None
 *         position_type = PositionType.internal
 *         if _is_cterm_mod(string):             # <<<<<<<<<<<<<<
 *             position_type = PositionType.c_term
 *             if n > 5:
 */
  __pyx_t_2 = (__pyx_f_9pyteomics_7cparser__is_cterm_mod(__pyx_v_string) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1291
 *         position_type = PositionType.internal
 *         if _is_cterm_mod(string):
 *             position_type = PositionType.c_term             # <<<<<<<<<<<<<<
 *             if n > 5:
 *                 if n > 6:
 */
    __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_c_term;

    /* "pyteomics/cparser.pyx":1292
 *         if _is_cterm_mod(string):
 *             position_type = PositionType.c_term
 *             if n > 5:             # <<<<<<<<<<<<<<
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 */
    __pyx_t_2 = ((__pyx_v_n > 5) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":1293
 *             position_type = PositionType.c_term
 *             if n > 5:
 *                 if n > 6:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 */
      __pyx_t_2 = ((__pyx_v_n > 6) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "pyteomics/cparser.pyx":1294
 *             if n > 5:
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))             # <<<<<<<<<<<<<<
 *                 target = string[-1]
 *         elif _is_nterm_mod(string):
 */
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_string);
        __Pyx_GIVEREF(__pyx_v_string);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_string);
        __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Terminal_Modifications_with_Targ, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1294, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":1293
 *             position_type = PositionType.c_term
 *             if n > 5:
 *                 if n > 6:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 */
      }

      /* "pyteomics/cparser.pyx":1295
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]             # <<<<<<<<<<<<<<
 *         elif _is_nterm_mod(string):
 *             position_type = PositionType.n_term
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_string, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(PyString_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 1295, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_target, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":1292
 *         if _is_cterm_mod(string):
 *             position_type = PositionType.c_term
 *             if n > 5:             # <<<<<<<<<<<<<<
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 */
    }

    /* "pyteomics/cparser.pyx":1290
 *         target = None
 *         position_type = PositionType.internal
 *         if _is_cterm_mod(string):             # <<<<<<<<<<<<<<
 *             position_type = PositionType.c_term
 *             if n > 5:
 */
    goto __pyx_L3;
  }

  /* "pyteomics/cparser.pyx":1296
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 *         elif _is_nterm_mod(string):             # <<<<<<<<<<<<<<
 *             position_type = PositionType.n_term
 *             if n > 5:
 */
  __pyx_t_2 = (__pyx_f_9pyteomics_7cparser__is_nterm_mod(__pyx_v_string) != 0);
  if (__pyx_t_2) {

    /* "pyteomics/cparser.pyx":1297
 *                 target = string[-1]
 *         elif _is_nterm_mod(string):
 *             position_type = PositionType.n_term             # <<<<<<<<<<<<<<
 *             if n > 5:
 *                 if n > 6:
 */
    __pyx_v_position_type = __pyx_e_9pyteomics_7cparser_n_term;

    /* "pyteomics/cparser.pyx":1298
 *         elif _is_nterm_mod(string):
 *             position_type = PositionType.n_term
 *             if n > 5:             # <<<<<<<<<<<<<<
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 */
    __pyx_t_2 = ((__pyx_v_n > 5) != 0);
    if (__pyx_t_2) {

      /* "pyteomics/cparser.pyx":1299
 *             position_type = PositionType.n_term
 *             if n > 5:
 *                 if n > 6:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 */
      __pyx_t_2 = ((__pyx_v_n > 6) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "pyteomics/cparser.pyx":1300
 *             if n > 5:
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))             # <<<<<<<<<<<<<<
 *                 target = string[-1]
 *         else:
 */
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_string);
        __Pyx_GIVEREF(__pyx_v_string);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_string);
        __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Terminal_Modifications_with_Targ, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1300, __pyx_L1_error)

        /* "pyteomics/cparser.pyx":1299
 *             position_type = PositionType.n_term
 *             if n > 5:
 *                 if n > 6:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 */
      }

      /* "pyteomics/cparser.pyx":1301
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]             # <<<<<<<<<<<<<<
 *         else:
 *             if n > 1:
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_string, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(PyString_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 1301, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_target, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "pyteomics/cparser.pyx":1298
 *         elif _is_nterm_mod(string):
 *             position_type = PositionType.n_term
 *             if n > 5:             # <<<<<<<<<<<<<<
 *                 if n > 6:
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 */
    }

    /* "pyteomics/cparser.pyx":1296
 *                     raise ValueError("Terminal Modifications with Target must be a single Amino Acid, got %s" % (string, ))
 *                 target = string[-1]
 *         elif _is_nterm_mod(string):             # <<<<<<<<<<<<<<
 *             position_type = PositionType.n_term
 *             if n > 5:
 */
    goto __pyx_L3;
  }

  /* "pyteomics/cparser.pyx":1303
 *                 target = string[-1]
 *         else:
 *             if n > 1:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Target must be a single Amino Acid, got %s" % (string, ))
 *             target = string
 */
  /*else*/ {
    __pyx_t_2 = ((__pyx_v_n > 1) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "pyteomics/cparser.pyx":1304
 *         else:
 *             if n > 1:
 *                 raise ValueError("Target must be a single Amino Acid, got %s" % (string, ))             # <<<<<<<<<<<<<<
 *             target = string
 *         inst = ModificationTarget._create(target, position_type)
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_string);
      __Pyx_GIVEREF(__pyx_v_string);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_string);
      __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Target_must_be_a_single_Amino_Ac, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1304, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":1303
 *                 target = string[-1]
 *         else:
 *             if n > 1:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Target must be a single Amino Acid, got %s" % (string, ))
 *             target = string
 */
    }

    /* "pyteomics/cparser.pyx":1305
 *             if n > 1:
 *                 raise ValueError("Target must be a single Amino Acid, got %s" % (string, ))
 *             target = string             # <<<<<<<<<<<<<<
 *         inst = ModificationTarget._create(target, position_type)
 *         return inst
 */
    __Pyx_INCREF(__pyx_v_string);
    __Pyx_DECREF_SET(__pyx_v_target, __pyx_v_string);
  }
  __pyx_L3:;

  /* "pyteomics/cparser.pyx":1306
 *                 raise ValueError("Target must be a single Amino Acid, got %s" % (string, ))
 *             target = string
 *         inst = ModificationTarget._create(target, position_type)             # <<<<<<<<<<<<<<
 *         return inst
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_f_9pyteomics_7cparser_18ModificationTarget__create(__pyx_v_target, __pyx_v_position_type)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_inst = ((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyteomics/cparser.pyx":1307
 *             target = string
 *         inst = ModificationTarget._create(target, position_type)
 *         return inst             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_inst));
  __pyx_r = __pyx_v_inst;
  goto __pyx_L0;

  /* "pyteomics/cparser.pyx":1281
 * 
 *     @staticmethod
 *     cdef ModificationTarget _from_string(str string):             # <<<<<<<<<<<<<<
 *         cdef:
 *             PositionType position_type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF((PyObject *)__pyx_v_inst);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1245
 * cdef class ModificationTarget(object):
 *     cdef:
 *         public str target             # <<<<<<<<<<<<<<
 *         public PositionType position_type
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target___get__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->target);
  __pyx_r = __pyx_v_self->target;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_2__set__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 1245, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->target);
  __Pyx_DECREF(__pyx_v_self->target);
  __pyx_v_self->target = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.target.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_4__del__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_6target_4__del__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->target);
  __Pyx_DECREF(__pyx_v_self->target);
  __pyx_v_self->target = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyteomics/cparser.pyx":1246
 *     cdef:
 *         public str target
 *         public PositionType position_type             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, target, position_type=PositionType.internal):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type___get__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type___get__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_self->position_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.position_type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type_2__set__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9pyteomics_7cparser_18ModificationTarget_13position_type_2__set__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_value)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1246, __pyx_L1_error)
  __pyx_v_self->position_type = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.position_type.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_18ModificationTarget_10__reduce_cython__[] = "ModificationTarget.__reduce_cython__(self)";
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_10__reduce_cython__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_10__reduce_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.position_type, self.target)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_v_self->position_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->target);
  __Pyx_GIVEREF(__pyx_v_self->target);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->target);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.position_type, self.target)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":7
 *     state = (self.position_type, self.target)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.target is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.position_type, self.target)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.target is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->target != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.target is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, None), state
 *     else:
 */
  __pyx_t_4 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":13
 *         use_setstate = self.target is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_ModificationTarge); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_94445299);
    __Pyx_GIVEREF(__pyx_int_94445299);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_94445299);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.target is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, None), state
 *     else:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ModificationTarget__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_ModificationTarge); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_94445299);
    __Pyx_GIVEREF(__pyx_int_94445299);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_94445299);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_5 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ModificationTarget__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_18ModificationTarget_12__setstate_cython__[] = "ModificationTarget.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_9pyteomics_7cparser_18ModificationTarget_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9pyteomics_7cparser_18ModificationTarget_12__setstate_cython__(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_18ModificationTarget_12__setstate_cython__(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ModificationTarget__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationTarget__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ModificationTarget, (type(self), 0x5a11ef3, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ModificationTarget__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyteomics.cparser.ModificationTarget.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9pyteomics_7cparser_16generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pyteomics/cparser.pyx":1310
 * 
 * 
 * def isoforms(str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *     cdef:
 *         IsoformGenerator isoform_generator
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_15isoforms(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_14isoforms[] = "isoforms(str sequence, **kwargs)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_15isoforms = {"isoforms", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_15isoforms, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_14isoforms};
static PyObject *__pyx_pw_9pyteomics_7cparser_15isoforms(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_kwargs = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isoforms (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, pos_args, "isoforms") < 0)) __PYX_ERR(0, 1310, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_sequence = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isoforms", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1310, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_CLEAR(__pyx_v_kwargs);
  __Pyx_AddTraceback("pyteomics.cparser.isoforms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sequence), (&PyString_Type), 1, "sequence", 1))) __PYX_ERR(0, 1310, __pyx_L1_error)
  __pyx_r = __pyx_pf_9pyteomics_7cparser_14isoforms(__pyx_self, __pyx_v_sequence, __pyx_v_kwargs);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_14isoforms(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sequence, PyObject *__pyx_v_kwargs) {
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isoforms", 0);
  __pyx_cur_scope = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct_1_isoforms(__pyx_ptype_9pyteomics_7cparser___pyx_scope_struct_1_isoforms, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1310, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_sequence = __pyx_v_sequence;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sequence);
  __pyx_cur_scope->__pyx_v_kwargs = __pyx_v_kwargs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_kwargs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_kwargs);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9pyteomics_7cparser_16generator1, __pyx_codeobj__5, (PyObject *) __pyx_cur_scope, __pyx_n_s_isoforms, __pyx_n_s_isoforms, __pyx_n_s_pyteomics_cparser); if (unlikely(!gen)) __PYX_ERR(0, 1310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyteomics.cparser.isoforms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9pyteomics_7cparser_16generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *__pyx_cur_scope = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  struct __pyx_opt_args_9pyteomics_7cparser__sequence_tostring __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isoforms", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    case 2: goto __pyx_L10_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1310, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1316
 *         object gen
 * 
 *     variable_mods = kwargs.get("variable_mods", None)             # <<<<<<<<<<<<<<
 *     fixed_mods = kwargs.get("fixed_mods", None)
 *     labels = kwargs.get("labels", None)
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_variable_mods, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_variable_mods = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1317
 * 
 *     variable_mods = kwargs.get("variable_mods", None)
 *     fixed_mods = kwargs.get("fixed_mods", None)             # <<<<<<<<<<<<<<
 *     labels = kwargs.get("labels", None)
 *     max_mods = kwargs.get("max_mods", None)
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_fixed_mods, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_fixed_mods = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1318
 *     variable_mods = kwargs.get("variable_mods", None)
 *     fixed_mods = kwargs.get("fixed_mods", None)
 *     labels = kwargs.get("labels", None)             # <<<<<<<<<<<<<<
 *     max_mods = kwargs.get("max_mods", None)
 *     override = kwargs.get("override", False)
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_labels, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_labels = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1319
 *     fixed_mods = kwargs.get("fixed_mods", None)
 *     labels = kwargs.get("labels", None)
 *     max_mods = kwargs.get("max_mods", None)             # <<<<<<<<<<<<<<
 *     override = kwargs.get("override", False)
 *     show_unmodified_termini = kwargs.get("show_unmodified_termini", False)
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_max_mods, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_max_mods = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1320
 *     labels = kwargs.get("labels", None)
 *     max_mods = kwargs.get("max_mods", None)
 *     override = kwargs.get("override", False)             # <<<<<<<<<<<<<<
 *     show_unmodified_termini = kwargs.get("show_unmodified_termini", False)
 *     _format = kwargs.get("format", "str")
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_override, Py_False); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_override = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1321
 *     max_mods = kwargs.get("max_mods", None)
 *     override = kwargs.get("override", False)
 *     show_unmodified_termini = kwargs.get("show_unmodified_termini", False)             # <<<<<<<<<<<<<<
 *     _format = kwargs.get("format", "str")
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_show_unmodified_termini, Py_False); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_show_unmodified_termini = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1322
 *     override = kwargs.get("override", False)
 *     show_unmodified_termini = kwargs.get("show_unmodified_termini", False)
 *     _format = kwargs.get("format", "str")             # <<<<<<<<<<<<<<
 * 
 *     isoform_generator = IsoformGenerator(
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_kwargs, __pyx_n_s_format, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v__format = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1325
 * 
 *     isoform_generator = IsoformGenerator(
 *         variable_mods=variable_mods,             # <<<<<<<<<<<<<<
 *         fixed_mods=fixed_mods,
 *         labels=labels,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_variable_mods, __pyx_cur_scope->__pyx_v_variable_mods) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1326
 *     isoform_generator = IsoformGenerator(
 *         variable_mods=variable_mods,
 *         fixed_mods=fixed_mods,             # <<<<<<<<<<<<<<
 *         labels=labels,
 *         max_mods=max_mods,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fixed_mods, __pyx_cur_scope->__pyx_v_fixed_mods) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1327
 *         variable_mods=variable_mods,
 *         fixed_mods=fixed_mods,
 *         labels=labels,             # <<<<<<<<<<<<<<
 *         max_mods=max_mods,
 *         override=override,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_labels, __pyx_cur_scope->__pyx_v_labels) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1328
 *         fixed_mods=fixed_mods,
 *         labels=labels,
 *         max_mods=max_mods,             # <<<<<<<<<<<<<<
 *         override=override,
 *         show_unmodified_termini=show_unmodified_termini)
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_max_mods, __pyx_cur_scope->__pyx_v_max_mods) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1329
 *         labels=labels,
 *         max_mods=max_mods,
 *         override=override,             # <<<<<<<<<<<<<<
 *         show_unmodified_termini=show_unmodified_termini)
 *     gen = isoform_generator.generate(sequence)
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_override, __pyx_cur_scope->__pyx_v_override) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1330
 *         max_mods=max_mods,
 *         override=override,
 *         show_unmodified_termini=show_unmodified_termini)             # <<<<<<<<<<<<<<
 *     gen = isoform_generator.generate(sequence)
 *     if _format == "str":
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_show_unmodified_termini, __pyx_cur_scope->__pyx_v_show_unmodified_termini) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1324
 *     _format = kwargs.get("format", "str")
 * 
 *     isoform_generator = IsoformGenerator(             # <<<<<<<<<<<<<<
 *         variable_mods=variable_mods,
 *         fixed_mods=fixed_mods,
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_9pyteomics_7cparser_IsoformGenerator), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_isoform_generator = ((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1331
 *         override=override,
 *         show_unmodified_termini=show_unmodified_termini)
 *     gen = isoform_generator.generate(sequence)             # <<<<<<<<<<<<<<
 *     if _format == "str":
 *         for form in gen:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_isoform_generator), __pyx_n_s_generate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_cur_scope->__pyx_v_sequence) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_cur_scope->__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_gen = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1332
 *         show_unmodified_termini=show_unmodified_termini)
 *     gen = isoform_generator.generate(sequence)
 *     if _format == "str":             # <<<<<<<<<<<<<<
 *         for form in gen:
 *             yield _sequence_tostring(
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_cur_scope->__pyx_v__format, __pyx_n_s_str, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "pyteomics/cparser.pyx":1333
 *     gen = isoform_generator.generate(sequence)
 *     if _format == "str":
 *         for form in gen:             # <<<<<<<<<<<<<<
 *             yield _sequence_tostring(
 *                 form, show_unmodified_termini=show_unmodified_termini)
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_gen)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_gen)) {
      __pyx_t_2 = __pyx_cur_scope->__pyx_v_gen; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1333, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1333, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1333, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1333, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1333, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1333, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1333, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_form);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_form, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1335
 *         for form in gen:
 *             yield _sequence_tostring(
 *                 form, show_unmodified_termini=show_unmodified_termini)             # <<<<<<<<<<<<<<
 *     elif _format == "split":
 *         for form in gen:
 */
      if (!(likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_form))||((__pyx_cur_scope->__pyx_v_form) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_cur_scope->__pyx_v_form)->tp_name), 0))) __PYX_ERR(0, 1335, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_show_unmodified_termini); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1335, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":1334
 *     if _format == "str":
 *         for form in gen:
 *             yield _sequence_tostring(             # <<<<<<<<<<<<<<
 *                 form, show_unmodified_termini=show_unmodified_termini)
 *     elif _format == "split":
 */
      __pyx_t_8.__pyx_n = 1;
      __pyx_t_8.show_unmodified_termini = __pyx_t_5;
      __pyx_t_1 = __pyx_f_9pyteomics_7cparser__sequence_tostring(((PyObject*)__pyx_cur_scope->__pyx_v_form), 0, &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      __Pyx_XGIVEREF(__pyx_t_2);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_6;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_7;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_6 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_7 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1334, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":1333
 *     gen = isoform_generator.generate(sequence)
 *     if _format == "str":
 *         for form in gen:             # <<<<<<<<<<<<<<
 *             yield _sequence_tostring(
 *                 form, show_unmodified_termini=show_unmodified_termini)
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1332
 *         show_unmodified_termini=show_unmodified_termini)
 *     gen = isoform_generator.generate(sequence)
 *     if _format == "str":             # <<<<<<<<<<<<<<
 *         for form in gen:
 *             yield _sequence_tostring(
 */
    goto __pyx_L4;
  }

  /* "pyteomics/cparser.pyx":1336
 *             yield _sequence_tostring(
 *                 form, show_unmodified_termini=show_unmodified_termini)
 *     elif _format == "split":             # <<<<<<<<<<<<<<
 *         for form in gen:
 *             yield form
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_cur_scope->__pyx_v__format, __pyx_n_s_split, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1336, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_5 != 0);
  if (likely(__pyx_t_4)) {

    /* "pyteomics/cparser.pyx":1337
 *                 form, show_unmodified_termini=show_unmodified_termini)
 *     elif _format == "split":
 *         for form in gen:             # <<<<<<<<<<<<<<
 *             yield form
 *     else:
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_gen)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_gen)) {
      __pyx_t_2 = __pyx_cur_scope->__pyx_v_gen; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1337, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1337, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1337, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1337, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1337, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1337, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_form);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_form, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyteomics/cparser.pyx":1338
 *     elif _format == "split":
 *         for form in gen:
 *             yield form             # <<<<<<<<<<<<<<
 *     else:
 *         raise PyteomicsError('Unsupported value of "format": {}'.format(_format))
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_form);
      __pyx_r = __pyx_cur_scope->__pyx_v_form;
      __Pyx_XGIVEREF(__pyx_t_2);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_6;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_7;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L10_resume_from_yield:;
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_6 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_7 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1338, __pyx_L1_error)

      /* "pyteomics/cparser.pyx":1337
 *                 form, show_unmodified_termini=show_unmodified_termini)
 *     elif _format == "split":
 *         for form in gen:             # <<<<<<<<<<<<<<
 *             yield form
 *     else:
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyteomics/cparser.pyx":1336
 *             yield _sequence_tostring(
 *                 form, show_unmodified_termini=show_unmodified_termini)
 *     elif _format == "split":             # <<<<<<<<<<<<<<
 *         for form in gen:
 *             yield form
 */
    goto __pyx_L4;
  }

  /* "pyteomics/cparser.pyx":1340
 *             yield form
 *     else:
 *         raise PyteomicsError('Unsupported value of "format": {}'.format(_format))             # <<<<<<<<<<<<<<
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Unsupported_value_of_format, __pyx_n_s_format); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_10, __pyx_cur_scope->__pyx_v__format) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_cur_scope->__pyx_v__format);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_9, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1340, __pyx_L1_error)
  }
  __pyx_L4:;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "pyteomics/cparser.pyx":1310
 * 
 * 
 * def isoforms(str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *     cdef:
 *         IsoformGenerator isoform_generator
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("isoforms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_SequencePosition(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_18__pyx_unpickle_SequencePosition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_17__pyx_unpickle_SequencePosition[] = "__pyx_unpickle_SequencePosition(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_18__pyx_unpickle_SequencePosition = {"__pyx_unpickle_SequencePosition", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_18__pyx_unpickle_SequencePosition, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_17__pyx_unpickle_SequencePosition};
static PyObject *__pyx_pw_9pyteomics_7cparser_18__pyx_unpickle_SequencePosition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_SequencePosition (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SequencePosition", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SequencePosition", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_SequencePosition") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SequencePosition", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_SequencePosition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_17__pyx_unpickle_SequencePosition(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_17__pyx_unpickle_SequencePosition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_SequencePosition", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x96edc61:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x96edc61) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x96edc61:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 *     __pyx_result = SequencePosition.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x96edc61:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = SequencePosition.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x96, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x96edc61:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 *     __pyx_result = SequencePosition.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 *     __pyx_result = SequencePosition.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = SequencePosition.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_SequencePosition__set_state(((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x96edc61 = (amino_acid, modification, position_type, terminal))" % __pyx_checksum)
 *     __pyx_result = SequencePosition.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_SequencePosition(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_SequencePosition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_SequencePosition__set_state(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_SequencePosition__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->amino_acid);
  __Pyx_DECREF(__pyx_v___pyx_result->amino_acid);
  __pyx_v___pyx_result->amino_acid = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->modification);
  __Pyx_DECREF(__pyx_v___pyx_result->modification);
  __pyx_v___pyx_result->modification = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->position_type = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->terminal);
  __Pyx_DECREF(__pyx_v___pyx_result->terminal);
  __pyx_v___pyx_result->terminal = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 4) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_SequencePosition__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_IsoformGenerator(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_20__pyx_unpickle_IsoformGenerator(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_19__pyx_unpickle_IsoformGenerator[] = "__pyx_unpickle_IsoformGenerator(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_20__pyx_unpickle_IsoformGenerator = {"__pyx_unpickle_IsoformGenerator", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_20__pyx_unpickle_IsoformGenerator, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_19__pyx_unpickle_IsoformGenerator};
static PyObject *__pyx_pw_9pyteomics_7cparser_20__pyx_unpickle_IsoformGenerator(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_IsoformGenerator (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_IsoformGenerator", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_IsoformGenerator", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_IsoformGenerator") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_IsoformGenerator", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_IsoformGenerator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_19__pyx_unpickle_IsoformGenerator(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_19__pyx_unpickle_IsoformGenerator(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_IsoformGenerator", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x2fc4213:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x2fc4213) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x2fc4213:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x2fc4213:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x2f, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x2fc4213:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_IsoformGenerator), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_IsoformGenerator__set_state(((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x2fc4213 = (fixed_mods, labels, last_indices, max_mods, original_sequence, override, persist, sequence, show_unmodified_termini, variable_mods))" % __pyx_checksum)
 *     __pyx_result = IsoformGenerator.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_IsoformGenerator(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_IsoformGenerator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_IsoformGenerator__set_state(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_IsoformGenerator__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->fixed_mods);
  __Pyx_DECREF(__pyx_v___pyx_result->fixed_mods);
  __pyx_v___pyx_result->fixed_mods = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->labels);
  __Pyx_DECREF(__pyx_v___pyx_result->labels);
  __pyx_v___pyx_result->labels = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->last_indices);
  __Pyx_DECREF(__pyx_v___pyx_result->last_indices);
  __pyx_v___pyx_result->last_indices = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_long(__pyx_t_1); if (unlikely((__pyx_t_2 == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->max_mods = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->original_sequence);
  __Pyx_DECREF(__pyx_v___pyx_result->original_sequence);
  __pyx_v___pyx_result->original_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->override = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->persist = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->sequence);
  __Pyx_DECREF(__pyx_v___pyx_result->sequence);
  __pyx_v___pyx_result->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->show_unmodified_termini = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->variable_mods);
  __Pyx_DECREF(__pyx_v___pyx_result->variable_mods);
  __pyx_v___pyx_result->variable_mods = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 10) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_IsoformGenerator__set_state(<IsoformGenerator> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_IsoformGenerator__set_state(IsoformGenerator __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.fixed_mods = __pyx_state[0]; __pyx_result.labels = __pyx_state[1]; __pyx_result.last_indices = __pyx_state[2]; __pyx_result.max_mods = __pyx_state[3]; __pyx_result.original_sequence = __pyx_state[4]; __pyx_result.override = __pyx_state[5]; __pyx_result.persist = __pyx_state[6]; __pyx_result.sequence = __pyx_state[7]; __pyx_result.show_unmodified_termini = __pyx_state[8]; __pyx_result.variable_mods = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_IsoformGenerator__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ModificationRule(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_22__pyx_unpickle_ModificationRule(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_21__pyx_unpickle_ModificationRule[] = "__pyx_unpickle_ModificationRule(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_22__pyx_unpickle_ModificationRule = {"__pyx_unpickle_ModificationRule", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_22__pyx_unpickle_ModificationRule, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_21__pyx_unpickle_ModificationRule};
static PyObject *__pyx_pw_9pyteomics_7cparser_22__pyx_unpickle_ModificationRule(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationRule (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationRule", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationRule", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ModificationRule") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationRule", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationRule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_21__pyx_unpickle_ModificationRule(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_21__pyx_unpickle_ModificationRule(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationRule", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xc83ff59:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xc83ff59) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xc83ff59:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 *     __pyx_result = ModificationRule.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xc83ff59:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ModificationRule.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xc8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xc83ff59:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 *     __pyx_result = ModificationRule.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationRule), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 *     __pyx_result = ModificationRule.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ModificationRule.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationRule__set_state(((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xc83ff59 = (modification, targets))" % __pyx_checksum)
 *     __pyx_result = ModificationRule.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ModificationRule(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationRule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationRule__set_state(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationRule__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->modification);
  __Pyx_DECREF(__pyx_v___pyx_result->modification);
  __pyx_v___pyx_result->modification = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->targets);
  __Pyx_DECREF(__pyx_v___pyx_result->targets);
  __pyx_v___pyx_result->targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationRule__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ModificationTarget(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9pyteomics_7cparser_24__pyx_unpickle_ModificationTarget(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9pyteomics_7cparser_23__pyx_unpickle_ModificationTarget[] = "__pyx_unpickle_ModificationTarget(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_9pyteomics_7cparser_24__pyx_unpickle_ModificationTarget = {"__pyx_unpickle_ModificationTarget", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_24__pyx_unpickle_ModificationTarget, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_23__pyx_unpickle_ModificationTarget};
static PyObject *__pyx_pw_9pyteomics_7cparser_24__pyx_unpickle_ModificationTarget(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationTarget (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationTarget", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationTarget", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ModificationTarget") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ModificationTarget", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationTarget", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9pyteomics_7cparser_23__pyx_unpickle_ModificationTarget(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9pyteomics_7cparser_23__pyx_unpickle_ModificationTarget(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationTarget", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x5a11ef3:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x5a11ef3) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x5a11ef3:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x5a11ef3:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x5a, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x5a11ef3:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationTarget), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationTarget__set_state(((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5a11ef3 = (position_type, target))" % __pyx_checksum)
 *     __pyx_result = ModificationTarget.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ModificationTarget(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationTarget", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_9pyteomics_7cparser___pyx_unpickle_ModificationTarget__set_state(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  enum __pyx_t_9pyteomics_7cparser_PositionType __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ModificationTarget__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((enum __pyx_t_9pyteomics_7cparser_PositionType)__Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->position_type = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->target);
  __Pyx_DECREF(__pyx_v___pyx_result->target);
  __pyx_v___pyx_result->target = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 2) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ModificationTarget__set_state(<ModificationTarget> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationTarget__set_state(ModificationTarget __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.position_type = __pyx_state[0]; __pyx_result.target = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyteomics.cparser.__pyx_unpickle_ModificationTarget__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

/* Python wrapper */
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_parents = 0;
  PyObject *__pyx_v_dct = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_parents,&__pyx_n_s_dct,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parents)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(1, 16, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dct)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(1, 16, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_parents = values[1];
    __pyx_v_dct = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "EnumBase":17
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)             # <<<<<<<<<<<<<<
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyType_Type)), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_cls));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_cls));
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, ((PyObject *)__pyx_v_cls));
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_parents);
    __Pyx_GIVEREF(__pyx_v_parents);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_v_parents);
    __Pyx_INCREF(__pyx_v_dct);
    __Pyx_GIVEREF(__pyx_v_dct);
    PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_4, __pyx_v_dct);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":18
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()             # <<<<<<<<<<<<<<
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 */
  __Pyx_INCREF(__Pyx_OrderedDict);
  __pyx_t_2 = __Pyx_OrderedDict; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members, __pyx_t_1) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "EnumBase":20
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())             # <<<<<<<<<<<<<<
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_values); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "EnumBase":22
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle___Pyx_EnumMeta__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__ = {"__new__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_value,&__pyx_n_s_name,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, 1); __PYX_ERR(1, 28, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__new__") < 0)) __PYX_ERR(1, 28, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_value = values[1];
    __pyx_v_name = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 28, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(__pyx_self, __pyx_v_cls, __pyx_v_value, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  if (likely(PyList_CheckExact(__pyx_v_cls)) || PyTuple_CheckExact(__pyx_v_cls)) {
    __pyx_t_1 = __pyx_v_cls; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_cls); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 29, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 29, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_v, __pyx_v_value, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 30, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(1, 30, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {

      /* "EnumBase":31
 *         for v in cls:
 *             if v == value:
 *                 return v             # <<<<<<<<<<<<<<
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_v);
      __pyx_r = __pyx_v_v;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    }

    /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  __pyx_t_5 = (__pyx_v_name == Py_None);
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (unlikely(__pyx_t_6)) {

    /* "EnumBase":33
 *                 return v
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)             # <<<<<<<<<<<<<<
 *         res = int.__new__(cls, value)
 *         res.name = name
 */
    __pyx_t_1 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Unknown_enum_value_s, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(1, 33, __pyx_L1_error)

    /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  }

  /* "EnumBase":34
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)             # <<<<<<<<<<<<<<
 *         res.name = name
 *         setattr(cls, name, res)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyInt_Type)), __pyx_n_s_new); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cls);
    __Pyx_GIVEREF(__pyx_v_cls);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_cls);
    __Pyx_INCREF(__pyx_v_value);
    __Pyx_GIVEREF(__pyx_v_value);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_value);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "EnumBase":35
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 *         res.name = name             # <<<<<<<<<<<<<<
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_res, __pyx_n_s_name, __pyx_v_name) < 0) __PYX_ERR(1, 35, __pyx_L1_error)

  /* "EnumBase":36
 *         res = int.__new__(cls, value)
 *         res.name = name
 *         setattr(cls, name, res)             # <<<<<<<<<<<<<<
 *         cls.__members__[name] = res
 *         return res
 */
  __pyx_t_10 = PyObject_SetAttr(__pyx_v_cls, __pyx_v_name, __pyx_v_res); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 36, __pyx_L1_error)

  /* "EnumBase":37
 *         res.name = name
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res             # <<<<<<<<<<<<<<
 *         return res
 *     def __repr__(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_members); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_v_name, __pyx_v_res) < 0)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "EnumBase":38
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 *         return res             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "EnumBase":40
 *         return res
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s_d, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__ = {"__str__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "EnumBase":42
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)             # <<<<<<<<<<<<<<
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta = {"__pyx_unpickle___Pyx_EnumMeta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle___Pyx_EnumMeta") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xd41d8cd) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype___Pyx_EnumMeta), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_unpickle___Pyx_EnumMeta__set_state(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_9pyteomics_7cparser_SequencePosition __pyx_vtable_9pyteomics_7cparser_SequencePosition;

static struct __pyx_obj_9pyteomics_7cparser_SequencePosition *__pyx_freelist_9pyteomics_7cparser_SequencePosition[5000];
static int __pyx_freecount_9pyteomics_7cparser_SequencePosition = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser_SequencePosition(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser_SequencePosition > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_SequencePosition)))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser_SequencePosition[--__pyx_freecount_9pyteomics_7cparser_SequencePosition];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser_SequencePosition));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)o);
  p->__pyx_vtab = __pyx_vtabptr_9pyteomics_7cparser_SequencePosition;
  p->modification = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->amino_acid = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->terminal = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser_SequencePosition(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser_SequencePosition *p = (struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)o;
  Py_CLEAR(p->modification);
  Py_CLEAR(p->amino_acid);
  Py_CLEAR(p->terminal);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser_SequencePosition < 5000) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_SequencePosition)))) {
    __pyx_freelist_9pyteomics_7cparser_SequencePosition[__pyx_freecount_9pyteomics_7cparser_SequencePosition++] = ((struct __pyx_obj_9pyteomics_7cparser_SequencePosition *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}
static PyObject *__pyx_sq_item_9pyteomics_7cparser_SequencePosition(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_tp_richcompare_9pyteomics_7cparser_SequencePosition(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_9pyteomics_7cparser_16SequencePosition_21__eq__(o1, o2);
    }
    case Py_NE: {
      return __pyx_pw_9pyteomics_7cparser_16SequencePosition_23__ne__(o1, o2);
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16SequencePosition_modification(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16SequencePosition_modification(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_12modification_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16SequencePosition_position_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16SequencePosition_position_type(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_13position_type_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16SequencePosition_amino_acid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16SequencePosition_amino_acid(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_10amino_acid_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16SequencePosition_terminal(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16SequencePosition_terminal(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16SequencePosition_8terminal_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_9pyteomics_7cparser_SequencePosition[] = {
  {"get_index", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_5get_index, METH_O, __pyx_doc_9pyteomics_7cparser_16SequencePosition_4get_index},
  {"add_modification", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_7add_modification, METH_O, __pyx_doc_9pyteomics_7cparser_16SequencePosition_6add_modification},
  {"as_tuple", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_13as_tuple, METH_NOARGS, __pyx_doc_9pyteomics_7cparser_16SequencePosition_12as_tuple},
  {"from_tuple", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_15from_tuple, METH_O, __pyx_doc_9pyteomics_7cparser_16SequencePosition_14from_tuple},
  {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_16SequencePosition_17parse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_16SequencePosition_16parse},
  {"from_iterable", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_19from_iterable, METH_O, __pyx_doc_9pyteomics_7cparser_16SequencePosition_18from_iterable},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_25__reduce_cython__, METH_NOARGS, __pyx_doc_9pyteomics_7cparser_16SequencePosition_24__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16SequencePosition_27__setstate_cython__, METH_O, __pyx_doc_9pyteomics_7cparser_16SequencePosition_26__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9pyteomics_7cparser_SequencePosition[] = {
  {(char *)"modification", __pyx_getprop_9pyteomics_7cparser_16SequencePosition_modification, __pyx_setprop_9pyteomics_7cparser_16SequencePosition_modification, (char *)"modification: str", 0},
  {(char *)"position_type", __pyx_getprop_9pyteomics_7cparser_16SequencePosition_position_type, __pyx_setprop_9pyteomics_7cparser_16SequencePosition_position_type, (char *)"position_type: 'PositionType'", 0},
  {(char *)"amino_acid", __pyx_getprop_9pyteomics_7cparser_16SequencePosition_amino_acid, __pyx_setprop_9pyteomics_7cparser_16SequencePosition_amino_acid, (char *)"amino_acid: str", 0},
  {(char *)"terminal", __pyx_getprop_9pyteomics_7cparser_16SequencePosition_terminal, __pyx_setprop_9pyteomics_7cparser_16SequencePosition_terminal, (char *)"terminal: str", 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_SequencePosition = {
  __pyx_pw_9pyteomics_7cparser_16SequencePosition_11__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_9pyteomics_7cparser_SequencePosition, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_SequencePosition = {
  __pyx_pw_9pyteomics_7cparser_16SequencePosition_11__len__, /*mp_length*/
  __pyx_pw_9pyteomics_7cparser_16SequencePosition_3__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_9pyteomics_7cparser_SequencePosition = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.SequencePosition", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser_SequencePosition), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser_SequencePosition, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_9pyteomics_7cparser_16SequencePosition_9__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_SequencePosition, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_SequencePosition, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  "SequencePosition(amino_acid, modification=None, terminal=None, position_type=None)", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  __pyx_tp_richcompare_9pyteomics_7cparser_SequencePosition, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9pyteomics_7cparser_SequencePosition, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9pyteomics_7cparser_SequencePosition, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_9pyteomics_7cparser_16SequencePosition_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser_SequencePosition, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_IsoformGenerator __pyx_vtable_9pyteomics_7cparser_IsoformGenerator;

static struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *__pyx_freelist_9pyteomics_7cparser_IsoformGenerator[100];
static int __pyx_freecount_9pyteomics_7cparser_IsoformGenerator = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser_IsoformGenerator(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser_IsoformGenerator > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser_IsoformGenerator[--__pyx_freecount_9pyteomics_7cparser_IsoformGenerator];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)o);
  p->__pyx_vtab = __pyx_vtabptr_9pyteomics_7cparser_IsoformGenerator;
  p->variable_mods = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->fixed_mods = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->labels = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->original_sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->last_indices = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser_IsoformGenerator(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *p = (struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->variable_mods);
  Py_CLEAR(p->fixed_mods);
  Py_CLEAR(p->labels);
  Py_CLEAR(p->sequence);
  Py_CLEAR(p->original_sequence);
  Py_CLEAR(p->last_indices);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser_IsoformGenerator < 100) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_9pyteomics_7cparser_IsoformGenerator[__pyx_freecount_9pyteomics_7cparser_IsoformGenerator++] = ((struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9pyteomics_7cparser_IsoformGenerator(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *p = (struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)o;
  if (p->variable_mods) {
    e = (*v)(p->variable_mods, a); if (e) return e;
  }
  if (p->fixed_mods) {
    e = (*v)(p->fixed_mods, a); if (e) return e;
  }
  if (p->labels) {
    e = (*v)(p->labels, a); if (e) return e;
  }
  if (p->sequence) {
    e = (*v)(p->sequence, a); if (e) return e;
  }
  if (p->original_sequence) {
    e = (*v)(p->original_sequence, a); if (e) return e;
  }
  if (p->last_indices) {
    e = (*v)(p->last_indices, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9pyteomics_7cparser_IsoformGenerator(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *p = (struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *)o;
  tmp = ((PyObject*)p->variable_mods);
  p->variable_mods = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->fixed_mods);
  p->fixed_mods = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->labels);
  p->labels = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->original_sequence);
  p->original_sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->last_indices);
  p->last_indices = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_variable_mods(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_variable_mods(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13variable_mods_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_fixed_mods(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_fixed_mods(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_10fixed_mods_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_labels(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_labels(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_6labels_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_max_mods(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_max_mods(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8max_mods_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_override(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_override(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8override_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_show_unmodified_termini(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_show_unmodified_termini(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_23show_unmodified_termini_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_persist(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_persist(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7persist_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_8sequence_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_original_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_original_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_17original_sequence_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_last_indices(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_last_indices(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_12last_indices_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_9pyteomics_7cparser_IsoformGenerator[] = {
  {"coerce_modification_dict", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_3coerce_modification_dict, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_2coerce_modification_dict},
  {"initialize_from_str", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_5initialize_from_str, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_4initialize_from_str},
  {"initialize_from_iterable", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_7initialize_from_iterable, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_6initialize_from_iterable},
  {"apply_fixed_mods", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_9apply_fixed_mods, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_8apply_fixed_mods},
  {"build_site_map", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_11build_site_map, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_10build_site_map},
  {"generate", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_13generate, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_12generate},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_18__reduce_cython__, METH_NOARGS, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_17__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16IsoformGenerator_20__setstate_cython__, METH_O, __pyx_doc_9pyteomics_7cparser_16IsoformGenerator_19__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9pyteomics_7cparser_IsoformGenerator[] = {
  {(char *)"variable_mods", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_variable_mods, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_variable_mods, (char *)"variable_mods: dict", 0},
  {(char *)"fixed_mods", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_fixed_mods, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_fixed_mods, (char *)"fixed_mods: dict", 0},
  {(char *)"labels", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_labels, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_labels, (char *)"labels: list", 0},
  {(char *)"max_mods", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_max_mods, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_max_mods, (char *)"max_mods: 'long'", 0},
  {(char *)"override", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_override, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_override, (char *)"override: 'bool'", 0},
  {(char *)"show_unmodified_termini", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_show_unmodified_termini, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_show_unmodified_termini, (char *)"show_unmodified_termini: 'bool'", 0},
  {(char *)"persist", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_persist, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_persist, (char *)"persist: 'bool'", 0},
  {(char *)"sequence", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_sequence, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_sequence, (char *)"sequence: list", 0},
  {(char *)"original_sequence", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_original_sequence, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_original_sequence, (char *)"original_sequence: list", 0},
  {(char *)"last_indices", __pyx_getprop_9pyteomics_7cparser_16IsoformGenerator_last_indices, __pyx_setprop_9pyteomics_7cparser_16IsoformGenerator_last_indices, (char *)"last_indices: list", 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_9pyteomics_7cparser_IsoformGenerator = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.IsoformGenerator", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser_IsoformGenerator, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_16__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "IsoformGenerator(variable_mods=None, fixed_mods=None, labels=None, max_mods=None, override=False, show_unmodified_termini=False, persist=True)", /*tp_doc*/
  __pyx_tp_traverse_9pyteomics_7cparser_IsoformGenerator, /*tp_traverse*/
  __pyx_tp_clear_9pyteomics_7cparser_IsoformGenerator, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9pyteomics_7cparser_IsoformGenerator, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9pyteomics_7cparser_IsoformGenerator, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_9pyteomics_7cparser_16IsoformGenerator_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser_IsoformGenerator, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationRule __pyx_vtable_9pyteomics_7cparser_ModificationRule;

static struct __pyx_obj_9pyteomics_7cparser_ModificationRule *__pyx_freelist_9pyteomics_7cparser_ModificationRule[100];
static int __pyx_freecount_9pyteomics_7cparser_ModificationRule = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser_ModificationRule(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser_ModificationRule > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationRule)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser_ModificationRule[--__pyx_freecount_9pyteomics_7cparser_ModificationRule];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationRule));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)o);
  p->__pyx_vtab = __pyx_vtabptr_9pyteomics_7cparser_ModificationRule;
  p->modification = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->targets = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser_ModificationRule(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *p = (struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->modification);
  Py_CLEAR(p->targets);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser_ModificationRule < 100) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationRule)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_9pyteomics_7cparser_ModificationRule[__pyx_freecount_9pyteomics_7cparser_ModificationRule++] = ((struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9pyteomics_7cparser_ModificationRule(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *p = (struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)o;
  if (p->targets) {
    e = (*v)(p->targets, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9pyteomics_7cparser_ModificationRule(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9pyteomics_7cparser_ModificationRule *p = (struct __pyx_obj_9pyteomics_7cparser_ModificationRule *)o;
  tmp = ((PyObject*)p->targets);
  p->targets = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16ModificationRule_modification(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16ModificationRule_modification(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16ModificationRule_12modification_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_16ModificationRule_targets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_16ModificationRule_targets(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_16ModificationRule_7targets_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_9pyteomics_7cparser_ModificationRule[] = {
  {"test", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16ModificationRule_3test, METH_O, __pyx_doc_9pyteomics_7cparser_16ModificationRule_2test},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16ModificationRule_9__reduce_cython__, METH_NOARGS, __pyx_doc_9pyteomics_7cparser_16ModificationRule_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_16ModificationRule_11__setstate_cython__, METH_O, __pyx_doc_9pyteomics_7cparser_16ModificationRule_10__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9pyteomics_7cparser_ModificationRule[] = {
  {(char *)"modification", __pyx_getprop_9pyteomics_7cparser_16ModificationRule_modification, __pyx_setprop_9pyteomics_7cparser_16ModificationRule_modification, (char *)"modification: str", 0},
  {(char *)"targets", __pyx_getprop_9pyteomics_7cparser_16ModificationRule_targets, __pyx_setprop_9pyteomics_7cparser_16ModificationRule_targets, (char *)"targets: list", 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_9pyteomics_7cparser_ModificationRule = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.ModificationRule", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationRule), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser_ModificationRule, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_9pyteomics_7cparser_16ModificationRule_7__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_9pyteomics_7cparser_16ModificationRule_5__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "ModificationRule(str label, targets)", /*tp_doc*/
  __pyx_tp_traverse_9pyteomics_7cparser_ModificationRule, /*tp_traverse*/
  __pyx_tp_clear_9pyteomics_7cparser_ModificationRule, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9pyteomics_7cparser_ModificationRule, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9pyteomics_7cparser_ModificationRule, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_9pyteomics_7cparser_16ModificationRule_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser_ModificationRule, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_9pyteomics_7cparser_ModificationTarget __pyx_vtable_9pyteomics_7cparser_ModificationTarget;

static struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *__pyx_freelist_9pyteomics_7cparser_ModificationTarget[1000];
static int __pyx_freecount_9pyteomics_7cparser_ModificationTarget = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser_ModificationTarget(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser_ModificationTarget > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser_ModificationTarget[--__pyx_freecount_9pyteomics_7cparser_ModificationTarget];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget));
    (void) PyObject_INIT(o, t);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)o);
  p->__pyx_vtab = __pyx_vtabptr_9pyteomics_7cparser_ModificationTarget;
  p->target = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser_ModificationTarget(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *p = (struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  Py_CLEAR(p->target);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser_ModificationTarget < 1000) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_9pyteomics_7cparser_ModificationTarget[__pyx_freecount_9pyteomics_7cparser_ModificationTarget++] = ((struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_18ModificationTarget_target(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_18ModificationTarget_target(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_3__set__(o, v);
  }
  else {
    return __pyx_pw_9pyteomics_7cparser_18ModificationTarget_6target_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9pyteomics_7cparser_18ModificationTarget_position_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_1__get__(o);
}

static int __pyx_setprop_9pyteomics_7cparser_18ModificationTarget_position_type(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9pyteomics_7cparser_18ModificationTarget_13position_type_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_9pyteomics_7cparser_ModificationTarget[] = {
  {"test", (PyCFunction)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_3test, METH_O, __pyx_doc_9pyteomics_7cparser_18ModificationTarget_2test},
  {"from_string", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_9from_string, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_18ModificationTarget_8from_string},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_11__reduce_cython__, METH_NOARGS, __pyx_doc_9pyteomics_7cparser_18ModificationTarget_10__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9pyteomics_7cparser_18ModificationTarget_13__setstate_cython__, METH_O, __pyx_doc_9pyteomics_7cparser_18ModificationTarget_12__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9pyteomics_7cparser_ModificationTarget[] = {
  {(char *)"target", __pyx_getprop_9pyteomics_7cparser_18ModificationTarget_target, __pyx_setprop_9pyteomics_7cparser_18ModificationTarget_target, (char *)"target: str", 0},
  {(char *)"position_type", __pyx_getprop_9pyteomics_7cparser_18ModificationTarget_position_type, __pyx_setprop_9pyteomics_7cparser_18ModificationTarget_position_type, (char *)"position_type: 'PositionType'", 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_9pyteomics_7cparser_ModificationTarget = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.ModificationTarget", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser_ModificationTarget, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_9pyteomics_7cparser_18ModificationTarget_7__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_9pyteomics_7cparser_18ModificationTarget_5__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "ModificationTarget(target, position_type=PositionType.internal)", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9pyteomics_7cparser_ModificationTarget, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9pyteomics_7cparser_ModificationTarget, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_9pyteomics_7cparser_18ModificationTarget_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser_ModificationTarget, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *__pyx_freelist_9pyteomics_7cparser___pyx_scope_struct__generate[8];
static int __pyx_freecount_9pyteomics_7cparser___pyx_scope_struct__generate = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct__generate(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct__generate > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate)))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser___pyx_scope_struct__generate[--__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct__generate];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser___pyx_scope_struct__generate(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *p = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_a);
  Py_CLEAR(p->__pyx_v_assignment);
  Py_CLEAR(p->__pyx_v_assignments);
  Py_CLEAR(p->__pyx_v_assignments_product);
  Py_CLEAR(p->__pyx_v_indices);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sequence);
  Py_CLEAR(p->__pyx_v_sequence_spec);
  Py_CLEAR(p->__pyx_v_subassignments);
  Py_CLEAR(p->__pyx_v_subindices);
  Py_CLEAR(p->__pyx_v_temp1);
  Py_CLEAR(p->__pyx_v_temp2);
  Py_CLEAR(p->__pyx_v_variable_mod_sites);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_3);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct__generate < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate)))) {
    __pyx_freelist_9pyteomics_7cparser___pyx_scope_struct__generate[__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct__generate++] = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9pyteomics_7cparser___pyx_scope_struct__generate(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *p = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate *)o;
  if (p->__pyx_v_a) {
    e = (*v)(p->__pyx_v_a, a); if (e) return e;
  }
  if (p->__pyx_v_assignment) {
    e = (*v)(p->__pyx_v_assignment, a); if (e) return e;
  }
  if (p->__pyx_v_assignments) {
    e = (*v)(p->__pyx_v_assignments, a); if (e) return e;
  }
  if (p->__pyx_v_assignments_product) {
    e = (*v)(p->__pyx_v_assignments_product, a); if (e) return e;
  }
  if (p->__pyx_v_indices) {
    e = (*v)(p->__pyx_v_indices, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sequence) {
    e = (*v)(p->__pyx_v_sequence, a); if (e) return e;
  }
  if (p->__pyx_v_sequence_spec) {
    e = (*v)(p->__pyx_v_sequence_spec, a); if (e) return e;
  }
  if (p->__pyx_v_subassignments) {
    e = (*v)(p->__pyx_v_subassignments, a); if (e) return e;
  }
  if (p->__pyx_v_subindices) {
    e = (*v)(p->__pyx_v_subindices, a); if (e) return e;
  }
  if (p->__pyx_v_temp1) {
    e = (*v)(p->__pyx_v_temp1, a); if (e) return e;
  }
  if (p->__pyx_v_temp2) {
    e = (*v)(p->__pyx_v_temp2, a); if (e) return e;
  }
  if (p->__pyx_v_variable_mod_sites) {
    e = (*v)(p->__pyx_v_variable_mod_sites, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.__pyx_scope_struct__generate", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct__generate), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser___pyx_scope_struct__generate, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9pyteomics_7cparser___pyx_scope_struct__generate, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct__generate, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *__pyx_freelist_9pyteomics_7cparser___pyx_scope_struct_1_isoforms[8];
static int __pyx_freecount_9pyteomics_7cparser___pyx_scope_struct_1_isoforms = 0;

static PyObject *__pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct_1_isoforms(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct_1_isoforms > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms)))) {
    o = (PyObject*)__pyx_freelist_9pyteomics_7cparser___pyx_scope_struct_1_isoforms[--__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct_1_isoforms];
    memset(o, 0, sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9pyteomics_7cparser___pyx_scope_struct_1_isoforms(PyObject *o) {
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *p = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__format);
  Py_CLEAR(p->__pyx_v_fixed_mods);
  Py_CLEAR(p->__pyx_v_form);
  Py_CLEAR(p->__pyx_v_gen);
  Py_CLEAR(p->__pyx_v_isoform_generator);
  Py_CLEAR(p->__pyx_v_kwargs);
  Py_CLEAR(p->__pyx_v_labels);
  Py_CLEAR(p->__pyx_v_max_mods);
  Py_CLEAR(p->__pyx_v_override);
  Py_CLEAR(p->__pyx_v_sequence);
  Py_CLEAR(p->__pyx_v_show_unmodified_termini);
  Py_CLEAR(p->__pyx_v_variable_mods);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct_1_isoforms < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms)))) {
    __pyx_freelist_9pyteomics_7cparser___pyx_scope_struct_1_isoforms[__pyx_freecount_9pyteomics_7cparser___pyx_scope_struct_1_isoforms++] = ((struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9pyteomics_7cparser___pyx_scope_struct_1_isoforms(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *p = (struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms *)o;
  if (p->__pyx_v_fixed_mods) {
    e = (*v)(p->__pyx_v_fixed_mods, a); if (e) return e;
  }
  if (p->__pyx_v_form) {
    e = (*v)(p->__pyx_v_form, a); if (e) return e;
  }
  if (p->__pyx_v_gen) {
    e = (*v)(p->__pyx_v_gen, a); if (e) return e;
  }
  if (p->__pyx_v_isoform_generator) {
    e = (*v)(((PyObject *)p->__pyx_v_isoform_generator), a); if (e) return e;
  }
  if (p->__pyx_v_kwargs) {
    e = (*v)(p->__pyx_v_kwargs, a); if (e) return e;
  }
  if (p->__pyx_v_labels) {
    e = (*v)(p->__pyx_v_labels, a); if (e) return e;
  }
  if (p->__pyx_v_max_mods) {
    e = (*v)(p->__pyx_v_max_mods, a); if (e) return e;
  }
  if (p->__pyx_v_override) {
    e = (*v)(p->__pyx_v_override, a); if (e) return e;
  }
  if (p->__pyx_v_show_unmodified_termini) {
    e = (*v)(p->__pyx_v_show_unmodified_termini, a); if (e) return e;
  }
  if (p->__pyx_v_variable_mods) {
    e = (*v)(p->__pyx_v_variable_mods, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.__pyx_scope_struct_1_isoforms", /*tp_name*/
  sizeof(struct __pyx_obj_9pyteomics_7cparser___pyx_scope_struct_1_isoforms), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9pyteomics_7cparser___pyx_scope_struct_1_isoforms, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9pyteomics_7cparser___pyx_scope_struct_1_isoforms, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9pyteomics_7cparser___pyx_scope_struct_1_isoforms, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (&PyType_Type)->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc___Pyx_EnumMeta(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  (&PyType_Type)->tp_dealloc(o);
}

static int __pyx_tp_traverse___Pyx_EnumMeta(PyObject *o, visitproc v, void *a) {
  int e;
  if (!(&PyType_Type)->tp_traverse); else { e = (&PyType_Type)->tp_traverse(o,v,a); if (e) return e; }
  return 0;
}

static int __pyx_tp_clear___Pyx_EnumMeta(PyObject *o) {
  if (!(&PyType_Type)->tp_clear); else (&PyType_Type)->tp_clear(o);
  return 0;
}
static PyObject *__pyx_sq_item___Pyx_EnumMeta(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyMethodDef __pyx_methods___Pyx_EnumMeta[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence___Pyx_EnumMeta = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item___Pyx_EnumMeta, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping___Pyx_EnumMeta = {
  0, /*mp_length*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __Pyx_EnumMeta = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyteomics.cparser.__Pyx_EnumMeta", /*tp_name*/
  sizeof(struct __pyx_obj___Pyx_EnumMeta), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___Pyx_EnumMeta, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence___Pyx_EnumMeta, /*tp_as_sequence*/
  &__pyx_tp_as_mapping___Pyx_EnumMeta, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse___Pyx_EnumMeta, /*tp_traverse*/
  __pyx_tp_clear___Pyx_EnumMeta, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods___Pyx_EnumMeta, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___Pyx_EnumMeta, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {"length", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_1length, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_length},
  {"_split_label", (PyCFunction)__pyx_pw_9pyteomics_7cparser_3_split_label, METH_O, __pyx_doc_9pyteomics_7cparser_2_split_label},
  {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_5parse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_4parse},
  {"tostring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_7tostring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_6tostring},
  {"amino_acid_composition", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_9amino_acid_composition, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_8amino_acid_composition},
  {"_sequence_tostring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9pyteomics_7cparser_11_sequence_tostring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9pyteomics_7cparser_10_sequence_tostring},
  {"copy_sequence", (PyCFunction)__pyx_pw_9pyteomics_7cparser_13copy_sequence, METH_O, __pyx_doc_9pyteomics_7cparser_12copy_sequence},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_cparser(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_cparser},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "cparser",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
  {&__pyx_n_s_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 0, 1, 1},
  {&__pyx_kp_s_A_Z_A_Z, __pyx_k_A_Z_A_Z, sizeof(__pyx_k_A_Z_A_Z), 0, 0, 1, 0},
  {&__pyx_kp_s_A_Z_A_Z_2, __pyx_k_A_Z_A_Z_2, sizeof(__pyx_k_A_Z_A_Z_2), 0, 0, 1, 0},
  {&__pyx_kp_s_A_Z_A_Z_3, __pyx_k_A_Z_A_Z_3, sizeof(__pyx_k_A_Z_A_Z_3), 0, 0, 1, 0},
  {&__pyx_n_s_BasicComposition, __pyx_k_BasicComposition, sizeof(__pyx_k_BasicComposition), 0, 0, 1, 1},
  {&__pyx_n_s_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 0, 1, 1},
  {&__pyx_kp_u_Calculate_amino_acid_composition, __pyx_k_Calculate_amino_acid_composition, sizeof(__pyx_k_Calculate_amino_acid_composition), 0, 1, 0, 0},
  {&__pyx_kp_u_Calculate_the_number_of_amino_ac, __pyx_k_Calculate_the_number_of_amino_ac, sizeof(__pyx_k_Calculate_the_number_of_amino_ac), 0, 1, 0, 0},
  {&__pyx_kp_s_Cannot_split_a_non_modX_label_s, __pyx_k_Cannot_split_a_non_modX_label_s, sizeof(__pyx_k_Cannot_split_a_non_modX_label_s), 0, 0, 1, 0},
  {&__pyx_n_s_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 0, 1, 1},
  {&__pyx_n_s_E, __pyx_k_E, sizeof(__pyx_k_E), 0, 0, 1, 1},
  {&__pyx_n_s_EnumBase, __pyx_k_EnumBase, sizeof(__pyx_k_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_EnumType, __pyx_k_EnumType, sizeof(__pyx_k_EnumType), 0, 0, 1, 1},
  {&__pyx_n_s_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 0, 1, 1},
  {&__pyx_n_s_G, __pyx_k_G, sizeof(__pyx_k_G), 0, 0, 1, 1},
  {&__pyx_n_s_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 0, 1, 1},
  {&__pyx_kp_s_H_2, __pyx_k_H_2, sizeof(__pyx_k_H_2), 0, 0, 1, 0},
  {&__pyx_n_s_I, __pyx_k_I, sizeof(__pyx_k_I), 0, 0, 1, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x2f, __pyx_k_Incompatible_checksums_s_vs_0x2f, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x2f), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x5a, __pyx_k_Incompatible_checksums_s_vs_0x5a, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x5a), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x96, __pyx_k_Incompatible_checksums_s_vs_0x96, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x96), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xc8, __pyx_k_Incompatible_checksums_s_vs_0xc8, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xc8), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_k_Incompatible_checksums_s_vs_0xd4, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xd4), 0, 0, 1, 0},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_n_s_IntEnum, __pyx_k_IntEnum, sizeof(__pyx_k_IntEnum), 0, 0, 1, 1},
  {&__pyx_n_s_IsoformGenerator, __pyx_k_IsoformGenerator, sizeof(__pyx_k_IsoformGenerator), 0, 0, 1, 1},
  {&__pyx_n_s_IsoformGenerator_generate, __pyx_k_IsoformGenerator_generate, sizeof(__pyx_k_IsoformGenerator_generate), 0, 0, 1, 1},
  {&__pyx_n_s_K, __pyx_k_K, sizeof(__pyx_k_K), 0, 0, 1, 1},
  {&__pyx_n_s_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 0, 1, 1},
  {&__pyx_n_s_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 0, 1, 1},
  {&__pyx_n_s_ModificationRule, __pyx_k_ModificationRule, sizeof(__pyx_k_ModificationRule), 0, 0, 1, 1},
  {&__pyx_n_s_ModificationTarget, __pyx_k_ModificationTarget, sizeof(__pyx_k_ModificationTarget), 0, 0, 1, 1},
  {&__pyx_n_s_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 0, 1, 1},
  {&__pyx_kp_s_Not_a_valid_modX_sequence, __pyx_k_Not_a_valid_modX_sequence, sizeof(__pyx_k_Not_a_valid_modX_sequence), 0, 0, 1, 0},
  {&__pyx_kp_s_OH, __pyx_k_OH, sizeof(__pyx_k_OH), 0, 0, 1, 0},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_n_s_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
  {&__pyx_kp_u_Parse_a_sequence_string_written, __pyx_k_Parse_a_sequence_string_written, sizeof(__pyx_k_Parse_a_sequence_string_written), 0, 1, 0, 0},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_PositionType, __pyx_k_PositionType, sizeof(__pyx_k_PositionType), 0, 0, 1, 1},
  {&__pyx_kp_s_Position_already_has_position_ty, __pyx_k_Position_already_has_position_ty, sizeof(__pyx_k_Position_already_has_position_ty), 0, 0, 1, 0},
  {&__pyx_n_s_PyteomicsError, __pyx_k_PyteomicsError, sizeof(__pyx_k_PyteomicsError), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase, __pyx_k_Pyx_EnumBase, sizeof(__pyx_k_Pyx_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___new, __pyx_k_Pyx_EnumBase___new, sizeof(__pyx_k_Pyx_EnumBase___new), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___repr, __pyx_k_Pyx_EnumBase___repr, sizeof(__pyx_k_Pyx_EnumBase___repr), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___str, __pyx_k_Pyx_EnumBase___str, sizeof(__pyx_k_Pyx_EnumBase___str), 0, 0, 1, 1},
  {&__pyx_n_s_Q, __pyx_k_Q, sizeof(__pyx_k_Q), 0, 0, 1, 1},
  {&__pyx_n_s_R, __pyx_k_R, sizeof(__pyx_k_R), 0, 0, 1, 1},
  {&__pyx_n_s_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 0, 1, 1},
  {&__pyx_n_s_SequencePosition, __pyx_k_SequencePosition, sizeof(__pyx_k_SequencePosition), 0, 0, 1, 1},
  {&__pyx_n_s_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 1, 1},
  {&__pyx_kp_s_Target_must_be_a_single_Amino_Ac, __pyx_k_Target_must_be_a_single_Amino_Ac, sizeof(__pyx_k_Target_must_be_a_single_Amino_Ac), 0, 0, 1, 0},
  {&__pyx_kp_s_Terminal_Modifications_with_Targ, __pyx_k_Terminal_Modifications_with_Targ, sizeof(__pyx_k_Terminal_Modifications_with_Targ), 0, 0, 1, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Unknown_enum_value_s, __pyx_k_Unknown_enum_value_s, sizeof(__pyx_k_Unknown_enum_value_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Unknown_label, __pyx_k_Unknown_label, sizeof(__pyx_k_Unknown_label), 0, 0, 1, 0},
  {&__pyx_kp_s_Unsupported_type_of_a_sequence_M, __pyx_k_Unsupported_type_of_a_sequence_M, sizeof(__pyx_k_Unsupported_type_of_a_sequence_M), 0, 0, 1, 0},
  {&__pyx_kp_s_Unsupported_type_of_sequence, __pyx_k_Unsupported_type_of_sequence, sizeof(__pyx_k_Unsupported_type_of_sequence), 0, 0, 1, 0},
  {&__pyx_kp_s_Unsupported_value_of_format, __pyx_k_Unsupported_value_of_format, sizeof(__pyx_k_Unsupported_value_of_format), 0, 0, 1, 0},
  {&__pyx_n_s_V, __pyx_k_V, sizeof(__pyx_k_V), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_W, __pyx_k_W, sizeof(__pyx_k_W), 0, 0, 1, 1},
  {&__pyx_n_s_Y, __pyx_k_Y, sizeof(__pyx_k_Y), 0, 0, 1, 1},
  {&__pyx_kp_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 0},
  {&__pyx_n_s_allow_unknown_modifications, __pyx_k_allow_unknown_modifications, sizeof(__pyx_k_allow_unknown_modifications), 0, 0, 1, 1},
  {&__pyx_n_s_amino_acid, __pyx_k_amino_acid, sizeof(__pyx_k_amino_acid), 0, 0, 1, 1},
  {&__pyx_kp_u_amino_acid_composition_line_566, __pyx_k_amino_acid_composition_line_566, sizeof(__pyx_k_amino_acid_composition_line_566), 0, 1, 0, 0},
  {&__pyx_n_s_apply_fixed_mods, __pyx_k_apply_fixed_mods, sizeof(__pyx_k_apply_fixed_mods), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_build_site_map, __pyx_k_build_site_map, sizeof(__pyx_k_build_site_map), 0, 0, 1, 1},
  {&__pyx_n_s_c_term, __pyx_k_c_term, sizeof(__pyx_k_c_term), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
  {&__pyx_n_s_coerce_modification_dict, __pyx_k_coerce_modification_dict, sizeof(__pyx_k_coerce_modification_dict), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_combinations, __pyx_k_combinations, sizeof(__pyx_k_combinations), 0, 0, 1, 1},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_cterm, __pyx_k_cterm, sizeof(__pyx_k_cterm), 0, 0, 1, 1},
  {&__pyx_n_s_dct, __pyx_k_dct, sizeof(__pyx_k_dct), 0, 0, 1, 1},
  {&__pyx_n_s_deque, __pyx_k_deque, sizeof(__pyx_k_deque), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_enum, __pyx_k_enum, sizeof(__pyx_k_enum), 0, 0, 1, 1},
  {&__pyx_n_s_findall, __pyx_k_findall, sizeof(__pyx_k_findall), 0, 0, 1, 1},
  {&__pyx_n_s_fixed_mods, __pyx_k_fixed_mods, sizeof(__pyx_k_fixed_mods), 0, 0, 1, 1},
  {&__pyx_n_s_form, __pyx_k_form, sizeof(__pyx_k_form), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_format_2, __pyx_k_format_2, sizeof(__pyx_k_format_2), 0, 0, 1, 1},
  {&__pyx_n_s_from_iterable, __pyx_k_from_iterable, sizeof(__pyx_k_from_iterable), 0, 0, 1, 1},
  {&__pyx_n_s_from_string, __pyx_k_from_string, sizeof(__pyx_k_from_string), 0, 0, 1, 1},
  {&__pyx_n_s_from_tuple, __pyx_k_from_tuple, sizeof(__pyx_k_from_tuple), 0, 0, 1, 1},
  {&__pyx_n_s_gen, __pyx_k_gen, sizeof(__pyx_k_gen), 0, 0, 1, 1},
  {&__pyx_n_s_generate, __pyx_k_generate, sizeof(__pyx_k_generate), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_groups, __pyx_k_groups, sizeof(__pyx_k_groups), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_include_unmodified, __pyx_k_include_unmodified, sizeof(__pyx_k_include_unmodified), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_initialize_from_iterable, __pyx_k_initialize_from_iterable, sizeof(__pyx_k_initialize_from_iterable), 0, 0, 1, 1},
  {&__pyx_n_s_initialize_from_str, __pyx_k_initialize_from_str, sizeof(__pyx_k_initialize_from_str), 0, 0, 1, 1},
  {&__pyx_n_s_internal, __pyx_k_internal, sizeof(__pyx_k_internal), 0, 0, 1, 1},
  {&__pyx_n_s_isoform_generator, __pyx_k_isoform_generator, sizeof(__pyx_k_isoform_generator), 0, 0, 1, 1},
  {&__pyx_n_s_isoforms, __pyx_k_isoforms, sizeof(__pyx_k_isoforms), 0, 0, 1, 1},
  {&__pyx_n_s_it, __pyx_k_it, sizeof(__pyx_k_it), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_itertools, __pyx_k_itertools, sizeof(__pyx_k_itertools), 0, 0, 1, 1},
  {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
  {&__pyx_n_s_label, __pyx_k_label, sizeof(__pyx_k_label), 0, 0, 1, 1},
  {&__pyx_n_s_labels, __pyx_k_labels, sizeof(__pyx_k_labels), 0, 0, 1, 1},
  {&__pyx_kp_u_length_line_118, __pyx_k_length_line_118, sizeof(__pyx_k_length_line_118), 0, 1, 0, 0},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
  {&__pyx_n_s_max_mods, __pyx_k_max_mods, sizeof(__pyx_k_max_mods), 0, 0, 1, 1},
  {&__pyx_n_s_members, __pyx_k_members, sizeof(__pyx_k_members), 0, 0, 1, 1},
  {&__pyx_n_s_memoize, __pyx_k_memoize, sizeof(__pyx_k_memoize), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_modification, __pyx_k_modification, sizeof(__pyx_k_modification), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_n_term, __pyx_k_n_term, sizeof(__pyx_k_n_term), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_nterm, __pyx_k_nterm, sizeof(__pyx_k_nterm), 0, 0, 1, 1},
  {&__pyx_n_s_override, __pyx_k_override, sizeof(__pyx_k_override), 0, 0, 1, 1},
  {&__pyx_n_s_parents, __pyx_k_parents, sizeof(__pyx_k_parents), 0, 0, 1, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_kp_u_parse_line_211, __pyx_k_parse_line_211, sizeof(__pyx_k_parse_line_211), 0, 1, 0, 0},
  {&__pyx_n_s_parsed_sequence, __pyx_k_parsed_sequence, sizeof(__pyx_k_parsed_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_persist, __pyx_k_persist, sizeof(__pyx_k_persist), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_position, __pyx_k_position, sizeof(__pyx_k_position), 0, 0, 1, 1},
  {&__pyx_n_s_position_type, __pyx_k_position_type, sizeof(__pyx_k_position_type), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_product, __pyx_k_product, sizeof(__pyx_k_product), 0, 0, 1, 1},
  {&__pyx_n_s_pyteomics_auxiliary, __pyx_k_pyteomics_auxiliary, sizeof(__pyx_k_pyteomics_auxiliary), 0, 0, 1, 1},
  {&__pyx_n_s_pyteomics_cparser, __pyx_k_pyteomics_cparser, sizeof(__pyx_k_pyteomics_cparser), 0, 0, 1, 1},
  {&__pyx_kp_s_pyteomics_cparser_pyx, __pyx_k_pyteomics_cparser_pyx, sizeof(__pyx_k_pyteomics_cparser_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_IsoformGenerator, __pyx_k_pyx_unpickle_IsoformGenerator, sizeof(__pyx_k_pyx_unpickle_IsoformGenerator), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ModificationRule, __pyx_k_pyx_unpickle_ModificationRule, sizeof(__pyx_k_pyx_unpickle_ModificationRule), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ModificationTarge, __pyx_k_pyx_unpickle_ModificationTarge, sizeof(__pyx_k_pyx_unpickle_ModificationTarge), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_SequencePosition, __pyx_k_pyx_unpickle_SequencePosition, sizeof(__pyx_k_pyx_unpickle_SequencePosition), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_k_pyx_unpickle___Pyx_EnumMeta, sizeof(__pyx_k_pyx_unpickle___Pyx_EnumMeta), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
  {&__pyx_kp_s_s_s_d, __pyx_k_s_s_d, sizeof(__pyx_k_s_s_d), 0, 0, 1, 0},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_kp_s_self___class_____name___self_mo, __pyx_k_self___class_____name___self_mo, sizeof(__pyx_k_self___class_____name___self_mo), 0, 0, 1, 0},
  {&__pyx_kp_s_self___class_____name___self_ta, __pyx_k_self___class_____name___self_ta, sizeof(__pyx_k_self___class_____name___self_ta), 0, 0, 1, 0},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_sequence, __pyx_k_sequence, sizeof(__pyx_k_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_sequence_spec, __pyx_k_sequence_spec, sizeof(__pyx_k_sequence_spec), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_show_unmodified_termini, __pyx_k_show_unmodified_termini, sizeof(__pyx_k_show_unmodified_termini), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_staticmethod, __pyx_k_staticmethod, sizeof(__pyx_k_staticmethod), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_n_s_str_2, __pyx_k_str_2, sizeof(__pyx_k_str_2), 0, 0, 1, 1},
  {&__pyx_n_s_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
  {&__pyx_n_s_target, __pyx_k_target, sizeof(__pyx_k_target), 0, 0, 1, 1},
  {&__pyx_n_s_targets, __pyx_k_targets, sizeof(__pyx_k_targets), 0, 0, 1, 1},
  {&__pyx_n_s_term_aa, __pyx_k_term_aa, sizeof(__pyx_k_term_aa), 0, 0, 1, 1},
  {&__pyx_n_s_terminal, __pyx_k_terminal, sizeof(__pyx_k_terminal), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_test_2, __pyx_k_test_2, sizeof(__pyx_k_test_2), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_universal, __pyx_k_universal, sizeof(__pyx_k_universal), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_variable_mods, __pyx_k_variable_mods, sizeof(__pyx_k_variable_mods), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_n_s_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 1276, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_n_s_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 154, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 201, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 496, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 735, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 832, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "pyteomics/cparser.pyx":66
 * """modX labels for the standard amino acids and unmodified termini."""
 * 
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')             # <<<<<<<<<<<<<<
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_A_Z_A_Z); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "pyteomics/cparser.pyx":67
 * 
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')             # <<<<<<<<<<<<<<
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')
 * 
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_A_Z_A_Z_2); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "pyteomics/cparser.pyx":68
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_A_Z_A_Z_3); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "pyteomics/cparser.pyx":1277
 * 
 *     @staticmethod
 *     def from_string(str string):             # <<<<<<<<<<<<<<
 *         return ModificationTarget._from_string(string)
 * 
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_n_s_string); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);
  __pyx_codeobj__10 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__9, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyteomics_cparser_pyx, __pyx_n_s_from_string, 1277, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__10)) __PYX_ERR(0, 1277, __pyx_L1_error)

  /* "pyteomics/cparser.pyx":1310
 * 
 * 
 * def isoforms(str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *     cdef:
 *         IsoformGenerator isoform_generator
 */
  __pyx_tuple__11 = PyTuple_Pack(12, __pyx_n_s_sequence, __pyx_n_s_kwargs, __pyx_n_s_isoform_generator, __pyx_n_s_format_2, __pyx_n_s_gen, __pyx_n_s_variable_mods, __pyx_n_s_fixed_mods, __pyx_n_s_labels, __pyx_n_s_max_mods, __pyx_n_s_override, __pyx_n_s_show_unmodified_termini, __pyx_n_s_form); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);
  __pyx_codeobj__5 = (PyObject*)__Pyx_PyCode_New(1, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyteomics_cparser_pyx, __pyx_n_s_isoforms, 1310, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__5)) __PYX_ERR(0, 1310, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_SequencePosition(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__12 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);
  __pyx_codeobj__13 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__12, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_SequencePosition, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__13)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__14 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);
  __pyx_codeobj__15 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__14, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_IsoformGenerator, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__15)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__16 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__16, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ModificationRule, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__18 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ModificationTarge, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_tuple__20 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_value, __pyx_n_s_name, __pyx_n_s_v, __pyx_n_s_res); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);
  __pyx_codeobj__21 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_new, 28, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__21)) __PYX_ERR(1, 28, __pyx_L1_error)
  __pyx_tuple__22 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_repr, 39, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) __PYX_ERR(1, 39, __pyx_L1_error)

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__25, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_str_2, 41, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(1, 41, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__27 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_50086419 = PyInt_FromLong(50086419L); if (unlikely(!__pyx_int_50086419)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_94445299 = PyInt_FromLong(94445299L); if (unlikely(!__pyx_int_94445299)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_158260321 = PyInt_FromLong(158260321L); if (unlikely(!__pyx_int_158260321)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_209977177 = PyInt_FromLong(209977177L); if (unlikely(!__pyx_int_209977177)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_9pyteomics_7cparser_std_amino_acids = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser_std_labels = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser_std_nterm = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser_std_cterm = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser__modX_sequence = Py_None; Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser__modX_group = Py_None; Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser__modX_split = Py_None; Py_INCREF(Py_None);
  __pyx_v_9pyteomics_7cparser__modX_split_findall = Py_None; Py_INCREF(Py_None);
  __Pyx_OrderedDict = Py_None; Py_INCREF(Py_None);
  __Pyx_EnumBase = Py_None; Py_INCREF(Py_None);
  __Pyx_globals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("parse", (void (*)(void))__pyx_f_9pyteomics_7cparser_parse, "PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_parse *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("amino_acid_composition", (void (*)(void))__pyx_f_9pyteomics_7cparser_amino_acid_composition, "PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_amino_acid_composition *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("_split_label", (void (*)(void))__pyx_f_9pyteomics_7cparser__split_label, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("tostring", (void (*)(void))__pyx_f_9pyteomics_7cparser_tostring, "PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_tostring *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_9pyteomics_7cparser_SequencePosition = &__pyx_vtable_9pyteomics_7cparser_SequencePosition;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition._create = (struct __pyx_obj_9pyteomics_7cparser_SequencePosition *(*)(PyObject *, PyObject *, PyObject *, enum __pyx_t_9pyteomics_7cparser_PositionType))__pyx_f_9pyteomics_7cparser_16SequencePosition__create;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.get_index = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, long, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16SequencePosition_get_index;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.get_size = (size_t (*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *))__pyx_f_9pyteomics_7cparser_16SequencePosition_get_size;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.is_modified = (int (*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *))__pyx_f_9pyteomics_7cparser_16SequencePosition_is_modified;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.add_modification = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16SequencePosition_add_modification;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.as_tuple = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16SequencePosition_as_tuple;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition.copy = (struct __pyx_obj_9pyteomics_7cparser_SequencePosition *(*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *))__pyx_f_9pyteomics_7cparser_16SequencePosition_copy;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition._eq = (int (*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *))__pyx_f_9pyteomics_7cparser_16SequencePosition__eq;
  __pyx_vtable_9pyteomics_7cparser_SequencePosition._eq_tuple = (int (*)(struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, PyObject *))__pyx_f_9pyteomics_7cparser_16SequencePosition__eq_tuple;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser_SequencePosition) < 0) __PYX_ERR(0, 700, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser_SequencePosition.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser_SequencePosition.tp_dictoffset && __pyx_type_9pyteomics_7cparser_SequencePosition.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser_SequencePosition.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  if (__Pyx_SetVtable(__pyx_type_9pyteomics_7cparser_SequencePosition.tp_dict, __pyx_vtabptr_9pyteomics_7cparser_SequencePosition) < 0) __PYX_ERR(0, 700, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SequencePosition, (PyObject *)&__pyx_type_9pyteomics_7cparser_SequencePosition) < 0) __PYX_ERR(0, 700, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_9pyteomics_7cparser_SequencePosition) < 0) __PYX_ERR(0, 700, __pyx_L1_error)
  __pyx_ptype_9pyteomics_7cparser_SequencePosition = &__pyx_type_9pyteomics_7cparser_SequencePosition;
  __pyx_vtabptr_9pyteomics_7cparser_IsoformGenerator = &__pyx_vtable_9pyteomics_7cparser_IsoformGenerator;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.coerce_modification_dict = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16IsoformGenerator_coerce_modification_dict;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.initialize_from_str = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_str;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.initialize_from_iterable = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16IsoformGenerator_initialize_from_iterable;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.apply_fixed_mods = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16IsoformGenerator_apply_fixed_mods;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.build_site_map = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_9pyteomics_7cparser_16IsoformGenerator_build_site_map *__pyx_optional_args))__pyx_f_9pyteomics_7cparser_16IsoformGenerator_build_site_map;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator._reset_sequence = (void (*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *))__pyx_f_9pyteomics_7cparser_16IsoformGenerator__reset_sequence;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.__pyx_fuse_0_apply_variable_assignment = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, long *, PyObject *, size_t))__pyx_fuse_0__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment;
  __pyx_vtable_9pyteomics_7cparser_IsoformGenerator.__pyx_fuse_1_apply_variable_assignment = (PyObject *(*)(struct __pyx_obj_9pyteomics_7cparser_IsoformGenerator *, PyObject *, long *, PyObject *, size_t))__pyx_fuse_1__pyx_f_9pyteomics_7cparser_16IsoformGenerator__apply_variable_assignment;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser_IsoformGenerator) < 0) __PYX_ERR(0, 990, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser_IsoformGenerator.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser_IsoformGenerator.tp_dictoffset && __pyx_type_9pyteomics_7cparser_IsoformGenerator.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser_IsoformGenerator.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_9pyteomics_7cparser_IsoformGenerator.tp_dict, __pyx_vtabptr_9pyteomics_7cparser_IsoformGenerator) < 0) __PYX_ERR(0, 990, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_IsoformGenerator, (PyObject *)&__pyx_type_9pyteomics_7cparser_IsoformGenerator) < 0) __PYX_ERR(0, 990, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_9pyteomics_7cparser_IsoformGenerator) < 0) __PYX_ERR(0, 990, __pyx_L1_error)
  __pyx_ptype_9pyteomics_7cparser_IsoformGenerator = &__pyx_type_9pyteomics_7cparser_IsoformGenerator;
  __pyx_vtabptr_9pyteomics_7cparser_ModificationRule = &__pyx_vtable_9pyteomics_7cparser_ModificationRule;
  __pyx_vtable_9pyteomics_7cparser_ModificationRule.test = (int (*)(struct __pyx_obj_9pyteomics_7cparser_ModificationRule *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_16ModificationRule_test;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser_ModificationRule) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser_ModificationRule.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser_ModificationRule.tp_dictoffset && __pyx_type_9pyteomics_7cparser_ModificationRule.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser_ModificationRule.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_9pyteomics_7cparser_ModificationRule.tp_dict, __pyx_vtabptr_9pyteomics_7cparser_ModificationRule) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ModificationRule, (PyObject *)&__pyx_type_9pyteomics_7cparser_ModificationRule) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_9pyteomics_7cparser_ModificationRule) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  __pyx_ptype_9pyteomics_7cparser_ModificationRule = &__pyx_type_9pyteomics_7cparser_ModificationRule;
  __pyx_vtabptr_9pyteomics_7cparser_ModificationTarget = &__pyx_vtable_9pyteomics_7cparser_ModificationTarget;
  __pyx_vtable_9pyteomics_7cparser_ModificationTarget.test = (int (*)(struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *, struct __pyx_obj_9pyteomics_7cparser_SequencePosition *, int __pyx_skip_dispatch))__pyx_f_9pyteomics_7cparser_18ModificationTarget_test;
  __pyx_vtable_9pyteomics_7cparser_ModificationTarget._create = (struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *(*)(PyObject *, enum __pyx_t_9pyteomics_7cparser_PositionType))__pyx_f_9pyteomics_7cparser_18ModificationTarget__create;
  __pyx_vtable_9pyteomics_7cparser_ModificationTarget._from_string = (struct __pyx_obj_9pyteomics_7cparser_ModificationTarget *(*)(PyObject *))__pyx_f_9pyteomics_7cparser_18ModificationTarget__from_string;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser_ModificationTarget) < 0) __PYX_ERR(0, 1243, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser_ModificationTarget.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser_ModificationTarget.tp_dictoffset && __pyx_type_9pyteomics_7cparser_ModificationTarget.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser_ModificationTarget.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_9pyteomics_7cparser_ModificationTarget.tp_dict, __pyx_vtabptr_9pyteomics_7cparser_ModificationTarget) < 0) __PYX_ERR(0, 1243, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ModificationTarget, (PyObject *)&__pyx_type_9pyteomics_7cparser_ModificationTarget) < 0) __PYX_ERR(0, 1243, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_9pyteomics_7cparser_ModificationTarget) < 0) __PYX_ERR(0, 1243, __pyx_L1_error)
  __pyx_ptype_9pyteomics_7cparser_ModificationTarget = &__pyx_type_9pyteomics_7cparser_ModificationTarget;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate.tp_dictoffset && __pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_9pyteomics_7cparser___pyx_scope_struct__generate = &__pyx_type_9pyteomics_7cparser___pyx_scope_struct__generate;
  if (PyType_Ready(&__pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms) < 0) __PYX_ERR(0, 1310, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms.tp_dictoffset && __pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_9pyteomics_7cparser___pyx_scope_struct_1_isoforms = &__pyx_type_9pyteomics_7cparser___pyx_scope_struct_1_isoforms;
  __Pyx_EnumMeta.tp_base = (&PyType_Type);
  if (PyType_Ready(&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __Pyx_EnumMeta.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__Pyx_EnumMeta.tp_dictoffset && __Pyx_EnumMeta.tp_getattro == PyObject_GenericGetAttr)) {
    __Pyx_EnumMeta.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_setup_reduce((PyObject*)&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_ptype___Pyx_EnumMeta = &__Pyx_EnumMeta;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initcparser(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initcparser(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_cparser(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_cparser(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_cparser(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'cparser' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_cparser(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("cparser", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_pyteomics__cparser) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "pyteomics.cparser")) {
      if (unlikely(PyDict_SetItemString(modules, "pyteomics.cparser", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  if (unlikely(__Pyx_modinit_function_export_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "pyteomics/cparser.pyx":41
 * 
 * 
 * import re             # <<<<<<<<<<<<<<
 * from collections import deque
 * import itertools as it
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_re, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":42
 * 
 * import re
 * from collections import deque             # <<<<<<<<<<<<<<
 * import itertools as it
 * from pyteomics.auxiliary import PyteomicsError, memoize, BasicComposition
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_deque);
  __Pyx_GIVEREF(__pyx_n_s_deque);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_deque);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_deque); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_deque, __pyx_t_1) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":43
 * import re
 * from collections import deque
 * import itertools as it             # <<<<<<<<<<<<<<
 * from pyteomics.auxiliary import PyteomicsError, memoize, BasicComposition
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_itertools, 0, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_it, __pyx_t_2) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":44
 * from collections import deque
 * import itertools as it
 * from pyteomics.auxiliary import PyteomicsError, memoize, BasicComposition             # <<<<<<<<<<<<<<
 * 
 * cdef:
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_PyteomicsError);
  __Pyx_GIVEREF(__pyx_n_s_PyteomicsError);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PyteomicsError);
  __Pyx_INCREF(__pyx_n_s_memoize);
  __Pyx_GIVEREF(__pyx_n_s_memoize);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_memoize);
  __Pyx_INCREF(__pyx_n_s_BasicComposition);
  __Pyx_GIVEREF(__pyx_n_s_BasicComposition);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_BasicComposition);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_pyteomics_auxiliary, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_PyteomicsError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PyteomicsError, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_memoize); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_memoize, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_BasicComposition); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BasicComposition, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":53
 * DEF TOSTRING_STACK_BUFFER_SIZE = 150
 * 
 * std_amino_acids = ['Q','W','E','R','T','Y','I','P','A','S',             # <<<<<<<<<<<<<<
 *                    'D','F','G','H','K','L','C','V','N','M']
 * """modX labels for the 20 standard amino acids."""
 */
  __pyx_t_1 = PyList_New(20); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Q);
  __Pyx_GIVEREF(__pyx_n_s_Q);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Q);
  __Pyx_INCREF(__pyx_n_s_W);
  __Pyx_GIVEREF(__pyx_n_s_W);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_W);
  __Pyx_INCREF(__pyx_n_s_E);
  __Pyx_GIVEREF(__pyx_n_s_E);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_E);
  __Pyx_INCREF(__pyx_n_s_R);
  __Pyx_GIVEREF(__pyx_n_s_R);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_s_R);
  __Pyx_INCREF(__pyx_n_s_T);
  __Pyx_GIVEREF(__pyx_n_s_T);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_s_T);
  __Pyx_INCREF(__pyx_n_s_Y);
  __Pyx_GIVEREF(__pyx_n_s_Y);
  PyList_SET_ITEM(__pyx_t_1, 5, __pyx_n_s_Y);
  __Pyx_INCREF(__pyx_n_s_I);
  __Pyx_GIVEREF(__pyx_n_s_I);
  PyList_SET_ITEM(__pyx_t_1, 6, __pyx_n_s_I);
  __Pyx_INCREF(__pyx_n_s_P);
  __Pyx_GIVEREF(__pyx_n_s_P);
  PyList_SET_ITEM(__pyx_t_1, 7, __pyx_n_s_P);
  __Pyx_INCREF(__pyx_n_s_A);
  __Pyx_GIVEREF(__pyx_n_s_A);
  PyList_SET_ITEM(__pyx_t_1, 8, __pyx_n_s_A);
  __Pyx_INCREF(__pyx_n_s_S);
  __Pyx_GIVEREF(__pyx_n_s_S);
  PyList_SET_ITEM(__pyx_t_1, 9, __pyx_n_s_S);
  __Pyx_INCREF(__pyx_n_s_D);
  __Pyx_GIVEREF(__pyx_n_s_D);
  PyList_SET_ITEM(__pyx_t_1, 10, __pyx_n_s_D);
  __Pyx_INCREF(__pyx_n_s_F);
  __Pyx_GIVEREF(__pyx_n_s_F);
  PyList_SET_ITEM(__pyx_t_1, 11, __pyx_n_s_F);
  __Pyx_INCREF(__pyx_n_s_G);
  __Pyx_GIVEREF(__pyx_n_s_G);
  PyList_SET_ITEM(__pyx_t_1, 12, __pyx_n_s_G);
  __Pyx_INCREF(__pyx_n_s_H);
  __Pyx_GIVEREF(__pyx_n_s_H);
  PyList_SET_ITEM(__pyx_t_1, 13, __pyx_n_s_H);
  __Pyx_INCREF(__pyx_n_s_K);
  __Pyx_GIVEREF(__pyx_n_s_K);
  PyList_SET_ITEM(__pyx_t_1, 14, __pyx_n_s_K);
  __Pyx_INCREF(__pyx_n_s_L);
  __Pyx_GIVEREF(__pyx_n_s_L);
  PyList_SET_ITEM(__pyx_t_1, 15, __pyx_n_s_L);
  __Pyx_INCREF(__pyx_n_s_C);
  __Pyx_GIVEREF(__pyx_n_s_C);
  PyList_SET_ITEM(__pyx_t_1, 16, __pyx_n_s_C);
  __Pyx_INCREF(__pyx_n_s_V);
  __Pyx_GIVEREF(__pyx_n_s_V);
  PyList_SET_ITEM(__pyx_t_1, 17, __pyx_n_s_V);
  __Pyx_INCREF(__pyx_n_s_N);
  __Pyx_GIVEREF(__pyx_n_s_N);
  PyList_SET_ITEM(__pyx_t_1, 18, __pyx_n_s_N);
  __Pyx_INCREF(__pyx_n_s_M);
  __Pyx_GIVEREF(__pyx_n_s_M);
  PyList_SET_ITEM(__pyx_t_1, 19, __pyx_n_s_M);
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser_std_amino_acids);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser_std_amino_acids, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":57
 * """modX labels for the 20 standard amino acids."""
 * 
 * std_nterm = 'H-'             # <<<<<<<<<<<<<<
 * """modX label for the unmodified N-terminus."""
 * 
 */
  __Pyx_INCREF(__pyx_kp_s_H_2);
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser_std_nterm);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser_std_nterm, __pyx_kp_s_H_2);
  __Pyx_GIVEREF(__pyx_kp_s_H_2);

  /* "pyteomics/cparser.pyx":60
 * """modX label for the unmodified N-terminus."""
 * 
 * std_cterm = '-OH'             # <<<<<<<<<<<<<<
 * """modX label for the unmodified C-terminus."""
 * 
 */
  __Pyx_INCREF(__pyx_kp_s_OH);
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser_std_cterm);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser_std_cterm, __pyx_kp_s_OH);
  __Pyx_GIVEREF(__pyx_kp_s_OH);

  /* "pyteomics/cparser.pyx":63
 * """modX label for the unmodified C-terminus."""
 * 
 * std_labels = std_amino_acids + [std_nterm, std_cterm]             # <<<<<<<<<<<<<<
 * """modX labels for the standard amino acids and unmodified termini."""
 * 
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_nterm);
  __Pyx_GIVEREF(__pyx_v_9pyteomics_7cparser_std_nterm);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_9pyteomics_7cparser_std_nterm);
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_cterm);
  __Pyx_GIVEREF(__pyx_v_9pyteomics_7cparser_std_cterm);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_9pyteomics_7cparser_std_cterm);
  __pyx_t_2 = PyNumber_Add(__pyx_v_9pyteomics_7cparser_std_amino_acids, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser_std_labels);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser_std_labels, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":66
 * """modX labels for the standard amino acids and unmodified termini."""
 * 
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')             # <<<<<<<<<<<<<<
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser__modX_sequence);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser__modX_sequence, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":67
 * 
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')             # <<<<<<<<<<<<<<
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser__modX_group);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser__modX_group, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":68
 * _modX_sequence = re.compile(r'^([^-]+-)?((?:[^A-Z-]*[A-Z])+)(-[^-]+)?$')
 * _modX_group = re.compile(r'[^A-Z-]*[A-Z]')
 * _modX_split = re.compile(r'([^A-Z-]*)([A-Z])')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser__modX_split);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser__modX_split, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":120
 * cpdef int length(object sequence,
 *                  int show_unmodified_termini=0, int split=0,
 *                  int allow_unknown_modifications=0, object labels=std_labels):             # <<<<<<<<<<<<<<
 *     """Calculate the number of amino acid residues in a polypeptide
 *     written in modX notation.
 */
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_labels);
  __pyx_k__2 = __pyx_v_9pyteomics_7cparser_std_labels;
  __Pyx_GIVEREF(__pyx_v_9pyteomics_7cparser_std_labels);

  /* "pyteomics/cparser.pyx":118
 *     return bool(match_modX(label))
 * 
 * cpdef int length(object sequence,             # <<<<<<<<<<<<<<
 *                  int show_unmodified_termini=0, int split=0,
 *                  int allow_unknown_modifications=0, object labels=std_labels):
 */
  __Pyx_INCREF(__pyx_v_9pyteomics_7cparser_std_labels);
  __pyx_k__2 = __pyx_v_9pyteomics_7cparser_std_labels;
  __Pyx_GIVEREF(__pyx_v_9pyteomics_7cparser_std_labels);

  /* "pyteomics/cparser.pyx":187
 * 
 * 
 * cdef object _modX_split_findall = _modX_split.findall             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9pyteomics_7cparser__modX_split, __pyx_n_s_findall); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_9pyteomics_7cparser__modX_split_findall);
  __Pyx_DECREF_SET(__pyx_v_9pyteomics_7cparser__modX_split_findall, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":813
 * 
 *     @classmethod
 *     def from_tuple(cls, tuple source):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size, i
 */
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition, __pyx_n_s_from_tuple); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pyteomics/cparser.pyx":812
 *             self.amino_acid, (self.modification), self.terminal, self.position_type)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_tuple(cls, tuple source):
 *         cdef:
 */
  __pyx_t_1 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition->tp_dict, __pyx_n_s_from_tuple, __pyx_t_1) < 0) __PYX_ERR(0, 813, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_9pyteomics_7cparser_SequencePosition);

  /* "pyteomics/cparser.pyx":852
 * 
 *     @classmethod
 *     def parse(cls, str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t n, i
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pyteomics/cparser.pyx":851
 *         return cls(amino_acid, modification, terminal, position_type)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def parse(cls, str sequence, **kwargs):
 *         cdef:
 */
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition->tp_dict, __pyx_n_s_parse, __pyx_t_2) < 0) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_9pyteomics_7cparser_SequencePosition);

  /* "pyteomics/cparser.pyx":866
 * 
 *     @classmethod
 *     def from_iterable(cls, object iterable):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t i, n
 */
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition, __pyx_n_s_from_iterable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pyteomics/cparser.pyx":865
 *         return result
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_iterable(cls, object iterable):
 *         cdef:
 */
  __pyx_t_1 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9pyteomics_7cparser_SequencePosition->tp_dict, __pyx_n_s_from_iterable, __pyx_t_1) < 0) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_9pyteomics_7cparser_SequencePosition);

  /* "pyteomics/cparser.pyx":1248
 *         public PositionType position_type
 * 
 *     def __init__(self, target, position_type=PositionType.internal):             # <<<<<<<<<<<<<<
 *         self.target = target
 *         self.position_type = position_type
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_internal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_k__4 = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyteomics/cparser.pyx":1277
 * 
 *     @staticmethod
 *     def from_string(str string):             # <<<<<<<<<<<<<<
 *         return ModificationTarget._from_string(string)
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_18ModificationTarget_9from_string, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationTarget->tp_dict, __pyx_n_s_from_string, __pyx_t_1) < 0) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_9pyteomics_7cparser_ModificationTarget);

  /* "pyteomics/cparser.pyx":1276
 *         return inst
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str string):
 *         return ModificationTarget._from_string(string)
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationTarget, __pyx_n_s_from_string); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9pyteomics_7cparser_ModificationTarget->tp_dict, __pyx_n_s_from_string, __pyx_t_2) < 0) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_9pyteomics_7cparser_ModificationTarget);

  /* "pyteomics/cparser.pyx":1310
 * 
 * 
 * def isoforms(str sequence, **kwargs):             # <<<<<<<<<<<<<<
 *     cdef:
 *         IsoformGenerator isoform_generator
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_15isoforms, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isoforms, __pyx_t_2) < 0) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_SequencePosition(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_18__pyx_unpickle_SequencePosition, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_SequencePosition, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_SequencePosition__set_state(<SequencePosition> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SequencePosition__set_state(SequencePosition __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.amino_acid = __pyx_state[0]; __pyx_result.modification = __pyx_state[1]; __pyx_result.position_type = __pyx_state[2]; __pyx_result.terminal = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_20__pyx_unpickle_IsoformGenerator, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_IsoformGenerator, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ModificationRule(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_22__pyx_unpickle_ModificationRule, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ModificationRule, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_ModificationRule__set_state(<ModificationRule> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ModificationRule__set_state(ModificationRule __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.modification = __pyx_state[0]; __pyx_result.targets = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_9pyteomics_7cparser_24__pyx_unpickle_ModificationTarget, NULL, __pyx_n_s_pyteomics_cparser); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ModificationTarge, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyteomics/cparser.pyx":1
 * # cython: embedsignature=True             # <<<<<<<<<<<<<<
 * # cython: profile=False
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_kp_u_length_line_118, __pyx_kp_u_Calculate_the_number_of_amino_ac) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_kp_u_parse_line_211, __pyx_kp_u_Parse_a_sequence_string_written) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_kp_u_amino_acid_composition_line_566, __pyx_kp_u_Calculate_amino_acid_composition) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_2, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x02070000) != 0);
  if (__pyx_t_3) {

    /* "EnumBase":10
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:
 *     from collections import OrderedDict as __Pyx_OrderedDict             # <<<<<<<<<<<<<<
 * else:
 *     __Pyx_OrderedDict = dict
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_OrderedDict);
    __Pyx_GIVEREF(__pyx_n_s_OrderedDict);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_OrderedDict);
    __pyx_t_1 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
    goto __pyx_L2;
  }

  /* "EnumBase":12
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 *     __Pyx_OrderedDict = dict             # <<<<<<<<<<<<<<
 * 
 * @cython.internal
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)(&PyDict_Type)));
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, ((PyObject *)(&PyDict_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyDict_Type)));
  }
  __pyx_L2:;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
  __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)(&PyInt_Type)));
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_1, __pyx_n_s_Pyx_EnumBase, __pyx_n_s_Pyx_EnumBase, (PyObject *) NULL, __pyx_n_s_EnumBase, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "EnumBase":27
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta             # <<<<<<<<<<<<<<
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_metaclass, ((PyObject *)__pyx_ptype___Pyx_EnumMeta)) < 0) __PYX_ERR(1, 27, __pyx_L1_error)

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_Pyx_EnumBase___new, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__21)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__22);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_new, __pyx_t_5) < 0) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__, 0, __pyx_n_s_Pyx_EnumBase___repr, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_repr, __pyx_t_5) < 0) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__, 0, __pyx_n_s_Pyx_EnumBase___str, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_str_2, __pyx_t_5) < 0) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Pyx_EnumBase, __pyx_t_1, __pyx_t_4, NULL, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__Pyx_EnumBase);
  __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_3) {

    /* "EnumBase":45
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 *     from enum import IntEnum as __Pyx_EnumBase             # <<<<<<<<<<<<<<
 * 
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_IntEnum);
    __Pyx_GIVEREF(__pyx_n_s_IntEnum);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_IntEnum);
    __pyx_t_2 = __Pyx_Import(__pyx_n_s_enum, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_IntEnum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XGOTREF(__Pyx_EnumBase);
    __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, NULL, __pyx_n_s_EnumBase); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "EnumType":50
 * 
 * 
 * cdef dict __Pyx_globals = globals()             # <<<<<<<<<<<<<<
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 */
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_XGOTREF(__Pyx_globals);
  __Pyx_DECREF_SET(__Pyx_globals, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     PositionType = __Pyx_EnumBase('PositionType', __Pyx_OrderedDict([
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_3) {

    /* "EnumType":54
 * 
 *     PositionType = __Pyx_EnumBase('PositionType', __Pyx_OrderedDict([
 *         ('n_term', n_term),             # <<<<<<<<<<<<<<
 *         ('c_term', c_term),
 *         ('internal', internal),
 */
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_n_term); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_n_term);
    __Pyx_GIVEREF(__pyx_n_s_n_term);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_n_term);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "EnumType":55
 *     PositionType = __Pyx_EnumBase('PositionType', __Pyx_OrderedDict([
 *         ('n_term', n_term),
 *         ('c_term', c_term),             # <<<<<<<<<<<<<<
 *         ('internal', internal),
 *         ('universal', universal),
 */
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_c_term); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_s_c_term);
    __Pyx_GIVEREF(__pyx_n_s_c_term);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_c_term);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "EnumType":56
 *         ('n_term', n_term),
 *         ('c_term', c_term),
 *         ('internal', internal),             # <<<<<<<<<<<<<<
 *         ('universal', universal),
 *     ]))
 */
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_internal); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_n_s_internal);
    __Pyx_GIVEREF(__pyx_n_s_internal);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_n_s_internal);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "EnumType":57
 *         ('c_term', c_term),
 *         ('internal', internal),
 *         ('universal', universal),             # <<<<<<<<<<<<<<
 *     ]))
 *     __Pyx_globals['n_term'] = PositionType.n_term
 */
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_universal); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_n_s_universal);
    __Pyx_GIVEREF(__pyx_n_s_universal);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_n_s_universal);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "EnumType":53
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 *     PositionType = __Pyx_EnumBase('PositionType', __Pyx_OrderedDict([             # <<<<<<<<<<<<<<
 *         ('n_term', n_term),
 *         ('c_term', c_term),
 */
    __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyList_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_2, 3, __pyx_t_6);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__Pyx_OrderedDict, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PositionType);
    __Pyx_GIVEREF(__pyx_n_s_PositionType);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PositionType);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__Pyx_EnumBase, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_PositionType, __pyx_t_6) < 0) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "EnumType":59
 *         ('universal', universal),
 *     ]))
 *     __Pyx_globals['n_term'] = PositionType.n_term             # <<<<<<<<<<<<<<
 *     __Pyx_globals['c_term'] = PositionType.c_term
 *     __Pyx_globals['internal'] = PositionType.internal
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_n_term); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 59, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_n_term, __pyx_t_2) < 0)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "EnumType":60
 *     ]))
 *     __Pyx_globals['n_term'] = PositionType.n_term
 *     __Pyx_globals['c_term'] = PositionType.c_term             # <<<<<<<<<<<<<<
 *     __Pyx_globals['internal'] = PositionType.internal
 *     __Pyx_globals['universal'] = PositionType.universal
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_c_term); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 60, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_c_term, __pyx_t_6) < 0)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "EnumType":61
 *     __Pyx_globals['n_term'] = PositionType.n_term
 *     __Pyx_globals['c_term'] = PositionType.c_term
 *     __Pyx_globals['internal'] = PositionType.internal             # <<<<<<<<<<<<<<
 *     __Pyx_globals['universal'] = PositionType.universal
 * else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_internal); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 61, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_internal, __pyx_t_2) < 0)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "EnumType":62
 *     __Pyx_globals['c_term'] = PositionType.c_term
 *     __Pyx_globals['internal'] = PositionType.internal
 *     __Pyx_globals['universal'] = PositionType.universal             # <<<<<<<<<<<<<<
 * else:
 *     class PositionType(__Pyx_EnumBase):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_universal); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 62, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_universal, __pyx_t_6) < 0)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     PositionType = __Pyx_EnumBase('PositionType', __Pyx_OrderedDict([
 */
    goto __pyx_L4;
  }

  /* "EnumType":64
 *     __Pyx_globals['universal'] = PositionType.universal
 * else:
 *     class PositionType(__Pyx_EnumBase):             # <<<<<<<<<<<<<<
 *         pass
 *     __Pyx_globals['n_term'] = PositionType(n_term, 'n_term')
 */
  /*else*/ {
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__Pyx_EnumBase);
    __Pyx_GIVEREF(__Pyx_EnumBase);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __Pyx_EnumBase);
    __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_6, __pyx_n_s_PositionType, __pyx_n_s_PositionType, (PyObject *) NULL, __pyx_n_s_EnumType, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_PositionType, __pyx_t_6, __pyx_t_5, NULL, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_PositionType, __pyx_t_4) < 0) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "EnumType":66
 *     class PositionType(__Pyx_EnumBase):
 *         pass
 *     __Pyx_globals['n_term'] = PositionType(n_term, 'n_term')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['c_term'] = PositionType(c_term, 'c_term')
 *     __Pyx_globals['internal'] = PositionType(internal, 'internal')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_n_term); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_n_term);
    __Pyx_GIVEREF(__pyx_n_s_n_term);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_n_s_n_term);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 66, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_n_term, __pyx_t_2) < 0)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "EnumType":67
 *         pass
 *     __Pyx_globals['n_term'] = PositionType(n_term, 'n_term')
 *     __Pyx_globals['c_term'] = PositionType(c_term, 'c_term')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['internal'] = PositionType(internal, 'internal')
 *     __Pyx_globals['universal'] = PositionType(universal, 'universal')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_c_term); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
    __Pyx_INCREF(__pyx_n_s_c_term);
    __Pyx_GIVEREF(__pyx_n_s_c_term);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_c_term);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 67, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_c_term, __pyx_t_5) < 0)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "EnumType":68
 *     __Pyx_globals['n_term'] = PositionType(n_term, 'n_term')
 *     __Pyx_globals['c_term'] = PositionType(c_term, 'c_term')
 *     __Pyx_globals['internal'] = PositionType(internal, 'internal')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['universal'] = PositionType(universal, 'universal')
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_internal); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_n_s_internal);
    __Pyx_GIVEREF(__pyx_n_s_internal);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_internal);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 68, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_internal, __pyx_t_6) < 0)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "EnumType":69
 *     __Pyx_globals['c_term'] = PositionType(c_term, 'c_term')
 *     __Pyx_globals['internal'] = PositionType(internal, 'internal')
 *     __Pyx_globals['universal'] = PositionType(universal, 'universal')             # <<<<<<<<<<<<<<
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_PositionType); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(__pyx_e_9pyteomics_7cparser_universal); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_universal);
    __Pyx_GIVEREF(__pyx_n_s_universal);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_n_s_universal);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 69, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_universal, __pyx_t_2) < 0)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L4:;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init pyteomics.cparser", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pyteomics.cparser");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* bytes_tailmatch */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction) {
    const char* self_ptr = PyBytes_AS_STRING(self);
    Py_ssize_t self_len = PyBytes_GET_SIZE(self);
    const char* sub_ptr;
    Py_ssize_t sub_len;
    int retval;
    Py_buffer view;
    view.obj = NULL;
    if ( PyBytes_Check(arg) ) {
        sub_ptr = PyBytes_AS_STRING(arg);
        sub_len = PyBytes_GET_SIZE(arg);
    }
#if PY_MAJOR_VERSION < 3
    else if ( PyUnicode_Check(arg) ) {
        return (int) PyUnicode_Tailmatch(self, arg, start, end, direction);
    }
#endif
    else {
        if (unlikely(PyObject_GetBuffer(self, &view, PyBUF_SIMPLE) == -1))
            return -1;
        sub_ptr = (const char*) view.buf;
        sub_len = view.len;
    }
    if (end > self_len)
        end = self_len;
    else if (end < 0)
        end += self_len;
    if (end < 0)
        end = 0;
    if (start < 0)
        start += self_len;
    if (start < 0)
        start = 0;
    if (direction > 0) {
        if (end-sub_len > start)
            start = end - sub_len;
    }
    if (start + sub_len <= end)
        retval = !memcmp(self_ptr+start, sub_ptr, (size_t)sub_len);
    else
        retval = 0;
    if (view.obj)
        PyBuffer_Release(&view);
    return retval;
}
static int __Pyx_PyBytes_TailmatchTuple(PyObject* self, PyObject* substrings,
                                        Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = PyTuple_GET_SIZE(substrings);
    for (i = 0; i < count; i++) {
        int result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = __Pyx_PyBytes_SingleTailmatch(self, PyTuple_GET_ITEM(substrings, i),
                                               start, end, direction);
#else
        PyObject* sub = PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = __Pyx_PyBytes_SingleTailmatch(self, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return result;
        }
    }
    return 0;
}
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyBytes_TailmatchTuple(self, substr, start, end, direction);
    }
    return __Pyx_PyBytes_SingleTailmatch(self, substr, start, end, direction);
}

/* unicode_tailmatch */
static int __Pyx_PyUnicode_TailmatchTuple(PyObject* s, PyObject* substrings,
                                          Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = PyTuple_GET_SIZE(substrings);
    for (i = 0; i < count; i++) {
        Py_ssize_t result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = PyUnicode_Tailmatch(s, PyTuple_GET_ITEM(substrings, i),
                                     start, end, direction);
#else
        PyObject* sub = PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = PyUnicode_Tailmatch(s, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return (int) result;
        }
    }
    return 0;
}
static int __Pyx_PyUnicode_Tailmatch(PyObject* s, PyObject* substr,
                                     Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyUnicode_TailmatchTuple(s, substr, start, end, direction);
    }
    return (int) PyUnicode_Tailmatch(s, substr, start, end, direction);
}

/* str_tailmatch */
static CYTHON_INLINE int __Pyx_PyStr_Tailmatch(PyObject* self, PyObject* arg, Py_ssize_t start,
                                               Py_ssize_t end, int direction)
{
    if (PY_MAJOR_VERSION < 3)
        return __Pyx_PyBytes_Tailmatch(self, arg, start, end, direction);
    else
        return __Pyx_PyUnicode_Tailmatch(self, arg, start, end, direction);
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_n_s_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyInt_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = Py_TYPE(iter)->tp_iternext;
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* MergeKeywords */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_items */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_items, d);
    else
        return PyDict_Items(d);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYSTON || CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (methoddescr_type == NULL) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (!meth) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* GetNameInClass */
static PyObject *__Pyx_GetGlobalNameAfterAttributeLookup(PyObject *name) {
    PyObject *result;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result) {
        result = __Pyx_GetGlobalNameAfterAttributeLookup(name);
    }
    return result;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names;
    PyObject *globals = __pyx_d;
    Py_INCREF(globals);
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_ITEM(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = __Pyx_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_9pyteomics_7cparser_PositionType(enum __pyx_t_9pyteomics_7cparser_PositionType value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum __pyx_t_9pyteomics_7cparser_PositionType neg_one = (enum __pyx_t_9pyteomics_7cparser_PositionType) -1, const_zero = (enum __pyx_t_9pyteomics_7cparser_PositionType) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE enum __pyx_t_9pyteomics_7cparser_PositionType __Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum __pyx_t_9pyteomics_7cparser_PositionType neg_one = (enum __pyx_t_9pyteomics_7cparser_PositionType) -1, const_zero = (enum __pyx_t_9pyteomics_7cparser_PositionType) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (enum __pyx_t_9pyteomics_7cparser_PositionType) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (enum __pyx_t_9pyteomics_7cparser_PositionType) 0;
                case  1: __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, digit, digits[0])
                case 2:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) >= 2 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) >= 3 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) >= 4 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[3]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (enum __pyx_t_9pyteomics_7cparser_PositionType) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (enum __pyx_t_9pyteomics_7cparser_PositionType) 0;
                case -1: __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 2 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((enum __pyx_t_9pyteomics_7cparser_PositionType)-1)*(((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 2 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) ((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 3 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((enum __pyx_t_9pyteomics_7cparser_PositionType)-1)*(((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 3 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) ((((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 4 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) (((enum __pyx_t_9pyteomics_7cparser_PositionType)-1)*(((((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[3]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(enum __pyx_t_9pyteomics_7cparser_PositionType, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) - 1 > 4 * PyLong_SHIFT) {
                            return (enum __pyx_t_9pyteomics_7cparser_PositionType) ((((((((((enum __pyx_t_9pyteomics_7cparser_PositionType)digits[3]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[2]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[1]) << PyLong_SHIFT) | (enum __pyx_t_9pyteomics_7cparser_PositionType)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(enum __pyx_t_9pyteomics_7cparser_PositionType, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(enum __pyx_t_9pyteomics_7cparser_PositionType) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(enum __pyx_t_9pyteomics_7cparser_PositionType, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            enum __pyx_t_9pyteomics_7cparser_PositionType val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (enum __pyx_t_9pyteomics_7cparser_PositionType) -1;
        }
    } else {
        enum __pyx_t_9pyteomics_7cparser_PositionType val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (enum __pyx_t_9pyteomics_7cparser_PositionType) -1;
        val = __Pyx_PyInt_As_enum____pyx_t_9pyteomics_7cparser_PositionType(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to enum __pyx_t_9pyteomics_7cparser_PositionType");
    return (enum __pyx_t_9pyteomics_7cparser_PositionType) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to enum __pyx_t_9pyteomics_7cparser_PositionType");
    return (enum __pyx_t_9pyteomics_7cparser_PositionType) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* CoroutineBase */
#include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
            _PyGen_SetStopIterationValue(result);
        }
        Py_CLEAR(result);
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* FunctionExport */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
